FwStandardSqlServerAttributesFwExcelOptions enum

Inheritance
  • Object
  • Enum
  • FwStandardSqlServerAttributesFwExcelOptions
Available extensions

Values

swaggerGeneratedUnknown → const FwStandardSqlServerAttributesFwExcelOptions
const FwStandardSqlServerAttributesFwExcelOptions(null)
required → const FwStandardSqlServerAttributesFwExcelOptions
const FwStandardSqlServerAttributesFwExcelOptions('Required')
const FwStandardSqlServerAttributesFwExcelOptions('Recommended')
optional → const FwStandardSqlServerAttributesFwExcelOptions
const FwStandardSqlServerAttributesFwExcelOptions('Optional')
omit → const FwStandardSqlServerAttributesFwExcelOptions
const FwStandardSqlServerAttributesFwExcelOptions('Omit')
none → const FwStandardSqlServerAttributesFwExcelOptions
const FwStandardSqlServerAttributesFwExcelOptions('None')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FwStandardSqlServerAttributesFwExcelOptions>
A constant List of the values in this enum, in order of their declaration.