AccountServices class abstract

Annotations
  • @ChopperApi.new()

Constructors

AccountServices()

Properties

client ↔ ChopperClient
getter/setter pairinherited
definitionType Type
Used internally to retrieve the service from ChopperClient.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accountForgotpasswordPost({required WebApiModulesAccountServicesAccountForgotPasswordRequest? body}) Future<Response<WebApiModulesAccountServicesAccountForgotPasswordResponse>>
accountGetsettingsPost({required WebApiModulesAccountServicesAccountGetSettingsRequest? body}) Future<Response<WebApiLogicAppFuncGetSettingsResponse>>
accountOfficelocationGet({String? locationid, String? warehouseid, String? departmentid}) Future<Response<WebApiModulesAccountServicesAccountAccountControllerGetOfficeLocationResponse>>
@param locationid @param warehouseid @param departmentid
accountResetpasswordexternalPost({required WebApiModulesAccountServicesAccountResetPasswordExternalRequest? body}) Future<Response<WebApiModulesAccountServicesAccountResetPasswordExternalResponse>>
accountResetpasswordPost({required WebApiModulesAccountServicesAccountResetPasswordRequest? body}) Future<Response<WebApiModulesAccountServicesAccountResetPasswordResponse>>
accountSessionGet({String? applicationId}) Future<Response<WebApiModulesAccountServicesAccountAccountControllerGetSessionResponse>>
@param applicationId
jwtAzureadPost({required WebApiModulesAccountServicesJwtAzureADRequest? body}) Future<Response<FwCoreControllersFwJwtControllerJwtResponseModel>>
jwtOktaPost({required WebApiModulesAccountServicesJwtOktaRequest? body}) Future<Response<FwCoreControllersFwJwtControllerJwtResponseModel>>
jwtPost({required FwStandardModelsFwApplicationUser? body}) Future<Response<FwCoreControllersFwJwtControllerJwtResponseModel>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
taskschedulerTaskstepsBrowsePost({required FwStandardModelsBrowseRequest? body}) Future<Response<FwStandardSqlServerFwJsonDataTable>>
taskschedulerTaskstepsExportexcelxlsxPost({required FwStandardModelsBrowseRequest? body}) Future<Response<FwCoreControllersFwDataControllerDoExportExcelXlsxExportFileAsyncResult>>
taskschedulerTaskstepsGet({int? pageno, int? pagesize, String? sort, List<FwStandardModelsFwQueryFilter>? filter}) Future<Response<FwStandardModelsFwQueryResponseWebApiModulesAdministratorTaskSchedulerTaskStepsLogic>>
@param pageno @param pagesize @param sort @param filter
taskschedulerTaskstepsIdDelete({required String? id}) Future<Response<bool>>
@param id
taskschedulerTaskstepsIdGet({required String? id}) Future<Response<WebApiModulesAdministratorTaskSchedulerTaskSteps>>
@param id
taskschedulerTaskstepsIdPut({required String? id, required WebApiModulesAdministratorTaskSchedulerTaskSteps? body}) Future<Response<WebApiModulesAdministratorTaskSchedulerTaskSteps>>
@param id
taskschedulerTaskstepsPost({required WebApiModulesAdministratorTaskSchedulerTaskSteps? body}) Future<Response<WebApiModulesAdministratorTaskSchedulerTaskSteps>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({ChopperClient? client, Client? httpClient, Authenticator? authenticator, ErrorConverter? errorConverter, Converter? converter, Uri? baseUrl, List<Interceptor>? interceptors}) AccountServices