WebApiLogicAppFuncDefaultSettingsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiLogicAppFuncDefaultSettingsResponse({String? defaultUnitId, String? defaultUnit, String? defaultDealStatusId, String? defaultDealStatus, bool? defaultDealPoRequired, String? defaultDealPoType, bool? defaultDealStagingExcludeOrderAfterWrap, String? defaultCustomerStatusId, String? defaultCustomerStatus, String? defaultCustomerPaymentTypeId, String? defaultCustomerPaymentType, String? defaultDealBillingCycleId, String? defaultDealBillingCycle, String? defaultVendorPaymentTermsId, String? defaultVendorPaymentTerms, String? defaultVendorOutgoingDeliveryType, String? defaultVendorIncomingDeliveryType, bool? defaultVendorRentalInventory, bool? defaultVendorSalesPartsInventory, bool? defaultVendorRepair, bool? defaultVendorManufacturer, bool? defaultVendorFreight, bool? defaultVendorInsurance, bool? defaultVendorSubRent, bool? defaultVendorSubSales, bool? defaultVendorSubMisc, bool? defaultVendorSubLabor, bool? defaultVendorSubVehicle, bool? defaultVendorConsignment, String? defaultNonRecurringBillingCycleId, String? defaultNonRecurringBillingCycle, String? defaultVendorBillingCycleId, String? defaultVendorBillingCycle, String? defaultVendorPaymentTypeId, String? defaultVendorPaymentType, String? defaultCustomerPaymentTermsId, String? defaultCustomerPaymentTerms, String? defaultRank, String? defaultCreditStatusId, String? defaultCreditStatus, bool? contactShowAllDeals, bool? defaultFulfillStrictPricingMatch, bool? defaultFulfillStrictNestingLvlMatch})
const
WebApiLogicAppFuncDefaultSettingsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

contactShowAllDeals bool?
final
defaultCreditStatus String?
final
defaultCreditStatusId String?
final
defaultCustomerPaymentTerms String?
final
defaultCustomerPaymentTermsId String?
final
defaultCustomerPaymentType String?
final
defaultCustomerPaymentTypeId String?
final
defaultCustomerStatus String?
final
defaultCustomerStatusId String?
final
defaultDealBillingCycle String?
final
defaultDealBillingCycleId String?
final
defaultDealPoRequired bool?
final
defaultDealPoType String?
final
defaultDealStagingExcludeOrderAfterWrap bool?
final
defaultDealStatus String?
final
defaultDealStatusId String?
final
defaultFulfillStrictNestingLvlMatch bool?
final
defaultFulfillStrictPricingMatch bool?
final
defaultNonRecurringBillingCycle String?
final
defaultNonRecurringBillingCycleId String?
final
defaultRank String?
final
defaultUnit String?
final
defaultUnitId String?
final
defaultVendorBillingCycle String?
final
defaultVendorBillingCycleId String?
final
defaultVendorConsignment bool?
final
defaultVendorFreight bool?
final
defaultVendorIncomingDeliveryType String?
final
defaultVendorInsurance bool?
final
defaultVendorManufacturer bool?
final
defaultVendorOutgoingDeliveryType String?
final
defaultVendorPaymentTerms String?
final
defaultVendorPaymentTermsId String?
final
defaultVendorPaymentType String?
final
defaultVendorPaymentTypeId String?
final
defaultVendorRentalInventory bool?
final
defaultVendorRepair bool?
final
defaultVendorSalesPartsInventory bool?
final
defaultVendorSubLabor bool?
final
defaultVendorSubMisc bool?
final
defaultVendorSubRent bool?
final
defaultVendorSubSales bool?
final
defaultVendorSubVehicle bool?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? defaultUnitId, String? defaultUnit, String? defaultDealStatusId, String? defaultDealStatus, bool? defaultDealPoRequired, String? defaultDealPoType, bool? defaultDealStagingExcludeOrderAfterWrap, String? defaultCustomerStatusId, String? defaultCustomerStatus, String? defaultCustomerPaymentTypeId, String? defaultCustomerPaymentType, String? defaultDealBillingCycleId, String? defaultDealBillingCycle, String? defaultVendorPaymentTermsId, String? defaultVendorPaymentTerms, String? defaultVendorOutgoingDeliveryType, String? defaultVendorIncomingDeliveryType, bool? defaultVendorRentalInventory, bool? defaultVendorSalesPartsInventory, bool? defaultVendorRepair, bool? defaultVendorManufacturer, bool? defaultVendorFreight, bool? defaultVendorInsurance, bool? defaultVendorSubRent, bool? defaultVendorSubSales, bool? defaultVendorSubMisc, bool? defaultVendorSubLabor, bool? defaultVendorSubVehicle, bool? defaultVendorConsignment, String? defaultNonRecurringBillingCycleId, String? defaultNonRecurringBillingCycle, String? defaultVendorBillingCycleId, String? defaultVendorBillingCycle, String? defaultVendorPaymentTypeId, String? defaultVendorPaymentType, String? defaultCustomerPaymentTermsId, String? defaultCustomerPaymentTerms, String? defaultRank, String? defaultCreditStatusId, String? defaultCreditStatus, bool? contactShowAllDeals, bool? defaultFulfillStrictPricingMatch, bool? defaultFulfillStrictNestingLvlMatch}) WebApiLogicAppFuncDefaultSettingsResponse

Available on WebApiLogicAppFuncDefaultSettingsResponse, provided by the $WebApiLogicAppFuncDefaultSettingsResponseExtension extension

copyWithWrapped({Wrapped<String?>? defaultUnitId, Wrapped<String?>? defaultUnit, Wrapped<String?>? defaultDealStatusId, Wrapped<String?>? defaultDealStatus, Wrapped<bool?>? defaultDealPoRequired, Wrapped<String?>? defaultDealPoType, Wrapped<bool?>? defaultDealStagingExcludeOrderAfterWrap, Wrapped<String?>? defaultCustomerStatusId, Wrapped<String?>? defaultCustomerStatus, Wrapped<String?>? defaultCustomerPaymentTypeId, Wrapped<String?>? defaultCustomerPaymentType, Wrapped<String?>? defaultDealBillingCycleId, Wrapped<String?>? defaultDealBillingCycle, Wrapped<String?>? defaultVendorPaymentTermsId, Wrapped<String?>? defaultVendorPaymentTerms, Wrapped<String?>? defaultVendorOutgoingDeliveryType, Wrapped<String?>? defaultVendorIncomingDeliveryType, Wrapped<bool?>? defaultVendorRentalInventory, Wrapped<bool?>? defaultVendorSalesPartsInventory, Wrapped<bool?>? defaultVendorRepair, Wrapped<bool?>? defaultVendorManufacturer, Wrapped<bool?>? defaultVendorFreight, Wrapped<bool?>? defaultVendorInsurance, Wrapped<bool?>? defaultVendorSubRent, Wrapped<bool?>? defaultVendorSubSales, Wrapped<bool?>? defaultVendorSubMisc, Wrapped<bool?>? defaultVendorSubLabor, Wrapped<bool?>? defaultVendorSubVehicle, Wrapped<bool?>? defaultVendorConsignment, Wrapped<String?>? defaultNonRecurringBillingCycleId, Wrapped<String?>? defaultNonRecurringBillingCycle, Wrapped<String?>? defaultVendorBillingCycleId, Wrapped<String?>? defaultVendorBillingCycle, Wrapped<String?>? defaultVendorPaymentTypeId, Wrapped<String?>? defaultVendorPaymentType, Wrapped<String?>? defaultCustomerPaymentTermsId, Wrapped<String?>? defaultCustomerPaymentTerms, Wrapped<String?>? defaultRank, Wrapped<String?>? defaultCreditStatusId, Wrapped<String?>? defaultCreditStatus, Wrapped<bool?>? contactShowAllDeals, Wrapped<bool?>? defaultFulfillStrictPricingMatch, Wrapped<bool?>? defaultFulfillStrictNestingLvlMatch}) WebApiLogicAppFuncDefaultSettingsResponse

Available on WebApiLogicAppFuncDefaultSettingsResponse, provided by the $WebApiLogicAppFuncDefaultSettingsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiLogicAppFuncDefaultSettingsResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiLogicAppFuncDefaultSettingsResponse instance)