WebApiLogicAppFuncInventorySettingsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiLogicAppFuncInventorySettingsResponse({String? iCodeMask, bool? padICodeWithZeros, bool? userAssignedICodes, bool? enable3WeekPricing, bool? enableTieredWeekPricing, String? tier1Name, String? tier2Name, String? tier3Name, String? tier4Name, String? tier5Name, bool? autoUpdateInventoryMetricImperialDimensions, bool? convertDimensionsToSmallestUnit, bool? autoSortInventoryByICode, bool? enableConsignment, bool? enableLease, String? defaultRentalSaleRetiredReasonId, String? defaultRentalSaleRetiredReason, String? defaultLossAndDamageRetiredReasonId, String? defaultLossAndDamageRetiredReason, String? defaultRentalQuantityInventoryCostCalculation, String? defaultSalesQuantityInventoryCostCalculation, String? defaultPartsQuantityInventoryCostCalculation, bool? fixedAssetTransferOwnership, bool? enableInventoryCertification, bool? trackItemsInRooms})
-
const
-
WebApiLogicAppFuncInventorySettingsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- autoSortInventoryByICode → bool?
-
final
- autoUpdateInventoryMetricImperialDimensions → bool?
-
final
- convertDimensionsToSmallestUnit → bool?
-
final
- defaultLossAndDamageRetiredReason → String?
-
final
- defaultLossAndDamageRetiredReasonId → String?
-
final
- defaultPartsQuantityInventoryCostCalculation → String?
-
final
- defaultRentalQuantityInventoryCostCalculation → String?
-
final
- defaultRentalSaleRetiredReason → String?
-
final
- defaultRentalSaleRetiredReasonId → String?
-
final
- defaultSalesQuantityInventoryCostCalculation → String?
-
final
- enable3WeekPricing → bool?
-
final
- enableConsignment → bool?
-
final
- enableInventoryCertification → bool?
-
final
- enableLease → bool?
-
final
- enableTieredWeekPricing → bool?
-
final
- fixedAssetTransferOwnership → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCodeMask → String?
-
final
- padICodeWithZeros → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tier1Name → String?
-
final
- tier2Name → String?
-
final
- tier3Name → String?
-
final
- tier4Name → String?
-
final
- tier5Name → String?
-
final
- trackItemsInRooms → bool?
-
final
- userAssignedICodes → bool?
-
final
Methods
-
copyWith(
{String? iCodeMask, bool? padICodeWithZeros, bool? userAssignedICodes, bool? enable3WeekPricing, bool? enableTieredWeekPricing, String? tier1Name, String? tier2Name, String? tier3Name, String? tier4Name, String? tier5Name, bool? autoUpdateInventoryMetricImperialDimensions, bool? convertDimensionsToSmallestUnit, bool? autoSortInventoryByICode, bool? enableConsignment, bool? enableLease, String? defaultRentalSaleRetiredReasonId, String? defaultRentalSaleRetiredReason, String? defaultLossAndDamageRetiredReasonId, String? defaultLossAndDamageRetiredReason, String? defaultRentalQuantityInventoryCostCalculation, String? defaultSalesQuantityInventoryCostCalculation, String? defaultPartsQuantityInventoryCostCalculation, bool? fixedAssetTransferOwnership, bool? enableInventoryCertification, bool? trackItemsInRooms}) → WebApiLogicAppFuncInventorySettingsResponse -
Available on WebApiLogicAppFuncInventorySettingsResponse, provided by the $WebApiLogicAppFuncInventorySettingsResponseExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? iCodeMask, Wrapped<bool?> ? padICodeWithZeros, Wrapped<bool?> ? userAssignedICodes, Wrapped<bool?> ? enable3WeekPricing, Wrapped<bool?> ? enableTieredWeekPricing, Wrapped<String?> ? tier1Name, Wrapped<String?> ? tier2Name, Wrapped<String?> ? tier3Name, Wrapped<String?> ? tier4Name, Wrapped<String?> ? tier5Name, Wrapped<bool?> ? autoUpdateInventoryMetricImperialDimensions, Wrapped<bool?> ? convertDimensionsToSmallestUnit, Wrapped<bool?> ? autoSortInventoryByICode, Wrapped<bool?> ? enableConsignment, Wrapped<bool?> ? enableLease, Wrapped<String?> ? defaultRentalSaleRetiredReasonId, Wrapped<String?> ? defaultRentalSaleRetiredReason, Wrapped<String?> ? defaultLossAndDamageRetiredReasonId, Wrapped<String?> ? defaultLossAndDamageRetiredReason, Wrapped<String?> ? defaultRentalQuantityInventoryCostCalculation, Wrapped<String?> ? defaultSalesQuantityInventoryCostCalculation, Wrapped<String?> ? defaultPartsQuantityInventoryCostCalculation, Wrapped<bool?> ? fixedAssetTransferOwnership, Wrapped<bool?> ? enableInventoryCertification, Wrapped<bool?> ? trackItemsInRooms}) → WebApiLogicAppFuncInventorySettingsResponse -
Available on WebApiLogicAppFuncInventorySettingsResponse, provided by the $WebApiLogicAppFuncInventorySettingsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiLogicAppFuncInventorySettingsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiLogicAppFuncInventorySettingsResponse instance)