WebApiLogicAppFuncSessionLocation class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiLogicAppFuncSessionLocation({String? locationid, String? location, String? locationcode, String? companyname, String? locationcolor, String? ratetype, String? ratetypedisplay, String? defaultcurrency, String? defaultcurrencyid, String? defaultcurrencycode, String? defaultcurrencysymbol, String? defaultpaymentby, String? defaulttaxoptionid, String? defaulttaxoption, String? countryid, String? country, String? countrycodeisoalpha2, String? phone, bool? useorderlocationbydefault, String? defaultrepairpotypeid, String? defaultrepairpotype, bool? emailinvoicetoorderedby, bool? emailinvoicetoaccountspayable, String? defaultpurchasepotypeid, String? defaultpurchasepotype, String? defaultsubrentalpoordertypeid, String? defaultsubrentalpoordertype, String? defaultsubsalespoordertypeid, String? defaultsubsalespoordertype, String? defaultsubmiscpoordertypeid, String? defaultsubmiscpoordertype, String? defaultsublaborpoordertypeid, String? defaultsublaborpoordertype, String? defaultcombinedpoordertypeid, String? defaultcombinedpoordertype, String? defaultdealoutdeliverytype, String? defaultdealindeliverytype})
const
WebApiLogicAppFuncSessionLocation.fromJson(Map<String, dynamic> json)
factory

Properties

companyname String?
final
country String?
final
countrycodeisoalpha2 String?
final
countryid String?
final
defaultcombinedpoordertype String?
final
defaultcombinedpoordertypeid String?
final
defaultcurrency String?
final
defaultcurrencycode String?
final
defaultcurrencyid String?
final
defaultcurrencysymbol String?
final
defaultdealindeliverytype String?
final
defaultdealoutdeliverytype String?
final
defaultpaymentby String?
final
defaultpurchasepotype String?
final
defaultpurchasepotypeid String?
final
defaultrepairpotype String?
final
defaultrepairpotypeid String?
final
defaultsublaborpoordertype String?
final
defaultsublaborpoordertypeid String?
final
defaultsubmiscpoordertype String?
final
defaultsubmiscpoordertypeid String?
final
defaultsubrentalpoordertype String?
final
defaultsubrentalpoordertypeid String?
final
defaultsubsalespoordertype String?
final
defaultsubsalespoordertypeid String?
final
defaulttaxoption String?
final
defaulttaxoptionid String?
final
emailinvoicetoaccountspayable bool?
final
emailinvoicetoorderedby bool?
final
hashCode int
The hash code for this object.
no setteroverride
location String?
final
locationcode String?
final
locationcolor String?
final
locationid String?
final
phone String?
final
ratetype String?
final
ratetypedisplay String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useorderlocationbydefault bool?
final

Methods

copyWith({String? locationid, String? location, String? locationcode, String? companyname, String? locationcolor, String? ratetype, String? ratetypedisplay, String? defaultcurrency, String? defaultcurrencyid, String? defaultcurrencycode, String? defaultcurrencysymbol, String? defaultpaymentby, String? defaulttaxoptionid, String? defaulttaxoption, String? countryid, String? country, String? countrycodeisoalpha2, String? phone, bool? useorderlocationbydefault, String? defaultrepairpotypeid, String? defaultrepairpotype, bool? emailinvoicetoorderedby, bool? emailinvoicetoaccountspayable, String? defaultpurchasepotypeid, String? defaultpurchasepotype, String? defaultsubrentalpoordertypeid, String? defaultsubrentalpoordertype, String? defaultsubsalespoordertypeid, String? defaultsubsalespoordertype, String? defaultsubmiscpoordertypeid, String? defaultsubmiscpoordertype, String? defaultsublaborpoordertypeid, String? defaultsublaborpoordertype, String? defaultcombinedpoordertypeid, String? defaultcombinedpoordertype, String? defaultdealoutdeliverytype, String? defaultdealindeliverytype}) WebApiLogicAppFuncSessionLocation

Available on WebApiLogicAppFuncSessionLocation, provided by the $WebApiLogicAppFuncSessionLocationExtension extension

copyWithWrapped({Wrapped<String?>? locationid, Wrapped<String?>? location, Wrapped<String?>? locationcode, Wrapped<String?>? companyname, Wrapped<String?>? locationcolor, Wrapped<String?>? ratetype, Wrapped<String?>? ratetypedisplay, Wrapped<String?>? defaultcurrency, Wrapped<String?>? defaultcurrencyid, Wrapped<String?>? defaultcurrencycode, Wrapped<String?>? defaultcurrencysymbol, Wrapped<String?>? defaultpaymentby, Wrapped<String?>? defaulttaxoptionid, Wrapped<String?>? defaulttaxoption, Wrapped<String?>? countryid, Wrapped<String?>? country, Wrapped<String?>? countrycodeisoalpha2, Wrapped<String?>? phone, Wrapped<bool?>? useorderlocationbydefault, Wrapped<String?>? defaultrepairpotypeid, Wrapped<String?>? defaultrepairpotype, Wrapped<bool?>? emailinvoicetoorderedby, Wrapped<bool?>? emailinvoicetoaccountspayable, Wrapped<String?>? defaultpurchasepotypeid, Wrapped<String?>? defaultpurchasepotype, Wrapped<String?>? defaultsubrentalpoordertypeid, Wrapped<String?>? defaultsubrentalpoordertype, Wrapped<String?>? defaultsubsalespoordertypeid, Wrapped<String?>? defaultsubsalespoordertype, Wrapped<String?>? defaultsubmiscpoordertypeid, Wrapped<String?>? defaultsubmiscpoordertype, Wrapped<String?>? defaultsublaborpoordertypeid, Wrapped<String?>? defaultsublaborpoordertype, Wrapped<String?>? defaultcombinedpoordertypeid, Wrapped<String?>? defaultcombinedpoordertype, Wrapped<String?>? defaultdealoutdeliverytype, Wrapped<String?>? defaultdealindeliverytype}) WebApiLogicAppFuncSessionLocation

Available on WebApiLogicAppFuncSessionLocation, provided by the $WebApiLogicAppFuncSessionLocationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiLogicAppFuncSessionLocation Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiLogicAppFuncSessionLocation instance)