WebApiLogicAppFuncSessionWarehouse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiLogicAppFuncSessionWarehouse({String? warehouseid, String? warehouse, String? warehousecode, bool? promptforcheckoutexceptions, bool? promptforcheckinexceptions, bool? storagecontainerstagingenable, bool? storagecontainerrescanrequired, bool? quikreceiptenable, int? transferavailabilitydays})
-
WebApiLogicAppFuncSessionWarehouse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- promptforcheckinexceptions → bool?
-
final
- promptforcheckoutexceptions → bool?
-
final
- quikreceiptenable → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storagecontainerrescanrequired → bool?
-
final
- storagecontainerstagingenable → bool?
-
final
- transferavailabilitydays → int?
-
final
- warehouse → String?
-
final
- warehousecode → String?
-
final
- warehouseid → String?
-
final
Methods
-
copyWith(
{String? warehouseid, String? warehouse, String? warehousecode, bool? promptforcheckoutexceptions, bool? promptforcheckinexceptions, bool? storagecontainerstagingenable, bool? storagecontainerrescanrequired, bool? quikreceiptenable, int? transferavailabilitydays}) → WebApiLogicAppFuncSessionWarehouse -
Available on WebApiLogicAppFuncSessionWarehouse, provided by the $WebApiLogicAppFuncSessionWarehouseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiLogicAppFuncSessionWarehouse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiLogicAppFuncSessionWarehouse instance)