WebApiLogicAppFuncSystemNumbersResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemNumbers List<WebApiLogicAppFuncSystemNumbersModel>?
final

Methods

copyWith({List<WebApiLogicAppFuncSystemNumbersModel>? systemNumbers}) WebApiLogicAppFuncSystemNumbersResponse

Available on WebApiLogicAppFuncSystemNumbersResponse, provided by the $WebApiLogicAppFuncSystemNumbersResponseExtension extension

copyWithWrapped({Wrapped<List<WebApiLogicAppFuncSystemNumbersModel>?>? systemNumbers}) WebApiLogicAppFuncSystemNumbersResponse

Available on WebApiLogicAppFuncSystemNumbersResponse, provided by the $WebApiLogicAppFuncSystemNumbersResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiLogicAppFuncSystemNumbersResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiLogicAppFuncSystemNumbersResponse instance)