WebApiLogicAppFuncSystemSettingsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiLogicAppFuncSystemSettingsResponse({bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? enableReceipts, bool? enableOriginalShow, bool? enablePayments, bool? enableVendorInvoice, bool? enablePropsWardrobe, bool? enableSetsWalls, bool? shareDealsAcrossOfficeLocations, bool? synchronizeCustomerStatusAndCreditStatus, bool? synchronizeDealStatusAndCreditStatus, String? systemName, String? companyName, bool? isVendorNumberAssignedByUser, String? quoteOrderMessageFormat, String? dataLanguageId, String? dataLanguage, bool? allCaps, bool? enableQuikLocate, bool? departmentFilter, bool? defaultBillingSelectAllOrders, bool? defaultProcessConsignmentSelectAllInvoices, bool? enableCrew, bool? disableHelpIcon, bool? consolidateOwnedAndSubbedLineItems, bool? setSubQuantityToZero, bool? promptUserOnPasteLineItems, String? overrideHelpURL, String? defaultSalesRepresentativeFilter})
const
WebApiLogicAppFuncSystemSettingsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

allCaps bool?
final
allowDeleteInvoices bool?
final
allowInvoiceDateChange bool?
final
companyName String?
final
consolidateOwnedAndSubbedLineItems bool?
final
dataLanguage String?
final
dataLanguageId String?
final
defaultBillingSelectAllOrders bool?
final
defaultProcessConsignmentSelectAllInvoices bool?
final
defaultSalesRepresentativeFilter String?
final
departmentFilter bool?
final
disableHelpIcon bool?
final
enableCrew bool?
final
enableOriginalShow bool?
final
enablePayments bool?
final
enablePropsWardrobe bool?
final
enableQuikLocate bool?
final
enableReceipts bool?
final
enableSetsWalls bool?
final
enableVendorInvoice bool?
final
hashCode int
The hash code for this object.
no setteroverride
isVendorNumberAssignedByUser bool?
final
overrideHelpURL String?
final
promptUserOnPasteLineItems bool?
final
quoteOrderMessageFormat String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setSubQuantityToZero bool?
final
shareDealsAcrossOfficeLocations bool?
final
synchronizeCustomerStatusAndCreditStatus bool?
final
synchronizeDealStatusAndCreditStatus bool?
final
systemName String?
final

Methods

copyWith({bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? enableReceipts, bool? enableOriginalShow, bool? enablePayments, bool? enableVendorInvoice, bool? enablePropsWardrobe, bool? enableSetsWalls, bool? shareDealsAcrossOfficeLocations, bool? synchronizeCustomerStatusAndCreditStatus, bool? synchronizeDealStatusAndCreditStatus, String? systemName, String? companyName, bool? isVendorNumberAssignedByUser, String? quoteOrderMessageFormat, String? dataLanguageId, String? dataLanguage, bool? allCaps, bool? enableQuikLocate, bool? departmentFilter, bool? defaultBillingSelectAllOrders, bool? defaultProcessConsignmentSelectAllInvoices, bool? enableCrew, bool? disableHelpIcon, bool? consolidateOwnedAndSubbedLineItems, bool? setSubQuantityToZero, bool? promptUserOnPasteLineItems, String? overrideHelpURL, String? defaultSalesRepresentativeFilter}) WebApiLogicAppFuncSystemSettingsResponse

Available on WebApiLogicAppFuncSystemSettingsResponse, provided by the $WebApiLogicAppFuncSystemSettingsResponseExtension extension

copyWithWrapped({Wrapped<bool?>? allowDeleteInvoices, Wrapped<bool?>? allowInvoiceDateChange, Wrapped<bool?>? enableReceipts, Wrapped<bool?>? enableOriginalShow, Wrapped<bool?>? enablePayments, Wrapped<bool?>? enableVendorInvoice, Wrapped<bool?>? enablePropsWardrobe, Wrapped<bool?>? enableSetsWalls, Wrapped<bool?>? shareDealsAcrossOfficeLocations, Wrapped<bool?>? synchronizeCustomerStatusAndCreditStatus, Wrapped<bool?>? synchronizeDealStatusAndCreditStatus, Wrapped<String?>? systemName, Wrapped<String?>? companyName, Wrapped<bool?>? isVendorNumberAssignedByUser, Wrapped<String?>? quoteOrderMessageFormat, Wrapped<String?>? dataLanguageId, Wrapped<String?>? dataLanguage, Wrapped<bool?>? allCaps, Wrapped<bool?>? enableQuikLocate, Wrapped<bool?>? departmentFilter, Wrapped<bool?>? defaultBillingSelectAllOrders, Wrapped<bool?>? defaultProcessConsignmentSelectAllInvoices, Wrapped<bool?>? enableCrew, Wrapped<bool?>? disableHelpIcon, Wrapped<bool?>? consolidateOwnedAndSubbedLineItems, Wrapped<bool?>? setSubQuantityToZero, Wrapped<bool?>? promptUserOnPasteLineItems, Wrapped<String?>? overrideHelpURL, Wrapped<String?>? defaultSalesRepresentativeFilter}) WebApiLogicAppFuncSystemSettingsResponse

Available on WebApiLogicAppFuncSystemSettingsResponse, provided by the $WebApiLogicAppFuncSystemSettingsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiLogicAppFuncSystemSettingsResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiLogicAppFuncSystemSettingsResponse instance)