WebApiLogicAppFuncUserSettingsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiLogicAppFuncUserSettingsResponse({int? soundProfileId, bool? webAdministrator, String? homeMenuGuid, String? homeMenuPath, bool? showUnreservedQuotes, bool? mainMenuPinned, String? quikActivitySetting, String? favoritesJson, String? emailSignature, String? availabilityPreference, bool? availabilityAllWarehouses, String? quikSearchMode, bool? showRentalItemsOutOnly, bool? autoPrintContract})
-
const
-
WebApiLogicAppFuncUserSettingsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- autoPrintContract → bool?
-
final
- availabilityAllWarehouses → bool?
-
final
- availabilityPreference → String?
-
final
- emailSignature → String?
-
final
- favoritesJson → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- homeMenuGuid → String?
-
final
- homeMenuPath → String?
-
final
- mainMenuPinned → bool?
-
final
- quikActivitySetting → String?
-
final
- quikSearchMode → String?
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- showRentalItemsOutOnly → bool?
-
final
- showUnreservedQuotes → bool?
-
final
- soundProfileId → int?
-
final
- webAdministrator → bool?
-
final
Methods
-
copyWith(
{int? soundProfileId, bool? webAdministrator, String? homeMenuGuid, String? homeMenuPath, bool? showUnreservedQuotes, bool? mainMenuPinned, String? quikActivitySetting, String? favoritesJson, String? emailSignature, String? availabilityPreference, bool? availabilityAllWarehouses, String? quikSearchMode, bool? showRentalItemsOutOnly, bool? autoPrintContract}) → WebApiLogicAppFuncUserSettingsResponse -
Available on WebApiLogicAppFuncUserSettingsResponse, provided by the $WebApiLogicAppFuncUserSettingsResponseExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? soundProfileId, Wrapped<bool?> ? webAdministrator, Wrapped<String?> ? homeMenuGuid, Wrapped<String?> ? homeMenuPath, Wrapped<bool?> ? showUnreservedQuotes, Wrapped<bool?> ? mainMenuPinned, Wrapped<String?> ? quikActivitySetting, Wrapped<String?> ? favoritesJson, Wrapped<String?> ? emailSignature, Wrapped<String?> ? availabilityPreference, Wrapped<bool?> ? availabilityAllWarehouses, Wrapped<String?> ? quikSearchMode, Wrapped<bool?> ? showRentalItemsOutOnly, Wrapped<bool?> ? autoPrintContract}) → WebApiLogicAppFuncUserSettingsResponse -
Available on WebApiLogicAppFuncUserSettingsResponse, provided by the $WebApiLogicAppFuncUserSettingsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiLogicAppFuncUserSettingsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiLogicAppFuncUserSettingsResponse instance)