WebApiModulesAccountServicesAccountAccountControllerGetSessionResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

applicationOptions → dynamic
final
applicationtree FwStandardAppManagerFwAmSecurityTreeNode?
final
clientcode String?
final
deal WebApiLogicAppFuncSessionDeal?
final
department WebApiLogicAppFuncSessionDepartment?
final
hashCode int
The hash code for this object.
no setteroverride
location WebApiLogicAppFuncSessionLocation?
final
plugins → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverVersion String?
final
systemSettings WebApiModulesAccountServicesAccountSystemSettingsResponse?
final
warehouse WebApiLogicAppFuncSessionWarehouse?
final
webUser WebApiLogicAppFuncSessionUser?
final

Methods

copyWith({WebApiLogicAppFuncSessionLocation? location, WebApiLogicAppFuncSessionWarehouse? warehouse, WebApiLogicAppFuncSessionDepartment? department, WebApiLogicAppFuncSessionUser? webUser, WebApiLogicAppFuncSessionDeal? deal, FwStandardAppManagerFwAmSecurityTreeNode? applicationtree, dynamic applicationOptions, String? clientcode, String? serverVersion, WebApiModulesAccountServicesAccountSystemSettingsResponse? systemSettings, dynamic plugins}) WebApiModulesAccountServicesAccountAccountControllerGetSessionResponse

Available on WebApiModulesAccountServicesAccountAccountControllerGetSessionResponse, provided by the $WebApiModulesAccountServicesAccountAccountControllerGetSessionResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override