WebApiModulesAccountServicesAccountForgotPasswordResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

copyWith({String? status, String? message}) WebApiModulesAccountServicesAccountForgotPasswordResponse

Available on WebApiModulesAccountServicesAccountForgotPasswordResponse, provided by the $WebApiModulesAccountServicesAccountForgotPasswordResponseExtension extension

copyWithWrapped({Wrapped<String?>? status, Wrapped<String?>? message}) WebApiModulesAccountServicesAccountForgotPasswordResponse

Available on WebApiModulesAccountServicesAccountForgotPasswordResponse, provided by the $WebApiModulesAccountServicesAccountForgotPasswordResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override