WebApiModulesAccountServicesJwtOktaRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAccountServicesJwtOktaRequest({String? token, String? issuer, String? audience})
const
WebApiModulesAccountServicesJwtOktaRequest.fromJson(Map<String, dynamic> json)
factory

Properties

audience String?
final
hashCode int
The hash code for this object.
no setteroverride
issuer String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
final

Methods

copyWith({String? token, String? issuer, String? audience}) WebApiModulesAccountServicesJwtOktaRequest

Available on WebApiModulesAccountServicesJwtOktaRequest, provided by the $WebApiModulesAccountServicesJwtOktaRequestExtension extension

copyWithWrapped({Wrapped<String?>? token, Wrapped<String?>? issuer, Wrapped<String?>? audience}) WebApiModulesAccountServicesJwtOktaRequest

Available on WebApiModulesAccountServicesJwtOktaRequest, provided by the $WebApiModulesAccountServicesJwtOktaRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAccountServicesJwtOktaRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAccountServicesJwtOktaRequest instance)