FwStandardModelsDataField class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModelsDataField({String? name, String? value, String? type})
const
FwStandardModelsDataField.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final
value String?
final

Methods

copyWith({String? name, String? value, String? type}) FwStandardModelsDataField

Available on FwStandardModelsDataField, provided by the $FwStandardModelsDataFieldExtension extension

copyWithWrapped({Wrapped<String?>? name, Wrapped<String?>? value, Wrapped<String?>? type}) FwStandardModelsDataField

Available on FwStandardModelsDataField, provided by the $FwStandardModelsDataFieldExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const FwStandardModelsDataField Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(FwStandardModelsDataField instance)