FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest({String? companyName, String? databaseName, String? url, String? applicationPool, String? sQLServerName, String? defaultDatabaseName, String? sQLUserId, String? sQLPassword, String? defaultApiPath, String? defaultApplicationPool, String? applicationPoolIdentity, String? applicationPoolUserName, String? applicationPoolPassword})
-
const
-
FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- applicationPool → String?
-
final
- applicationPoolIdentity → String?
-
final
- applicationPoolPassword → String?
-
final
- applicationPoolUserName → String?
-
final
- companyName → String?
-
final
- databaseName → String?
-
final
- defaultApiPath → String?
-
final
- defaultApplicationPool → String?
-
final
- defaultDatabaseName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sQLPassword → String?
-
final
- sQLServerName → String?
-
final
- sQLUserId → String?
-
final
- url → String?
-
final
Methods
-
copyWith(
{String? companyName, String? databaseName, String? url, String? applicationPool, String? sQLServerName, String? defaultDatabaseName, String? sQLUserId, String? sQLPassword, String? defaultApiPath, String? defaultApplicationPool, String? applicationPoolIdentity, String? applicationPoolUserName, String? applicationPoolPassword}) → FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest -
Available on FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest, provided by the $FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? companyName, Wrapped<String?> ? databaseName, Wrapped<String?> ? url, Wrapped<String?> ? applicationPool, Wrapped<String?> ? sQLServerName, Wrapped<String?> ? defaultDatabaseName, Wrapped<String?> ? sQLUserId, Wrapped<String?> ? sQLPassword, Wrapped<String?> ? defaultApiPath, Wrapped<String?> ? defaultApplicationPool, Wrapped<String?> ? applicationPoolIdentity, Wrapped<String?> ? applicationPoolUserName, Wrapped<String?> ? applicationPoolPassword}) → FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest -
Available on FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest, provided by the $FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModulesAdministratorCreateNewSystemCreateNewSystemRequest instance)