FwStandardModulesAdministratorCreateNewSystemGetDefaultsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

applicationPool String?
final
databaseName String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

copyWith({String? databaseName, String? applicationPool, String? url}) FwStandardModulesAdministratorCreateNewSystemGetDefaultsResponse

Available on FwStandardModulesAdministratorCreateNewSystemGetDefaultsResponse, provided by the $FwStandardModulesAdministratorCreateNewSystemGetDefaultsResponseExtension extension

copyWithWrapped({Wrapped<String?>? databaseName, Wrapped<String?>? applicationPool, Wrapped<String?>? url}) FwStandardModulesAdministratorCreateNewSystemGetDefaultsResponse

Available on FwStandardModulesAdministratorCreateNewSystemGetDefaultsResponse, provided by the $FwStandardModulesAdministratorCreateNewSystemGetDefaultsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override