FwStandardModulesAdministratorCustomFormCustomFormLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorCustomFormCustomFormLogic({String? customFormId, String? webUserId, String? userName, String? baseForm, String? description, String? html, bool? active, bool? inactive, String? assignTo, bool? selfAssign, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
FwStandardModulesAdministratorCustomFormCustomFormLogic.fromJson(Map<String, dynamic> json)
factory

Properties

active bool?
final
assignTo String?
final
auditNote String?
final
baseForm String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
customFormId String?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
html String?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfAssign bool?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userName String?
final
webUserId String?
final

Methods

copyWith({String? customFormId, String? webUserId, String? userName, String? baseForm, String? description, String? html, bool? active, bool? inactive, String? assignTo, bool? selfAssign, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) FwStandardModulesAdministratorCustomFormCustomFormLogic

Available on FwStandardModulesAdministratorCustomFormCustomFormLogic, provided by the $FwStandardModulesAdministratorCustomFormCustomFormLogicExtension extension

copyWithWrapped({Wrapped<String?>? customFormId, Wrapped<String?>? webUserId, Wrapped<String?>? userName, Wrapped<String?>? baseForm, Wrapped<String?>? description, Wrapped<String?>? html, Wrapped<bool?>? active, Wrapped<bool?>? inactive, Wrapped<String?>? assignTo, Wrapped<bool?>? selfAssign, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) FwStandardModulesAdministratorCustomFormCustomFormLogic

Available on FwStandardModulesAdministratorCustomFormCustomFormLogic, provided by the $FwStandardModulesAdministratorCustomFormCustomFormLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override