FwStandardModulesAdministratorCustomReportCssCustomReportCssLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorCustomReportCssCustomReportCssLogic({int? customReportCssId, String? description, String? css, bool? isGlobal, bool? inactive, bool? active, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
FwStandardModulesAdministratorCustomReportCssCustomReportCssLogic.fromJson(Map<String, dynamic> json)
factory

Properties

active bool?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
css String?
final
custom List<FwStandardDataFwCustomValue>?
final
customReportCssId int?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
isGlobal bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? customReportCssId, String? description, String? css, bool? isGlobal, bool? inactive, bool? active, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) FwStandardModulesAdministratorCustomReportCssCustomReportCssLogic

Available on FwStandardModulesAdministratorCustomReportCssCustomReportCssLogic, provided by the $FwStandardModulesAdministratorCustomReportCssCustomReportCssLogicExtension extension

copyWithWrapped({Wrapped<int?>? customReportCssId, Wrapped<String?>? description, Wrapped<String?>? css, Wrapped<bool?>? isGlobal, Wrapped<bool?>? inactive, Wrapped<bool?>? active, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) FwStandardModulesAdministratorCustomReportCssCustomReportCssLogic

Available on FwStandardModulesAdministratorCustomReportCssCustomReportCssLogic, provided by the $FwStandardModulesAdministratorCustomReportCssCustomReportCssLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override