FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic({String? duplicateRuleId, String? moduleName, String? ruleName, bool? caseSensitive, bool? systemRule, String? fields, String? fieldTypes, String? ruleNameColor, bool? considerBlanks, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? $fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
$fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- auditNote → String?
-
final
- caseSensitive → bool?
-
final
- considerBlanks → bool?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- duplicateRuleId → String?
-
final
- fields → String?
-
final
- fieldTypes → String?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- moduleName → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- ruleName → String?
-
final
- ruleNameColor → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemRule → bool?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? duplicateRuleId, String? moduleName, String? ruleName, bool? caseSensitive, bool? systemRule, String? fields, String? fieldTypes, String? ruleNameColor, bool? considerBlanks, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? $fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic -
Available on FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic, provided by the $FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogicExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? duplicateRuleId, Wrapped<String?> ? moduleName, Wrapped<String?> ? ruleName, Wrapped<bool?> ? caseSensitive, Wrapped<bool?> ? systemRule, Wrapped<String?> ? fields, Wrapped<String?> ? fieldTypes, Wrapped<String?> ? ruleNameColor, Wrapped<bool?> ? considerBlanks, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? $fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic -
Available on FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic, provided by the $FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogicExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModulesAdministratorDuplicateRuleDuplicateRuleLogic instance)