FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic({String? appEmailId, String? description, String? filterId, String? subject, String? emailText, String? category, String? bodyFormat, String? emailType, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic.fromJson(Map<String, dynamic> json)
factory

Properties

appEmailId String?
final
auditNote String?
final
bodyFormat String?
final
category String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
emailText String?
final
emailType String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
filterId String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? appEmailId, String? description, String? filterId, String? subject, String? emailText, String? category, String? bodyFormat, String? emailType, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic

Available on FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic, provided by the $FwStandardModulesAdministratorEmailTemplateEmailTemplateLogicExtension extension

copyWithWrapped({Wrapped<String?>? appEmailId, Wrapped<String?>? description, Wrapped<String?>? filterId, Wrapped<String?>? subject, Wrapped<String?>? emailText, Wrapped<String?>? category, Wrapped<String?>? bodyFormat, Wrapped<String?>? emailType, Wrapped<bool?>? inactive, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic

Available on FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic, provided by the $FwStandardModulesAdministratorEmailTemplateEmailTemplateLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override