FwStandardModulesAdministratorGroupCopySecurityNodeRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

fromGroupId String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityId String?
final
toGroupIds String?
final

Methods

copyWith({String? fromGroupId, String? toGroupIds, String? securityId}) FwStandardModulesAdministratorGroupCopySecurityNodeRequest

Available on FwStandardModulesAdministratorGroupCopySecurityNodeRequest, provided by the $FwStandardModulesAdministratorGroupCopySecurityNodeRequestExtension extension

copyWithWrapped({Wrapped<String?>? fromGroupId, Wrapped<String?>? toGroupIds, Wrapped<String?>? securityId}) FwStandardModulesAdministratorGroupCopySecurityNodeRequest

Available on FwStandardModulesAdministratorGroupCopySecurityNodeRequest, provided by the $FwStandardModulesAdministratorGroupCopySecurityNodeRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override