FwStandardModulesAdministratorWebAlertLogWebAlertLogLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorWebAlertLogWebAlertLogLogic({int? webAlertLogId, String? alertId, DateTime? createDateTime, String? alertSubject, String? alertBody, String? alertFrom, String? alertTo, String? status, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
FwStandardModulesAdministratorWebAlertLogWebAlertLogLogic.fromJson(Map<String, dynamic> json)
factory

Properties

alertBody String?
final
alertFrom String?
final
alertId String?
final
alertSubject String?
final
alertTo String?
final
auditNote String?
final
createDateTime DateTime?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
errorMessage String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
webAlertLogId int?
final

Methods

copyWith({int? webAlertLogId, String? alertId, DateTime? createDateTime, String? alertSubject, String? alertBody, String? alertFrom, String? alertTo, String? status, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) FwStandardModulesAdministratorWebAlertLogWebAlertLogLogic

Available on FwStandardModulesAdministratorWebAlertLogWebAlertLogLogic, provided by the $FwStandardModulesAdministratorWebAlertLogWebAlertLogLogicExtension extension

copyWithWrapped({Wrapped<int?>? webAlertLogId, Wrapped<String?>? alertId, Wrapped<DateTime?>? createDateTime, Wrapped<String?>? alertSubject, Wrapped<String?>? alertBody, Wrapped<String?>? alertFrom, Wrapped<String?>? alertTo, Wrapped<String?>? status, Wrapped<String?>? errorMessage, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) FwStandardModulesAdministratorWebAlertLogWebAlertLogLogic

Available on FwStandardModulesAdministratorWebAlertLogWebAlertLogLogic, provided by the $FwStandardModulesAdministratorWebAlertLogWebAlertLogLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override