FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic({int? webAuditId, String? moduleName, String? title, String? auditType, String? uniqueId1, String? uniqueId2, String? uniqueId3, String? webUserId, String? userId, String? userName, String? json, String? metaData1, String? metaData2, String? metaData3, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
auditType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
json String?
final
metaData1 String?
final
metaData2 String?
final
metaData3 String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
moduleName String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
uniqueId1 String?
final
uniqueId2 String?
final
uniqueId3 String?
final
urlIdentifier → dynamic
final
userId String?
final
userName String?
final
webAuditId int?
final
webUserId String?
final

Methods

copyWith({int? webAuditId, String? moduleName, String? title, String? auditType, String? uniqueId1, String? uniqueId2, String? uniqueId3, String? webUserId, String? userId, String? userName, String? json, String? metaData1, String? metaData2, String? metaData3, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic

Available on FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic, provided by the $FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogicExtension extension

copyWithWrapped({Wrapped<int?>? webAuditId, Wrapped<String?>? moduleName, Wrapped<String?>? title, Wrapped<String?>? auditType, Wrapped<String?>? uniqueId1, Wrapped<String?>? uniqueId2, Wrapped<String?>? uniqueId3, Wrapped<String?>? webUserId, Wrapped<String?>? userId, Wrapped<String?>? userName, Wrapped<String?>? json, Wrapped<String?>? metaData1, Wrapped<String?>? metaData2, Wrapped<String?>? metaData3, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic

Available on FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic, provided by the $FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override