WebApiModulesAccountServicesHubSpotSearchHubSpotContactsWithinPeriodRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

accessToken String?
final
hashCode int
The hash code for this object.
no setteroverride
lastSyncEpoch int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webusersid String?
final

Methods

copyWith({String? webusersid, String? accessToken, int? lastSyncEpoch}) WebApiModulesAccountServicesHubSpotSearchHubSpotContactsWithinPeriodRequest

Available on WebApiModulesAccountServicesHubSpotSearchHubSpotContactsWithinPeriodRequest, provided by the $WebApiModulesAccountServicesHubSpotSearchHubSpotContactsWithinPeriodRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override