WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistory({int? createNewSystemHistoryId, String? usersId, String? userName, String? companyName, String? databaseName, String? url, String? applicationPool, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistory.fromJson(Map<String, dynamic> json)
factory

Properties

applicationPool String?
final
auditNote String?
final
companyName String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
createNewSystemHistoryId int?
final
custom List<FwStandardDataFwCustomValue>?
final
databaseName String?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
errorMessage String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
url String?
final
urlIdentifier → dynamic
final
userName String?
final
usersId String?
final

Methods

copyWith({int? createNewSystemHistoryId, String? usersId, String? userName, String? companyName, String? databaseName, String? url, String? applicationPool, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistory

Available on WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistory, provided by the $WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistoryExtension extension

copyWithWrapped({Wrapped<int?>? createNewSystemHistoryId, Wrapped<String?>? usersId, Wrapped<String?>? userName, Wrapped<String?>? companyName, Wrapped<String?>? databaseName, Wrapped<String?>? url, Wrapped<String?>? applicationPool, Wrapped<String?>? errorMessage, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistory

Available on WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistory, provided by the $WebApiModulesAdministratorCreateNewSystemHistoryCreateNewSystemHistoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override