WebApiModulesAdministratorCustomFieldCustomField class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorCustomFieldCustomField({String? customFieldId, String? moduleName, String? fieldName, String? customTableName, String? customFieldName, String? fieldType, String? controlType, int? stringLength, int? floatDecimalDigits, String? validationModule, String? validationFieldId, String? validationFieldName, String? listFieldAllowedValues, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAdministratorCustomFieldCustomField.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
controlType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
customFieldId String?
final
customFieldName String?
final
customTableName String?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fieldName String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fieldType String?
final
floatDecimalDigits int?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
listFieldAllowedValues String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
moduleName String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringLength int?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
validationFieldId String?
final
validationFieldName String?
final
validationModule String?
final

Methods

copyWith({String? customFieldId, String? moduleName, String? fieldName, String? customTableName, String? customFieldName, String? fieldType, String? controlType, int? stringLength, int? floatDecimalDigits, String? validationModule, String? validationFieldId, String? validationFieldName, String? listFieldAllowedValues, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAdministratorCustomFieldCustomField

Available on WebApiModulesAdministratorCustomFieldCustomField, provided by the $WebApiModulesAdministratorCustomFieldCustomFieldExtension extension

copyWithWrapped({Wrapped<String?>? customFieldId, Wrapped<String?>? moduleName, Wrapped<String?>? fieldName, Wrapped<String?>? customTableName, Wrapped<String?>? customFieldName, Wrapped<String?>? fieldType, Wrapped<String?>? controlType, Wrapped<int?>? stringLength, Wrapped<int?>? floatDecimalDigits, Wrapped<String?>? validationModule, Wrapped<String?>? validationFieldId, Wrapped<String?>? validationFieldName, Wrapped<String?>? listFieldAllowedValues, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAdministratorCustomFieldCustomField

Available on WebApiModulesAdministratorCustomFieldCustomField, provided by the $WebApiModulesAdministratorCustomFieldCustomFieldExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override