WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory({int? systemUpdateHistoryId, String? usersId, String? userName, DateTime? updateDateTime, String? fromVersion, String? toVersion, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
errorMessage String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fromVersion String?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemUpdateHistoryId int?
final
toVersion String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
updateDateTime DateTime?
final
urlIdentifier → dynamic
final
userName String?
final
usersId String?
final

Methods

copyWith({int? systemUpdateHistoryId, String? usersId, String? userName, DateTime? updateDateTime, String? fromVersion, String? toVersion, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory

Available on WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory, provided by the $WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistoryExtension extension

copyWithWrapped({Wrapped<int?>? systemUpdateHistoryId, Wrapped<String?>? usersId, Wrapped<String?>? userName, Wrapped<DateTime?>? updateDateTime, Wrapped<String?>? fromVersion, Wrapped<String?>? toVersion, Wrapped<String?>? errorMessage, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory

Available on WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory, provided by the $WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override