WebApiModulesAdministratorUserCreateUserSalesRepresentativeContactResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

contactId String?
final
hashCode int
The hash code for this object.
no setteroverride
msg String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
success bool?
final

Methods

copyWith({String? contactId, int? status, bool? success, String? msg}) WebApiModulesAdministratorUserCreateUserSalesRepresentativeContactResponse

Available on WebApiModulesAdministratorUserCreateUserSalesRepresentativeContactResponse, provided by the $WebApiModulesAdministratorUserCreateUserSalesRepresentativeContactResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override