WebApiModulesAdministratorUserKissFlowUser class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorUserKissFlowUser({String? userId, String? name, String? loginName, String? fullName, String? firstName, String? middleInitial, String? lastName, String? groupName, String? userTitle, String? officeLocation, String? warehouse, bool? inactive, String? email})
const
WebApiModulesAdministratorUserKissFlowUser.fromJson(Map<String, dynamic> json)
factory

Properties

email String?
final
firstName String?
final
fullName String?
final
groupName String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
lastName String?
final
loginName String?
final
middleInitial String?
final
name String?
final
officeLocation String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
final
userTitle String?
final
warehouse String?
final

Methods

copyWith({String? userId, String? name, String? loginName, String? fullName, String? firstName, String? middleInitial, String? lastName, String? groupName, String? userTitle, String? officeLocation, String? warehouse, bool? inactive, String? email}) WebApiModulesAdministratorUserKissFlowUser

Available on WebApiModulesAdministratorUserKissFlowUser, provided by the $WebApiModulesAdministratorUserKissFlowUserExtension extension

copyWithWrapped({Wrapped<String?>? userId, Wrapped<String?>? name, Wrapped<String?>? loginName, Wrapped<String?>? fullName, Wrapped<String?>? firstName, Wrapped<String?>? middleInitial, Wrapped<String?>? lastName, Wrapped<String?>? groupName, Wrapped<String?>? userTitle, Wrapped<String?>? officeLocation, Wrapped<String?>? warehouse, Wrapped<bool?>? inactive, Wrapped<String?>? email}) WebApiModulesAdministratorUserKissFlowUser

Available on WebApiModulesAdministratorUserKissFlowUser, provided by the $WebApiModulesAdministratorUserKissFlowUserExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAdministratorUserKissFlowUser Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAdministratorUserKissFlowUser instance)