WebApiModulesAdministratorUserUser class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAdministratorUserUser({String? userId, String? contactId, String? name, String? loginName, String? fullName, String? firstName, String? middleInitial, String? lastName, String? password, bool? passwordChanged, String? barCode, String? groupId, String? groupName, String? scheduleColor, String? userTitleId, String? userTitle, String? email, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? address1, String? address2, String? city, String? state, String? zipCode, String? countryId, String? country, String? officePhone, String? officeExtension, String? fax, String? directPhone, String? pager, String? pagerPin, String? cellular, String? homePhone, String? defaultDepartmentType, String? primaryDepartmentId, String? primaryDepartment, String? rentalDepartmentId, String? rentalDepartment, String? salesDepartmentId, String? salesDepartment, String? partsDepartmentId, String? partsDepartment, String? miscDepartmentId, String? miscDepartment, String? laborDepartmentId, String? laborDepartment, String? facilityDepartmentId, String? facilityDepartment, String? transportationDepartmentId, String? transportationDepartment, String? rentalInventoryTypeId, String? rentalInventoryType, String? salesInventoryTypeId, String? salesInventoryType, String? partsInventoryTypeId, String? partsInventoryType, String? miscTypeId, String? miscType, String? laborTypeId, String? laborType, String? facilityTypeId, String? facilityType, String? transportationTypeId, String? transportationType, bool? noMiscellaneousOnQuotes, bool? noMiscellaneousOnOrders, bool? noMiscellaneousOnPurchaseOrders, bool? limitDaysPerWeek, double? minimumDaysPerWeek, bool? allowCreditLimitOverride, bool? limitDiscount, double? maximumDiscount, bool? limitSubDiscount, double? maximumSubDiscount, String? discountRule, bool? stagingAllowIncreaseDecreaseOrderQuantity, bool? allowStagingOfItemsWhenReservedOnOtherOrdersQuotes, bool? allowContractIfDealRequiresPOAndOrderHasPendingPO, bool? allowContractIfPendingItemsExist, bool? allowContractIfCustomerDealDoesNotHaveApprovedCredit, bool? allowContractIfCustomerDealIsOverTheirCreditLimit, bool? allowContractIfCustomerDealInsuranceCoverageIsLess, bool? allowContractIfCustomerDealDoesNotHaveValidInsuranceCertificate, bool? allowContractIfCustomerDealDoesNotHaveValidNonTaxCertificate, bool? allowReceiveSubsWhenPositiveConflictExists, bool? allowStagingOfUnreservedConsignedItems, bool? allowStagingOfUnapprovedItems, bool? allowSubstitutesAtStaging, bool? deleteOriginalOnSubstitution, bool? quikActivityAllowPrintDollarAmounts, bool? quikScanAllowCreateContract, bool? quikScanAllowApplyAll, bool? allowCrossICodeExchange, bool? allowCrossICodePendingExchange, bool? allowChangeAvailabilityPriority, bool? userMustChangePassword, bool? passwordExpires, int? passwordExpireDays, String? passwordUpdatedDateTime, bool? accountLocked, String? memo, bool? allowCrossLocationEditAndDelete, String? lastLoggedOn, bool? disableInsertIntoActiveOrder, bool? inactive, String? dateStamp, String? webUserId, bool? webAccess, bool? webAdministrator, int? browseDefaultRows, String? applicationTheme, String? homeMenuGuid, String? homeMenuPath, String? successSoundId, String? successSound, String? successBase64Sound, String? errorSoundId, String? errorSound, String? errorBase64Sound, String? notificationSoundId, String? notificationSound, String? notificationBase64Sound, int? firstDayOfWeek, bool? webQuoteRequest, String? emailSignature, String? locale, String? availabilityPreference, bool? availabilityAllWarehouses, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesAdministratorUserUser.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountLocked → bool?
-
final
- address1 → String?
-
final
- address2 → String?
-
final
- allowChangeAvailabilityPriority → bool?
-
final
- allowContractIfCustomerDealDoesNotHaveApprovedCredit → bool?
-
final
- allowContractIfCustomerDealDoesNotHaveValidInsuranceCertificate → bool?
-
final
- allowContractIfCustomerDealDoesNotHaveValidNonTaxCertificate → bool?
-
final
- allowContractIfCustomerDealInsuranceCoverageIsLess → bool?
-
final
- allowContractIfCustomerDealIsOverTheirCreditLimit → bool?
-
final
- allowContractIfDealRequiresPOAndOrderHasPendingPO → bool?
-
final
- allowContractIfPendingItemsExist → bool?
-
final
- allowCreditLimitOverride → bool?
-
final
- allowCrossICodeExchange → bool?
-
final
- allowCrossICodePendingExchange → bool?
-
final
- allowCrossLocationEditAndDelete → bool?
-
final
- allowReceiveSubsWhenPositiveConflictExists → bool?
-
final
- allowStagingOfItemsWhenReservedOnOtherOrdersQuotes → bool?
-
final
- allowStagingOfUnapprovedItems → bool?
-
final
- allowStagingOfUnreservedConsignedItems → bool?
-
final
- allowSubstitutesAtStaging → bool?
-
final
- applicationTheme → String?
-
final
- auditNote → String?
-
final
- availabilityAllWarehouses → bool?
-
final
- availabilityPreference → String?
-
final
- barCode → String?
-
final
- browseDefaultRows → int?
-
final
- cellular → String?
-
final
- city → String?
-
final
- contactId → String?
-
final
- country → String?
-
final
- countryId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- defaultDepartmentType → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- deleteOriginalOnSubstitution → bool?
-
final
- directPhone → String?
-
final
- disableInsertIntoActiveOrder → bool?
-
final
- discountRule → String?
-
final
- email → String?
-
final
- emailSignature → String?
-
final
- errorBase64Sound → String?
-
final
- errorSound → String?
-
final
- errorSoundId → String?
-
final
- facilityDepartment → String?
-
final
- facilityDepartmentId → String?
-
final
- facilityType → String?
-
final
- facilityTypeId → String?
-
final
- fax → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- firstDayOfWeek → int?
-
final
- firstName → String?
-
final
- fullName → String?
-
final
- groupId → String?
-
final
- groupName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- homeMenuGuid → String?
-
final
- homeMenuPath → String?
-
final
- homePhone → String?
-
final
- inactive → bool?
-
final
- laborDepartment → String?
-
final
- laborDepartmentId → String?
-
final
- laborType → String?
-
final
- laborTypeId → String?
-
final
- lastLoggedOn → String?
-
final
- lastName → String?
-
final
- limitDaysPerWeek → bool?
-
final
- limitDiscount → bool?
-
final
- limitSubDiscount → bool?
-
final
- locale → String?
-
final
- loginName → String?
-
final
- maximumDiscount → double?
-
final
- maximumSubDiscount → double?
-
final
- memo → String?
-
final
- middleInitial → String?
-
final
- minimumDaysPerWeek → double?
-
final
- miscDepartment → String?
-
final
- miscDepartmentId → String?
-
final
- miscType → String?
-
final
- miscTypeId → String?
-
final
- name → String?
-
final
- noMiscellaneousOnOrders → bool?
-
final
- noMiscellaneousOnPurchaseOrders → bool?
-
final
- noMiscellaneousOnQuotes → bool?
-
final
- notificationBase64Sound → String?
-
final
- notificationSound → String?
-
final
- notificationSoundId → String?
-
final
- officeExtension → String?
-
final
- officeLocation → String?
-
final
- officeLocationId → String?
-
final
- officePhone → String?
-
final
- pager → String?
-
final
- pagerPin → String?
-
final
- partsDepartment → String?
-
final
- partsDepartmentId → String?
-
final
- partsInventoryType → String?
-
final
- partsInventoryTypeId → String?
-
final
- password → String?
-
final
- passwordChanged → bool?
-
final
- passwordExpireDays → int?
-
final
- passwordExpires → bool?
-
final
- passwordUpdatedDateTime → String?
-
final
- primaryDepartment → String?
-
final
- primaryDepartmentId → String?
-
final
- quikActivityAllowPrintDollarAmounts → bool?
-
final
- quikScanAllowApplyAll → bool?
-
final
- quikScanAllowCreateContract → bool?
-
final
- recordTitle → String?
-
final
- rentalDepartment → String?
-
final
- rentalDepartmentId → String?
-
final
- rentalInventoryType → String?
-
final
- rentalInventoryTypeId → String?
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesDepartment → String?
-
final
- salesDepartmentId → String?
-
final
- salesInventoryType → String?
-
final
- salesInventoryTypeId → String?
-
final
- scheduleColor → String?
-
final
-
final
- stagingAllowIncreaseDecreaseOrderQuantity → bool?
-
final
- state → String?
-
final
- successBase64Sound → String?
-
final
- successSound → String?
-
final
- successSoundId → String?
-
final
- transportationDepartment → String?
-
final
- transportationDepartmentId → String?
-
final
- transportationType → String?
-
final
- transportationTypeId → String?
-
final
- userId → String?
-
final
- userMustChangePassword → bool?
-
final
- userTitle → String?
-
final
- userTitleId → String?
-
final
- warehouse → String?
-
final
- warehouseId → String?
-
final
- webAccess → bool?
-
final
- webAdministrator → bool?
-
final
- webQuoteRequest → bool?
-
final
- webUserId → String?
-
final
- zipCode → String?
-
final
Methods
-
copyWith(
{String? userId, String? contactId, String? name, String? loginName, String? fullName, String? firstName, String? middleInitial, String? lastName, String? password, bool? passwordChanged, String? barCode, String? groupId, String? groupName, String? scheduleColor, String? userTitleId, String? userTitle, String? email, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? address1, String? address2, String? city, String? state, String? zipCode, String? countryId, String? country, String? officePhone, String? officeExtension, String? fax, String? directPhone, String? pager, String? pagerPin, String? cellular, String? homePhone, String? defaultDepartmentType, String? primaryDepartmentId, String? primaryDepartment, String? rentalDepartmentId, String? rentalDepartment, String? salesDepartmentId, String? salesDepartment, String? partsDepartmentId, String? partsDepartment, String? miscDepartmentId, String? miscDepartment, String? laborDepartmentId, String? laborDepartment, String? facilityDepartmentId, String? facilityDepartment, String? transportationDepartmentId, String? transportationDepartment, String? rentalInventoryTypeId, String? rentalInventoryType, String? salesInventoryTypeId, String? salesInventoryType, String? partsInventoryTypeId, String? partsInventoryType, String? miscTypeId, String? miscType, String? laborTypeId, String? laborType, String? facilityTypeId, String? facilityType, String? transportationTypeId, String? transportationType, bool? noMiscellaneousOnQuotes, bool? noMiscellaneousOnOrders, bool? noMiscellaneousOnPurchaseOrders, bool? limitDaysPerWeek, double? minimumDaysPerWeek, bool? allowCreditLimitOverride, bool? limitDiscount, double? maximumDiscount, bool? limitSubDiscount, double? maximumSubDiscount, String? discountRule, bool? stagingAllowIncreaseDecreaseOrderQuantity, bool? allowStagingOfItemsWhenReservedOnOtherOrdersQuotes, bool? allowContractIfDealRequiresPOAndOrderHasPendingPO, bool? allowContractIfPendingItemsExist, bool? allowContractIfCustomerDealDoesNotHaveApprovedCredit, bool? allowContractIfCustomerDealIsOverTheirCreditLimit, bool? allowContractIfCustomerDealInsuranceCoverageIsLess, bool? allowContractIfCustomerDealDoesNotHaveValidInsuranceCertificate, bool? allowContractIfCustomerDealDoesNotHaveValidNonTaxCertificate, bool? allowReceiveSubsWhenPositiveConflictExists, bool? allowStagingOfUnreservedConsignedItems, bool? allowStagingOfUnapprovedItems, bool? allowSubstitutesAtStaging, bool? deleteOriginalOnSubstitution, bool? quikActivityAllowPrintDollarAmounts, bool? quikScanAllowCreateContract, bool? quikScanAllowApplyAll, bool? allowCrossICodeExchange, bool? allowCrossICodePendingExchange, bool? allowChangeAvailabilityPriority, bool? userMustChangePassword, bool? passwordExpires, int? passwordExpireDays, String? passwordUpdatedDateTime, bool? accountLocked, String? memo, bool? allowCrossLocationEditAndDelete, String? lastLoggedOn, bool? disableInsertIntoActiveOrder, bool? inactive, String? dateStamp, String? webUserId, bool? webAccess, bool? webAdministrator, int? browseDefaultRows, String? applicationTheme, String? homeMenuGuid, String? homeMenuPath, String? successSoundId, String? successSound, String? successBase64Sound, String? errorSoundId, String? errorSound, String? errorBase64Sound, String? notificationSoundId, String? notificationSound, String? notificationBase64Sound, int? firstDayOfWeek, bool? webQuoteRequest, String? emailSignature, String? locale, String? availabilityPreference, bool? availabilityAllWarehouses, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesAdministratorUserUser -
Available on WebApiModulesAdministratorUserUser, provided by the $WebApiModulesAdministratorUserUserExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAdministratorUserUser Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAdministratorUserUser instance)