Exports class abstract

Annotations
  • @ChopperApi.new()

Constructors

Exports()

Properties

client ↔ ChopperClient
getter/setter pairinherited
definitionType Type
Used internally to retrieve the service from ChopperClient.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoicebatchexportEmptyobjectGet() Future<Response<FwStandardSqlServerFwJsonDataTable>>
invoicebatchexportExportPost({required WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequest? body}) Future<Response<WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportResponse>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiptbatchexportEmptyobjectGet() Future<Response<FwStandardSqlServerFwJsonDataTable>>
receiptbatchexportExportPost({required WebApiModulesExportsReceiptBatchExportReceiptBatchExportRequest? body}) Future<Response<WebApiModulesExportsReceiptBatchExportReceiptBatchExportResponse>>
taskschedulerTaskstepsBrowsePost({required FwStandardModelsBrowseRequest? body}) Future<Response<FwStandardSqlServerFwJsonDataTable>>
taskschedulerTaskstepsExportexcelxlsxPost({required FwStandardModelsBrowseRequest? body}) Future<Response<FwCoreControllersFwDataControllerDoExportExcelXlsxExportFileAsyncResult>>
taskschedulerTaskstepsGet({int? pageno, int? pagesize, String? sort, List<FwStandardModelsFwQueryFilter>? filter}) Future<Response<FwStandardModelsFwQueryResponseWebApiModulesAdministratorTaskSchedulerTaskStepsLogic>>
@param pageno @param pagesize @param sort @param filter
taskschedulerTaskstepsIdDelete({required String? id}) Future<Response<bool>>
@param id
taskschedulerTaskstepsIdGet({required String? id}) Future<Response<WebApiModulesAdministratorTaskSchedulerTaskSteps>>
@param id
taskschedulerTaskstepsIdPut({required String? id, required WebApiModulesAdministratorTaskSchedulerTaskSteps? body}) Future<Response<WebApiModulesAdministratorTaskSchedulerTaskSteps>>
@param id
taskschedulerTaskstepsPost({required WebApiModulesAdministratorTaskSchedulerTaskSteps? body}) Future<Response<WebApiModulesAdministratorTaskSchedulerTaskSteps>>
toString() String
A string representation of this object.
inherited
vendorinvoicebatchexportEmptyobjectGet() Future<Response<FwStandardSqlServerFwJsonDataTable>>
vendorinvoicebatchexportExportPost({required WebApiModulesExportsVendorInvoiceBatchExportVendorInvoiceBatchExportRequest? body}) Future<Response<WebApiModulesExportsVendorInvoiceBatchExportVendorInvoiceBatchExportResponse>>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({ChopperClient? client, Client? httpClient, Authenticator? authenticator, ErrorConverter? errorConverter, Converter? converter, Uri? baseUrl, List<Interceptor>? interceptors}) Exports