WebApiModulesAdministratorTaskSchedulerTaskSteps class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorTaskSchedulerTaskSteps({int? taskStepsId, int? taskId, String? name, int? stepNumber, String? type, String? command, String? onSuccessActionDisplay, String? onFailureActionDisplay, int? onSuccessAction, int? retryAttempts, int? retryInterval, int? onFailureAction, int? onSuccessTaskStepsId, int? onFailureTaskStepsId, String? outputFilename, int? lastRunOutcome, int? lastRunDuration, int? lastRunRetries, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAdministratorTaskSchedulerTaskSteps.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
command String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
lastRunDuration int?
final
lastRunOutcome int?
final
lastRunRetries int?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
name String?
final
onFailureAction int?
final
onFailureActionDisplay String?
final
onFailureTaskStepsId int?
final
onSuccessAction int?
final
onSuccessActionDisplay String?
final
onSuccessTaskStepsId int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
outputFilename String?
final
recordTitle String?
final
retryAttempts int?
final
retryInterval int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepNumber int?
final
taskId int?
final
taskStepsId int?
final
translation List<FwStandardDataFwTranslatedValue>?
final
type String?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? taskStepsId, int? taskId, String? name, int? stepNumber, String? type, String? command, String? onSuccessActionDisplay, String? onFailureActionDisplay, int? onSuccessAction, int? retryAttempts, int? retryInterval, int? onFailureAction, int? onSuccessTaskStepsId, int? onFailureTaskStepsId, String? outputFilename, int? lastRunOutcome, int? lastRunDuration, int? lastRunRetries, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAdministratorTaskSchedulerTaskSteps

Available on WebApiModulesAdministratorTaskSchedulerTaskSteps, provided by the $WebApiModulesAdministratorTaskSchedulerTaskStepsExtension extension

copyWithWrapped({Wrapped<int?>? taskStepsId, Wrapped<int?>? taskId, Wrapped<String?>? name, Wrapped<int?>? stepNumber, Wrapped<String?>? type, Wrapped<String?>? command, Wrapped<String?>? onSuccessActionDisplay, Wrapped<String?>? onFailureActionDisplay, Wrapped<int?>? onSuccessAction, Wrapped<int?>? retryAttempts, Wrapped<int?>? retryInterval, Wrapped<int?>? onFailureAction, Wrapped<int?>? onSuccessTaskStepsId, Wrapped<int?>? onFailureTaskStepsId, Wrapped<String?>? outputFilename, Wrapped<int?>? lastRunOutcome, Wrapped<int?>? lastRunDuration, Wrapped<int?>? lastRunRetries, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAdministratorTaskSchedulerTaskSteps

Available on WebApiModulesAdministratorTaskSchedulerTaskSteps, provided by the $WebApiModulesAdministratorTaskSchedulerTaskStepsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override