WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

batchId String?
final
dataExportFormatId String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? batchId, String? dataExportFormatId}) WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequest

Available on WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequest, provided by the $WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequestExtension extension

copyWithWrapped({Wrapped<String?>? batchId, Wrapped<String?>? dataExportFormatId}) WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequest

Available on WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequest, provided by the $WebApiModulesExportsInvoiceBatchExportInvoiceBatchExportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override