FwStandardModelsCopyLogicRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardModelsCopyLogicRequest({List<
FwStandardModelsDataField> ? dataFields}) -
const
-
FwStandardModelsCopyLogicRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
dataFields
→ List<
FwStandardModelsDataField> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< FwStandardModelsDataField> ? dataFields}) → FwStandardModelsCopyLogicRequest -
Available on FwStandardModelsCopyLogicRequest, provided by the $FwStandardModelsCopyLogicRequestExtension extension
-
copyWithWrapped(
{Wrapped< List< ? dataFields}) → FwStandardModelsCopyLogicRequestFwStandardModelsDataField> ?> -
Available on FwStandardModelsCopyLogicRequest, provided by the $FwStandardModelsCopyLogicRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModelsCopyLogicRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModelsCopyLogicRequest instance)