FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic({List<
WebApiModulesAgentCustomerNoteCustomerNote> ? items, int? pageNo, int? pageSize, int? totalItems, String? sort}) -
const
-
FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
WebApiModulesAgentCustomerNoteCustomerNote> ? -
final
- pageNo → int?
-
final
- pageSize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sort → String?
-
final
- totalItems → int?
-
final
Methods
-
copyWith(
{List< WebApiModulesAgentCustomerNoteCustomerNote> ? items, int? pageNo, int? pageSize, int? totalItems, String? sort}) → FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic -
Available on FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic, provided by the $FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogicExtension extension
-
copyWithWrapped(
{Wrapped< List< ? items, Wrapped<WebApiModulesAgentCustomerNoteCustomerNote> ?>int?> ? pageNo, Wrapped<int?> ? pageSize, Wrapped<int?> ? totalItems, Wrapped<String?> ? sort}) → FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic -
Available on FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic, provided by the $FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogicExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModelsFwQueryResponseWebApiModulesAgentCustomerNoteCustomerNoteLogic instance)