FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic({List<
WebApiModulesHomeDeliveryDelivery> ? items, int? pageNo, int? pageSize, int? totalItems, String? sort}) -
const
-
FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
WebApiModulesHomeDeliveryDelivery> ? -
final
- pageNo → int?
-
final
- pageSize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sort → String?
-
final
- totalItems → int?
-
final
Methods
-
copyWith(
{List< WebApiModulesHomeDeliveryDelivery> ? items, int? pageNo, int? pageSize, int? totalItems, String? sort}) → FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic -
Available on FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic, provided by the $FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogicExtension extension
-
copyWithWrapped(
{Wrapped< List< ? items, Wrapped<WebApiModulesHomeDeliveryDelivery> ?>int?> ? pageNo, Wrapped<int?> ? pageSize, Wrapped<int?> ? totalItems, Wrapped<String?> ? sort}) → FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic -
Available on FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic, provided by the $FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogicExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModelsFwQueryResponseWebApiModulesHomeDeliveryDeliveryLogic instance)