FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic({List<
WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory> ? items, int? pageNo, int? pageSize, int? totalItems, String? sort}) -
const
-
FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory> ? -
final
- pageNo → int?
-
final
- pageSize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sort → String?
-
final
- totalItems → int?
-
final
Methods
-
copyWith(
{List< WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory> ? items, int? pageNo, int? pageSize, int? totalItems, String? sort}) → FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic -
Available on FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic, provided by the $FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogicExtension extension
-
copyWithWrapped(
{Wrapped< List< ? items, Wrapped<WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory> ?>int?> ? pageNo, Wrapped<int?> ? pageSize, Wrapped<int?> ? totalItems, Wrapped<String?> ? sort}) → FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic -
Available on FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic, provided by the $FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogicExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModelsFwQueryResponseWebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryLogic instance)