quoteQuoteidDocumentsGet method
Future<Response<FwStandardModelsGetResponseFwStandardGridsAppDocumentAppDocumentGetManyResponse> >
quoteQuoteidDocumentsGet({})
Get documents.
@param quoteid Unique identifier
@param DocumentTypeId Unique Identifier Filter|Sort
@param Description Document description Filter|Sort
@param DateStamp Document last modified data Filter|Sort
@param PageNo The page number in the result set starting from 1. PageNo is required when the PageSize is specified.
@param PageSize Limit result set to the specified amount.
@param Sort A sort expression to use of the form: Field1:asc,Field2:desc
Implementation
Future<
chopper.Response<
FwStandardModelsGetResponseFwStandardGridsAppDocumentAppDocumentGetManyResponse>>
quoteQuoteidDocumentsGet(
{required String? quoteid,
String? documentTypeId,
String? description,
String? dateStamp,
int? pageNo,
int? pageSize,
String? sort}) {
generatedMapping.putIfAbsent(
FwStandardModelsGetResponseFwStandardGridsAppDocumentAppDocumentGetManyResponse,
() =>
FwStandardModelsGetResponseFwStandardGridsAppDocumentAppDocumentGetManyResponse
.fromJsonFactory);
return _quoteQuoteidDocumentsGet(
quoteid: quoteid,
documentTypeId: documentTypeId,
description: description,
dateStamp: dateStamp,
pageNo: pageNo,
pageSize: pageSize,
sort: sort);
}