WebApiApplyBottomLineDiscountPercentRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiApplyBottomLineDiscountPercentRequest({String? orderId, String? purchaseOrderId, String? invoiceId, String? recType, bool? subs, double? discountPercent, String? moduleType})
const
WebApiApplyBottomLineDiscountPercentRequest.fromJson(Map<String, dynamic> json)
factory

Properties

discountPercent double?
final
hashCode int
The hash code for this object.
no setteroverride
invoiceId String?
final
moduleType String?
final
orderId String?
final
purchaseOrderId String?
final
recType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subs bool?
final

Methods

copyWith({String? orderId, String? purchaseOrderId, String? invoiceId, String? recType, bool? subs, double? discountPercent, String? moduleType}) WebApiApplyBottomLineDiscountPercentRequest

Available on WebApiApplyBottomLineDiscountPercentRequest, provided by the $WebApiApplyBottomLineDiscountPercentRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? purchaseOrderId, Wrapped<String?>? invoiceId, Wrapped<String?>? recType, Wrapped<bool?>? subs, Wrapped<double?>? discountPercent, Wrapped<String?>? moduleType}) WebApiApplyBottomLineDiscountPercentRequest

Available on WebApiApplyBottomLineDiscountPercentRequest, provided by the $WebApiApplyBottomLineDiscountPercentRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiApplyBottomLineDiscountPercentRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiApplyBottomLineDiscountPercentRequest instance)