WebApiApplyBottomLineTotalRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiApplyBottomLineTotalRequest({String? orderId, String? purchaseOrderId, String? invoiceId, String? recType, bool? subs, String? totalType, double? total, bool? includeTaxInTotal, String? moduleType, double? weightPercentage})
const
WebApiApplyBottomLineTotalRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
includeTaxInTotal bool?
final
invoiceId String?
final
moduleType String?
final
orderId String?
final
purchaseOrderId String?
final
recType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subs bool?
final
total double?
final
totalType String?
final
weightPercentage double?
final

Methods

copyWith({String? orderId, String? purchaseOrderId, String? invoiceId, String? recType, bool? subs, String? totalType, double? total, bool? includeTaxInTotal, String? moduleType, double? weightPercentage}) WebApiApplyBottomLineTotalRequest

Available on WebApiApplyBottomLineTotalRequest, provided by the $WebApiApplyBottomLineTotalRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? purchaseOrderId, Wrapped<String?>? invoiceId, Wrapped<String?>? recType, Wrapped<bool?>? subs, Wrapped<String?>? totalType, Wrapped<double?>? total, Wrapped<bool?>? includeTaxInTotal, Wrapped<String?>? moduleType, Wrapped<double?>? weightPercentage}) WebApiApplyBottomLineTotalRequest

Available on WebApiApplyBottomLineTotalRequest, provided by the $WebApiApplyBottomLineTotalRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiApplyBottomLineTotalRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiApplyBottomLineTotalRequest instance)