WebApiLogicSortItemsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiLogicSortItemsResponse({int? status, bool? success, String? msg, DateTime? sortStartDateTime, DateTime? itemDateStamp})
-
const
-
WebApiLogicSortItemsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- itemDateStamp → DateTime?
-
final
- msg → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortStartDateTime → DateTime?
-
final
- status → int?
-
final
- success → bool?
-
final
Methods
-
copyWith(
{int? status, bool? success, String? msg, DateTime? sortStartDateTime, DateTime? itemDateStamp}) → WebApiLogicSortItemsResponse -
Available on WebApiLogicSortItemsResponse, provided by the $WebApiLogicSortItemsResponseExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? status, Wrapped<bool?> ? success, Wrapped<String?> ? msg, Wrapped<DateTime?> ? sortStartDateTime, Wrapped<DateTime?> ? itemDateStamp}) → WebApiLogicSortItemsResponse -
Available on WebApiLogicSortItemsResponse, provided by the $WebApiLogicSortItemsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiLogicSortItemsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiLogicSortItemsResponse instance)