WebApiModulesAgentCustomerCustomer class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentCustomerCustomer({String? customerId, String? customerNumber, String? officeLocationId, String? officeLocation, String? departmentId, String? department, String? customerTypeId, String? customerType, String? customerCategoryId, String? customerCategory, String? customer, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? zipCode, String? parentCustomerId, String? parentCustomer, String? phone, String? fax, String? phoneTollFree, String? otherPhone, String? webAddress, String? customerStatusId, String? customerStatus, String? statusAsOf, bool? termsAndConditionsOnFile, String? billingAddressType, String? billToAttention1, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToCountryId, String? billToCountry, String? billToZipCode, String? paymentTermsId, String? paymentTerms, bool? vehicleRentalAgreementComplete, bool? useDiscountTemplate, String? discountTemplateId, String? discountTemplate, String? creditStatusId, String? creditStatus, String? creditStatusThroughDate, bool? creditApplicationOnFile, bool? creditUnlimited, int? creditLimit, int? creditBalance, int? creditAvailable, bool? creditResponsiblePartyOnFile, String? creditResponsibleParty, bool? tradeReferencesVerified, String? tradeReferencesVerifiedBy, String? tradeReferencesVerifiedOn, String? creditCardTypeId, String? creditCardType, int? creditCardLimit, String? creditCardNo, String? creditCardCode, int? creditCardExpirationMonth, int? creditCardExpirationYear, String? creditCardName, bool? creditCardAuthorizationOnFile, bool? insuranceCertificationOnFile, String? insuranceCertificationValidThrough, int? insuranceCoverageLiability, int? insuranceCoverageLiabilityDeductible, int? insuranceCoveragePropertyValue, int? insuranceCoveragePropertyValueDeductible, String? insuranceCompanyId, String? insuranceCompany, String? insuranceAgent, String? insuranceCompanyAddress1, String? insuranceCompanyAddress2, String? insuranceCompanyCity, String? insuranceCompanyState, String? insuranceCompanyZipCode, String? insuranceCompanyCountryId, String? insuranceCompanyCountry, String? insuranceCompanyPhone, String? insuranceCompanyFax, bool? vehicleInsuranceCertficationOnFile, bool? taxable, String? taxStateOfIncorporationId, String? taxStateOfIncorporation, String? taxFederalNo, int? nonTaxableYear, String? nonTaxableCertificateNo, String? nonTaxableCertificateValidThrough, bool? nonTaxableCertificateOnFile, bool? disableQuoteOrderActivity, bool? disableRental, bool? disableSales, bool? disableFacilities, bool? disableTransportation, bool? disableLabor, bool? disableMisc, bool? disableRentalSale, bool? disableSubRental, bool? disableSubSale, bool? disableSubLabor, bool? disableSubMisc, bool? splitRental, bool? splitRentalTaxCustomer, int? ownedEquipmentSplitRentalPerecent, int? subRentalEquipmentSplitRentalPerecent, bool? rebateRental, int? ownedEquipmentRebateRentalPerecent, int? subRentalEquipmentRebateRentalPerecent, String? splitRentalLogoFileName, int? splitRentalLogoWidth, int? splitRentalLogoHeight, String? shippingAddressType, String? shipAttention, String? shipAddress1, String? shipAddress2, String? shipCity, String? shipState, String? shipCountryId, String? shipCountry, String? shipZipCode, String? email, bool? multipleCurrencies, String? currencyId, String? currencyCode, String? currencySymbol, double? securityDepositAmount, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesAgentCustomerCustomer.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address1 → String?
-
final
- address2 → String?
-
final
- auditNote → String?
-
final
- billingAddressType → String?
-
final
- billToAddress1 → String?
-
final
- billToAddress2 → String?
-
final
- billToAttention1 → String?
-
final
- billToAttention2 → String?
-
final
- billToCity → String?
-
final
- billToCountry → String?
-
final
- billToCountryId → String?
-
final
- billToState → String?
-
final
- billToZipCode → String?
-
final
- city → String?
-
final
- country → String?
-
final
- countryId → String?
-
final
- creditApplicationOnFile → bool?
-
final
- creditAvailable → int?
-
final
- creditBalance → int?
-
final
- creditCardAuthorizationOnFile → bool?
-
final
- creditCardCode → String?
-
final
- creditCardExpirationMonth → int?
-
final
- creditCardExpirationYear → int?
-
final
- creditCardLimit → int?
-
final
- creditCardName → String?
-
final
- creditCardNo → String?
-
final
- creditCardType → String?
-
final
- creditCardTypeId → String?
-
final
- creditLimit → int?
-
final
- creditResponsibleParty → String?
-
final
- creditResponsiblePartyOnFile → bool?
-
final
- creditStatus → String?
-
final
- creditStatusId → String?
-
final
- creditStatusThroughDate → String?
-
final
- creditUnlimited → bool?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerCategory → String?
-
final
- customerCategoryId → String?
-
final
- customerId → String?
-
final
- customerNumber → String?
-
final
- customerStatus → String?
-
final
- customerStatusId → String?
-
final
- customerType → String?
-
final
- customerTypeId → String?
-
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
- disableFacilities → bool?
-
final
- disableLabor → bool?
-
final
- disableMisc → bool?
-
final
- disableQuoteOrderActivity → bool?
-
final
- disableRental → bool?
-
final
- disableRentalSale → bool?
-
final
- disableSales → bool?
-
final
- disableSubLabor → bool?
-
final
- disableSubMisc → bool?
-
final
- disableSubRental → bool?
-
final
- disableSubSale → bool?
-
final
- disableTransportation → bool?
-
final
- discountTemplate → String?
-
final
- discountTemplateId → String?
-
final
- email → String?
-
final
- fax → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactive → bool?
-
final
- insuranceAgent → String?
-
final
- insuranceCertificationOnFile → bool?
-
final
- insuranceCertificationValidThrough → String?
-
final
- insuranceCompany → String?
-
final
- insuranceCompanyAddress1 → String?
-
final
- insuranceCompanyAddress2 → String?
-
final
- insuranceCompanyCity → String?
-
final
- insuranceCompanyCountry → String?
-
final
- insuranceCompanyCountryId → String?
-
final
- insuranceCompanyFax → String?
-
final
- insuranceCompanyId → String?
-
final
- insuranceCompanyPhone → String?
-
final
- insuranceCompanyState → String?
-
final
- insuranceCompanyZipCode → String?
-
final
- insuranceCoverageLiability → int?
-
final
- insuranceCoverageLiabilityDeductible → int?
-
final
- insuranceCoveragePropertyValue → int?
-
final
- insuranceCoveragePropertyValueDeductible → int?
-
final
- multipleCurrencies → bool?
-
final
- nonTaxableCertificateNo → String?
-
final
- nonTaxableCertificateOnFile → bool?
-
final
- nonTaxableCertificateValidThrough → String?
-
final
- nonTaxableYear → int?
-
final
- officeLocation → String?
-
final
- officeLocationId → String?
-
final
- otherPhone → String?
-
final
- ownedEquipmentRebateRentalPerecent → int?
-
final
- ownedEquipmentSplitRentalPerecent → int?
-
final
- parentCustomer → String?
-
final
- parentCustomerId → String?
-
final
- paymentTerms → String?
-
final
- paymentTermsId → String?
-
final
- phone → String?
-
final
- phoneTollFree → String?
-
final
- rebateRental → bool?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityDepositAmount → double?
-
final
- shipAddress1 → String?
-
final
- shipAddress2 → String?
-
final
- shipAttention → String?
-
final
- shipCity → String?
-
final
- shipCountry → String?
-
final
- shipCountryId → String?
-
final
- shippingAddressType → String?
-
final
- shipState → String?
-
final
- shipZipCode → String?
-
final
- splitRental → bool?
-
final
- splitRentalLogoFileName → String?
-
final
- splitRentalLogoHeight → int?
-
final
- splitRentalLogoWidth → int?
-
final
- splitRentalTaxCustomer → bool?
-
final
- state → String?
-
final
- statusAsOf → String?
-
final
- subRentalEquipmentRebateRentalPerecent → int?
-
final
- subRentalEquipmentSplitRentalPerecent → int?
-
final
- taxable → bool?
-
final
- taxFederalNo → String?
-
final
- taxStateOfIncorporation → String?
-
final
- taxStateOfIncorporationId → String?
-
final
- termsAndConditionsOnFile → bool?
-
final
- tradeReferencesVerified → bool?
-
final
- tradeReferencesVerifiedBy → String?
-
final
- tradeReferencesVerifiedOn → String?
-
final
- useDiscountTemplate → bool?
-
final
- vehicleInsuranceCertficationOnFile → bool?
-
final
- vehicleRentalAgreementComplete → bool?
-
final
- webAddress → String?
-
final
- zipCode → String?
-
final
Methods
-
copyWith(
{String? customerId, String? customerNumber, String? officeLocationId, String? officeLocation, String? departmentId, String? department, String? customerTypeId, String? customerType, String? customerCategoryId, String? customerCategory, String? customer, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? zipCode, String? parentCustomerId, String? parentCustomer, String? phone, String? fax, String? phoneTollFree, String? otherPhone, String? webAddress, String? customerStatusId, String? customerStatus, String? statusAsOf, bool? termsAndConditionsOnFile, String? billingAddressType, String? billToAttention1, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToCountryId, String? billToCountry, String? billToZipCode, String? paymentTermsId, String? paymentTerms, bool? vehicleRentalAgreementComplete, bool? useDiscountTemplate, String? discountTemplateId, String? discountTemplate, String? creditStatusId, String? creditStatus, String? creditStatusThroughDate, bool? creditApplicationOnFile, bool? creditUnlimited, int? creditLimit, int? creditBalance, int? creditAvailable, bool? creditResponsiblePartyOnFile, String? creditResponsibleParty, bool? tradeReferencesVerified, String? tradeReferencesVerifiedBy, String? tradeReferencesVerifiedOn, String? creditCardTypeId, String? creditCardType, int? creditCardLimit, String? creditCardNo, String? creditCardCode, int? creditCardExpirationMonth, int? creditCardExpirationYear, String? creditCardName, bool? creditCardAuthorizationOnFile, bool? insuranceCertificationOnFile, String? insuranceCertificationValidThrough, int? insuranceCoverageLiability, int? insuranceCoverageLiabilityDeductible, int? insuranceCoveragePropertyValue, int? insuranceCoveragePropertyValueDeductible, String? insuranceCompanyId, String? insuranceCompany, String? insuranceAgent, String? insuranceCompanyAddress1, String? insuranceCompanyAddress2, String? insuranceCompanyCity, String? insuranceCompanyState, String? insuranceCompanyZipCode, String? insuranceCompanyCountryId, String? insuranceCompanyCountry, String? insuranceCompanyPhone, String? insuranceCompanyFax, bool? vehicleInsuranceCertficationOnFile, bool? taxable, String? taxStateOfIncorporationId, String? taxStateOfIncorporation, String? taxFederalNo, int? nonTaxableYear, String? nonTaxableCertificateNo, String? nonTaxableCertificateValidThrough, bool? nonTaxableCertificateOnFile, bool? disableQuoteOrderActivity, bool? disableRental, bool? disableSales, bool? disableFacilities, bool? disableTransportation, bool? disableLabor, bool? disableMisc, bool? disableRentalSale, bool? disableSubRental, bool? disableSubSale, bool? disableSubLabor, bool? disableSubMisc, bool? splitRental, bool? splitRentalTaxCustomer, int? ownedEquipmentSplitRentalPerecent, int? subRentalEquipmentSplitRentalPerecent, bool? rebateRental, int? ownedEquipmentRebateRentalPerecent, int? subRentalEquipmentRebateRentalPerecent, String? splitRentalLogoFileName, int? splitRentalLogoWidth, int? splitRentalLogoHeight, String? shippingAddressType, String? shipAttention, String? shipAddress1, String? shipAddress2, String? shipCity, String? shipState, String? shipCountryId, String? shipCountry, String? shipZipCode, String? email, bool? multipleCurrencies, String? currencyId, String? currencyCode, String? currencySymbol, double? securityDepositAmount, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesAgentCustomerCustomer -
Available on WebApiModulesAgentCustomerCustomer, provided by the $WebApiModulesAgentCustomerCustomerExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentCustomerCustomer Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentCustomerCustomer instance)