WebApiModulesAgentDealDeal class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentDealDeal({String? dealId, String? deal, String? dealNumber, String? customerId, String? customer, String? customerNumber, String? officeLocationId, String? officeLocation, String? dealTypeId, String? dealType, String? address1, String? address2, String? city, String? state, String? zipCode, String? countryId, String? country, String? phone, String? phoneTollFree, String? fax, String? phoneOther, String? departmentId, String? department, String? csrId, String? csr, String? defaultAgentId, String? defaultAgent, String? defaultProjectManagerId, String? defaultProjectManager, String? dealClassificationId, String? dealClassification, String? productionTypeId, String? productionType, String? dealStatusId, String? dealStatus, String? statusAsOf, String? expectedWrapDate, String? billingCycleId, String? billingCycle, String? paymentTermsId, String? paymentTerms, String? paymentTypeId, String? paymentType, String? defaultRate, bool? multipleCurrencies, String? currencyId, String? currencyCode, String? currencySymbol, bool? useCustomerDiscount, String? customerDiscountTemplateId, bool? useDiscountTemplate, String? discountTemplateId, String? discountTemplate, double? rentalDaysPerWeek, double? rentalDiscountPercent, double? salesDiscountPercent, double? facilitiesDaysPerWeek, double? facilitiesDiscountPercent, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, double? commissionRate, bool? commissionIncludesVendorItems, bool? poRequired, String? poType, String? billToAddressType, String? billToAttention1, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToCountryId, String? billToCountry, String? billToZipCode, bool? assessFinanceCharge, bool? allowBillingScheduleOverride, bool? allowRebateCreditInvoices, bool? useCustomerCredit, String? creditStatusId, String? creditStatus, String? creditStatusThrough, bool? creditApplicationOnFile, bool? unlimitedCredit, int? creditLimit, int? creditBalance, int? creditAvailable, int? customerCreditLimit, int? customerCreditBalance, int? customerCreditAvailable, bool? creditResponsiblePartyOnFile, String? creditResponsibleParty, bool? tradeReferencesVerified, String? tradeReferencesVerifiedBy, String? tradeReferencesVerifiedOn, String? creditCardTypeId, String? creditCardType, int? creditCardLimit, String? creditCardNumber, String? creditCardCode, String? creditCardName, int? creditCardExpirationMonth, int? creditCardExpirationYear, bool? creditCardAuthorizationFormOnFile, double? depletingDepositThresholdAmount, int? depletingDepositThresholdPercent, double? depletingDepositTotal, double? depletingDepositApplied, double? depletingDepositRemaining, bool? useCustomerInsurance, bool? insuranceCertification, String? insuranceCertificationValidThrough, int? insuranceCoverageLiability, int? insuranceCoverageLiabilityDeductible, int? insuranceCoverageProperty, int? insuranceCoveragePropertyDeductible, double? securityDepositAmount, String? insuranceCompanyId, String? insuranceCompany, String? insuranceCompanyAgent, String? insuranceCompanyAddress1, String? insuranceCompanyAddress2, String? insuranceCompanyCity, String? insuranceCompanyState, String? insuranceCompanyZipCode, String? insuranceCompanyCountryId, String? insuranceCompanyCountry, String? insuranceCompanyPhone, String? insuranceCompanyFax, bool? vehicleInsuranceCertification, bool? useCustomerTax, bool? taxable, String? taxStateOfIncorporationId, String? taxStateOfIncorporation, String? taxFederalNo, int? nonTaxableYear, String? nonTaxableCertificateNo, String? nonTaxableCertificateValidThrough, bool? nonTaxableCertificateOnFile, bool? disableQuoteOrderActivity, bool? disableRental, bool? disableSales, bool? disableFacilities, bool? disableTransportation, bool? disableLabor, bool? disableMisc, bool? disableRentalSale, bool? disableSubRental, bool? disableSubSale, bool? disableSubLabor, bool? disableSubMisc, String? defaultOutgoingDeliveryType, String? defaultIncomingDeliveryType, String? shippingAddressType, String? shipAttention, String? shipAddress1, String? shipAddress2, String? shipCity, String? shipState, String? shipCountryId, String? shipCountry, String? shipZipCode, bool? rebateRental, String? rebateCustomerId, String? rebateCustomer, int? ownedEquipmentRebateRentalPerecent, int? subRentalEquipmentRebateRentalPerecent, bool? enableWebQuoteRequest, String? email, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesAgentDealDeal.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address1 → String?
-
final
- address2 → String?
-
final
- allowBillingScheduleOverride → bool?
-
final
- allowRebateCreditInvoices → bool?
-
final
- assessFinanceCharge → bool?
-
final
- auditNote → String?
-
final
- billingCycle → String?
-
final
- billingCycleId → String?
-
final
- billToAddress1 → String?
-
final
- billToAddress2 → String?
-
final
- billToAddressType → String?
-
final
- billToAttention1 → String?
-
final
- billToAttention2 → String?
-
final
- billToCity → String?
-
final
- billToCountry → String?
-
final
- billToCountryId → String?
-
final
- billToState → String?
-
final
- billToZipCode → String?
-
final
- city → String?
-
final
- commissionIncludesVendorItems → bool?
-
final
- commissionRate → double?
-
final
- country → String?
-
final
- countryId → String?
-
final
- creditApplicationOnFile → bool?
-
final
- creditAvailable → int?
-
final
- creditBalance → int?
-
final
- creditCardAuthorizationFormOnFile → bool?
-
final
- creditCardCode → String?
-
final
- creditCardExpirationMonth → int?
-
final
- creditCardExpirationYear → int?
-
final
- creditCardLimit → int?
-
final
- creditCardName → String?
-
final
- creditCardNumber → String?
-
final
- creditCardType → String?
-
final
- creditCardTypeId → String?
-
final
- creditLimit → int?
-
final
- creditResponsibleParty → String?
-
final
- creditResponsiblePartyOnFile → bool?
-
final
- creditStatus → String?
-
final
- creditStatusId → String?
-
final
- creditStatusThrough → String?
-
final
- csr → String?
-
final
- csrId → String?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerCreditAvailable → int?
-
final
- customerCreditBalance → int?
-
final
- customerCreditLimit → int?
-
final
- customerDiscountTemplateId → String?
-
final
- customerId → String?
-
final
- customerNumber → String?
-
final
- dateStamp → String?
-
final
- deal → String?
-
final
- dealClassification → String?
-
final
- dealClassificationId → String?
-
final
- dealId → String?
-
final
- dealNumber → String?
-
final
- dealStatus → String?
-
final
- dealStatusId → String?
-
final
- dealType → String?
-
final
- dealTypeId → String?
-
final
- defaultAgent → String?
-
final
- defaultAgentId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultIncomingDeliveryType → String?
-
final
- defaultOutgoingDeliveryType → String?
-
final
- defaultProjectManager → String?
-
final
- defaultProjectManagerId → String?
-
final
- defaultRate → String?
-
final
- department → String?
-
final
- departmentId → String?
-
final
- depletingDepositApplied → double?
-
final
- depletingDepositRemaining → double?
-
final
- depletingDepositThresholdAmount → double?
-
final
- depletingDepositThresholdPercent → int?
-
final
- depletingDepositTotal → double?
-
final
- disableFacilities → bool?
-
final
- disableLabor → bool?
-
final
- disableMisc → bool?
-
final
- disableQuoteOrderActivity → bool?
-
final
- disableRental → bool?
-
final
- disableRentalSale → bool?
-
final
- disableSales → bool?
-
final
- disableSubLabor → bool?
-
final
- disableSubMisc → bool?
-
final
- disableSubRental → bool?
-
final
- disableSubSale → bool?
-
final
- disableTransportation → bool?
-
final
- discountTemplate → String?
-
final
- discountTemplateId → String?
-
final
- email → String?
-
final
- enableWebQuoteRequest → bool?
-
final
- expectedWrapDate → String?
-
final
- facilitiesDaysPerWeek → double?
-
final
- facilitiesDiscountPercent → double?
-
final
- fax → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- insuranceCertification → bool?
-
final
- insuranceCertificationValidThrough → String?
-
final
- insuranceCompany → String?
-
final
- insuranceCompanyAddress1 → String?
-
final
- insuranceCompanyAddress2 → String?
-
final
- insuranceCompanyAgent → String?
-
final
- insuranceCompanyCity → String?
-
final
- insuranceCompanyCountry → String?
-
final
- insuranceCompanyCountryId → String?
-
final
- insuranceCompanyFax → String?
-
final
- insuranceCompanyId → String?
-
final
- insuranceCompanyPhone → String?
-
final
- insuranceCompanyState → String?
-
final
- insuranceCompanyZipCode → String?
-
final
- insuranceCoverageLiability → int?
-
final
- insuranceCoverageLiabilityDeductible → int?
-
final
- insuranceCoverageProperty → int?
-
final
- insuranceCoveragePropertyDeductible → int?
-
final
- multipleCurrencies → bool?
-
final
- nonTaxableCertificateNo → String?
-
final
- nonTaxableCertificateOnFile → bool?
-
final
- nonTaxableCertificateValidThrough → String?
-
final
- nonTaxableYear → int?
-
final
- officeLocation → String?
-
final
- officeLocationId → String?
-
final
- outsideSalesRepresentative → String?
-
final
- outsideSalesRepresentativeId → String?
-
final
- ownedEquipmentRebateRentalPerecent → int?
-
final
- paymentTerms → String?
-
final
- paymentTermsId → String?
-
final
- paymentType → String?
-
final
- paymentTypeId → String?
-
final
- phone → String?
-
final
- phoneOther → String?
-
final
- phoneTollFree → String?
-
final
- poRequired → bool?
-
final
- poType → String?
-
final
- productionType → String?
-
final
- productionTypeId → String?
-
final
- rebateCustomer → String?
-
final
- rebateCustomerId → String?
-
final
- rebateRental → bool?
-
final
- recordTitle → String?
-
final
- rentalDaysPerWeek → double?
-
final
- rentalDiscountPercent → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesDiscountPercent → double?
-
final
- securityDepositAmount → double?
-
final
- shipAddress1 → String?
-
final
- shipAddress2 → String?
-
final
- shipAttention → String?
-
final
- shipCity → String?
-
final
- shipCountry → String?
-
final
- shipCountryId → String?
-
final
- shippingAddressType → String?
-
final
- shipState → String?
-
final
- shipZipCode → String?
-
final
- state → String?
-
final
- statusAsOf → String?
-
final
- subRentalEquipmentRebateRentalPerecent → int?
-
final
- taxable → bool?
-
final
- taxFederalNo → String?
-
final
- taxStateOfIncorporation → String?
-
final
- taxStateOfIncorporationId → String?
-
final
- tradeReferencesVerified → bool?
-
final
- tradeReferencesVerifiedBy → String?
-
final
- tradeReferencesVerifiedOn → String?
-
final
- unlimitedCredit → bool?
-
final
- useCustomerCredit → bool?
-
final
- useCustomerDiscount → bool?
-
final
- useCustomerInsurance → bool?
-
final
- useCustomerTax → bool?
-
final
- useDiscountTemplate → bool?
-
final
- vehicleInsuranceCertification → bool?
-
final
- zipCode → String?
-
final
Methods
-
copyWith(
{String? dealId, String? deal, String? dealNumber, String? customerId, String? customer, String? customerNumber, String? officeLocationId, String? officeLocation, String? dealTypeId, String? dealType, String? address1, String? address2, String? city, String? state, String? zipCode, String? countryId, String? country, String? phone, String? phoneTollFree, String? fax, String? phoneOther, String? departmentId, String? department, String? csrId, String? csr, String? defaultAgentId, String? defaultAgent, String? defaultProjectManagerId, String? defaultProjectManager, String? dealClassificationId, String? dealClassification, String? productionTypeId, String? productionType, String? dealStatusId, String? dealStatus, String? statusAsOf, String? expectedWrapDate, String? billingCycleId, String? billingCycle, String? paymentTermsId, String? paymentTerms, String? paymentTypeId, String? paymentType, String? defaultRate, bool? multipleCurrencies, String? currencyId, String? currencyCode, String? currencySymbol, bool? useCustomerDiscount, String? customerDiscountTemplateId, bool? useDiscountTemplate, String? discountTemplateId, String? discountTemplate, double? rentalDaysPerWeek, double? rentalDiscountPercent, double? salesDiscountPercent, double? facilitiesDaysPerWeek, double? facilitiesDiscountPercent, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, double? commissionRate, bool? commissionIncludesVendorItems, bool? poRequired, String? poType, String? billToAddressType, String? billToAttention1, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToCountryId, String? billToCountry, String? billToZipCode, bool? assessFinanceCharge, bool? allowBillingScheduleOverride, bool? allowRebateCreditInvoices, bool? useCustomerCredit, String? creditStatusId, String? creditStatus, String? creditStatusThrough, bool? creditApplicationOnFile, bool? unlimitedCredit, int? creditLimit, int? creditBalance, int? creditAvailable, int? customerCreditLimit, int? customerCreditBalance, int? customerCreditAvailable, bool? creditResponsiblePartyOnFile, String? creditResponsibleParty, bool? tradeReferencesVerified, String? tradeReferencesVerifiedBy, String? tradeReferencesVerifiedOn, String? creditCardTypeId, String? creditCardType, int? creditCardLimit, String? creditCardNumber, String? creditCardCode, String? creditCardName, int? creditCardExpirationMonth, int? creditCardExpirationYear, bool? creditCardAuthorizationFormOnFile, double? depletingDepositThresholdAmount, int? depletingDepositThresholdPercent, double? depletingDepositTotal, double? depletingDepositApplied, double? depletingDepositRemaining, bool? useCustomerInsurance, bool? insuranceCertification, String? insuranceCertificationValidThrough, int? insuranceCoverageLiability, int? insuranceCoverageLiabilityDeductible, int? insuranceCoverageProperty, int? insuranceCoveragePropertyDeductible, double? securityDepositAmount, String? insuranceCompanyId, String? insuranceCompany, String? insuranceCompanyAgent, String? insuranceCompanyAddress1, String? insuranceCompanyAddress2, String? insuranceCompanyCity, String? insuranceCompanyState, String? insuranceCompanyZipCode, String? insuranceCompanyCountryId, String? insuranceCompanyCountry, String? insuranceCompanyPhone, String? insuranceCompanyFax, bool? vehicleInsuranceCertification, bool? useCustomerTax, bool? taxable, String? taxStateOfIncorporationId, String? taxStateOfIncorporation, String? taxFederalNo, int? nonTaxableYear, String? nonTaxableCertificateNo, String? nonTaxableCertificateValidThrough, bool? nonTaxableCertificateOnFile, bool? disableQuoteOrderActivity, bool? disableRental, bool? disableSales, bool? disableFacilities, bool? disableTransportation, bool? disableLabor, bool? disableMisc, bool? disableRentalSale, bool? disableSubRental, bool? disableSubSale, bool? disableSubLabor, bool? disableSubMisc, String? defaultOutgoingDeliveryType, String? defaultIncomingDeliveryType, String? shippingAddressType, String? shipAttention, String? shipAddress1, String? shipAddress2, String? shipCity, String? shipState, String? shipCountryId, String? shipCountry, String? shipZipCode, bool? rebateRental, String? rebateCustomerId, String? rebateCustomer, int? ownedEquipmentRebateRentalPerecent, int? subRentalEquipmentRebateRentalPerecent, bool? enableWebQuoteRequest, String? email, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesAgentDealDeal -
Available on WebApiModulesAgentDealDeal, provided by the $WebApiModulesAgentDealDealExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentDealDeal Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentDealDeal instance)