WebApiModulesAgentDealDealDocument class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentDealDealDocument({String? dealId, bool? copying, String? documentId, String? documentTypeId, String? uniqueId1, String? uniqueId2, int? uniqueId1Int, String? description, String? inputByUsersId, String? attachDate, String? attachTime, bool? attachToEmail, bool? inactive, String? dateStamp, String? extension, String? documentType, String? inputBy, bool? hasImage, bool? hasFile, int? appImageCount, bool? fileIsModified, String? fileDataUrl, String? filePath, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesAgentDealDealDocument.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appImageCount → int?
-
final
- attachDate → String?
-
final
- attachTime → String?
-
final
- attachToEmail → bool?
-
final
- auditNote → String?
-
final
- copying → bool?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
- documentId → String?
-
final
- documentType → String?
-
final
- documentTypeId → String?
-
final
- extension → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fileDataUrl → String?
-
final
- fileIsModified → bool?
-
final
- filePath → String?
-
final
- hasFile → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImage → bool?
-
final
- inactive → bool?
-
final
- inputBy → String?
-
final
- inputByUsersId → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uniqueId1 → String?
-
final
- uniqueId1Int → int?
-
final
- uniqueId2 → String?
-
final
Methods
-
copyWith(
{String? dealId, bool? copying, String? documentId, String? documentTypeId, String? uniqueId1, String? uniqueId2, int? uniqueId1Int, String? description, String? inputByUsersId, String? attachDate, String? attachTime, bool? attachToEmail, bool? inactive, String? dateStamp, String? extension, String? documentType, String? inputBy, bool? hasImage, bool? hasFile, int? appImageCount, bool? fileIsModified, String? fileDataUrl, String? filePath, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesAgentDealDealDocument -
Available on WebApiModulesAgentDealDealDocument, provided by the $WebApiModulesAgentDealDealDocumentExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentDealDealDocument Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentDealDealDocument instance)