WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest({String? sourceOrderId, String? sessionId, String? defaultRate})
-
const
-
WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- defaultRate → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- sourceOrderId → String?
-
final
Methods
-
copyWith(
{String? sourceOrderId, String? sessionId, String? defaultRate}) → WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest -
Available on WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest, provided by the $WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? sourceOrderId, Wrapped<String?> ? sessionId, Wrapped<String?> ? defaultRate}) → WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest -
Available on WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest, provided by the $WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentLossAndDamageCompleteLossAndDamageSessionRequest instance)