WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequest({required String orderId, required String locationId, required String warehouseId, String? sessionId})
const
WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
locationId String
final
orderId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
warehouseId String
final

Methods

copyWith({String? orderId, String? locationId, String? warehouseId, String? sessionId}) WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequest

Available on WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequest, provided by the $WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequestExtension extension

copyWithWrapped({Wrapped<String>? orderId, Wrapped<String>? locationId, Wrapped<String>? warehouseId, Wrapped<String?>? sessionId}) WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequest

Available on WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequest, provided by the $WebApiModulesAgentLossAndDamageRetireLossAndDamageItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override