WebApiModulesAgentOrderCopyQuoteOrderRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentOrderCopyQuoteOrderRequest({required String copyToType, String? locationId, String? warehouseId, String? newDescription, String? pickDate, String? pickTime, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, bool? copyLineItemUnitCosts, bool? copyWithUserSelectedDates, bool? copyLineItemNotes, bool? useCurrentPricing, bool? copyOrderNotes, bool? combineSubs, bool? copyDocuments, bool? copyCarrierShipVia, bool? useCurrentDealTax})
-
const
-
WebApiModulesAgentOrderCopyQuoteOrderRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- combineSubs → bool?
-
final
- copyCarrierShipVia → bool?
-
final
- copyDocuments → bool?
-
final
- copyLineItemNotes → bool?
-
final
- copyLineItemUnitCosts → bool?
-
final
- copyOrderNotes → bool?
-
final
- copyToType → String
-
final
- copyWithUserSelectedDates → bool?
-
final
- estimatedStartDate → String?
-
final
- estimatedStartTime → String?
-
final
- estimatedStopDate → String?
-
final
- estimatedStopTime → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- locationId → String?
-
final
- newDescription → String?
-
final
- pickDate → String?
-
final
- pickTime → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useCurrentDealTax → bool?
-
final
- useCurrentPricing → bool?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? copyToType, String? locationId, String? warehouseId, String? newDescription, String? pickDate, String? pickTime, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, bool? copyLineItemUnitCosts, bool? copyWithUserSelectedDates, bool? copyLineItemNotes, bool? useCurrentPricing, bool? copyOrderNotes, bool? combineSubs, bool? copyDocuments, bool? copyCarrierShipVia, bool? useCurrentDealTax}) → WebApiModulesAgentOrderCopyQuoteOrderRequest -
Available on WebApiModulesAgentOrderCopyQuoteOrderRequest, provided by the $WebApiModulesAgentOrderCopyQuoteOrderRequestExtension extension
-
copyWithWrapped(
{Wrapped< String> ? copyToType, Wrapped<String?> ? locationId, Wrapped<String?> ? warehouseId, Wrapped<String?> ? newDescription, Wrapped<String?> ? pickDate, Wrapped<String?> ? pickTime, Wrapped<String?> ? estimatedStartDate, Wrapped<String?> ? estimatedStartTime, Wrapped<String?> ? estimatedStopDate, Wrapped<String?> ? estimatedStopTime, Wrapped<bool?> ? copyLineItemUnitCosts, Wrapped<bool?> ? copyWithUserSelectedDates, Wrapped<bool?> ? copyLineItemNotes, Wrapped<bool?> ? useCurrentPricing, Wrapped<bool?> ? copyOrderNotes, Wrapped<bool?> ? combineSubs, Wrapped<bool?> ? copyDocuments, Wrapped<bool?> ? copyCarrierShipVia, Wrapped<bool?> ? useCurrentDealTax}) → WebApiModulesAgentOrderCopyQuoteOrderRequest -
Available on WebApiModulesAgentOrderCopyQuoteOrderRequest, provided by the $WebApiModulesAgentOrderCopyQuoteOrderRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderCopyQuoteOrderRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderCopyQuoteOrderRequest instance)