WebApiModulesAgentOrderCrewHoursPerDay class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentOrderCrewHoursPerDay({String? scheduleDate, double? scheduleHours})
const
WebApiModulesAgentOrderCrewHoursPerDay.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleDate String?
final
scheduleHours double?
final

Methods

copyWith({String? scheduleDate, double? scheduleHours}) WebApiModulesAgentOrderCrewHoursPerDay

Available on WebApiModulesAgentOrderCrewHoursPerDay, provided by the $WebApiModulesAgentOrderCrewHoursPerDayExtension extension

copyWithWrapped({Wrapped<String?>? scheduleDate, Wrapped<double?>? scheduleHours}) WebApiModulesAgentOrderCrewHoursPerDay

Available on WebApiModulesAgentOrderCrewHoursPerDay, provided by the $WebApiModulesAgentOrderCrewHoursPerDayExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAgentOrderCrewHoursPerDay Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAgentOrderCrewHoursPerDay instance)