WebApiModulesAgentOrderCrewWorkWeek class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentOrderCrewWorkWeek({bool? monday, bool? tuesday, bool? wednesday, bool? thursday, bool? friday, bool? saturday, bool? sunday, double? hoursPerDay, double? crewHoursOT, double? crewHoursDT, String? orderId})
-
const
-
WebApiModulesAgentOrderCrewWorkWeek.fromJson(Map<
String, dynamic> json) -
factory
Properties
- crewHoursDT → double?
-
final
- crewHoursOT → double?
-
final
- friday → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hoursPerDay → double?
-
final
- monday → bool?
-
final
- orderId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saturday → bool?
-
final
- sunday → bool?
-
final
- thursday → bool?
-
final
- tuesday → bool?
-
final
- wednesday → bool?
-
final
Methods
-
copyWith(
{bool? monday, bool? tuesday, bool? wednesday, bool? thursday, bool? friday, bool? saturday, bool? sunday, double? hoursPerDay, double? crewHoursOT, double? crewHoursDT, String? orderId}) → WebApiModulesAgentOrderCrewWorkWeek -
Available on WebApiModulesAgentOrderCrewWorkWeek, provided by the $WebApiModulesAgentOrderCrewWorkWeekExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? monday, Wrapped<bool?> ? tuesday, Wrapped<bool?> ? wednesday, Wrapped<bool?> ? thursday, Wrapped<bool?> ? friday, Wrapped<bool?> ? saturday, Wrapped<bool?> ? sunday, Wrapped<double?> ? hoursPerDay, Wrapped<double?> ? crewHoursOT, Wrapped<double?> ? crewHoursDT, Wrapped<String?> ? orderId}) → WebApiModulesAgentOrderCrewWorkWeek -
Available on WebApiModulesAgentOrderCrewWorkWeek, provided by the $WebApiModulesAgentOrderCrewWorkWeekExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderCrewWorkWeek Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderCrewWorkWeek instance)