WebApiModulesAgentOrderItemInsertLineItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentOrderItemInsertLineItemRequest({String? orderId, String? aboveOrderItemId, String? belowOrderItemId, String? primaryItemId})
const
WebApiModulesAgentOrderItemInsertLineItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

aboveOrderItemId String?
final
belowOrderItemId String?
final
hashCode int
The hash code for this object.
no setteroverride
orderId String?
final
primaryItemId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? orderId, String? aboveOrderItemId, String? belowOrderItemId, String? primaryItemId}) WebApiModulesAgentOrderItemInsertLineItemRequest

Available on WebApiModulesAgentOrderItemInsertLineItemRequest, provided by the $WebApiModulesAgentOrderItemInsertLineItemRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? aboveOrderItemId, Wrapped<String?>? belowOrderItemId, Wrapped<String?>? primaryItemId}) WebApiModulesAgentOrderItemInsertLineItemRequest

Available on WebApiModulesAgentOrderItemInsertLineItemRequest, provided by the $WebApiModulesAgentOrderItemInsertLineItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override