WebApiModulesAgentOrderItemInsertOptionRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentOrderItemInsertOptionRequest({String? orderId, String? parentOrderItemId, List<
WebApiModulesAgentOrderItemCompleteKitOption> ? items}) -
const
-
WebApiModulesAgentOrderItemInsertOptionRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
WebApiModulesAgentOrderItemCompleteKitOption> ? -
final
- orderId → String?
-
final
- parentOrderItemId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? orderId, String? parentOrderItemId, List< WebApiModulesAgentOrderItemCompleteKitOption> ? items}) → WebApiModulesAgentOrderItemInsertOptionRequest -
Available on WebApiModulesAgentOrderItemInsertOptionRequest, provided by the $WebApiModulesAgentOrderItemInsertOptionRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? orderId, Wrapped<String?> ? parentOrderItemId, Wrapped<List< ? items}) → WebApiModulesAgentOrderItemInsertOptionRequestWebApiModulesAgentOrderItemCompleteKitOption> ?> -
Available on WebApiModulesAgentOrderItemInsertOptionRequest, provided by the $WebApiModulesAgentOrderItemInsertOptionRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderItemInsertOptionRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderItemInsertOptionRequest instance)