WebApiModulesAgentOrderItemOrderItemDefaultRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentOrderItemOrderItemDefaultRequest({String? inventoryId, String? classification, String? recType, String? orderType, String? orderId, String? warehouseId, String? rateType, String? orderTypeId, bool? nonTaxable, double? rentalTaxRate1, bool? rentalExempt, double? salesTaxRate1, bool? salesExempt, double? laborTaxRate1, bool? laborExempt, bool? consignment, String? poTypeId, String? vendorId, bool? isSub, bool? useEstimatedDatesForBilling, String? estimatedStartDate, String? estimatedStopDate, double? quantityOrdered, double? hours, double? hoursOvertime, double? hoursDoubletime, double? daysPerWeek, String? locationId, String? currencyId, double? replacementCost})
const
WebApiModulesAgentOrderItemOrderItemDefaultRequest.fromJson(Map<String, dynamic> json)
factory

Properties

classification String?
final
consignment bool?
final
currencyId String?
final
daysPerWeek double?
final
estimatedStartDate String?
final
estimatedStopDate String?
final
hashCode int
The hash code for this object.
no setteroverride
hours double?
final
hoursDoubletime double?
final
hoursOvertime double?
final
inventoryId String?
final
isSub bool?
final
laborExempt bool?
final
laborTaxRate1 double?
final
locationId String?
final
nonTaxable bool?
final
orderId String?
final
orderType String?
final
orderTypeId String?
final
poTypeId String?
final
quantityOrdered double?
final
rateType String?
final
recType String?
final
rentalExempt bool?
final
rentalTaxRate1 double?
final
replacementCost double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesExempt bool?
final
salesTaxRate1 double?
final
useEstimatedDatesForBilling bool?
final
vendorId String?
final
warehouseId String?
final

Methods

copyWith({String? inventoryId, String? classification, String? recType, String? orderType, String? orderId, String? warehouseId, String? rateType, String? orderTypeId, bool? nonTaxable, double? rentalTaxRate1, bool? rentalExempt, double? salesTaxRate1, bool? salesExempt, double? laborTaxRate1, bool? laborExempt, bool? consignment, String? poTypeId, String? vendorId, bool? isSub, bool? useEstimatedDatesForBilling, String? estimatedStartDate, String? estimatedStopDate, double? quantityOrdered, double? hours, double? hoursOvertime, double? hoursDoubletime, double? daysPerWeek, String? locationId, String? currencyId, double? replacementCost}) WebApiModulesAgentOrderItemOrderItemDefaultRequest

Available on WebApiModulesAgentOrderItemOrderItemDefaultRequest, provided by the $WebApiModulesAgentOrderItemOrderItemDefaultRequestExtension extension

copyWithWrapped({Wrapped<String?>? inventoryId, Wrapped<String?>? classification, Wrapped<String?>? recType, Wrapped<String?>? orderType, Wrapped<String?>? orderId, Wrapped<String?>? warehouseId, Wrapped<String?>? rateType, Wrapped<String?>? orderTypeId, Wrapped<bool?>? nonTaxable, Wrapped<double?>? rentalTaxRate1, Wrapped<bool?>? rentalExempt, Wrapped<double?>? salesTaxRate1, Wrapped<bool?>? salesExempt, Wrapped<double?>? laborTaxRate1, Wrapped<bool?>? laborExempt, Wrapped<bool?>? consignment, Wrapped<String?>? poTypeId, Wrapped<String?>? vendorId, Wrapped<bool?>? isSub, Wrapped<bool?>? useEstimatedDatesForBilling, Wrapped<String?>? estimatedStartDate, Wrapped<String?>? estimatedStopDate, Wrapped<double?>? quantityOrdered, Wrapped<double?>? hours, Wrapped<double?>? hoursOvertime, Wrapped<double?>? hoursDoubletime, Wrapped<double?>? daysPerWeek, Wrapped<String?>? locationId, Wrapped<String?>? currencyId, Wrapped<double?>? replacementCost}) WebApiModulesAgentOrderItemOrderItemDefaultRequest

Available on WebApiModulesAgentOrderItemOrderItemDefaultRequest, provided by the $WebApiModulesAgentOrderItemOrderItemDefaultRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override