WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequest({String? orderId, String? itemOrder, bool? consolidateOwnedAndSubbedLineItems, bool? setSubQuantityToZero})
const
WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequest.fromJson(Map<String, dynamic> json)
factory

Properties

consolidateOwnedAndSubbedLineItems bool?
final
hashCode int
The hash code for this object.
no setteroverride
itemOrder String?
final
orderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setSubQuantityToZero bool?
final

Methods

copyWith({String? orderId, String? itemOrder, bool? consolidateOwnedAndSubbedLineItems, bool? setSubQuantityToZero}) WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequest

Available on WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequest, provided by the $WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? itemOrder, Wrapped<bool?>? consolidateOwnedAndSubbedLineItems, Wrapped<bool?>? setSubQuantityToZero}) WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequest

Available on WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequest, provided by the $WebApiModulesAgentOrderItemPasteOrderItemsFromClipboardRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override