WebApiModulesAgentOrderItemSplitOrderItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentOrderItemSplitOrderItemRequest({String? orderId, String? orderItemId, double? splitQuantity, double? splitConsignQuantity, bool? splitEntirePackage, bool? separateLine, bool? notYetStagedOnly, bool? stagedOutOnly, bool? outOnly, bool? inOnly, String? consignorId, String? consignorAgreementId, bool? reSortItemsAfterSplit})
const
WebApiModulesAgentOrderItemSplitOrderItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

consignorAgreementId String?
final
consignorId String?
final
hashCode int
The hash code for this object.
no setteroverride
inOnly bool?
final
notYetStagedOnly bool?
final
orderId String?
final
orderItemId String?
final
outOnly bool?
final
reSortItemsAfterSplit bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separateLine bool?
final
splitConsignQuantity double?
final
splitEntirePackage bool?
final
splitQuantity double?
final
stagedOutOnly bool?
final

Methods

copyWith({String? orderId, String? orderItemId, double? splitQuantity, double? splitConsignQuantity, bool? splitEntirePackage, bool? separateLine, bool? notYetStagedOnly, bool? stagedOutOnly, bool? outOnly, bool? inOnly, String? consignorId, String? consignorAgreementId, bool? reSortItemsAfterSplit}) WebApiModulesAgentOrderItemSplitOrderItemRequest

Available on WebApiModulesAgentOrderItemSplitOrderItemRequest, provided by the $WebApiModulesAgentOrderItemSplitOrderItemRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<double?>? splitQuantity, Wrapped<double?>? splitConsignQuantity, Wrapped<bool?>? splitEntirePackage, Wrapped<bool?>? separateLine, Wrapped<bool?>? notYetStagedOnly, Wrapped<bool?>? stagedOutOnly, Wrapped<bool?>? outOnly, Wrapped<bool?>? inOnly, Wrapped<String?>? consignorId, Wrapped<String?>? consignorAgreementId, Wrapped<bool?>? reSortItemsAfterSplit}) WebApiModulesAgentOrderItemSplitOrderItemRequest

Available on WebApiModulesAgentOrderItemSplitOrderItemRequest, provided by the $WebApiModulesAgentOrderItemSplitOrderItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override