WebApiModulesAgentOrderNoteOrderNote class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentOrderNoteOrderNote({String? orderNoteId, String? orderId, String? noteDate, String? userId, String? notesDescription, bool? billing, bool? printOnOrder, bool? copyToInvoice, bool? scheduleNote, String? scheduleNoteDate, bool? pickList, String? userName, String? notes, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAgentOrderNoteOrderNote.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
billing bool?
final
copyToInvoice bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
noteDate String?
final
notes String?
final
notesDescription String?
final
orderId String?
final
orderNoteId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
pickList bool?
final
printOnOrder bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleNote bool?
final
scheduleNoteDate String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userId String?
final
userName String?
final

Methods

copyWith({String? orderNoteId, String? orderId, String? noteDate, String? userId, String? notesDescription, bool? billing, bool? printOnOrder, bool? copyToInvoice, bool? scheduleNote, String? scheduleNoteDate, bool? pickList, String? userName, String? notes, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAgentOrderNoteOrderNote

Available on WebApiModulesAgentOrderNoteOrderNote, provided by the $WebApiModulesAgentOrderNoteOrderNoteExtension extension

copyWithWrapped({Wrapped<String?>? orderNoteId, Wrapped<String?>? orderId, Wrapped<String?>? noteDate, Wrapped<String?>? userId, Wrapped<String?>? notesDescription, Wrapped<bool?>? billing, Wrapped<bool?>? printOnOrder, Wrapped<bool?>? copyToInvoice, Wrapped<bool?>? scheduleNote, Wrapped<String?>? scheduleNoteDate, Wrapped<bool?>? pickList, Wrapped<String?>? userName, Wrapped<String?>? notes, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAgentOrderNoteOrderNote

Available on WebApiModulesAgentOrderNoteOrderNote, provided by the $WebApiModulesAgentOrderNoteOrderNoteExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAgentOrderNoteOrderNote Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAgentOrderNoteOrderNote instance)