WebApiModulesAgentOrderTotals class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentOrderTotals({String? grossTotal, String? premiumTotal, String? discount, String? subTotal, String? tax, String? tax1, String? tax2, String? total})
const
WebApiModulesAgentOrderTotals.fromJson(Map<String, dynamic> json)
factory

Properties

discount String?
final
grossTotal String?
final
hashCode int
The hash code for this object.
no setteroverride
premiumTotal String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTotal String?
final
tax String?
final
tax1 String?
final
tax2 String?
final
total String?
final

Methods

copyWith({String? grossTotal, String? premiumTotal, String? discount, String? subTotal, String? tax, String? tax1, String? tax2, String? total}) WebApiModulesAgentOrderTotals

Available on WebApiModulesAgentOrderTotals, provided by the $WebApiModulesAgentOrderTotalsExtension extension

copyWithWrapped({Wrapped<String?>? grossTotal, Wrapped<String?>? premiumTotal, Wrapped<String?>? discount, Wrapped<String?>? subTotal, Wrapped<String?>? tax, Wrapped<String?>? tax1, Wrapped<String?>? tax2, Wrapped<String?>? total}) WebApiModulesAgentOrderTotals

Available on WebApiModulesAgentOrderTotals, provided by the $WebApiModulesAgentOrderTotalsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAgentOrderTotals Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAgentOrderTotals instance)