WebApiModulesAgentOrderVerifyManualSortItemsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentOrderVerifyManualSortItemsResponse({int? status, bool? success, String? msg, List<
WebApiModulesAgentOrderSortingCorruptionItem> ? itemsWithSortingCorruption}) -
const
-
WebApiModulesAgentOrderVerifyManualSortItemsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
itemsWithSortingCorruption
→ List<
WebApiModulesAgentOrderSortingCorruptionItem> ? -
final
- msg → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- success → bool?
-
final
Methods
-
copyWith(
{int? status, bool? success, String? msg, List< WebApiModulesAgentOrderSortingCorruptionItem> ? itemsWithSortingCorruption}) → WebApiModulesAgentOrderVerifyManualSortItemsResponse -
Available on WebApiModulesAgentOrderVerifyManualSortItemsResponse, provided by the $WebApiModulesAgentOrderVerifyManualSortItemsResponseExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? status, Wrapped<bool?> ? success, Wrapped<String?> ? msg, Wrapped<List< ? itemsWithSortingCorruption}) → WebApiModulesAgentOrderVerifyManualSortItemsResponseWebApiModulesAgentOrderSortingCorruptionItem> ?> -
Available on WebApiModulesAgentOrderVerifyManualSortItemsResponse, provided by the $WebApiModulesAgentOrderVerifyManualSortItemsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderVerifyManualSortItemsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderVerifyManualSortItemsResponse instance)