WebApiModulesAgentProjectProject class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentProjectProject({String? projectId, String? projectNumber, String? project, String? projectDate, String? officeLocationId, String? officeLocation, String? orderTypeId, String? orderType, String? warehouseId, String? warehouse, String? departmentId, String? department, String? dealId, String? deal, String? status, String? statusDate, String? projectManagerId, String? projectManager, String? agentId, String? agent, String? primaryContact, String? requestedBy, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, String? projectDescription, String? rateType, String? rateTypeDisplay, bool? rental, bool? sales, bool? facilities, bool? labor, bool? miscellaneous, bool? transportation, bool? rentalSale, String? pickDate, String? pickTime, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, bool? ccPrimaryApproverWhenEmailingBackupApprover, bool? hasWeeklyOnly, bool? hasMonthlyOnly, bool? hasWeeklyAndMonthly, bool? purchaseOrderHasWeeklyOnly, bool? purchaseOrderHasMonthlyOnly, bool? purchaseOrderHasWeeklyAndMonthly, String? marketTypeId, String? marketType, String? marketSegmentId, String? marketSegment, String? marketSegmentJobId, String? marketSegmentJob, bool? syncMarket, bool? syncDeliverShip, String? outDeliveryId, String? outDeliveryDeliveryType, String? outDeliveryRequiredDate, String? outDeliveryRequiredTime, String? outDeliveryTargetShipDate, String? outDeliveryTargetShipTime, String? outDeliveryDirection, String? outDeliveryAddressType, String? outDeliveryFromLocation, String? outDeliveryFromContact, String? outDeliveryFromContactPhone, String? outDeliveryFromAlternateContact, String? outDeliveryFromAlternateContactPhone, String? outDeliveryFromAttention, String? outDeliveryFromAddress1, String? outDeliveryFromAddress2, String? outDeliveryFromCity, String? outDeliveryFromState, String? outDeliveryFromZipCode, String? outDeliveryFromCountry, String? outDeliveryFromCountryId, String? outDeliveryFromCountryCodeIsoAlpha2, int? outDeliveryFromCountryCodePhone, String? outDeliveryFromCrossStreets, String? outDeliveryToLocation, String? outDeliveryToContact, String? outDeliveryToContactPhone, String? outDeliveryToAlternateContact, String? outDeliveryToAlternateContactPhone, String? outDeliveryToAttention, String? outDeliveryToAddress1, String? outDeliveryToAddress2, String? outDeliveryToCity, String? outDeliveryToState, String? outDeliveryToZipCode, String? outDeliveryToCountryId, String? outDeliveryToCountry, String? outDeliveryToCountryCodeIsoAlpha2, int? outDeliveryToCountryCodePhone, String? outDeliveryToContactFax, String? outDeliveryToCrossStreets, String? outDeliveryDeliveryNotes, String? outDeliveryCarrierId, String? outDeliveryCarrier, String? outDeliveryCarrierAccount, String? outDeliveryShipViaId, String? outDeliveryShipVia, String? outDeliveryInvoiceId, String? outDeliveryVendorInvoiceId, double? outDeliveryEstimatedFreight, double? outDeliveryFreightInvoiceAmount, String? outDeliveryChargeType, String? outDeliveryFreightTrackingNumber, String? outDeliveryFreightTrackingUrl, String? outDeliveryPackageCode, bool? outDeliveryBillPoFreightOnOrder, String? outDeliveryOnlineOrderNumber, String? outDeliveryToVenue, String? outDeliveryToVenueId, String? outDeliveryToWarehouse, String? outDeliveryToWarehouseId, String? outDeliveryDateStamp, String? inDeliveryId, String? inDeliveryDeliveryType, String? inDeliveryRequiredDate, String? inDeliveryRequiredTime, String? inDeliveryTargetShipDate, String? inDeliveryTargetShipTime, String? inDeliveryDirection, String? inDeliveryAddressType, String? inDeliveryFromLocation, String? inDeliveryFromContact, String? inDeliveryFromContactPhone, String? inDeliveryFromAlternateContact, String? inDeliveryFromAlternateContactPhone, String? inDeliveryFromAttention, String? inDeliveryFromAddress1, String? inDeliveryFromAddress2, String? inDeliveryFromCity, String? inDeliveryFromState, String? inDeliveryFromZipCode, String? inDeliveryFromCountry, String? inDeliveryFromCountryId, String? inDeliveryFromCountryCodeIsoAlpha2, int? inDeliveryFromCountryCodePhone, String? inDeliveryFromCrossStreets, String? inDeliveryToLocation, String? inDeliveryToContact, String? inDeliveryToContactPhone, String? inDeliveryToAlternateContact, String? inDeliveryToAlternateContactPhone, String? inDeliveryToAttention, String? inDeliveryToAddress1, String? inDeliveryToAddress2, String? inDeliveryToCity, String? inDeliveryToState, String? inDeliveryToZipCode, String? inDeliveryToCountryId, String? inDeliveryToCountry, String? inDeliveryToCountryCodeIsoAlpha2, int? inDeliveryToCountryCodePhone, String? inDeliveryToContactFax, String? inDeliveryToCrossStreets, String? inDeliveryDeliveryNotes, String? inDeliveryCarrierId, String? inDeliveryCarrier, String? inDeliveryCarrierAccount, String? inDeliveryShipViaId, String? inDeliveryShipVia, String? inDeliveryInvoiceId, String? inDeliveryVendorInvoiceId, double? inDeliveryEstimatedFreight, double? inDeliveryFreightInvoiceAmount, String? inDeliveryChargeType, String? inDeliveryFreightTrackingNumber, String? inDeliveryFreightTrackingUrl, String? inDeliveryPackageCode, bool? inDeliveryBillPoFreightOnOrder, String? inDeliveryOnlineOrderNumber, String? inDeliveryOnlineOrderStatus, String? inDeliveryToVenue, String? inDeliveryToVenueId, String? inDeliveryToWarehouse, String? inDeliveryToWarehouseId, String? inDeliveryDateStamp, bool? syncBilling, String? billingStartDate, String? billingEndDate, double? billingWeeks, double? billingMonths, String? delayBillingSearchUntil, bool? useEstimatedDatesForBilling, bool? lockBillingDates, bool? specifyBillingDatesByType, bool? doNotBillDayWhenItemsAreCheckedInByCertainTime, String? checkInByTimeToAvoidBilling, String? rentalBillingStartDate, String? rentalBillingEndDate, String? laborBillingStartDate, String? laborBillingEndDate, String? miscellaneousBillingStartDate, String? miscellaneousBillingEndDate, String? facilitiesBillingStartDate, String? facilitiesBillingEndDate, String? vehicleBillingStartDate, String? vehicleBillingEndDate, String? billingCycleId, String? billingCycle, String? billingCycleType, String? paymentTermsId, String? paymentTerms, String? paymentTermsColor, String? paymentTypeId, String? paymentType, String? paymentTypeType, double? paymentTypeFeePercentage, String? currencyId, bool? updateAllRatesToNewCurrency, String? confirmUpdateAllRatesToNewCurrency, String? currencyCode, String? currency, String? currencySymbol, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, String? rentalTaxAlias, String? salesTaxAlias, String? laborTaxAlias, String? taxId, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, String? determineQuantitiesToBillBasedOn, bool? includePrepFeesInRentalRate, String? hiatusDiscountFrom, String? crewBilling, String? printIssuedToAddressFrom, String? issuedToName, String? issuedToAttention, String? issuedToAttention2, String? issuedToAddress1, String? issuedToAddress2, String? issuedToCity, String? issuedToState, String? issuedToZipCode, String? issuedToCountryId, String? issuedToCountry, String? issuedToCountryCodeIsoAlpha2, int? issuedToCountryCodePhone, bool? roundTripRentals, String? discountReasonId, String? discountReason, bool? billToAddressDifferentFromIssuedToAddress, String? billToAddressId, String? billToName, String? billToAttention, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountryId, String? billToCountry, String? billToCountryCodeIsoAlpha2, int? billToCountryCodePhone, bool? noCharge, String? noChargeReason, List<WebApiModulesAgentOrderDatesOrderDates>? activityDatesAndTimes, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAgentProjectProject.fromJson(Map<String, dynamic> json)
factory

Properties

activityDatesAndTimes List<WebApiModulesAgentOrderDatesOrderDates>?
final
agent String?
final
agentId String?
final
auditNote String?
final
billingCycle String?
final
billingCycleId String?
final
billingCycleType String?
final
billingEndDate String?
final
billingMonths double?
final
billingStartDate String?
final
billingWeeks double?
final
billToAddress1 String?
final
billToAddress2 String?
final
billToAddressDifferentFromIssuedToAddress bool?
final
billToAddressId String?
final
billToAttention String?
final
billToAttention2 String?
final
billToCity String?
final
billToCountry String?
final
billToCountryCodeIsoAlpha2 String?
final
billToCountryCodePhone int?
final
billToCountryId String?
final
billToName String?
final
billToState String?
final
billToZipCode String?
final
ccPrimaryApproverWhenEmailingBackupApprover bool?
final
checkInByTimeToAvoidBilling String?
final
confirmUpdateAllRatesToNewCurrency String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
crewBilling String?
final
currency String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
deal String?
final
dealId String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
delayBillingSearchUntil String?
final
department String?
final
departmentId String?
final
determineQuantitiesToBillBasedOn String?
final
discountReason String?
final
discountReasonId String?
final
doNotBillDayWhenItemsAreCheckedInByCertainTime bool?
final
estimatedStartDate String?
final
estimatedStartTime String?
final
estimatedStopDate String?
final
estimatedStopTime String?
final
facilities bool?
final
facilitiesBillingEndDate String?
final
facilitiesBillingStartDate String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hasMonthlyOnly bool?
final
hasWeeklyAndMonthly bool?
final
hasWeeklyOnly bool?
final
hiatusDiscountFrom String?
final
inactive bool?
final
includePrepFeesInRentalRate bool?
final
inDeliveryAddressType String?
final
inDeliveryBillPoFreightOnOrder bool?
final
inDeliveryCarrier String?
final
inDeliveryCarrierAccount String?
final
inDeliveryCarrierId String?
final
inDeliveryChargeType String?
final
inDeliveryDateStamp String?
final
inDeliveryDeliveryNotes String?
final
inDeliveryDeliveryType String?
final
inDeliveryDirection String?
final
inDeliveryEstimatedFreight double?
final
inDeliveryFreightInvoiceAmount double?
final
inDeliveryFreightTrackingNumber String?
final
inDeliveryFreightTrackingUrl String?
final
inDeliveryFromAddress1 String?
final
inDeliveryFromAddress2 String?
final
inDeliveryFromAlternateContact String?
final
inDeliveryFromAlternateContactPhone String?
final
inDeliveryFromAttention String?
final
inDeliveryFromCity String?
final
inDeliveryFromContact String?
final
inDeliveryFromContactPhone String?
final
inDeliveryFromCountry String?
final
inDeliveryFromCountryCodeIsoAlpha2 String?
final
inDeliveryFromCountryCodePhone int?
final
inDeliveryFromCountryId String?
final
inDeliveryFromCrossStreets String?
final
inDeliveryFromLocation String?
final
inDeliveryFromState String?
final
inDeliveryFromZipCode String?
final
inDeliveryId String?
final
inDeliveryInvoiceId String?
final
inDeliveryOnlineOrderNumber String?
final
inDeliveryOnlineOrderStatus String?
final
inDeliveryPackageCode String?
final
inDeliveryRequiredDate String?
final
inDeliveryRequiredTime String?
final
inDeliveryShipVia String?
final
inDeliveryShipViaId String?
final
inDeliveryTargetShipDate String?
final
inDeliveryTargetShipTime String?
final
inDeliveryToAddress1 String?
final
inDeliveryToAddress2 String?
final
inDeliveryToAlternateContact String?
final
inDeliveryToAlternateContactPhone String?
final
inDeliveryToAttention String?
final
inDeliveryToCity String?
final
inDeliveryToContact String?
final
inDeliveryToContactFax String?
final
inDeliveryToContactPhone String?
final
inDeliveryToCountry String?
final
inDeliveryToCountryCodeIsoAlpha2 String?
final
inDeliveryToCountryCodePhone int?
final
inDeliveryToCountryId String?
final
inDeliveryToCrossStreets String?
final
inDeliveryToLocation String?
final
inDeliveryToState String?
final
inDeliveryToVenue String?
final
inDeliveryToVenueId String?
final
inDeliveryToWarehouse String?
final
inDeliveryToWarehouseId String?
final
inDeliveryToZipCode String?
final
inDeliveryVendorInvoiceId String?
final
issuedToAddress1 String?
final
issuedToAddress2 String?
final
issuedToAttention String?
final
issuedToAttention2 String?
final
issuedToCity String?
final
issuedToCountry String?
final
issuedToCountryCodeIsoAlpha2 String?
final
issuedToCountryCodePhone int?
final
issuedToCountryId String?
final
issuedToName String?
final
issuedToState String?
final
issuedToZipCode String?
final
labor bool?
final
laborBillingEndDate String?
final
laborBillingStartDate String?
final
laborTaxAlias String?
final
laborTaxRate1 double?
final
laborTaxRate2 double?
final
lockBillingDates bool?
final
marketSegment String?
final
marketSegmentId String?
final
marketSegmentJob String?
final
marketSegmentJobId String?
final
marketType String?
final
marketTypeId String?
final
miscellaneous bool?
final
miscellaneousBillingEndDate String?
final
miscellaneousBillingStartDate String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
noCharge bool?
final
noChargeReason String?
final
officeLocation String?
final
officeLocationId String?
final
orderType String?
final
orderTypeId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
outDeliveryAddressType String?
final
outDeliveryBillPoFreightOnOrder bool?
final
outDeliveryCarrier String?
final
outDeliveryCarrierAccount String?
final
outDeliveryCarrierId String?
final
outDeliveryChargeType String?
final
outDeliveryDateStamp String?
final
outDeliveryDeliveryNotes String?
final
outDeliveryDeliveryType String?
final
outDeliveryDirection String?
final
outDeliveryEstimatedFreight double?
final
outDeliveryFreightInvoiceAmount double?
final
outDeliveryFreightTrackingNumber String?
final
outDeliveryFreightTrackingUrl String?
final
outDeliveryFromAddress1 String?
final
outDeliveryFromAddress2 String?
final
outDeliveryFromAlternateContact String?
final
outDeliveryFromAlternateContactPhone String?
final
outDeliveryFromAttention String?
final
outDeliveryFromCity String?
final
outDeliveryFromContact String?
final
outDeliveryFromContactPhone String?
final
outDeliveryFromCountry String?
final
outDeliveryFromCountryCodeIsoAlpha2 String?
final
outDeliveryFromCountryCodePhone int?
final
outDeliveryFromCountryId String?
final
outDeliveryFromCrossStreets String?
final
outDeliveryFromLocation String?
final
outDeliveryFromState String?
final
outDeliveryFromZipCode String?
final
outDeliveryId String?
final
outDeliveryInvoiceId String?
final
outDeliveryOnlineOrderNumber String?
final
outDeliveryPackageCode String?
final
outDeliveryRequiredDate String?
final
outDeliveryRequiredTime String?
final
outDeliveryShipVia String?
final
outDeliveryShipViaId String?
final
outDeliveryTargetShipDate String?
final
outDeliveryTargetShipTime String?
final
outDeliveryToAddress1 String?
final
outDeliveryToAddress2 String?
final
outDeliveryToAlternateContact String?
final
outDeliveryToAlternateContactPhone String?
final
outDeliveryToAttention String?
final
outDeliveryToCity String?
final
outDeliveryToContact String?
final
outDeliveryToContactFax String?
final
outDeliveryToContactPhone String?
final
outDeliveryToCountry String?
final
outDeliveryToCountryCodeIsoAlpha2 String?
final
outDeliveryToCountryCodePhone int?
final
outDeliveryToCountryId String?
final
outDeliveryToCrossStreets String?
final
outDeliveryToLocation String?
final
outDeliveryToState String?
final
outDeliveryToVenue String?
final
outDeliveryToVenueId String?
final
outDeliveryToWarehouse String?
final
outDeliveryToWarehouseId String?
final
outDeliveryToZipCode String?
final
outDeliveryVendorInvoiceId String?
final
outsideSalesRepresentative String?
final
outsideSalesRepresentativeId String?
final
paymentTerms String?
final
paymentTermsColor String?
final
paymentTermsId String?
final
paymentType String?
final
paymentTypeFeePercentage double?
final
paymentTypeId String?
final
paymentTypeType String?
final
pickDate String?
final
pickTime String?
final
primaryContact String?
final
printIssuedToAddressFrom String?
final
project String?
final
projectDate String?
final
projectDescription String?
final
projectId String?
final
projectManager String?
final
projectManagerId String?
final
projectNumber String?
final
purchaseOrderHasMonthlyOnly bool?
final
purchaseOrderHasWeeklyAndMonthly bool?
final
purchaseOrderHasWeeklyOnly bool?
final
rateType String?
final
rateTypeDisplay String?
final
recordTitle String?
final
rental bool?
final
rentalBillingEndDate String?
final
rentalBillingStartDate String?
final
rentalSale bool?
final
rentalTaxAlias String?
final
rentalTaxRate1 double?
final
rentalTaxRate2 double?
final
requestedBy String?
final
roundTripRentals bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sales bool?
final
salesTaxAlias String?
final
salesTaxRate1 double?
final
salesTaxRate2 double?
final
specifyBillingDatesByType bool?
final
status String?
final
statusDate String?
final
syncBilling bool?
final
syncDeliverShip bool?
final
syncMarket bool?
final
tax1Name String?
final
tax2Name String?
final
taxId String?
final
taxOption String?
final
taxOptionId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
transportation bool?
final
updateAllRatesToNewCurrency bool?
final
urlIdentifier → dynamic
final
useEstimatedDatesForBilling bool?
final
vehicleBillingEndDate String?
final
vehicleBillingStartDate String?
final
warehouse String?
final
warehouseId String?
final

Methods

copyWith({String? projectId, String? projectNumber, String? project, String? projectDate, String? officeLocationId, String? officeLocation, String? orderTypeId, String? orderType, String? warehouseId, String? warehouse, String? departmentId, String? department, String? dealId, String? deal, String? status, String? statusDate, String? projectManagerId, String? projectManager, String? agentId, String? agent, String? primaryContact, String? requestedBy, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, String? projectDescription, String? rateType, String? rateTypeDisplay, bool? rental, bool? sales, bool? facilities, bool? labor, bool? miscellaneous, bool? transportation, bool? rentalSale, String? pickDate, String? pickTime, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, bool? ccPrimaryApproverWhenEmailingBackupApprover, bool? hasWeeklyOnly, bool? hasMonthlyOnly, bool? hasWeeklyAndMonthly, bool? purchaseOrderHasWeeklyOnly, bool? purchaseOrderHasMonthlyOnly, bool? purchaseOrderHasWeeklyAndMonthly, String? marketTypeId, String? marketType, String? marketSegmentId, String? marketSegment, String? marketSegmentJobId, String? marketSegmentJob, bool? syncMarket, bool? syncDeliverShip, String? outDeliveryId, String? outDeliveryDeliveryType, String? outDeliveryRequiredDate, String? outDeliveryRequiredTime, String? outDeliveryTargetShipDate, String? outDeliveryTargetShipTime, String? outDeliveryDirection, String? outDeliveryAddressType, String? outDeliveryFromLocation, String? outDeliveryFromContact, String? outDeliveryFromContactPhone, String? outDeliveryFromAlternateContact, String? outDeliveryFromAlternateContactPhone, String? outDeliveryFromAttention, String? outDeliveryFromAddress1, String? outDeliveryFromAddress2, String? outDeliveryFromCity, String? outDeliveryFromState, String? outDeliveryFromZipCode, String? outDeliveryFromCountry, String? outDeliveryFromCountryId, String? outDeliveryFromCountryCodeIsoAlpha2, int? outDeliveryFromCountryCodePhone, String? outDeliveryFromCrossStreets, String? outDeliveryToLocation, String? outDeliveryToContact, String? outDeliveryToContactPhone, String? outDeliveryToAlternateContact, String? outDeliveryToAlternateContactPhone, String? outDeliveryToAttention, String? outDeliveryToAddress1, String? outDeliveryToAddress2, String? outDeliveryToCity, String? outDeliveryToState, String? outDeliveryToZipCode, String? outDeliveryToCountryId, String? outDeliveryToCountry, String? outDeliveryToCountryCodeIsoAlpha2, int? outDeliveryToCountryCodePhone, String? outDeliveryToContactFax, String? outDeliveryToCrossStreets, String? outDeliveryDeliveryNotes, String? outDeliveryCarrierId, String? outDeliveryCarrier, String? outDeliveryCarrierAccount, String? outDeliveryShipViaId, String? outDeliveryShipVia, String? outDeliveryInvoiceId, String? outDeliveryVendorInvoiceId, double? outDeliveryEstimatedFreight, double? outDeliveryFreightInvoiceAmount, String? outDeliveryChargeType, String? outDeliveryFreightTrackingNumber, String? outDeliveryFreightTrackingUrl, String? outDeliveryPackageCode, bool? outDeliveryBillPoFreightOnOrder, String? outDeliveryOnlineOrderNumber, String? outDeliveryToVenue, String? outDeliveryToVenueId, String? outDeliveryToWarehouse, String? outDeliveryToWarehouseId, String? outDeliveryDateStamp, String? inDeliveryId, String? inDeliveryDeliveryType, String? inDeliveryRequiredDate, String? inDeliveryRequiredTime, String? inDeliveryTargetShipDate, String? inDeliveryTargetShipTime, String? inDeliveryDirection, String? inDeliveryAddressType, String? inDeliveryFromLocation, String? inDeliveryFromContact, String? inDeliveryFromContactPhone, String? inDeliveryFromAlternateContact, String? inDeliveryFromAlternateContactPhone, String? inDeliveryFromAttention, String? inDeliveryFromAddress1, String? inDeliveryFromAddress2, String? inDeliveryFromCity, String? inDeliveryFromState, String? inDeliveryFromZipCode, String? inDeliveryFromCountry, String? inDeliveryFromCountryId, String? inDeliveryFromCountryCodeIsoAlpha2, int? inDeliveryFromCountryCodePhone, String? inDeliveryFromCrossStreets, String? inDeliveryToLocation, String? inDeliveryToContact, String? inDeliveryToContactPhone, String? inDeliveryToAlternateContact, String? inDeliveryToAlternateContactPhone, String? inDeliveryToAttention, String? inDeliveryToAddress1, String? inDeliveryToAddress2, String? inDeliveryToCity, String? inDeliveryToState, String? inDeliveryToZipCode, String? inDeliveryToCountryId, String? inDeliveryToCountry, String? inDeliveryToCountryCodeIsoAlpha2, int? inDeliveryToCountryCodePhone, String? inDeliveryToContactFax, String? inDeliveryToCrossStreets, String? inDeliveryDeliveryNotes, String? inDeliveryCarrierId, String? inDeliveryCarrier, String? inDeliveryCarrierAccount, String? inDeliveryShipViaId, String? inDeliveryShipVia, String? inDeliveryInvoiceId, String? inDeliveryVendorInvoiceId, double? inDeliveryEstimatedFreight, double? inDeliveryFreightInvoiceAmount, String? inDeliveryChargeType, String? inDeliveryFreightTrackingNumber, String? inDeliveryFreightTrackingUrl, String? inDeliveryPackageCode, bool? inDeliveryBillPoFreightOnOrder, String? inDeliveryOnlineOrderNumber, String? inDeliveryOnlineOrderStatus, String? inDeliveryToVenue, String? inDeliveryToVenueId, String? inDeliveryToWarehouse, String? inDeliveryToWarehouseId, String? inDeliveryDateStamp, bool? syncBilling, String? billingStartDate, String? billingEndDate, double? billingWeeks, double? billingMonths, String? delayBillingSearchUntil, bool? useEstimatedDatesForBilling, bool? lockBillingDates, bool? specifyBillingDatesByType, bool? doNotBillDayWhenItemsAreCheckedInByCertainTime, String? checkInByTimeToAvoidBilling, String? rentalBillingStartDate, String? rentalBillingEndDate, String? laborBillingStartDate, String? laborBillingEndDate, String? miscellaneousBillingStartDate, String? miscellaneousBillingEndDate, String? facilitiesBillingStartDate, String? facilitiesBillingEndDate, String? vehicleBillingStartDate, String? vehicleBillingEndDate, String? billingCycleId, String? billingCycle, String? billingCycleType, String? paymentTermsId, String? paymentTerms, String? paymentTermsColor, String? paymentTypeId, String? paymentType, String? paymentTypeType, double? paymentTypeFeePercentage, String? currencyId, bool? updateAllRatesToNewCurrency, String? confirmUpdateAllRatesToNewCurrency, String? currencyCode, String? currency, String? currencySymbol, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, String? rentalTaxAlias, String? salesTaxAlias, String? laborTaxAlias, String? taxId, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, String? determineQuantitiesToBillBasedOn, bool? includePrepFeesInRentalRate, String? hiatusDiscountFrom, String? crewBilling, String? printIssuedToAddressFrom, String? issuedToName, String? issuedToAttention, String? issuedToAttention2, String? issuedToAddress1, String? issuedToAddress2, String? issuedToCity, String? issuedToState, String? issuedToZipCode, String? issuedToCountryId, String? issuedToCountry, String? issuedToCountryCodeIsoAlpha2, int? issuedToCountryCodePhone, bool? roundTripRentals, String? discountReasonId, String? discountReason, bool? billToAddressDifferentFromIssuedToAddress, String? billToAddressId, String? billToName, String? billToAttention, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountryId, String? billToCountry, String? billToCountryCodeIsoAlpha2, int? billToCountryCodePhone, bool? noCharge, String? noChargeReason, List<WebApiModulesAgentOrderDatesOrderDates>? activityDatesAndTimes, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAgentProjectProject

Available on WebApiModulesAgentProjectProject, provided by the $WebApiModulesAgentProjectProjectExtension extension

copyWithWrapped({Wrapped<String?>? projectId, Wrapped<String?>? projectNumber, Wrapped<String?>? project, Wrapped<String?>? projectDate, Wrapped<String?>? officeLocationId, Wrapped<String?>? officeLocation, Wrapped<String?>? orderTypeId, Wrapped<String?>? orderType, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? departmentId, Wrapped<String?>? department, Wrapped<String?>? dealId, Wrapped<String?>? deal, Wrapped<String?>? status, Wrapped<String?>? statusDate, Wrapped<String?>? projectManagerId, Wrapped<String?>? projectManager, Wrapped<String?>? agentId, Wrapped<String?>? agent, Wrapped<String?>? primaryContact, Wrapped<String?>? requestedBy, Wrapped<String?>? outsideSalesRepresentativeId, Wrapped<String?>? outsideSalesRepresentative, Wrapped<String?>? projectDescription, Wrapped<String?>? rateType, Wrapped<String?>? rateTypeDisplay, Wrapped<bool?>? rental, Wrapped<bool?>? sales, Wrapped<bool?>? facilities, Wrapped<bool?>? labor, Wrapped<bool?>? miscellaneous, Wrapped<bool?>? transportation, Wrapped<bool?>? rentalSale, Wrapped<String?>? pickDate, Wrapped<String?>? pickTime, Wrapped<String?>? estimatedStartDate, Wrapped<String?>? estimatedStartTime, Wrapped<String?>? estimatedStopDate, Wrapped<String?>? estimatedStopTime, Wrapped<bool?>? ccPrimaryApproverWhenEmailingBackupApprover, Wrapped<bool?>? hasWeeklyOnly, Wrapped<bool?>? hasMonthlyOnly, Wrapped<bool?>? hasWeeklyAndMonthly, Wrapped<bool?>? purchaseOrderHasWeeklyOnly, Wrapped<bool?>? purchaseOrderHasMonthlyOnly, Wrapped<bool?>? purchaseOrderHasWeeklyAndMonthly, Wrapped<String?>? marketTypeId, Wrapped<String?>? marketType, Wrapped<String?>? marketSegmentId, Wrapped<String?>? marketSegment, Wrapped<String?>? marketSegmentJobId, Wrapped<String?>? marketSegmentJob, Wrapped<bool?>? syncMarket, Wrapped<bool?>? syncDeliverShip, Wrapped<String?>? outDeliveryId, Wrapped<String?>? outDeliveryDeliveryType, Wrapped<String?>? outDeliveryRequiredDate, Wrapped<String?>? outDeliveryRequiredTime, Wrapped<String?>? outDeliveryTargetShipDate, Wrapped<String?>? outDeliveryTargetShipTime, Wrapped<String?>? outDeliveryDirection, Wrapped<String?>? outDeliveryAddressType, Wrapped<String?>? outDeliveryFromLocation, Wrapped<String?>? outDeliveryFromContact, Wrapped<String?>? outDeliveryFromContactPhone, Wrapped<String?>? outDeliveryFromAlternateContact, Wrapped<String?>? outDeliveryFromAlternateContactPhone, Wrapped<String?>? outDeliveryFromAttention, Wrapped<String?>? outDeliveryFromAddress1, Wrapped<String?>? outDeliveryFromAddress2, Wrapped<String?>? outDeliveryFromCity, Wrapped<String?>? outDeliveryFromState, Wrapped<String?>? outDeliveryFromZipCode, Wrapped<String?>? outDeliveryFromCountry, Wrapped<String?>? outDeliveryFromCountryId, Wrapped<String?>? outDeliveryFromCountryCodeIsoAlpha2, Wrapped<int?>? outDeliveryFromCountryCodePhone, Wrapped<String?>? outDeliveryFromCrossStreets, Wrapped<String?>? outDeliveryToLocation, Wrapped<String?>? outDeliveryToContact, Wrapped<String?>? outDeliveryToContactPhone, Wrapped<String?>? outDeliveryToAlternateContact, Wrapped<String?>? outDeliveryToAlternateContactPhone, Wrapped<String?>? outDeliveryToAttention, Wrapped<String?>? outDeliveryToAddress1, Wrapped<String?>? outDeliveryToAddress2, Wrapped<String?>? outDeliveryToCity, Wrapped<String?>? outDeliveryToState, Wrapped<String?>? outDeliveryToZipCode, Wrapped<String?>? outDeliveryToCountryId, Wrapped<String?>? outDeliveryToCountry, Wrapped<String?>? outDeliveryToCountryCodeIsoAlpha2, Wrapped<int?>? outDeliveryToCountryCodePhone, Wrapped<String?>? outDeliveryToContactFax, Wrapped<String?>? outDeliveryToCrossStreets, Wrapped<String?>? outDeliveryDeliveryNotes, Wrapped<String?>? outDeliveryCarrierId, Wrapped<String?>? outDeliveryCarrier, Wrapped<String?>? outDeliveryCarrierAccount, Wrapped<String?>? outDeliveryShipViaId, Wrapped<String?>? outDeliveryShipVia, Wrapped<String?>? outDeliveryInvoiceId, Wrapped<String?>? outDeliveryVendorInvoiceId, Wrapped<double?>? outDeliveryEstimatedFreight, Wrapped<double?>? outDeliveryFreightInvoiceAmount, Wrapped<String?>? outDeliveryChargeType, Wrapped<String?>? outDeliveryFreightTrackingNumber, Wrapped<String?>? outDeliveryFreightTrackingUrl, Wrapped<String?>? outDeliveryPackageCode, Wrapped<bool?>? outDeliveryBillPoFreightOnOrder, Wrapped<String?>? outDeliveryOnlineOrderNumber, Wrapped<String?>? outDeliveryToVenue, Wrapped<String?>? outDeliveryToVenueId, Wrapped<String?>? outDeliveryToWarehouse, Wrapped<String?>? outDeliveryToWarehouseId, Wrapped<String?>? outDeliveryDateStamp, Wrapped<String?>? inDeliveryId, Wrapped<String?>? inDeliveryDeliveryType, Wrapped<String?>? inDeliveryRequiredDate, Wrapped<String?>? inDeliveryRequiredTime, Wrapped<String?>? inDeliveryTargetShipDate, Wrapped<String?>? inDeliveryTargetShipTime, Wrapped<String?>? inDeliveryDirection, Wrapped<String?>? inDeliveryAddressType, Wrapped<String?>? inDeliveryFromLocation, Wrapped<String?>? inDeliveryFromContact, Wrapped<String?>? inDeliveryFromContactPhone, Wrapped<String?>? inDeliveryFromAlternateContact, Wrapped<String?>? inDeliveryFromAlternateContactPhone, Wrapped<String?>? inDeliveryFromAttention, Wrapped<String?>? inDeliveryFromAddress1, Wrapped<String?>? inDeliveryFromAddress2, Wrapped<String?>? inDeliveryFromCity, Wrapped<String?>? inDeliveryFromState, Wrapped<String?>? inDeliveryFromZipCode, Wrapped<String?>? inDeliveryFromCountry, Wrapped<String?>? inDeliveryFromCountryId, Wrapped<String?>? inDeliveryFromCountryCodeIsoAlpha2, Wrapped<int?>? inDeliveryFromCountryCodePhone, Wrapped<String?>? inDeliveryFromCrossStreets, Wrapped<String?>? inDeliveryToLocation, Wrapped<String?>? inDeliveryToContact, Wrapped<String?>? inDeliveryToContactPhone, Wrapped<String?>? inDeliveryToAlternateContact, Wrapped<String?>? inDeliveryToAlternateContactPhone, Wrapped<String?>? inDeliveryToAttention, Wrapped<String?>? inDeliveryToAddress1, Wrapped<String?>? inDeliveryToAddress2, Wrapped<String?>? inDeliveryToCity, Wrapped<String?>? inDeliveryToState, Wrapped<String?>? inDeliveryToZipCode, Wrapped<String?>? inDeliveryToCountryId, Wrapped<String?>? inDeliveryToCountry, Wrapped<String?>? inDeliveryToCountryCodeIsoAlpha2, Wrapped<int?>? inDeliveryToCountryCodePhone, Wrapped<String?>? inDeliveryToContactFax, Wrapped<String?>? inDeliveryToCrossStreets, Wrapped<String?>? inDeliveryDeliveryNotes, Wrapped<String?>? inDeliveryCarrierId, Wrapped<String?>? inDeliveryCarrier, Wrapped<String?>? inDeliveryCarrierAccount, Wrapped<String?>? inDeliveryShipViaId, Wrapped<String?>? inDeliveryShipVia, Wrapped<String?>? inDeliveryInvoiceId, Wrapped<String?>? inDeliveryVendorInvoiceId, Wrapped<double?>? inDeliveryEstimatedFreight, Wrapped<double?>? inDeliveryFreightInvoiceAmount, Wrapped<String?>? inDeliveryChargeType, Wrapped<String?>? inDeliveryFreightTrackingNumber, Wrapped<String?>? inDeliveryFreightTrackingUrl, Wrapped<String?>? inDeliveryPackageCode, Wrapped<bool?>? inDeliveryBillPoFreightOnOrder, Wrapped<String?>? inDeliveryOnlineOrderNumber, Wrapped<String?>? inDeliveryOnlineOrderStatus, Wrapped<String?>? inDeliveryToVenue, Wrapped<String?>? inDeliveryToVenueId, Wrapped<String?>? inDeliveryToWarehouse, Wrapped<String?>? inDeliveryToWarehouseId, Wrapped<String?>? inDeliveryDateStamp, Wrapped<bool?>? syncBilling, Wrapped<String?>? billingStartDate, Wrapped<String?>? billingEndDate, Wrapped<double?>? billingWeeks, Wrapped<double?>? billingMonths, Wrapped<String?>? delayBillingSearchUntil, Wrapped<bool?>? useEstimatedDatesForBilling, Wrapped<bool?>? lockBillingDates, Wrapped<bool?>? specifyBillingDatesByType, Wrapped<bool?>? doNotBillDayWhenItemsAreCheckedInByCertainTime, Wrapped<String?>? checkInByTimeToAvoidBilling, Wrapped<String?>? rentalBillingStartDate, Wrapped<String?>? rentalBillingEndDate, Wrapped<String?>? laborBillingStartDate, Wrapped<String?>? laborBillingEndDate, Wrapped<String?>? miscellaneousBillingStartDate, Wrapped<String?>? miscellaneousBillingEndDate, Wrapped<String?>? facilitiesBillingStartDate, Wrapped<String?>? facilitiesBillingEndDate, Wrapped<String?>? vehicleBillingStartDate, Wrapped<String?>? vehicleBillingEndDate, Wrapped<String?>? billingCycleId, Wrapped<String?>? billingCycle, Wrapped<String?>? billingCycleType, Wrapped<String?>? paymentTermsId, Wrapped<String?>? paymentTerms, Wrapped<String?>? paymentTermsColor, Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<String?>? paymentTypeType, Wrapped<double?>? paymentTypeFeePercentage, Wrapped<String?>? currencyId, Wrapped<bool?>? updateAllRatesToNewCurrency, Wrapped<String?>? confirmUpdateAllRatesToNewCurrency, Wrapped<String?>? currencyCode, Wrapped<String?>? currency, Wrapped<String?>? currencySymbol, Wrapped<String?>? taxOptionId, Wrapped<String?>? taxOption, Wrapped<String?>? tax1Name, Wrapped<String?>? tax2Name, Wrapped<String?>? rentalTaxAlias, Wrapped<String?>? salesTaxAlias, Wrapped<String?>? laborTaxAlias, Wrapped<String?>? taxId, Wrapped<double?>? rentalTaxRate1, Wrapped<double?>? salesTaxRate1, Wrapped<double?>? laborTaxRate1, Wrapped<double?>? rentalTaxRate2, Wrapped<double?>? salesTaxRate2, Wrapped<double?>? laborTaxRate2, Wrapped<String?>? determineQuantitiesToBillBasedOn, Wrapped<bool?>? includePrepFeesInRentalRate, Wrapped<String?>? hiatusDiscountFrom, Wrapped<String?>? crewBilling, Wrapped<String?>? printIssuedToAddressFrom, Wrapped<String?>? issuedToName, Wrapped<String?>? issuedToAttention, Wrapped<String?>? issuedToAttention2, Wrapped<String?>? issuedToAddress1, Wrapped<String?>? issuedToAddress2, Wrapped<String?>? issuedToCity, Wrapped<String?>? issuedToState, Wrapped<String?>? issuedToZipCode, Wrapped<String?>? issuedToCountryId, Wrapped<String?>? issuedToCountry, Wrapped<String?>? issuedToCountryCodeIsoAlpha2, Wrapped<int?>? issuedToCountryCodePhone, Wrapped<bool?>? roundTripRentals, Wrapped<String?>? discountReasonId, Wrapped<String?>? discountReason, Wrapped<bool?>? billToAddressDifferentFromIssuedToAddress, Wrapped<String?>? billToAddressId, Wrapped<String?>? billToName, Wrapped<String?>? billToAttention, Wrapped<String?>? billToAttention2, Wrapped<String?>? billToAddress1, Wrapped<String?>? billToAddress2, Wrapped<String?>? billToCity, Wrapped<String?>? billToState, Wrapped<String?>? billToZipCode, Wrapped<String?>? billToCountryId, Wrapped<String?>? billToCountry, Wrapped<String?>? billToCountryCodeIsoAlpha2, Wrapped<int?>? billToCountryCodePhone, Wrapped<bool?>? noCharge, Wrapped<String?>? noChargeReason, Wrapped<List<WebApiModulesAgentOrderDatesOrderDates>?>? activityDatesAndTimes, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAgentProjectProject

Available on WebApiModulesAgentProjectProject, provided by the $WebApiModulesAgentProjectProjectExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAgentProjectProject Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAgentProjectProject instance)