WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse({String? returnContractIds, String? inContractIds, int? status, bool? success, String? msg, List<
WebApiModulesWarehouseContractContract> ? contracts}) -
const
-
WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
contracts
→ List<
WebApiModulesWarehouseContractContract> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inContractIds → String?
-
final
- msg → String?
-
final
- returnContractIds → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- success → bool?
-
final
Methods
-
copyWith(
{String? returnContractIds, String? inContractIds, int? status, bool? success, String? msg, List< WebApiModulesWarehouseContractContract> ? contracts}) → WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse -
Available on WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse, provided by the $WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponseExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? returnContractIds, Wrapped<String?> ? inContractIds, Wrapped<int?> ? status, Wrapped<bool?> ? success, Wrapped<String?> ? msg, Wrapped<List< ? contracts}) → WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponseWebApiModulesWarehouseContractContract> ?> -
Available on WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse, provided by the $WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentPurchaseOrderConfirmVendorRetrieveResponse instance)