WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequest({String? purchaseOrderId, String? usersId, String? approvalNote, String? firstApprover})
const
WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequest.fromJson(Map<String, dynamic> json)
factory

Properties

approvalNote String?
final
firstApprover String?
final
hashCode int
The hash code for this object.
no setteroverride
purchaseOrderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usersId String?
final

Methods

copyWith({String? purchaseOrderId, String? usersId, String? approvalNote, String? firstApprover}) WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequest

Available on WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequest, provided by the $WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequestExtension extension

copyWithWrapped({Wrapped<String?>? purchaseOrderId, Wrapped<String?>? usersId, Wrapped<String?>? approvalNote, Wrapped<String?>? firstApprover}) WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequest

Available on WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequest, provided by the $WebApiModulesAgentPurchaseOrderFirstApprovePurchaseOrderRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override