WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponse({String? purchaseOrderId, String? purchaseOrderNumber, String? description, String? purchaseOrderDate, String? requisitionNumber, String? requisitionDate, String? vendorId, String? vendor, String? agentId, String? agent, String? status, String? statusDate, String? referenceNumber, bool? needsApproval, String? approvedByUserId, String? departmentId, String? department, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, int? quantityHolding, int? quantityToBarCode, bool? rental, bool? sales, bool? parts, bool? labor, bool? miscellaneous, bool? vehicle, bool? subRent, bool? subSale, bool? subLabor, bool? subMiscellaneous, bool? subVehicle, bool? repair, bool? consignment, String? consignorAgreementId, String? consignorAgreementNumber, bool? vendorHasConsignment, String? orderId, String? orderNumber, String? dealNumber, String? dealId, String? deal, String? rateType, String? termsConditionsId, String? termsConditions, bool? departmentLocationRequiresApproval, double? total, String? poTypeId, String? poType, String? poClassificationId, String? poClassification, List<
WebApiModulesHomeControlsOrderDatesOrderDates> ? activityDatesAndTimes, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, String? billingStartDate, String? billingEndDate, double? billingWeeks, double? billingMonths, double? invoicedAmount, String? projectManagerId, String? projectManager, String? receiveDeliveryId, String? receiveDeliveryDeliveryType, String? receiveDeliveryRequiredDate, String? receiveDeliveryRequiredTime, String? receiveDeliveryTargetShipDate, String? receiveDeliveryTargetShipTime, String? receiveDeliveryDirection, String? receiveDeliveryAddressType, String? receiveDeliveryFromLocation, String? receiveDeliveryFromContact, String? receiveDeliveryFromContactPhone, String? receiveDeliveryFromAlternateContact, String? receiveDeliveryFromAlternateContactPhone, String? receiveDeliveryFromAttention, String? receiveDeliveryFromAddress1, String? receiveDeliveryFromAdd2ress, String? receiveDeliveryFromCity, String? receiveDeliveryFromState, String? receiveDeliveryFromZipCode, String? receiveDeliveryFromCountry, String? receiveDeliveryFromCountryId, String? receiveDeliveryFromCrossStreets, String? receiveDeliveryToLocation, String? receiveDeliveryToVenue, String? receiveDeliveryToVenueId, String? receiveDeliveryToWarehouse, String? receiveDeliveryToWarehouseId, String? receiveDeliveryToContact, String? receiveDeliveryToContactPhone, String? receiveDeliveryToAlternateContact, String? receiveDeliveryToAlternateContactPhone, String? receiveDeliveryToAttention, String? receiveDeliveryToAddress1, String? receiveDeliveryToAddress2, String? receiveDeliveryToCity, String? receiveDeliveryToState, String? receiveDeliveryToZipCode, String? receiveDeliveryToCountryId, String? receiveDeliveryToCountry, String? receiveDeliveryToContactFax, String? receiveDeliveryToCrossStreets, String? receiveDeliveryDeliveryNotes, String? receiveDeliveryCarrierId, String? receiveDeliveryCarrier, String? receiveDeliveryCarrierAccount, String? receiveDeliveryShipViaId, String? receiveDeliveryShipVia, String? receiveDeliveryInvoiceId, String? receiveDeliveryVendorInvoiceId, double? receiveDeliveryEstimatedFreight, double? receiveDeliveryFreightInvoiceAmount, String? receiveDeliveryChargeType, String? receiveDeliveryFreightTrackingNumber, String? receiveDeliveryFreightTrackingUrl, bool? receiveDeliveryDropShip, String? receiveDeliveryPackageCode, bool? receiveDeliveryBillPoFreightOnOrder, String? receiveDeliveryOnlineOrderNumber, String? receiveDeliveryOnlineOrderStatus, String? receiveDeliveryDateStamp, String? returnDeliveryId, String? returnDeliveryDeliveryType, String? returnDeliveryRequiredDate, String? returnDeliveryRequiredTime, String? returnDeliveryTargetShipDate, String? returnDeliveryTargetShipTime, String? returnDeliveryDirection, String? returnDeliveryAddressType, String? returnDeliveryFromLocation, String? returnDeliveryFromContact, String? returnDeliveryFromContactPhone, String? returnDeliveryFromAlternateContact, String? returnDeliveryFromAlternateContactPhone, String? returnDeliveryFromAttention, String? returnDeliveryFromAddress1, String? returnDeliveryFromAdd2ress, String? returnDeliveryFromCity, String? returnDeliveryFromState, String? returnDeliveryFromZipCode, String? returnDeliveryFromCountry, String? returnDeliveryFromCountryId, String? returnDeliveryFromCrossStreets, String? returnDeliveryToLocation, String? returnDeliveryToVenue, String? returnDeliveryToVenueId, String? returnDeliveryToWarehouse, String? returnDeliveryToWarehouseId, String? returnDeliveryToContact, String? returnDeliveryToContactPhone, String? returnDeliveryToAlternateContact, String? returnDeliveryToAlternateContactPhone, String? returnDeliveryToAttention, String? returnDeliveryToAddress1, String? returnDeliveryToAddress2, String? returnDeliveryToCity, String? returnDeliveryToState, String? returnDeliveryToZipCode, String? returnDeliveryToCountryId, String? returnDeliveryToCountry, String? returnDeliveryToContactFax, String? returnDeliveryToCrossStreets, String? returnDeliveryDeliveryNotes, String? returnDeliveryCarrierId, String? returnDeliveryCarrier, String? returnDeliveryCarrierAccount, String? returnDeliveryShipViaId, String? returnDeliveryShipVia, String? returnDeliveryInvoiceId, String? returnDeliveryVendorInvoiceId, double? returnDeliveryEstimatedFreight, double? returnDeliveryFreightInvoiceAmount, String? returnDeliveryChargeType, String? returnDeliveryFreightTrackingNumber, String? returnDeliveryFreightTrackingUrl, bool? returnDeliveryVendorRetrieve, String? returnDeliveryPackageCode, bool? returnDeliveryBillPoFreightOnOrder, String? returnDeliveryOnlineOrderNumber, String? returnDeliveryOnlineOrderStatus, String? returnDeliveryDateStamp, bool? enableProjects, String? projectId, String? projectNumber, String? project, String? projectDrawingsId, String? projectDrawings, String? projectItemsOrderedId, String? projectItemsOrdered, String? projectDropShipId, String? projectDropShip, String? projectAsBuildId, String? projectAsBuild, String? projectCommissioningId, String? projectCommissioning, String? projectDepositId, String? projectDeposit, String? location, String? currencyId, bool? updateAllRatesToNewCurrency, String? confirmUpdateAllRatesToNewCurrency, String? currencyCode, String? currency, String? currencySymbol, String? billingCycleId, String? billingCycle, String? remitToAttention1, String? remitToAttention2, String? remitToAddress1, String? remitToAddress2, String? remitToCity, String? remitToState, String? remitToCountryId, String? remitToCountry, String? remitToZipCode, String? remitToEmail, String? remitToPhone, String? paymentTypeId, String? paymentType, String? paymentTermsId, String? paymentTerms, int? paymentTermsDueInDays, String? taxOptionId, String? taxOption, String? taxId, String? tax1Name, String? tax2Name, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, bool? hasLossAndDamageItem, bool? hasRentalSaleItem, bool? hasConsignItem, bool? hasPartsItem, double? rentalDiscountPercent, double? rentalTotal, bool? rentalTotalIncludesTax, double? salesDiscountPercent, double? salesTotal, bool? salesTotalIncludesTax, double? partsDiscountPercent, double? partsTotal, bool? partsTotalIncludesTax, double? vehicleDiscountPercent, double? vehicleTotal, bool? vehicleTotalIncludesTax, double? miscDiscountPercent, double? miscTotal, bool? miscTotalIncludesTax, double? laborDiscountPercent, double? laborTotal, bool? laborTotalIncludesTax, double? subRentalDaysPerWeek, double? subRentalDiscountPercent, double? weeklySubRentalTotal, double? monthlySubRentalTotal, double? periodSubRentalTotal, bool? weeklySubRentalTotalIncludesTax, bool? monthlySubRentalTotalIncludesTax, bool? periodSubRentalTotalIncludesTax, double? subSalesDiscountPercent, double? subSalesTotal, bool? subSalesTotalIncludesTax, double? subVehicleDaysPerWeek, double? subvehicleDiscountPercent, double? weeklySubVehicleTotal, double? monthlySubVehicleTotal, double? periodSubVehicleTotal, bool? weeklySubVehicleTotalIncludesTax, bool? monthlySubVehicleTotalIncludesTax, bool? periodSubVehicleTotalIncludesTax, double? subMiscDiscountPercent, double? weeklySubMiscTotal, double? monthlySubMiscTotal, double? periodSubMiscTotal, bool? weeklySubMiscTotalIncludesTax, bool? monthlySubMiscTotalIncludesTax, bool? periodSubMiscTotalIncludesTax, double? subLaborDiscountPercent, double? weeklySubLaborTotal, double? monthlySubLaborTotal, double? periodSubLaborTotal, bool? weeklySubLaborTotalIncludesTax, bool? monthlySubLaborTotalIncludesTax, bool? periodSubLaborTotalIncludesTax, bool? miscellaneousIsComplete, bool? subMiscellaneousIsComplete, bool? laborIsComplete, bool? subLaborIsComplete, String? currencyColor, String? statusColor, String? purchaseOrderNumberColor, String? vendorColor, String? descriptionColor, String? expensePOColor, bool? hasConsignorFee, bool? hasOrdertran, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<WebApiModulesHomeControlsOrderItemOrderItem> ? items, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
activityDatesAndTimes
→ List<
WebApiModulesHomeControlsOrderDatesOrderDates> ? -
final
- agent → String?
-
final
- agentId → String?
-
final
- approvedByUserId → String?
-
final
- auditNote → String?
-
final
- billingCycle → String?
-
final
- billingCycleId → String?
-
final
- billingEndDate → String?
-
final
- billingMonths → double?
-
final
- billingStartDate → String?
-
final
- billingWeeks → double?
-
final
- confirmUpdateAllRatesToNewCurrency → String?
-
final
- consignment → bool?
-
final
- consignorAgreementId → String?
-
final
- consignorAgreementNumber → String?
-
final
- currency → String?
-
final
- currencyCode → String?
-
final
- currencyColor → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- deal → String?
-
final
- dealId → String?
-
final
- dealNumber → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
- departmentLocationRequiresApproval → bool?
-
final
- description → String?
-
final
- descriptionColor → String?
-
final
- enableProjects → bool?
-
final
- estimatedStartDate → String?
-
final
- estimatedStartTime → String?
-
final
- estimatedStopDate → String?
-
final
- estimatedStopTime → String?
-
final
- expensePOColor → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasConsignItem → bool?
-
final
- hasConsignorFee → bool?
-
final
- hasFacilitiesItem → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasLaborItem → bool?
-
final
- hasLossAndDamageItem → bool?
-
final
- hasMiscellaneousItem → bool?
-
final
- hasOrdertran → bool?
-
final
- hasPartsItem → bool?
-
final
- hasRentalItem → bool?
-
final
- hasRentalSaleItem → bool?
-
final
- hasSalesItem → bool?
-
final
- invoicedAmount → double?
-
final
-
items
→ List<
WebApiModulesHomeControlsOrderItemOrderItem> ? -
final
- labor → bool?
-
final
- laborDiscountPercent → double?
-
final
- laborIsComplete → bool?
-
final
- laborTaxRate1 → double?
-
final
- laborTaxRate2 → double?
-
final
- laborTotal → double?
-
final
- laborTotalIncludesTax → bool?
-
final
- location → String?
-
final
- miscDiscountPercent → double?
-
final
- miscellaneous → bool?
-
final
- miscellaneousIsComplete → bool?
-
final
- miscTotal → double?
-
final
- miscTotalIncludesTax → bool?
-
final
- monthlySubLaborTotal → double?
-
final
- monthlySubLaborTotalIncludesTax → bool?
-
final
- monthlySubMiscTotal → double?
-
final
- monthlySubMiscTotalIncludesTax → bool?
-
final
- monthlySubRentalTotal → double?
-
final
- monthlySubRentalTotalIncludesTax → bool?
-
final
- monthlySubVehicleTotal → double?
-
final
- monthlySubVehicleTotalIncludesTax → bool?
-
final
- needsApproval → bool?
-
final
- officeLocation → String?
-
final
- officeLocationId → String?
-
final
- orderId → String?
-
final
- orderNumber → String?
-
final
- parts → bool?
-
final
- partsDiscountPercent → double?
-
final
- partsTotal → double?
-
final
- partsTotalIncludesTax → bool?
-
final
- paymentTerms → String?
-
final
- paymentTermsDueInDays → int?
-
final
- paymentTermsId → String?
-
final
- paymentType → String?
-
final
- paymentTypeId → String?
-
final
- periodSubLaborTotal → double?
-
final
- periodSubLaborTotalIncludesTax → bool?
-
final
- periodSubMiscTotal → double?
-
final
- periodSubMiscTotalIncludesTax → bool?
-
final
- periodSubRentalTotal → double?
-
final
- periodSubRentalTotalIncludesTax → bool?
-
final
- periodSubVehicleTotal → double?
-
final
- periodSubVehicleTotalIncludesTax → bool?
-
final
- poClassification → String?
-
final
- poClassificationId → String?
-
final
- poType → String?
-
final
- poTypeId → String?
-
final
- project → String?
-
final
- projectAsBuild → String?
-
final
- projectAsBuildId → String?
-
final
- projectCommissioning → String?
-
final
- projectCommissioningId → String?
-
final
- projectDeposit → String?
-
final
- projectDepositId → String?
-
final
- projectDrawings → String?
-
final
- projectDrawingsId → String?
-
final
- projectDropShip → String?
-
final
- projectDropShipId → String?
-
final
- projectId → String?
-
final
- projectItemsOrdered → String?
-
final
- projectItemsOrderedId → String?
-
final
- projectManager → String?
-
final
- projectManagerId → String?
-
final
- projectNumber → String?
-
final
- purchaseOrderDate → String?
-
final
- purchaseOrderId → String?
-
final
- purchaseOrderNumber → String?
-
final
- purchaseOrderNumberColor → String?
-
final
- quantityHolding → int?
-
final
- quantityToBarCode → int?
-
final
- rateType → String?
-
final
- receiveDeliveryAddressType → String?
-
final
- receiveDeliveryBillPoFreightOnOrder → bool?
-
final
- receiveDeliveryCarrier → String?
-
final
- receiveDeliveryCarrierAccount → String?
-
final
- receiveDeliveryCarrierId → String?
-
final
- receiveDeliveryChargeType → String?
-
final
- receiveDeliveryDateStamp → String?
-
final
- receiveDeliveryDeliveryNotes → String?
-
final
- receiveDeliveryDeliveryType → String?
-
final
- receiveDeliveryDirection → String?
-
final
- receiveDeliveryDropShip → bool?
-
final
- receiveDeliveryEstimatedFreight → double?
-
final
- receiveDeliveryFreightInvoiceAmount → double?
-
final
- receiveDeliveryFreightTrackingNumber → String?
-
final
- receiveDeliveryFreightTrackingUrl → String?
-
final
- receiveDeliveryFromAdd2ress → String?
-
final
- receiveDeliveryFromAddress1 → String?
-
final
- receiveDeliveryFromAlternateContact → String?
-
final
- receiveDeliveryFromAlternateContactPhone → String?
-
final
- receiveDeliveryFromAttention → String?
-
final
- receiveDeliveryFromCity → String?
-
final
- receiveDeliveryFromContact → String?
-
final
- receiveDeliveryFromContactPhone → String?
-
final
- receiveDeliveryFromCountry → String?
-
final
- receiveDeliveryFromCountryId → String?
-
final
- receiveDeliveryFromCrossStreets → String?
-
final
- receiveDeliveryFromLocation → String?
-
final
- receiveDeliveryFromState → String?
-
final
- receiveDeliveryFromZipCode → String?
-
final
- receiveDeliveryId → String?
-
final
- receiveDeliveryInvoiceId → String?
-
final
- receiveDeliveryOnlineOrderNumber → String?
-
final
- receiveDeliveryOnlineOrderStatus → String?
-
final
- receiveDeliveryPackageCode → String?
-
final
- receiveDeliveryRequiredDate → String?
-
final
- receiveDeliveryRequiredTime → String?
-
final
- receiveDeliveryShipVia → String?
-
final
- receiveDeliveryShipViaId → String?
-
final
- receiveDeliveryTargetShipDate → String?
-
final
- receiveDeliveryTargetShipTime → String?
-
final
- receiveDeliveryToAddress1 → String?
-
final
- receiveDeliveryToAddress2 → String?
-
final
- receiveDeliveryToAlternateContact → String?
-
final
- receiveDeliveryToAlternateContactPhone → String?
-
final
- receiveDeliveryToAttention → String?
-
final
- receiveDeliveryToCity → String?
-
final
- receiveDeliveryToContact → String?
-
final
- receiveDeliveryToContactFax → String?
-
final
- receiveDeliveryToContactPhone → String?
-
final
- receiveDeliveryToCountry → String?
-
final
- receiveDeliveryToCountryId → String?
-
final
- receiveDeliveryToCrossStreets → String?
-
final
- receiveDeliveryToLocation → String?
-
final
- receiveDeliveryToState → String?
-
final
- receiveDeliveryToVenue → String?
-
final
- receiveDeliveryToVenueId → String?
-
final
- receiveDeliveryToWarehouse → String?
-
final
- receiveDeliveryToWarehouseId → String?
-
final
- receiveDeliveryToZipCode → String?
-
final
- receiveDeliveryVendorInvoiceId → String?
-
final
- recordTitle → String?
-
final
- referenceNumber → String?
-
final
- remitToAddress1 → String?
-
final
- remitToAddress2 → String?
-
final
- remitToAttention1 → String?
-
final
- remitToAttention2 → String?
-
final
- remitToCity → String?
-
final
- remitToCountry → String?
-
final
- remitToCountryId → String?
-
final
- remitToEmail → String?
-
final
- remitToPhone → String?
-
final
- remitToState → String?
-
final
- remitToZipCode → String?
-
final
- rental → bool?
-
final
- rentalDiscountPercent → double?
-
final
- rentalTaxRate1 → double?
-
final
- rentalTaxRate2 → double?
-
final
- rentalTotal → double?
-
final
- rentalTotalIncludesTax → bool?
-
final
- repair → bool?
-
final
- requisitionDate → String?
-
final
- requisitionNumber → String?
-
final
- returnDeliveryAddressType → String?
-
final
- returnDeliveryBillPoFreightOnOrder → bool?
-
final
- returnDeliveryCarrier → String?
-
final
- returnDeliveryCarrierAccount → String?
-
final
- returnDeliveryCarrierId → String?
-
final
- returnDeliveryChargeType → String?
-
final
- returnDeliveryDateStamp → String?
-
final
- returnDeliveryDeliveryNotes → String?
-
final
- returnDeliveryDeliveryType → String?
-
final
- returnDeliveryDirection → String?
-
final
- returnDeliveryEstimatedFreight → double?
-
final
- returnDeliveryFreightInvoiceAmount → double?
-
final
- returnDeliveryFreightTrackingNumber → String?
-
final
- returnDeliveryFreightTrackingUrl → String?
-
final
- returnDeliveryFromAdd2ress → String?
-
final
- returnDeliveryFromAddress1 → String?
-
final
- returnDeliveryFromAlternateContact → String?
-
final
- returnDeliveryFromAlternateContactPhone → String?
-
final
- returnDeliveryFromAttention → String?
-
final
- returnDeliveryFromCity → String?
-
final
- returnDeliveryFromContact → String?
-
final
- returnDeliveryFromContactPhone → String?
-
final
- returnDeliveryFromCountry → String?
-
final
- returnDeliveryFromCountryId → String?
-
final
- returnDeliveryFromCrossStreets → String?
-
final
- returnDeliveryFromLocation → String?
-
final
- returnDeliveryFromState → String?
-
final
- returnDeliveryFromZipCode → String?
-
final
- returnDeliveryId → String?
-
final
- returnDeliveryInvoiceId → String?
-
final
- returnDeliveryOnlineOrderNumber → String?
-
final
- returnDeliveryOnlineOrderStatus → String?
-
final
- returnDeliveryPackageCode → String?
-
final
- returnDeliveryRequiredDate → String?
-
final
- returnDeliveryRequiredTime → String?
-
final
- returnDeliveryShipVia → String?
-
final
- returnDeliveryShipViaId → String?
-
final
- returnDeliveryTargetShipDate → String?
-
final
- returnDeliveryTargetShipTime → String?
-
final
- returnDeliveryToAddress1 → String?
-
final
- returnDeliveryToAddress2 → String?
-
final
- returnDeliveryToAlternateContact → String?
-
final
- returnDeliveryToAlternateContactPhone → String?
-
final
- returnDeliveryToAttention → String?
-
final
- returnDeliveryToCity → String?
-
final
- returnDeliveryToContact → String?
-
final
- returnDeliveryToContactFax → String?
-
final
- returnDeliveryToContactPhone → String?
-
final
- returnDeliveryToCountry → String?
-
final
- returnDeliveryToCountryId → String?
-
final
- returnDeliveryToCrossStreets → String?
-
final
- returnDeliveryToLocation → String?
-
final
- returnDeliveryToState → String?
-
final
- returnDeliveryToVenue → String?
-
final
- returnDeliveryToVenueId → String?
-
final
- returnDeliveryToWarehouse → String?
-
final
- returnDeliveryToWarehouseId → String?
-
final
- returnDeliveryToZipCode → String?
-
final
- returnDeliveryVendorInvoiceId → String?
-
final
- returnDeliveryVendorRetrieve → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sales → bool?
-
final
- salesDiscountPercent → double?
-
final
- salesTaxRate1 → double?
-
final
- salesTaxRate2 → double?
-
final
- salesTotal → double?
-
final
- salesTotalIncludesTax → bool?
-
final
- status → String?
-
final
- statusColor → String?
-
final
- statusDate → String?
-
final
- subLabor → bool?
-
final
- subLaborDiscountPercent → double?
-
final
- subLaborIsComplete → bool?
-
final
- subMiscDiscountPercent → double?
-
final
- subMiscellaneous → bool?
-
final
- subMiscellaneousIsComplete → bool?
-
final
- subRent → bool?
-
final
- subRentalDaysPerWeek → double?
-
final
- subRentalDiscountPercent → double?
-
final
- subSale → bool?
-
final
- subSalesDiscountPercent → double?
-
final
- subSalesTotal → double?
-
final
- subSalesTotalIncludesTax → bool?
-
final
- subVehicle → bool?
-
final
- subVehicleDaysPerWeek → double?
-
final
- subvehicleDiscountPercent → double?
-
final
- tax1Name → String?
-
final
- tax2Name → String?
-
final
- taxId → String?
-
final
- taxOption → String?
-
final
- taxOptionId → String?
-
final
- termsConditions → String?
-
final
- termsConditionsId → String?
-
final
- total → double?
-
final
- updateAllRatesToNewCurrency → bool?
-
final
- vehicle → bool?
-
final
- vehicleDiscountPercent → double?
-
final
- vehicleTotal → double?
-
final
- vehicleTotalIncludesTax → bool?
-
final
- vendor → String?
-
final
- vendorColor → String?
-
final
- vendorHasConsignment → bool?
-
final
- vendorId → String?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
- weeklySubLaborTotal → double?
-
final
- weeklySubLaborTotalIncludesTax → bool?
-
final
- weeklySubMiscTotal → double?
-
final
- weeklySubMiscTotalIncludesTax → bool?
-
final
- weeklySubRentalTotal → double?
-
final
- weeklySubRentalTotalIncludesTax → bool?
-
final
- weeklySubVehicleTotal → double?
-
final
- weeklySubVehicleTotalIncludesTax → bool?
-
final
Methods
-
copyWith(
{String? purchaseOrderId, String? purchaseOrderNumber, String? description, String? purchaseOrderDate, String? requisitionNumber, String? requisitionDate, String? vendorId, String? vendor, String? agentId, String? agent, String? status, String? statusDate, String? referenceNumber, bool? needsApproval, String? approvedByUserId, String? departmentId, String? department, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, int? quantityHolding, int? quantityToBarCode, bool? rental, bool? sales, bool? parts, bool? labor, bool? miscellaneous, bool? vehicle, bool? subRent, bool? subSale, bool? subLabor, bool? subMiscellaneous, bool? subVehicle, bool? repair, bool? consignment, String? consignorAgreementId, String? consignorAgreementNumber, bool? vendorHasConsignment, String? orderId, String? orderNumber, String? dealNumber, String? dealId, String? deal, String? rateType, String? termsConditionsId, String? termsConditions, bool? departmentLocationRequiresApproval, double? total, String? poTypeId, String? poType, String? poClassificationId, String? poClassification, List< WebApiModulesHomeControlsOrderDatesOrderDates> ? activityDatesAndTimes, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, String? billingStartDate, String? billingEndDate, double? billingWeeks, double? billingMonths, double? invoicedAmount, String? projectManagerId, String? projectManager, String? receiveDeliveryId, String? receiveDeliveryDeliveryType, String? receiveDeliveryRequiredDate, String? receiveDeliveryRequiredTime, String? receiveDeliveryTargetShipDate, String? receiveDeliveryTargetShipTime, String? receiveDeliveryDirection, String? receiveDeliveryAddressType, String? receiveDeliveryFromLocation, String? receiveDeliveryFromContact, String? receiveDeliveryFromContactPhone, String? receiveDeliveryFromAlternateContact, String? receiveDeliveryFromAlternateContactPhone, String? receiveDeliveryFromAttention, String? receiveDeliveryFromAddress1, String? receiveDeliveryFromAdd2ress, String? receiveDeliveryFromCity, String? receiveDeliveryFromState, String? receiveDeliveryFromZipCode, String? receiveDeliveryFromCountry, String? receiveDeliveryFromCountryId, String? receiveDeliveryFromCrossStreets, String? receiveDeliveryToLocation, String? receiveDeliveryToVenue, String? receiveDeliveryToVenueId, String? receiveDeliveryToWarehouse, String? receiveDeliveryToWarehouseId, String? receiveDeliveryToContact, String? receiveDeliveryToContactPhone, String? receiveDeliveryToAlternateContact, String? receiveDeliveryToAlternateContactPhone, String? receiveDeliveryToAttention, String? receiveDeliveryToAddress1, String? receiveDeliveryToAddress2, String? receiveDeliveryToCity, String? receiveDeliveryToState, String? receiveDeliveryToZipCode, String? receiveDeliveryToCountryId, String? receiveDeliveryToCountry, String? receiveDeliveryToContactFax, String? receiveDeliveryToCrossStreets, String? receiveDeliveryDeliveryNotes, String? receiveDeliveryCarrierId, String? receiveDeliveryCarrier, String? receiveDeliveryCarrierAccount, String? receiveDeliveryShipViaId, String? receiveDeliveryShipVia, String? receiveDeliveryInvoiceId, String? receiveDeliveryVendorInvoiceId, double? receiveDeliveryEstimatedFreight, double? receiveDeliveryFreightInvoiceAmount, String? receiveDeliveryChargeType, String? receiveDeliveryFreightTrackingNumber, String? receiveDeliveryFreightTrackingUrl, bool? receiveDeliveryDropShip, String? receiveDeliveryPackageCode, bool? receiveDeliveryBillPoFreightOnOrder, String? receiveDeliveryOnlineOrderNumber, String? receiveDeliveryOnlineOrderStatus, String? receiveDeliveryDateStamp, String? returnDeliveryId, String? returnDeliveryDeliveryType, String? returnDeliveryRequiredDate, String? returnDeliveryRequiredTime, String? returnDeliveryTargetShipDate, String? returnDeliveryTargetShipTime, String? returnDeliveryDirection, String? returnDeliveryAddressType, String? returnDeliveryFromLocation, String? returnDeliveryFromContact, String? returnDeliveryFromContactPhone, String? returnDeliveryFromAlternateContact, String? returnDeliveryFromAlternateContactPhone, String? returnDeliveryFromAttention, String? returnDeliveryFromAddress1, String? returnDeliveryFromAdd2ress, String? returnDeliveryFromCity, String? returnDeliveryFromState, String? returnDeliveryFromZipCode, String? returnDeliveryFromCountry, String? returnDeliveryFromCountryId, String? returnDeliveryFromCrossStreets, String? returnDeliveryToLocation, String? returnDeliveryToVenue, String? returnDeliveryToVenueId, String? returnDeliveryToWarehouse, String? returnDeliveryToWarehouseId, String? returnDeliveryToContact, String? returnDeliveryToContactPhone, String? returnDeliveryToAlternateContact, String? returnDeliveryToAlternateContactPhone, String? returnDeliveryToAttention, String? returnDeliveryToAddress1, String? returnDeliveryToAddress2, String? returnDeliveryToCity, String? returnDeliveryToState, String? returnDeliveryToZipCode, String? returnDeliveryToCountryId, String? returnDeliveryToCountry, String? returnDeliveryToContactFax, String? returnDeliveryToCrossStreets, String? returnDeliveryDeliveryNotes, String? returnDeliveryCarrierId, String? returnDeliveryCarrier, String? returnDeliveryCarrierAccount, String? returnDeliveryShipViaId, String? returnDeliveryShipVia, String? returnDeliveryInvoiceId, String? returnDeliveryVendorInvoiceId, double? returnDeliveryEstimatedFreight, double? returnDeliveryFreightInvoiceAmount, String? returnDeliveryChargeType, String? returnDeliveryFreightTrackingNumber, String? returnDeliveryFreightTrackingUrl, bool? returnDeliveryVendorRetrieve, String? returnDeliveryPackageCode, bool? returnDeliveryBillPoFreightOnOrder, String? returnDeliveryOnlineOrderNumber, String? returnDeliveryOnlineOrderStatus, String? returnDeliveryDateStamp, bool? enableProjects, String? projectId, String? projectNumber, String? project, String? projectDrawingsId, String? projectDrawings, String? projectItemsOrderedId, String? projectItemsOrdered, String? projectDropShipId, String? projectDropShip, String? projectAsBuildId, String? projectAsBuild, String? projectCommissioningId, String? projectCommissioning, String? projectDepositId, String? projectDeposit, String? location, String? currencyId, bool? updateAllRatesToNewCurrency, String? confirmUpdateAllRatesToNewCurrency, String? currencyCode, String? currency, String? currencySymbol, String? billingCycleId, String? billingCycle, String? remitToAttention1, String? remitToAttention2, String? remitToAddress1, String? remitToAddress2, String? remitToCity, String? remitToState, String? remitToCountryId, String? remitToCountry, String? remitToZipCode, String? remitToEmail, String? remitToPhone, String? paymentTypeId, String? paymentType, String? paymentTermsId, String? paymentTerms, int? paymentTermsDueInDays, String? taxOptionId, String? taxOption, String? taxId, String? tax1Name, String? tax2Name, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, bool? hasLossAndDamageItem, bool? hasRentalSaleItem, bool? hasConsignItem, bool? hasPartsItem, double? rentalDiscountPercent, double? rentalTotal, bool? rentalTotalIncludesTax, double? salesDiscountPercent, double? salesTotal, bool? salesTotalIncludesTax, double? partsDiscountPercent, double? partsTotal, bool? partsTotalIncludesTax, double? vehicleDiscountPercent, double? vehicleTotal, bool? vehicleTotalIncludesTax, double? miscDiscountPercent, double? miscTotal, bool? miscTotalIncludesTax, double? laborDiscountPercent, double? laborTotal, bool? laborTotalIncludesTax, double? subRentalDaysPerWeek, double? subRentalDiscountPercent, double? weeklySubRentalTotal, double? monthlySubRentalTotal, double? periodSubRentalTotal, bool? weeklySubRentalTotalIncludesTax, bool? monthlySubRentalTotalIncludesTax, bool? periodSubRentalTotalIncludesTax, double? subSalesDiscountPercent, double? subSalesTotal, bool? subSalesTotalIncludesTax, double? subVehicleDaysPerWeek, double? subvehicleDiscountPercent, double? weeklySubVehicleTotal, double? monthlySubVehicleTotal, double? periodSubVehicleTotal, bool? weeklySubVehicleTotalIncludesTax, bool? monthlySubVehicleTotalIncludesTax, bool? periodSubVehicleTotalIncludesTax, double? subMiscDiscountPercent, double? weeklySubMiscTotal, double? monthlySubMiscTotal, double? periodSubMiscTotal, bool? weeklySubMiscTotalIncludesTax, bool? monthlySubMiscTotalIncludesTax, bool? periodSubMiscTotalIncludesTax, double? subLaborDiscountPercent, double? weeklySubLaborTotal, double? monthlySubLaborTotal, double? periodSubLaborTotal, bool? weeklySubLaborTotalIncludesTax, bool? monthlySubLaborTotalIncludesTax, bool? periodSubLaborTotalIncludesTax, bool? miscellaneousIsComplete, bool? subMiscellaneousIsComplete, bool? laborIsComplete, bool? subLaborIsComplete, String? currencyColor, String? statusColor, String? purchaseOrderNumberColor, String? vendorColor, String? descriptionColor, String? expensePOColor, bool? hasConsignorFee, bool? hasOrdertran, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<WebApiModulesHomeControlsOrderItemOrderItem> ? items, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponse -
Available on WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponse, provided by the $WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentPurchaseOrderGetPurchaseOrderResponse instance)