WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequest({String? purchaseOrderNumber, String? userEmail, String? rejectionReason, String? rejectionNote})
const
WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
purchaseOrderNumber String?
final
rejectionNote String?
final
rejectionReason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userEmail String?
final

Methods

copyWith({String? purchaseOrderNumber, String? userEmail, String? rejectionReason, String? rejectionNote}) WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequest

Available on WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequest, provided by the $WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequestExtension extension

copyWithWrapped({Wrapped<String?>? purchaseOrderNumber, Wrapped<String?>? userEmail, Wrapped<String?>? rejectionReason, Wrapped<String?>? rejectionNote}) WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequest

Available on WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequest, provided by the $WebApiModulesAgentPurchaseOrderKissFlowPoRejectRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override