WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCode class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCode({int? purchaseOrderReceiveBarCodeId, String? barCode, String? inspectionNumber, String? inspectionVendorId, String? inspectionVendor, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, String? purchaseOrderItemId, String? purchaseOrderId, int? orderTranId, String? internalChar, String? receiveContractId, String? receiveContractNumber, String? returnContractId, String? inventoryId, String? scannableBarCode, String? iCode, String? description, String? iCodeDescription, String? packingSlipNumber, String? warehouseId, String? itemId, String? purchaseId, String? availableFor, String? availableForDisplay, String? trackedBy, bool? serialNumberIsMixedCase, String? itemOrder, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCode.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
availableFor String?
final
availableForDisplay String?
final
barCode String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
iCodeDescription String?
final
inspectionNumber String?
final
inspectionVendor String?
final
inspectionVendorId String?
final
internalChar String?
final
inventoryId String?
final
itemId String?
final
itemOrder String?
final
manufactureDate String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderTranId int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
packingSlipNumber String?
final
printQuantity int?
final
purchaseId String?
final
purchaseOrderId String?
final
purchaseOrderItemId String?
final
purchaseOrderReceiveBarCodeId int?
final
receiveContractId String?
final
receiveContractNumber String?
final
recordTitle String?
final
returnContractId String?
final
rfId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scannableBarCode String?
final
serialNumber String?
final
serialNumberIsMixedCase bool?
final
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouseId String?
final

Methods

copyWith({int? purchaseOrderReceiveBarCodeId, String? barCode, String? inspectionNumber, String? inspectionVendorId, String? inspectionVendor, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, String? purchaseOrderItemId, String? purchaseOrderId, int? orderTranId, String? internalChar, String? receiveContractId, String? receiveContractNumber, String? returnContractId, String? inventoryId, String? scannableBarCode, String? iCode, String? description, String? iCodeDescription, String? packingSlipNumber, String? warehouseId, String? itemId, String? purchaseId, String? availableFor, String? availableForDisplay, String? trackedBy, bool? serialNumberIsMixedCase, String? itemOrder, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCode

Available on WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCode, provided by the $WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCodeExtension extension

copyWithWrapped({Wrapped<int?>? purchaseOrderReceiveBarCodeId, Wrapped<String?>? barCode, Wrapped<String?>? inspectionNumber, Wrapped<String?>? inspectionVendorId, Wrapped<String?>? inspectionVendor, Wrapped<String?>? manufactureDate, Wrapped<int?>? printQuantity, Wrapped<String?>? serialNumber, Wrapped<String?>? rfId, Wrapped<String?>? purchaseOrderItemId, Wrapped<String?>? purchaseOrderId, Wrapped<int?>? orderTranId, Wrapped<String?>? internalChar, Wrapped<String?>? receiveContractId, Wrapped<String?>? receiveContractNumber, Wrapped<String?>? returnContractId, Wrapped<String?>? inventoryId, Wrapped<String?>? scannableBarCode, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? iCodeDescription, Wrapped<String?>? packingSlipNumber, Wrapped<String?>? warehouseId, Wrapped<String?>? itemId, Wrapped<String?>? purchaseId, Wrapped<String?>? availableFor, Wrapped<String?>? availableForDisplay, Wrapped<String?>? trackedBy, Wrapped<bool?>? serialNumberIsMixedCase, Wrapped<String?>? itemOrder, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCode

Available on WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCode, provided by the $WebApiModulesAgentPurchaseOrderReceiveBarCodePurchaseOrderReceiveBarCodeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override