WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode({int? purchaseOrderReturnBarCodeId, String? barCode, String? inspectionNumber, String? inspectionVendorId, String? inspectionVendor, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, String? purchaseOrderItemId, String? purchaseOrderId, int? orderTranId, String? internalChar, String? returnContractId, String? inventoryId, String? scannableBarCode, String? iCode, String? description, String? iCodeDescription, String? packingSlipNumber, String? warehouseId, String? itemId, String? purchaseId, String? availableFor, String? availableForDisplay, String? trackedBy, bool? serialNumberIsMixedCase, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- availableFor → String?
-
final
- availableForDisplay → String?
-
final
- barCode → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- iCode → String?
-
final
- iCodeDescription → String?
-
final
- inspectionNumber → String?
-
final
- inspectionVendor → String?
-
final
- inspectionVendorId → String?
-
final
- internalChar → String?
-
final
- inventoryId → String?
-
final
- itemId → String?
-
final
- manufactureDate → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- orderTranId → int?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- packingSlipNumber → String?
-
final
- printQuantity → int?
-
final
- purchaseId → String?
-
final
- purchaseOrderId → String?
-
final
- purchaseOrderItemId → String?
-
final
- purchaseOrderReturnBarCodeId → int?
-
final
- recordTitle → String?
-
final
- returnContractId → String?
-
final
- rfId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannableBarCode → String?
-
final
- serialNumber → String?
-
final
- serialNumberIsMixedCase → bool?
-
final
- trackedBy → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{int? purchaseOrderReturnBarCodeId, String? barCode, String? inspectionNumber, String? inspectionVendorId, String? inspectionVendor, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, String? purchaseOrderItemId, String? purchaseOrderId, int? orderTranId, String? internalChar, String? returnContractId, String? inventoryId, String? scannableBarCode, String? iCode, String? description, String? iCodeDescription, String? packingSlipNumber, String? warehouseId, String? itemId, String? purchaseId, String? availableFor, String? availableForDisplay, String? trackedBy, bool? serialNumberIsMixedCase, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode -
Available on WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode, provided by the $WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCodeExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? purchaseOrderReturnBarCodeId, Wrapped<String?> ? barCode, Wrapped<String?> ? inspectionNumber, Wrapped<String?> ? inspectionVendorId, Wrapped<String?> ? inspectionVendor, Wrapped<String?> ? manufactureDate, Wrapped<int?> ? printQuantity, Wrapped<String?> ? serialNumber, Wrapped<String?> ? rfId, Wrapped<String?> ? purchaseOrderItemId, Wrapped<String?> ? purchaseOrderId, Wrapped<int?> ? orderTranId, Wrapped<String?> ? internalChar, Wrapped<String?> ? returnContractId, Wrapped<String?> ? inventoryId, Wrapped<String?> ? scannableBarCode, Wrapped<String?> ? iCode, Wrapped<String?> ? description, Wrapped<String?> ? iCodeDescription, Wrapped<String?> ? packingSlipNumber, Wrapped<String?> ? warehouseId, Wrapped<String?> ? itemId, Wrapped<String?> ? purchaseId, Wrapped<String?> ? availableFor, Wrapped<String?> ? availableForDisplay, Wrapped<String?> ? trackedBy, Wrapped<bool?> ? serialNumberIsMixedCase, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode -
Available on WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode, provided by the $WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCodeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentPurchaseOrderReturnBarCodePurchaseOrderReturnBarCode instance)