WebApiModulesAgentPurchaseOrderReturnItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentPurchaseOrderReturnItemRequest({String? contractId, String? purchaseOrderId, String? purchaseOrderItemId, int? quantity, String? barCode})
WebApiModulesAgentPurchaseOrderReturnItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

barCode String?
final
contractId String?
final
hashCode int
The hash code for this object.
no setteroverride
purchaseOrderId String?
final
purchaseOrderItemId String?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? contractId, String? purchaseOrderId, String? purchaseOrderItemId, int? quantity, String? barCode}) WebApiModulesAgentPurchaseOrderReturnItemRequest

Available on WebApiModulesAgentPurchaseOrderReturnItemRequest, provided by the $WebApiModulesAgentPurchaseOrderReturnItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override