WebApiModulesAgentQuoteQuote class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentQuoteQuote({String? quoteId, String? quoteNumber, String? quoteDate, int? versionNumber, String? convertedToOrderId, String? convertedToOrderNumber, bool? convertedToOrder, String? description, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, String? departmentId, String? department, String? customerId, String? customer, String? customerNumber, String? dealId, String? deal, String? dealNumber, String? rateType, String? rateTypeDisplay, String? agentId, String? agent, String? projectManagerId, String? projectManager, bool? rental, bool? sales, bool? miscellaneous, bool? labor, bool? facilities, bool? transportation, bool? rentalSale, bool? lossAndDamage, bool? repair, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, bool? hasLossAndDamageItem, bool? hasRentalSaleItem, bool? hasRepair, List<
WebApiModulesHomeControlsOrderDatesOrderDates> ? activityDatesAndTimes, String? pickDate, String? pickTime, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, String? pickUpDate, String? pickUpTime, String? prepDate, String? prepTime, String? loadInDate, String? loadInTime, String? strikeDate, String? strikeTime, String? testDate, String? testTime, String? orderTypeId, String? orderType, bool? orderTypeCombineActivityTabs, bool? pendingPo, String? poNumber, double? poAmount, String? location, String? orderLocationId, String? orderLocation, String? referenceNumber, double? total, String? status, String? statusDate, String? poApprovalStatusId, bool? lockBillingDates, bool? specifyBillingDatesByType, String? rentalBillingStartDate, String? rentalBillingEndDate, String? laborBillingStartDate, String? laborBillingEndDate, String? miscellaneousBillingStartDate, String? miscellaneousBillingEndDate, String? facilitiesBillingStartDate, String? facilitiesBillingEndDate, String? vehicleBillingStartDate, String? vehicleBillingEndDate, String? delayBillingSearchUntil, bool? includePrepFeesInRentalRate, String? billingStartDate, String? billingEndDate, double? billingWeeks, double? billingMonths, String? determineQuantitiesToBillBasedOn, String? billingCycleId, String? billingCycle, String? billingCycleType, String? paymentTermsId, String? paymentTerms, String? paymentTypeId, String? paymentType, String? currencyId, bool? updateAllRatesToNewCurrency, String? confirmUpdateAllRatesToNewCurrency, String? currencyCode, String? currency, String? currencySymbol, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, String? taxId, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, bool? noCharge, String? noChargeReason, String? printIssuedToAddressFrom, String? issuedToName, String? issuedToAttention, String? issuedToAttention2, String? issuedToAddress1, String? issuedToAddress2, String? issuedToCity, String? issuedToState, String? issuedToZipCode, String? issuedToCountryId, String? issuedToCountry, bool? billToAddressDifferentFromIssuedToAddress, String? billToAddressId, String? billToName, String? billToAttention, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountryId, String? billToCountry, String? discountReasonId, String? discountReason, bool? requireContactConfirmation, bool? includeInBillingAnalysis, String? hiatusDiscountFrom, bool? roundTripRentals, bool? inGroup, int? groupNumber, int? groupColor, double? groupOrderBy, String? coverLetterId, String? coverLetter, String? termsConditionsId, String? termsConditions, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, String? marketTypeId, String? marketType, String? marketSegmentId, String? marketSegment, String? marketSegmentJobId, String? marketSegmentJob, String? outDeliveryId, String? outDeliveryDeliveryType, String? outDeliveryRequiredDate, String? outDeliveryRequiredTime, String? outDeliveryTargetShipDate, String? outDeliveryTargetShipTime, String? outDeliveryDirection, String? outDeliveryAddressType, String? outDeliveryFromLocation, String? outDeliveryFromContact, String? outDeliveryFromContactPhone, String? outDeliveryFromAlternateContact, String? outDeliveryFromAlternateContactPhone, String? outDeliveryFromAttention, String? outDeliveryFromAddress1, String? outDeliveryFromAdd2ress, String? outDeliveryFromCity, String? outDeliveryFromState, String? outDeliveryFromZipCode, String? outDeliveryFromCountry, String? outDeliveryFromCountryId, String? outDeliveryFromCrossStreets, String? outDeliveryToLocation, String? outDeliveryToContact, String? outDeliveryToContactPhone, String? outDeliveryToAlternateContact, String? outDeliveryToAlternateContactPhone, String? outDeliveryToAttention, String? outDeliveryToAddress1, String? outDeliveryToAddress2, String? outDeliveryToCity, String? outDeliveryToState, String? outDeliveryToZipCode, String? outDeliveryToCountryId, String? outDeliveryToCountry, String? outDeliveryToContactFax, String? outDeliveryToCrossStreets, String? outDeliveryDeliveryNotes, String? outDeliveryCarrierId, String? outDeliveryCarrier, String? outDeliveryCarrierAccount, String? outDeliveryShipViaId, String? outDeliveryShipVia, String? outDeliveryInvoiceId, String? outDeliveryVendorInvoiceId, double? outDeliveryEstimatedFreight, double? outDeliveryFreightInvoiceAmount, String? outDeliveryChargeType, String? outDeliveryFreightTrackingNumber, String? outDeliveryFreightTrackingUrl, String? outDeliveryPackageCode, bool? outDeliveryBillPoFreightOnOrder, String? outDeliveryOnlineOrderNumber, String? outDeliveryToVenue, String? outDeliveryToVenueId, String? outDeliveryToWarehouse, String? outDeliveryToWarehouseId, String? outDeliveryDateStamp, String? inDeliveryId, String? inDeliveryDeliveryType, String? inDeliveryRequiredDate, String? inDeliveryRequiredTime, String? inDeliveryTargetShipDate, String? inDeliveryTargetShipTime, String? inDeliveryDirection, String? inDeliveryAddressType, String? inDeliveryFromLocation, String? inDeliveryFromContact, String? inDeliveryFromContactPhone, String? inDeliveryFromAlternateContact, String? inDeliveryFromAlternateContactPhone, String? inDeliveryFromAttention, String? inDeliveryFromAddress1, String? inDeliveryFromAdd2ress, String? inDeliveryFromCity, String? inDeliveryFromState, String? inDeliveryFromZipCode, String? inDeliveryFromCountry, String? inDeliveryFromCountryId, String? inDeliveryFromCrossStreets, String? inDeliveryToLocation, String? inDeliveryToContact, String? inDeliveryToContactPhone, String? inDeliveryToAlternateContact, String? inDeliveryToAlternateContactPhone, String? inDeliveryToAttention, String? inDeliveryToAddress1, String? inDeliveryToAddress2, String? inDeliveryToCity, String? inDeliveryToState, String? inDeliveryToZipCode, String? inDeliveryToCountryId, String? inDeliveryToCountry, String? inDeliveryToContactFax, String? inDeliveryToCrossStreets, String? inDeliveryDeliveryNotes, String? inDeliveryCarrierId, String? inDeliveryCarrier, String? inDeliveryCarrierAccount, String? inDeliveryShipViaId, String? inDeliveryShipVia, String? inDeliveryInvoiceId, String? inDeliveryVendorInvoiceId, double? inDeliveryEstimatedFreight, double? inDeliveryFreightInvoiceAmount, String? inDeliveryChargeType, String? inDeliveryFreightTrackingNumber, String? inDeliveryFreightTrackingUrl, String? inDeliveryPackageCode, bool? inDeliveryBillPoFreightOnOrder, String? inDeliveryOnlineOrderNumber, String? inDeliveryOnlineOrderStatus, String? inDeliveryToVenue, String? inDeliveryToVenueId, String? inDeliveryToWarehouse, String? inDeliveryToWarehouseId, String? inDeliveryDateStamp, double? rentalDaysPerWeek, double? rentalDiscountPercent, double? weeklyRentalTotal, double? monthlyRentalTotal, double? periodRentalTotal, bool? weeklyRentalTotalIncludesTax, bool? monthlyRentalTotalIncludesTax, bool? periodRentalTotalIncludesTax, bool? billLockedTotal, double? salesDiscountPercent, double? salesTotal, bool? salesTotalIncludesTax, double? partsDiscountPercent, double? partsTotal, bool? partsTotalIncludesTax, double? spaceDaysPerWeek, double? spaceDiscountPercent, double? spaceSplitPercent, double? weeklySpaceTotal, double? monthlySpaceTotal, double? periodSpaceTotal, bool? weeklySpaceTotalIncludesTax, bool? monthlySpaceTotalIncludesTax, bool? periodSpaceTotalIncludesTax, double? vehicleDaysPerWeek, double? vehicleDiscountPercent, double? weeklyVehicleTotal, double? monthlyVehicleTotal, double? periodVehicleTotal, bool? weeklyVehicleTotalIncludesTax, bool? monthlyVehicleTotalIncludesTax, bool? periodVehicleTotalIncludesTax, double? miscDiscountPercent, double? weeklyMiscTotal, double? monthlyMiscTotal, double? periodMiscTotal, bool? weeklyMiscTotalIncludesTax, bool? monthlyMiscTotalIncludesTax, bool? periodMiscTotalIncludesTax, double? laborDiscountPercent, double? weeklyLaborTotal, double? monthlyLaborTotal, double? periodLaborTotal, bool? weeklyLaborTotalIncludesTax, bool? monthlyLaborTotalIncludesTax, bool? periodLaborTotalIncludesTax, double? rentalSaleDiscountPercent, double? rentalSaleTotal, bool? rentalSaleTotalIncludesTax, double? lossAndDamageDiscountPercent, double? lossAndDamageTotal, bool? lossAndDamageTotalIncludesTax, double? combinedDaysPerWeek, double? combinedDiscountPercent, double? weeklyCombinedTotal, double? monthlyCombinedTotal, double? periodCombinedTotal, bool? weeklyCombinedTotalIncludesTax, bool? monthlyCombinedTotalIncludesTax, bool? periodCombinedTotalIncludesTax, bool? disableEditingRentalRate, bool? disableEditingSalesRate, bool? disableEditingMiscellaneousRate, bool? disableEditingLaborRate, bool? disableEditingRentalSaleRate, bool? disableEditingLossAndDamageRate, double? rentalExtendedTotal, double? salesExtendedTotal, double? laborExtendedTotal, double? miscellaneousExtendedTotal, double? rentalSaleExtendedTotal, double? lossAndDamageExtendedTotal, bool? hasNotes, bool? hasDocuments, bool? hasEmailHistory, bool? hasContacts, bool? hasSubPurchaseOrders, bool? hasPickLists, bool? hasContracts, bool? hasSuspendedContracts, bool? hasMultiOrderContracts, bool? hasInvoices, bool? hasBillingWorksheets, bool? hasMultiOrderInvoices, bool? hasSnapshots, double? totalReplacementCost, String? presentationLayerId, String? presentationLayer, bool? isManualSort, String? quoteOrderTitle, bool? unassignedSubs, bool? nonTaxable, bool? enableProjects, String? projectId, String? projectNumber, String? project, String? projectDrawingsId, String? projectDrawings, String? projectItemsOrderedId, String? projectItemsOrdered, String? projectDropShipId, String? projectDropShip, String? projectAsBuildId, String? projectAsBuild, String? projectCommissioningId, String? projectCommissioning, String? projectDepositId, String? projectDeposit, String? inputByUserId, String? modifiedByUserId, bool? useEstimatedDatesForBilling, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesAgentQuoteQuote.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
activityDatesAndTimes
→ List<
WebApiModulesHomeControlsOrderDatesOrderDates> ? -
final
- agent → String?
-
final
- agentId → String?
-
final
- auditNote → String?
-
final
- billingCycle → String?
-
final
- billingCycleId → String?
-
final
- billingCycleType → String?
-
final
- billingEndDate → String?
-
final
- billingMonths → double?
-
final
- billingStartDate → String?
-
final
- billingWeeks → double?
-
final
- billLockedTotal → bool?
-
final
- billToAddress1 → String?
-
final
- billToAddress2 → String?
-
final
- billToAddressDifferentFromIssuedToAddress → bool?
-
final
- billToAddressId → String?
-
final
- billToAttention → String?
-
final
- billToAttention2 → String?
-
final
- billToCity → String?
-
final
- billToCountry → String?
-
final
- billToCountryId → String?
-
final
- billToName → String?
-
final
- billToState → String?
-
final
- billToZipCode → String?
-
final
- combinedDaysPerWeek → double?
-
final
- combinedDiscountPercent → double?
-
final
- confirmUpdateAllRatesToNewCurrency → String?
-
final
- convertedToOrder → bool?
-
final
- convertedToOrderId → String?
-
final
- convertedToOrderNumber → String?
-
final
- coverLetter → String?
-
final
- coverLetterId → String?
-
final
- currency → String?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerId → String?
-
final
- customerNumber → String?
-
final
- dateStamp → String?
-
final
- deal → String?
-
final
- dealId → String?
-
final
- dealNumber → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- delayBillingSearchUntil → String?
-
final
- department → String?
-
final
- departmentId → String?
-
final
- description → String?
-
final
- determineQuantitiesToBillBasedOn → String?
-
final
- disableEditingLaborRate → bool?
-
final
- disableEditingLossAndDamageRate → bool?
-
final
- disableEditingMiscellaneousRate → bool?
-
final
- disableEditingRentalRate → bool?
-
final
- disableEditingRentalSaleRate → bool?
-
final
- disableEditingSalesRate → bool?
-
final
- discountReason → String?
-
final
- discountReasonId → String?
-
final
- enableProjects → bool?
-
final
- estimatedStartDate → String?
-
final
- estimatedStartTime → String?
-
final
- estimatedStopDate → String?
-
final
- estimatedStopTime → String?
-
final
- facilities → bool?
-
final
- facilitiesBillingEndDate → String?
-
final
- facilitiesBillingStartDate → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- groupColor → int?
-
final
- groupNumber → int?
-
final
- groupOrderBy → double?
-
final
- hasBillingWorksheets → bool?
-
final
- hasContacts → bool?
-
final
- hasContracts → bool?
-
final
- hasDocuments → bool?
-
final
- hasEmailHistory → bool?
-
final
- hasFacilitiesItem → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasInvoices → bool?
-
final
- hasLaborItem → bool?
-
final
- hasLossAndDamageItem → bool?
-
final
- hasMiscellaneousItem → bool?
-
final
- hasMultiOrderContracts → bool?
-
final
- hasMultiOrderInvoices → bool?
-
final
- hasNotes → bool?
-
final
- hasPickLists → bool?
-
final
- hasRentalItem → bool?
-
final
- hasRentalSaleItem → bool?
-
final
- hasRepair → bool?
-
final
- hasSalesItem → bool?
-
final
- hasSnapshots → bool?
-
final
- hasSubPurchaseOrders → bool?
-
final
- hasSuspendedContracts → bool?
-
final
- hiatusDiscountFrom → String?
-
final
- includeInBillingAnalysis → bool?
-
final
- includePrepFeesInRentalRate → bool?
-
final
- inDeliveryAddressType → String?
-
final
- inDeliveryBillPoFreightOnOrder → bool?
-
final
- inDeliveryCarrier → String?
-
final
- inDeliveryCarrierAccount → String?
-
final
- inDeliveryCarrierId → String?
-
final
- inDeliveryChargeType → String?
-
final
- inDeliveryDateStamp → String?
-
final
- inDeliveryDeliveryNotes → String?
-
final
- inDeliveryDeliveryType → String?
-
final
- inDeliveryDirection → String?
-
final
- inDeliveryEstimatedFreight → double?
-
final
- inDeliveryFreightInvoiceAmount → double?
-
final
- inDeliveryFreightTrackingNumber → String?
-
final
- inDeliveryFreightTrackingUrl → String?
-
final
- inDeliveryFromAdd2ress → String?
-
final
- inDeliveryFromAddress1 → String?
-
final
- inDeliveryFromAlternateContact → String?
-
final
- inDeliveryFromAlternateContactPhone → String?
-
final
- inDeliveryFromAttention → String?
-
final
- inDeliveryFromCity → String?
-
final
- inDeliveryFromContact → String?
-
final
- inDeliveryFromContactPhone → String?
-
final
- inDeliveryFromCountry → String?
-
final
- inDeliveryFromCountryId → String?
-
final
- inDeliveryFromCrossStreets → String?
-
final
- inDeliveryFromLocation → String?
-
final
- inDeliveryFromState → String?
-
final
- inDeliveryFromZipCode → String?
-
final
- inDeliveryId → String?
-
final
- inDeliveryInvoiceId → String?
-
final
- inDeliveryOnlineOrderNumber → String?
-
final
- inDeliveryOnlineOrderStatus → String?
-
final
- inDeliveryPackageCode → String?
-
final
- inDeliveryRequiredDate → String?
-
final
- inDeliveryRequiredTime → String?
-
final
- inDeliveryShipVia → String?
-
final
- inDeliveryShipViaId → String?
-
final
- inDeliveryTargetShipDate → String?
-
final
- inDeliveryTargetShipTime → String?
-
final
- inDeliveryToAddress1 → String?
-
final
- inDeliveryToAddress2 → String?
-
final
- inDeliveryToAlternateContact → String?
-
final
- inDeliveryToAlternateContactPhone → String?
-
final
- inDeliveryToAttention → String?
-
final
- inDeliveryToCity → String?
-
final
- inDeliveryToContact → String?
-
final
- inDeliveryToContactFax → String?
-
final
- inDeliveryToContactPhone → String?
-
final
- inDeliveryToCountry → String?
-
final
- inDeliveryToCountryId → String?
-
final
- inDeliveryToCrossStreets → String?
-
final
- inDeliveryToLocation → String?
-
final
- inDeliveryToState → String?
-
final
- inDeliveryToVenue → String?
-
final
- inDeliveryToVenueId → String?
-
final
- inDeliveryToWarehouse → String?
-
final
- inDeliveryToWarehouseId → String?
-
final
- inDeliveryToZipCode → String?
-
final
- inDeliveryVendorInvoiceId → String?
-
final
- inGroup → bool?
-
final
- inputByUserId → String?
-
final
- isManualSort → bool?
-
final
- issuedToAddress1 → String?
-
final
- issuedToAddress2 → String?
-
final
- issuedToAttention → String?
-
final
- issuedToAttention2 → String?
-
final
- issuedToCity → String?
-
final
- issuedToCountry → String?
-
final
- issuedToCountryId → String?
-
final
- issuedToName → String?
-
final
- issuedToState → String?
-
final
- issuedToZipCode → String?
-
final
- labor → bool?
-
final
- laborBillingEndDate → String?
-
final
- laborBillingStartDate → String?
-
final
- laborDiscountPercent → double?
-
final
- laborExtendedTotal → double?
-
final
- laborTaxRate1 → double?
-
final
- laborTaxRate2 → double?
-
final
- loadInDate → String?
-
final
- loadInTime → String?
-
final
- location → String?
-
final
- lockBillingDates → bool?
-
final
- lossAndDamage → bool?
-
final
- lossAndDamageDiscountPercent → double?
-
final
- lossAndDamageExtendedTotal → double?
-
final
- lossAndDamageTotal → double?
-
final
- lossAndDamageTotalIncludesTax → bool?
-
final
- marketSegment → String?
-
final
- marketSegmentId → String?
-
final
- marketSegmentJob → String?
-
final
- marketSegmentJobId → String?
-
final
- marketType → String?
-
final
- marketTypeId → String?
-
final
- miscDiscountPercent → double?
-
final
- miscellaneous → bool?
-
final
- miscellaneousBillingEndDate → String?
-
final
- miscellaneousBillingStartDate → String?
-
final
- miscellaneousExtendedTotal → double?
-
final
- modifiedByUserId → String?
-
final
- monthlyCombinedTotal → double?
-
final
- monthlyCombinedTotalIncludesTax → bool?
-
final
- monthlyLaborTotal → double?
-
final
- monthlyLaborTotalIncludesTax → bool?
-
final
- monthlyMiscTotal → double?
-
final
- monthlyMiscTotalIncludesTax → bool?
-
final
- monthlyRentalTotal → double?
-
final
- monthlyRentalTotalIncludesTax → bool?
-
final
- monthlySpaceTotal → double?
-
final
- monthlySpaceTotalIncludesTax → bool?
-
final
- monthlyVehicleTotal → double?
-
final
- monthlyVehicleTotalIncludesTax → bool?
-
final
- noCharge → bool?
-
final
- noChargeReason → String?
-
final
- nonTaxable → bool?
-
final
- officeLocation → String?
-
final
- officeLocationId → String?
-
final
- orderLocation → String?
-
final
- orderLocationId → String?
-
final
- orderType → String?
-
final
- orderTypeCombineActivityTabs → bool?
-
final
- orderTypeId → String?
-
final
- outDeliveryAddressType → String?
-
final
- outDeliveryBillPoFreightOnOrder → bool?
-
final
- outDeliveryCarrier → String?
-
final
- outDeliveryCarrierAccount → String?
-
final
- outDeliveryCarrierId → String?
-
final
- outDeliveryChargeType → String?
-
final
- outDeliveryDateStamp → String?
-
final
- outDeliveryDeliveryNotes → String?
-
final
- outDeliveryDeliveryType → String?
-
final
- outDeliveryDirection → String?
-
final
- outDeliveryEstimatedFreight → double?
-
final
- outDeliveryFreightInvoiceAmount → double?
-
final
- outDeliveryFreightTrackingNumber → String?
-
final
- outDeliveryFreightTrackingUrl → String?
-
final
- outDeliveryFromAdd2ress → String?
-
final
- outDeliveryFromAddress1 → String?
-
final
- outDeliveryFromAlternateContact → String?
-
final
- outDeliveryFromAlternateContactPhone → String?
-
final
- outDeliveryFromAttention → String?
-
final
- outDeliveryFromCity → String?
-
final
- outDeliveryFromContact → String?
-
final
- outDeliveryFromContactPhone → String?
-
final
- outDeliveryFromCountry → String?
-
final
- outDeliveryFromCountryId → String?
-
final
- outDeliveryFromCrossStreets → String?
-
final
- outDeliveryFromLocation → String?
-
final
- outDeliveryFromState → String?
-
final
- outDeliveryFromZipCode → String?
-
final
- outDeliveryId → String?
-
final
- outDeliveryInvoiceId → String?
-
final
- outDeliveryOnlineOrderNumber → String?
-
final
- outDeliveryPackageCode → String?
-
final
- outDeliveryRequiredDate → String?
-
final
- outDeliveryRequiredTime → String?
-
final
- outDeliveryShipVia → String?
-
final
- outDeliveryShipViaId → String?
-
final
- outDeliveryTargetShipDate → String?
-
final
- outDeliveryTargetShipTime → String?
-
final
- outDeliveryToAddress1 → String?
-
final
- outDeliveryToAddress2 → String?
-
final
- outDeliveryToAlternateContact → String?
-
final
- outDeliveryToAlternateContactPhone → String?
-
final
- outDeliveryToAttention → String?
-
final
- outDeliveryToCity → String?
-
final
- outDeliveryToContact → String?
-
final
- outDeliveryToContactFax → String?
-
final
- outDeliveryToContactPhone → String?
-
final
- outDeliveryToCountry → String?
-
final
- outDeliveryToCountryId → String?
-
final
- outDeliveryToCrossStreets → String?
-
final
- outDeliveryToLocation → String?
-
final
- outDeliveryToState → String?
-
final
- outDeliveryToVenue → String?
-
final
- outDeliveryToVenueId → String?
-
final
- outDeliveryToWarehouse → String?
-
final
- outDeliveryToWarehouseId → String?
-
final
- outDeliveryToZipCode → String?
-
final
- outDeliveryVendorInvoiceId → String?
-
final
- outsideSalesRepresentative → String?
-
final
- outsideSalesRepresentativeId → String?
-
final
- partsDiscountPercent → double?
-
final
- partsTotal → double?
-
final
- partsTotalIncludesTax → bool?
-
final
- paymentTerms → String?
-
final
- paymentTermsId → String?
-
final
- paymentType → String?
-
final
- paymentTypeId → String?
-
final
- pendingPo → bool?
-
final
- periodCombinedTotal → double?
-
final
- periodCombinedTotalIncludesTax → bool?
-
final
- periodLaborTotal → double?
-
final
- periodLaborTotalIncludesTax → bool?
-
final
- periodMiscTotal → double?
-
final
- periodMiscTotalIncludesTax → bool?
-
final
- periodRentalTotal → double?
-
final
- periodRentalTotalIncludesTax → bool?
-
final
- periodSpaceTotal → double?
-
final
- periodSpaceTotalIncludesTax → bool?
-
final
- periodVehicleTotal → double?
-
final
- periodVehicleTotalIncludesTax → bool?
-
final
- pickDate → String?
-
final
- pickTime → String?
-
final
- pickUpDate → String?
-
final
- pickUpTime → String?
-
final
- poAmount → double?
-
final
- poApprovalStatusId → String?
-
final
- poNumber → String?
-
final
- prepDate → String?
-
final
- prepTime → String?
-
final
- presentationLayer → String?
-
final
- presentationLayerId → String?
-
final
- printIssuedToAddressFrom → String?
-
final
- project → String?
-
final
- projectAsBuild → String?
-
final
- projectAsBuildId → String?
-
final
- projectCommissioning → String?
-
final
- projectCommissioningId → String?
-
final
- projectDeposit → String?
-
final
- projectDepositId → String?
-
final
- projectDrawings → String?
-
final
- projectDrawingsId → String?
-
final
- projectDropShip → String?
-
final
- projectDropShipId → String?
-
final
- projectId → String?
-
final
- projectItemsOrdered → String?
-
final
- projectItemsOrderedId → String?
-
final
- projectManager → String?
-
final
- projectManagerId → String?
-
final
- projectNumber → String?
-
final
- quoteDate → String?
-
final
- quoteId → String?
-
final
- quoteNumber → String?
-
final
- quoteOrderTitle → String?
-
final
- rateType → String?
-
final
- rateTypeDisplay → String?
-
final
- recordTitle → String?
-
final
- referenceNumber → String?
-
final
- rental → bool?
-
final
- rentalBillingEndDate → String?
-
final
- rentalBillingStartDate → String?
-
final
- rentalDaysPerWeek → double?
-
final
- rentalDiscountPercent → double?
-
final
- rentalExtendedTotal → double?
-
final
- rentalSale → bool?
-
final
- rentalSaleDiscountPercent → double?
-
final
- rentalSaleExtendedTotal → double?
-
final
- rentalSaleTotal → double?
-
final
- rentalSaleTotalIncludesTax → bool?
-
final
- rentalTaxRate1 → double?
-
final
- rentalTaxRate2 → double?
-
final
- repair → bool?
-
final
- requireContactConfirmation → bool?
-
final
- roundTripRentals → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sales → bool?
-
final
- salesDiscountPercent → double?
-
final
- salesExtendedTotal → double?
-
final
- salesTaxRate1 → double?
-
final
- salesTaxRate2 → double?
-
final
- salesTotal → double?
-
final
- salesTotalIncludesTax → bool?
-
final
- spaceDaysPerWeek → double?
-
final
- spaceDiscountPercent → double?
-
final
- spaceSplitPercent → double?
-
final
- specifyBillingDatesByType → bool?
-
final
- status → String?
-
final
- statusDate → String?
-
final
- strikeDate → String?
-
final
- strikeTime → String?
-
final
- tax1Name → String?
-
final
- tax2Name → String?
-
final
- taxId → String?
-
final
- taxOption → String?
-
final
- taxOptionId → String?
-
final
- termsConditions → String?
-
final
- termsConditionsId → String?
-
final
- testDate → String?
-
final
- testTime → String?
-
final
- total → double?
-
final
- totalReplacementCost → double?
-
final
- transportation → bool?
-
final
- unassignedSubs → bool?
-
final
- updateAllRatesToNewCurrency → bool?
-
final
- useEstimatedDatesForBilling → bool?
-
final
- vehicleBillingEndDate → String?
-
final
- vehicleBillingStartDate → String?
-
final
- vehicleDaysPerWeek → double?
-
final
- vehicleDiscountPercent → double?
-
final
- versionNumber → int?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
- weeklyCombinedTotal → double?
-
final
- weeklyCombinedTotalIncludesTax → bool?
-
final
- weeklyLaborTotal → double?
-
final
- weeklyLaborTotalIncludesTax → bool?
-
final
- weeklyMiscTotal → double?
-
final
- weeklyMiscTotalIncludesTax → bool?
-
final
- weeklyRentalTotal → double?
-
final
- weeklyRentalTotalIncludesTax → bool?
-
final
- weeklySpaceTotal → double?
-
final
- weeklySpaceTotalIncludesTax → bool?
-
final
- weeklyVehicleTotal → double?
-
final
- weeklyVehicleTotalIncludesTax → bool?
-
final
Methods
-
copyWith(
{String? quoteId, String? quoteNumber, String? quoteDate, int? versionNumber, String? convertedToOrderId, String? convertedToOrderNumber, bool? convertedToOrder, String? description, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, String? departmentId, String? department, String? customerId, String? customer, String? customerNumber, String? dealId, String? deal, String? dealNumber, String? rateType, String? rateTypeDisplay, String? agentId, String? agent, String? projectManagerId, String? projectManager, bool? rental, bool? sales, bool? miscellaneous, bool? labor, bool? facilities, bool? transportation, bool? rentalSale, bool? lossAndDamage, bool? repair, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, bool? hasLossAndDamageItem, bool? hasRentalSaleItem, bool? hasRepair, List< WebApiModulesHomeControlsOrderDatesOrderDates> ? activityDatesAndTimes, String? pickDate, String? pickTime, String? estimatedStartDate, String? estimatedStartTime, String? estimatedStopDate, String? estimatedStopTime, String? pickUpDate, String? pickUpTime, String? prepDate, String? prepTime, String? loadInDate, String? loadInTime, String? strikeDate, String? strikeTime, String? testDate, String? testTime, String? orderTypeId, String? orderType, bool? orderTypeCombineActivityTabs, bool? pendingPo, String? poNumber, double? poAmount, String? location, String? orderLocationId, String? orderLocation, String? referenceNumber, double? total, String? status, String? statusDate, String? poApprovalStatusId, bool? lockBillingDates, bool? specifyBillingDatesByType, String? rentalBillingStartDate, String? rentalBillingEndDate, String? laborBillingStartDate, String? laborBillingEndDate, String? miscellaneousBillingStartDate, String? miscellaneousBillingEndDate, String? facilitiesBillingStartDate, String? facilitiesBillingEndDate, String? vehicleBillingStartDate, String? vehicleBillingEndDate, String? delayBillingSearchUntil, bool? includePrepFeesInRentalRate, String? billingStartDate, String? billingEndDate, double? billingWeeks, double? billingMonths, String? determineQuantitiesToBillBasedOn, String? billingCycleId, String? billingCycle, String? billingCycleType, String? paymentTermsId, String? paymentTerms, String? paymentTypeId, String? paymentType, String? currencyId, bool? updateAllRatesToNewCurrency, String? confirmUpdateAllRatesToNewCurrency, String? currencyCode, String? currency, String? currencySymbol, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, String? taxId, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, bool? noCharge, String? noChargeReason, String? printIssuedToAddressFrom, String? issuedToName, String? issuedToAttention, String? issuedToAttention2, String? issuedToAddress1, String? issuedToAddress2, String? issuedToCity, String? issuedToState, String? issuedToZipCode, String? issuedToCountryId, String? issuedToCountry, bool? billToAddressDifferentFromIssuedToAddress, String? billToAddressId, String? billToName, String? billToAttention, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountryId, String? billToCountry, String? discountReasonId, String? discountReason, bool? requireContactConfirmation, bool? includeInBillingAnalysis, String? hiatusDiscountFrom, bool? roundTripRentals, bool? inGroup, int? groupNumber, int? groupColor, double? groupOrderBy, String? coverLetterId, String? coverLetter, String? termsConditionsId, String? termsConditions, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, String? marketTypeId, String? marketType, String? marketSegmentId, String? marketSegment, String? marketSegmentJobId, String? marketSegmentJob, String? outDeliveryId, String? outDeliveryDeliveryType, String? outDeliveryRequiredDate, String? outDeliveryRequiredTime, String? outDeliveryTargetShipDate, String? outDeliveryTargetShipTime, String? outDeliveryDirection, String? outDeliveryAddressType, String? outDeliveryFromLocation, String? outDeliveryFromContact, String? outDeliveryFromContactPhone, String? outDeliveryFromAlternateContact, String? outDeliveryFromAlternateContactPhone, String? outDeliveryFromAttention, String? outDeliveryFromAddress1, String? outDeliveryFromAdd2ress, String? outDeliveryFromCity, String? outDeliveryFromState, String? outDeliveryFromZipCode, String? outDeliveryFromCountry, String? outDeliveryFromCountryId, String? outDeliveryFromCrossStreets, String? outDeliveryToLocation, String? outDeliveryToContact, String? outDeliveryToContactPhone, String? outDeliveryToAlternateContact, String? outDeliveryToAlternateContactPhone, String? outDeliveryToAttention, String? outDeliveryToAddress1, String? outDeliveryToAddress2, String? outDeliveryToCity, String? outDeliveryToState, String? outDeliveryToZipCode, String? outDeliveryToCountryId, String? outDeliveryToCountry, String? outDeliveryToContactFax, String? outDeliveryToCrossStreets, String? outDeliveryDeliveryNotes, String? outDeliveryCarrierId, String? outDeliveryCarrier, String? outDeliveryCarrierAccount, String? outDeliveryShipViaId, String? outDeliveryShipVia, String? outDeliveryInvoiceId, String? outDeliveryVendorInvoiceId, double? outDeliveryEstimatedFreight, double? outDeliveryFreightInvoiceAmount, String? outDeliveryChargeType, String? outDeliveryFreightTrackingNumber, String? outDeliveryFreightTrackingUrl, String? outDeliveryPackageCode, bool? outDeliveryBillPoFreightOnOrder, String? outDeliveryOnlineOrderNumber, String? outDeliveryToVenue, String? outDeliveryToVenueId, String? outDeliveryToWarehouse, String? outDeliveryToWarehouseId, String? outDeliveryDateStamp, String? inDeliveryId, String? inDeliveryDeliveryType, String? inDeliveryRequiredDate, String? inDeliveryRequiredTime, String? inDeliveryTargetShipDate, String? inDeliveryTargetShipTime, String? inDeliveryDirection, String? inDeliveryAddressType, String? inDeliveryFromLocation, String? inDeliveryFromContact, String? inDeliveryFromContactPhone, String? inDeliveryFromAlternateContact, String? inDeliveryFromAlternateContactPhone, String? inDeliveryFromAttention, String? inDeliveryFromAddress1, String? inDeliveryFromAdd2ress, String? inDeliveryFromCity, String? inDeliveryFromState, String? inDeliveryFromZipCode, String? inDeliveryFromCountry, String? inDeliveryFromCountryId, String? inDeliveryFromCrossStreets, String? inDeliveryToLocation, String? inDeliveryToContact, String? inDeliveryToContactPhone, String? inDeliveryToAlternateContact, String? inDeliveryToAlternateContactPhone, String? inDeliveryToAttention, String? inDeliveryToAddress1, String? inDeliveryToAddress2, String? inDeliveryToCity, String? inDeliveryToState, String? inDeliveryToZipCode, String? inDeliveryToCountryId, String? inDeliveryToCountry, String? inDeliveryToContactFax, String? inDeliveryToCrossStreets, String? inDeliveryDeliveryNotes, String? inDeliveryCarrierId, String? inDeliveryCarrier, String? inDeliveryCarrierAccount, String? inDeliveryShipViaId, String? inDeliveryShipVia, String? inDeliveryInvoiceId, String? inDeliveryVendorInvoiceId, double? inDeliveryEstimatedFreight, double? inDeliveryFreightInvoiceAmount, String? inDeliveryChargeType, String? inDeliveryFreightTrackingNumber, String? inDeliveryFreightTrackingUrl, String? inDeliveryPackageCode, bool? inDeliveryBillPoFreightOnOrder, String? inDeliveryOnlineOrderNumber, String? inDeliveryOnlineOrderStatus, String? inDeliveryToVenue, String? inDeliveryToVenueId, String? inDeliveryToWarehouse, String? inDeliveryToWarehouseId, String? inDeliveryDateStamp, double? rentalDaysPerWeek, double? rentalDiscountPercent, double? weeklyRentalTotal, double? monthlyRentalTotal, double? periodRentalTotal, bool? weeklyRentalTotalIncludesTax, bool? monthlyRentalTotalIncludesTax, bool? periodRentalTotalIncludesTax, bool? billLockedTotal, double? salesDiscountPercent, double? salesTotal, bool? salesTotalIncludesTax, double? partsDiscountPercent, double? partsTotal, bool? partsTotalIncludesTax, double? spaceDaysPerWeek, double? spaceDiscountPercent, double? spaceSplitPercent, double? weeklySpaceTotal, double? monthlySpaceTotal, double? periodSpaceTotal, bool? weeklySpaceTotalIncludesTax, bool? monthlySpaceTotalIncludesTax, bool? periodSpaceTotalIncludesTax, double? vehicleDaysPerWeek, double? vehicleDiscountPercent, double? weeklyVehicleTotal, double? monthlyVehicleTotal, double? periodVehicleTotal, bool? weeklyVehicleTotalIncludesTax, bool? monthlyVehicleTotalIncludesTax, bool? periodVehicleTotalIncludesTax, double? miscDiscountPercent, double? weeklyMiscTotal, double? monthlyMiscTotal, double? periodMiscTotal, bool? weeklyMiscTotalIncludesTax, bool? monthlyMiscTotalIncludesTax, bool? periodMiscTotalIncludesTax, double? laborDiscountPercent, double? weeklyLaborTotal, double? monthlyLaborTotal, double? periodLaborTotal, bool? weeklyLaborTotalIncludesTax, bool? monthlyLaborTotalIncludesTax, bool? periodLaborTotalIncludesTax, double? rentalSaleDiscountPercent, double? rentalSaleTotal, bool? rentalSaleTotalIncludesTax, double? lossAndDamageDiscountPercent, double? lossAndDamageTotal, bool? lossAndDamageTotalIncludesTax, double? combinedDaysPerWeek, double? combinedDiscountPercent, double? weeklyCombinedTotal, double? monthlyCombinedTotal, double? periodCombinedTotal, bool? weeklyCombinedTotalIncludesTax, bool? monthlyCombinedTotalIncludesTax, bool? periodCombinedTotalIncludesTax, bool? disableEditingRentalRate, bool? disableEditingSalesRate, bool? disableEditingMiscellaneousRate, bool? disableEditingLaborRate, bool? disableEditingRentalSaleRate, bool? disableEditingLossAndDamageRate, double? rentalExtendedTotal, double? salesExtendedTotal, double? laborExtendedTotal, double? miscellaneousExtendedTotal, double? rentalSaleExtendedTotal, double? lossAndDamageExtendedTotal, bool? hasNotes, bool? hasDocuments, bool? hasEmailHistory, bool? hasContacts, bool? hasSubPurchaseOrders, bool? hasPickLists, bool? hasContracts, bool? hasSuspendedContracts, bool? hasMultiOrderContracts, bool? hasInvoices, bool? hasBillingWorksheets, bool? hasMultiOrderInvoices, bool? hasSnapshots, double? totalReplacementCost, String? presentationLayerId, String? presentationLayer, bool? isManualSort, String? quoteOrderTitle, bool? unassignedSubs, bool? nonTaxable, bool? enableProjects, String? projectId, String? projectNumber, String? project, String? projectDrawingsId, String? projectDrawings, String? projectItemsOrderedId, String? projectItemsOrdered, String? projectDropShipId, String? projectDropShip, String? projectAsBuildId, String? projectAsBuild, String? projectCommissioningId, String? projectCommissioning, String? projectDepositId, String? projectDeposit, String? inputByUserId, String? modifiedByUserId, bool? useEstimatedDatesForBilling, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesAgentQuoteQuote -
Available on WebApiModulesAgentQuoteQuote, provided by the $WebApiModulesAgentQuoteQuoteExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentQuoteQuote Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentQuoteQuote instance)