WebApiModulesAgentQuoteQuoteDocumentPutRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentQuoteQuoteDocumentPutRequest({String? quoteId, String? documentId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath})
const
WebApiModulesAgentQuoteQuoteDocumentPutRequest.fromJson(Map<String, dynamic> json)
factory

Properties

attachToEmail bool?
final
description String?
final
documentId String?
final
documentTypeId String?
final
fileDataUrl String?
final
fileIsModified bool?
final
filePath String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
quoteId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? quoteId, String? documentId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath}) WebApiModulesAgentQuoteQuoteDocumentPutRequest

Available on WebApiModulesAgentQuoteQuoteDocumentPutRequest, provided by the $WebApiModulesAgentQuoteQuoteDocumentPutRequestExtension extension

copyWithWrapped({Wrapped<String?>? quoteId, Wrapped<String?>? documentId, Wrapped<String?>? documentTypeId, Wrapped<String?>? description, Wrapped<bool?>? attachToEmail, Wrapped<bool?>? inactive, Wrapped<bool?>? fileIsModified, Wrapped<String?>? fileDataUrl, Wrapped<String?>? filePath}) WebApiModulesAgentQuoteQuoteDocumentPutRequest

Available on WebApiModulesAgentQuoteQuoteDocumentPutRequest, provided by the $WebApiModulesAgentQuoteQuoteDocumentPutRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAgentQuoteQuoteDocumentPutRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAgentQuoteQuoteDocumentPutRequest instance)