WebApiModulesAgentVendorVendor class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentVendorVendor({String? vendorId, String? vendor, String? vendorDisplayName, String? vendorNameType, String? vendorNumber, String? federalIdNumber, String? officeLocationId, String? officeLocation, String? salutation, String? firstName, String? middleInitial, String? lastName, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? countryCodeIsoAlpha2, int? countryCodePhone, String? zipCode, String? vendorClassId, String? vendorClass, String? phone, String? fax, String? phoneTollFree, String? otherPhone, String? webAddress, String? email, String? activeDate, String? inactiveDate, bool? subRent, bool? subSales, bool? subMisc, bool? subLabor, bool? subVehicle, bool? repair, bool? rentalInventory, bool? salesPartsInventory, bool? manufacturer, bool? freight, bool? insurance, bool? consignment, String? vendorColor, double? defaultSubRentDaysPerWeek, double? defaultSubRentDiscountPercent, double? defaultSubSaleDiscountPercent, String? defaultRate, String? billingCycleId, String? billingCycle, String? paymentTermsId, String? paymentTerms, String? paymentTermsColor, String? accountNumber, String? defaultPoClassificationId, String? defaultPoClassification, String? defaultPoTypeId, String? defaultPoType, bool? defaultPoTypeIsInternal, String? organizationTypeId, String? organizationType, bool? multipleCurrencies, String? defaultCurrencyId, String? defaultCurrencyCode, String? defaultCurrency, String? defaultCurrencySymbol, String? remitAttention1, String? remitAttention2, String? remitAddress1, String? remitAddress2, String? remitCity, String? remitState, String? remitCountryId, String? remitCountry, String? remitCountryCodeIsoAlpha2, int? remitCountryCodePhone, String? remitZipCode, String? remitPayeeNo, String? externalId, bool? automaticallyAdjustContractDates, String? shippingTrackingLink, String? defaultOutgoingDeliveryType, String? defaultIncomingDeliveryType, String? customerId, String? customer, String? inputDate, String? lastModifiedDate, String? primaryContactId, String? primaryContact, String? primaryContactPhone, String? primaryContactExtension, bool? isInternal, String? internalLocationId, String? internalLocation, String? internalWarehouseId, String? internalWarehouse, String? internalOrderDealId, String? taxOption, bool? excludeItemsWithZero, bool? inactive, String? paymentTypeId, String? paymentType, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAgentVendorVendor.fromJson(Map<String, dynamic> json)
factory

Properties

accountNumber String?
final
activeDate String?
final
address1 String?
final
address2 String?
final
auditNote String?
final
automaticallyAdjustContractDates bool?
final
billingCycle String?
final
billingCycleId String?
final
city String?
final
consignment bool?
final
country String?
final
countryCodeIsoAlpha2 String?
final
countryCodePhone int?
final
countryId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
customer String?
final
customerId String?
final
dateStamp String?
final
defaultCurrency String?
final
defaultCurrencyCode String?
final
defaultCurrencyId String?
final
defaultCurrencySymbol String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultIncomingDeliveryType String?
final
defaultOutgoingDeliveryType String?
final
defaultPoClassification String?
final
defaultPoClassificationId String?
final
defaultPoType String?
final
defaultPoTypeId String?
final
defaultPoTypeIsInternal bool?
final
defaultRate String?
final
defaultSubRentDaysPerWeek double?
final
defaultSubRentDiscountPercent double?
final
defaultSubSaleDiscountPercent double?
final
email String?
final
excludeItemsWithZero bool?
final
externalId String?
final
fax String?
final
federalIdNumber String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
firstName String?
final
freight bool?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
inactiveDate String?
final
inputDate String?
final
insurance bool?
final
internalLocation String?
final
internalLocationId String?
final
internalOrderDealId String?
final
internalWarehouse String?
final
internalWarehouseId String?
final
isInternal bool?
final
lastModifiedDate String?
final
lastName String?
final
manufacturer bool?
final
middleInitial String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
multipleCurrencies bool?
final
officeLocation String?
final
officeLocationId String?
final
organizationType String?
final
organizationTypeId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
otherPhone String?
final
paymentTerms String?
final
paymentTermsColor String?
final
paymentTermsId String?
final
paymentType String?
final
paymentTypeId String?
final
phone String?
final
phoneTollFree String?
final
primaryContact String?
final
primaryContactExtension String?
final
primaryContactId String?
final
primaryContactPhone String?
final
recordTitle String?
final
remitAddress1 String?
final
remitAddress2 String?
final
remitAttention1 String?
final
remitAttention2 String?
final
remitCity String?
final
remitCountry String?
final
remitCountryCodeIsoAlpha2 String?
final
remitCountryCodePhone int?
final
remitCountryId String?
final
remitPayeeNo String?
final
remitState String?
final
remitZipCode String?
final
rentalInventory bool?
final
repair bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesPartsInventory bool?
final
salutation String?
final
final
state String?
final
subLabor bool?
final
subMisc bool?
final
subRent bool?
final
subSales bool?
final
subVehicle bool?
final
taxOption String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
vendor String?
final
vendorClass String?
final
vendorClassId String?
final
vendorColor String?
final
vendorDisplayName String?
final
vendorId String?
final
vendorNameType String?
final
vendorNumber String?
final
webAddress String?
final
zipCode String?
final

Methods

copyWith({String? vendorId, String? vendor, String? vendorDisplayName, String? vendorNameType, String? vendorNumber, String? federalIdNumber, String? officeLocationId, String? officeLocation, String? salutation, String? firstName, String? middleInitial, String? lastName, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? countryCodeIsoAlpha2, int? countryCodePhone, String? zipCode, String? vendorClassId, String? vendorClass, String? phone, String? fax, String? phoneTollFree, String? otherPhone, String? webAddress, String? email, String? activeDate, String? inactiveDate, bool? subRent, bool? subSales, bool? subMisc, bool? subLabor, bool? subVehicle, bool? repair, bool? rentalInventory, bool? salesPartsInventory, bool? manufacturer, bool? freight, bool? insurance, bool? consignment, String? vendorColor, double? defaultSubRentDaysPerWeek, double? defaultSubRentDiscountPercent, double? defaultSubSaleDiscountPercent, String? defaultRate, String? billingCycleId, String? billingCycle, String? paymentTermsId, String? paymentTerms, String? paymentTermsColor, String? accountNumber, String? defaultPoClassificationId, String? defaultPoClassification, String? defaultPoTypeId, String? defaultPoType, bool? defaultPoTypeIsInternal, String? organizationTypeId, String? organizationType, bool? multipleCurrencies, String? defaultCurrencyId, String? defaultCurrencyCode, String? defaultCurrency, String? defaultCurrencySymbol, String? remitAttention1, String? remitAttention2, String? remitAddress1, String? remitAddress2, String? remitCity, String? remitState, String? remitCountryId, String? remitCountry, String? remitCountryCodeIsoAlpha2, int? remitCountryCodePhone, String? remitZipCode, String? remitPayeeNo, String? externalId, bool? automaticallyAdjustContractDates, String? shippingTrackingLink, String? defaultOutgoingDeliveryType, String? defaultIncomingDeliveryType, String? customerId, String? customer, String? inputDate, String? lastModifiedDate, String? primaryContactId, String? primaryContact, String? primaryContactPhone, String? primaryContactExtension, bool? isInternal, String? internalLocationId, String? internalLocation, String? internalWarehouseId, String? internalWarehouse, String? internalOrderDealId, String? taxOption, bool? excludeItemsWithZero, bool? inactive, String? paymentTypeId, String? paymentType, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAgentVendorVendor

Available on WebApiModulesAgentVendorVendor, provided by the $WebApiModulesAgentVendorVendorExtension extension

copyWithWrapped({Wrapped<String?>? vendorId, Wrapped<String?>? vendor, Wrapped<String?>? vendorDisplayName, Wrapped<String?>? vendorNameType, Wrapped<String?>? vendorNumber, Wrapped<String?>? federalIdNumber, Wrapped<String?>? officeLocationId, Wrapped<String?>? officeLocation, Wrapped<String?>? salutation, Wrapped<String?>? firstName, Wrapped<String?>? middleInitial, Wrapped<String?>? lastName, Wrapped<String?>? address1, Wrapped<String?>? address2, Wrapped<String?>? city, Wrapped<String?>? state, Wrapped<String?>? countryId, Wrapped<String?>? country, Wrapped<String?>? countryCodeIsoAlpha2, Wrapped<int?>? countryCodePhone, Wrapped<String?>? zipCode, Wrapped<String?>? vendorClassId, Wrapped<String?>? vendorClass, Wrapped<String?>? phone, Wrapped<String?>? fax, Wrapped<String?>? phoneTollFree, Wrapped<String?>? otherPhone, Wrapped<String?>? webAddress, Wrapped<String?>? email, Wrapped<String?>? activeDate, Wrapped<String?>? inactiveDate, Wrapped<bool?>? subRent, Wrapped<bool?>? subSales, Wrapped<bool?>? subMisc, Wrapped<bool?>? subLabor, Wrapped<bool?>? subVehicle, Wrapped<bool?>? repair, Wrapped<bool?>? rentalInventory, Wrapped<bool?>? salesPartsInventory, Wrapped<bool?>? manufacturer, Wrapped<bool?>? freight, Wrapped<bool?>? insurance, Wrapped<bool?>? consignment, Wrapped<String?>? vendorColor, Wrapped<double?>? defaultSubRentDaysPerWeek, Wrapped<double?>? defaultSubRentDiscountPercent, Wrapped<double?>? defaultSubSaleDiscountPercent, Wrapped<String?>? defaultRate, Wrapped<String?>? billingCycleId, Wrapped<String?>? billingCycle, Wrapped<String?>? paymentTermsId, Wrapped<String?>? paymentTerms, Wrapped<String?>? paymentTermsColor, Wrapped<String?>? accountNumber, Wrapped<String?>? defaultPoClassificationId, Wrapped<String?>? defaultPoClassification, Wrapped<String?>? defaultPoTypeId, Wrapped<String?>? defaultPoType, Wrapped<bool?>? defaultPoTypeIsInternal, Wrapped<String?>? organizationTypeId, Wrapped<String?>? organizationType, Wrapped<bool?>? multipleCurrencies, Wrapped<String?>? defaultCurrencyId, Wrapped<String?>? defaultCurrencyCode, Wrapped<String?>? defaultCurrency, Wrapped<String?>? defaultCurrencySymbol, Wrapped<String?>? remitAttention1, Wrapped<String?>? remitAttention2, Wrapped<String?>? remitAddress1, Wrapped<String?>? remitAddress2, Wrapped<String?>? remitCity, Wrapped<String?>? remitState, Wrapped<String?>? remitCountryId, Wrapped<String?>? remitCountry, Wrapped<String?>? remitCountryCodeIsoAlpha2, Wrapped<int?>? remitCountryCodePhone, Wrapped<String?>? remitZipCode, Wrapped<String?>? remitPayeeNo, Wrapped<String?>? externalId, Wrapped<bool?>? automaticallyAdjustContractDates, Wrapped<String?>? shippingTrackingLink, Wrapped<String?>? defaultOutgoingDeliveryType, Wrapped<String?>? defaultIncomingDeliveryType, Wrapped<String?>? customerId, Wrapped<String?>? customer, Wrapped<String?>? inputDate, Wrapped<String?>? lastModifiedDate, Wrapped<String?>? primaryContactId, Wrapped<String?>? primaryContact, Wrapped<String?>? primaryContactPhone, Wrapped<String?>? primaryContactExtension, Wrapped<bool?>? isInternal, Wrapped<String?>? internalLocationId, Wrapped<String?>? internalLocation, Wrapped<String?>? internalWarehouseId, Wrapped<String?>? internalWarehouse, Wrapped<String?>? internalOrderDealId, Wrapped<String?>? taxOption, Wrapped<bool?>? excludeItemsWithZero, Wrapped<bool?>? inactive, Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAgentVendorVendor

Available on WebApiModulesAgentVendorVendor, provided by the $WebApiModulesAgentVendorVendorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAgentVendorVendor Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAgentVendorVendor instance)