WebApiModulesAgentVendorVendorDocumentPostRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAgentVendorVendorDocumentPostRequest({String? vendorId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath})
const
WebApiModulesAgentVendorVendorDocumentPostRequest.fromJson(Map<String, dynamic> json)
factory

Properties

attachToEmail bool?
final
description String?
final
documentTypeId String?
final
fileDataUrl String?
final
fileIsModified bool?
final
filePath String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vendorId String?
final

Methods

copyWith({String? vendorId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath}) WebApiModulesAgentVendorVendorDocumentPostRequest

Available on WebApiModulesAgentVendorVendorDocumentPostRequest, provided by the $WebApiModulesAgentVendorVendorDocumentPostRequestExtension extension

copyWithWrapped({Wrapped<String?>? vendorId, Wrapped<String?>? documentTypeId, Wrapped<String?>? description, Wrapped<bool?>? attachToEmail, Wrapped<bool?>? inactive, Wrapped<bool?>? fileIsModified, Wrapped<String?>? fileDataUrl, Wrapped<String?>? filePath}) WebApiModulesAgentVendorVendorDocumentPostRequest

Available on WebApiModulesAgentVendorVendorDocumentPostRequest, provided by the $WebApiModulesAgentVendorVendorDocumentPostRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override