WebApiModulesBilingInvoiceInvoiceDocumentPostRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBilingInvoiceInvoiceDocumentPostRequest({String? invoiceId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath})
const
WebApiModulesBilingInvoiceInvoiceDocumentPostRequest.fromJson(Map<String, dynamic> json)
factory

Properties

attachToEmail bool?
final
description String?
final
documentTypeId String?
final
fileDataUrl String?
final
fileIsModified bool?
final
filePath String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
invoiceId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? invoiceId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath}) WebApiModulesBilingInvoiceInvoiceDocumentPostRequest

Available on WebApiModulesBilingInvoiceInvoiceDocumentPostRequest, provided by the $WebApiModulesBilingInvoiceInvoiceDocumentPostRequestExtension extension

copyWithWrapped({Wrapped<String?>? invoiceId, Wrapped<String?>? documentTypeId, Wrapped<String?>? description, Wrapped<bool?>? attachToEmail, Wrapped<bool?>? inactive, Wrapped<bool?>? fileIsModified, Wrapped<String?>? fileDataUrl, Wrapped<String?>? filePath}) WebApiModulesBilingInvoiceInvoiceDocumentPostRequest

Available on WebApiModulesBilingInvoiceInvoiceDocumentPostRequest, provided by the $WebApiModulesBilingInvoiceInvoiceDocumentPostRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override