WebApiModulesBillingBankAccountBankAccount class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingBankAccountBankAccount({int? bankAccountId, String? accountName, String? checkNumber, String? officeLocationId, String? location, String? currencyId, String? currency, String? currencyCode, String? currencySymbol, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingBankAccountBankAccount.fromJson(Map<String, dynamic> json)
factory

Properties

accountName String?
final
auditNote String?
final
bankAccountId int?
final
checkNumber String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currency String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
location String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officeLocationId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? bankAccountId, String? accountName, String? checkNumber, String? officeLocationId, String? location, String? currencyId, String? currency, String? currencyCode, String? currencySymbol, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingBankAccountBankAccount

Available on WebApiModulesBillingBankAccountBankAccount, provided by the $WebApiModulesBillingBankAccountBankAccountExtension extension

copyWithWrapped({Wrapped<int?>? bankAccountId, Wrapped<String?>? accountName, Wrapped<String?>? checkNumber, Wrapped<String?>? officeLocationId, Wrapped<String?>? location, Wrapped<String?>? currencyId, Wrapped<String?>? currency, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingBankAccountBankAccount

Available on WebApiModulesBillingBankAccountBankAccount, provided by the $WebApiModulesBillingBankAccountBankAccountExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesBillingBankAccountBankAccount Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesBillingBankAccountBankAccount instance)