WebApiModulesBillingBillingCreateGroupInvoicesRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingBillingCreateGroupInvoicesRequest({double? newTotal, bool? includeTaxInTotal, String? sessionId, List<String>? billingIds})
const
WebApiModulesBillingBillingCreateGroupInvoicesRequest.fromJson(Map<String, dynamic> json)
factory

Properties

billingIds List<String>?
final
hashCode int
The hash code for this object.
no setteroverride
includeTaxInTotal bool?
final
newTotal double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final

Methods

copyWith({double? newTotal, bool? includeTaxInTotal, String? sessionId, List<String>? billingIds}) WebApiModulesBillingBillingCreateGroupInvoicesRequest

Available on WebApiModulesBillingBillingCreateGroupInvoicesRequest, provided by the $WebApiModulesBillingBillingCreateGroupInvoicesRequestExtension extension

copyWithWrapped({Wrapped<double?>? newTotal, Wrapped<bool?>? includeTaxInTotal, Wrapped<String?>? sessionId, Wrapped<List<String>?>? billingIds}) WebApiModulesBillingBillingCreateGroupInvoicesRequest

Available on WebApiModulesBillingBillingCreateGroupInvoicesRequest, provided by the $WebApiModulesBillingBillingCreateGroupInvoicesRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override