WebApiModulesBillingBillingCreateInvoiceRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingBillingCreateInvoiceRequest({String? orderId, DateTime? periodStart, DateTime? periodEnd, String? billPeriodEvent, bool? includeNotYetOut, bool? forceDates})
const
WebApiModulesBillingBillingCreateInvoiceRequest.fromJson(Map<String, dynamic> json)
factory

Properties

billPeriodEvent String?
final
forceDates bool?
final
hashCode int
The hash code for this object.
no setteroverride
includeNotYetOut bool?
final
orderId String?
final
periodEnd DateTime?
final
periodStart DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? orderId, DateTime? periodStart, DateTime? periodEnd, String? billPeriodEvent, bool? includeNotYetOut, bool? forceDates}) WebApiModulesBillingBillingCreateInvoiceRequest

Available on WebApiModulesBillingBillingCreateInvoiceRequest, provided by the $WebApiModulesBillingBillingCreateInvoiceRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<DateTime?>? periodStart, Wrapped<DateTime?>? periodEnd, Wrapped<String?>? billPeriodEvent, Wrapped<bool?>? includeNotYetOut, Wrapped<bool?>? forceDates}) WebApiModulesBillingBillingCreateInvoiceRequest

Available on WebApiModulesBillingBillingCreateInvoiceRequest, provided by the $WebApiModulesBillingBillingCreateInvoiceRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override