WebApiModulesBillingBillingCreateInvoicesResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesBillingBillingCreateInvoicesResponse({int? status, bool? success, String? msg, String? invoiceCreationBatchId, List<
WebApiModulesBillingInvoiceInvoice> ? invoices}) -
const
-
WebApiModulesBillingBillingCreateInvoicesResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- invoiceCreationBatchId → String?
-
final
-
invoices
→ List<
WebApiModulesBillingInvoiceInvoice> ? -
final
- msg → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- success → bool?
-
final
Methods
-
copyWith(
{int? status, bool? success, String? msg, String? invoiceCreationBatchId, List< WebApiModulesBillingInvoiceInvoice> ? invoices}) → WebApiModulesBillingBillingCreateInvoicesResponse -
Available on WebApiModulesBillingBillingCreateInvoicesResponse, provided by the $WebApiModulesBillingBillingCreateInvoicesResponseExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? status, Wrapped<bool?> ? success, Wrapped<String?> ? msg, Wrapped<String?> ? invoiceCreationBatchId, Wrapped<List< ? invoices}) → WebApiModulesBillingBillingCreateInvoicesResponseWebApiModulesBillingInvoiceInvoice> ?> -
Available on WebApiModulesBillingBillingCreateInvoicesResponse, provided by the $WebApiModulesBillingBillingCreateInvoicesResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesBillingBillingCreateInvoicesResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesBillingBillingCreateInvoicesResponse instance)