WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequest({String? orderId, DateTime? startDate, DateTime? endDate, String? billPeriodEvent, bool? forQuikSale})
const
WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequest.fromJson(Map<String, dynamic> json)
factory

Properties

billPeriodEvent String?
final
endDate DateTime?
final
forQuikSale bool?
final
hashCode int
The hash code for this object.
no setteroverride
orderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
final

Methods

copyWith({String? orderId, DateTime? startDate, DateTime? endDate, String? billPeriodEvent, bool? forQuikSale}) WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequest

Available on WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequest, provided by the $WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<DateTime?>? startDate, Wrapped<DateTime?>? endDate, Wrapped<String?>? billPeriodEvent, Wrapped<bool?>? forQuikSale}) WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequest

Available on WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequest, provided by the $WebApiModulesBillingBillingGetPreviewInvoiceTotalsRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override