WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponse({int? status, bool? success, String? msg, String? currencyId, String? currency, String? currencyCode, String? currencySymbol, double? grossTotal, String? grossTotalString, double? discountAmount, String? discountAmountString, double? subTotal, String? subTotalString, double? tax1, String? tax1String, double? tax2, String? tax2String, double? tax, String? taxString, double? total, String? totalString})
const
WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

currency String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
discountAmount double?
final
discountAmountString String?
final
grossTotal double?
final
grossTotalString String?
final
hashCode int
The hash code for this object.
no setteroverride
msg String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
subTotal double?
final
subTotalString String?
final
success bool?
final
tax double?
final
tax1 double?
final
tax1String String?
final
tax2 double?
final
tax2String String?
final
taxString String?
final
total double?
final
totalString String?
final

Methods

copyWith({int? status, bool? success, String? msg, String? currencyId, String? currency, String? currencyCode, String? currencySymbol, double? grossTotal, String? grossTotalString, double? discountAmount, String? discountAmountString, double? subTotal, String? subTotalString, double? tax1, String? tax1String, double? tax2, String? tax2String, double? tax, String? taxString, double? total, String? totalString}) WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponse

Available on WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponse, provided by the $WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponseExtension extension

copyWithWrapped({Wrapped<int?>? status, Wrapped<bool?>? success, Wrapped<String?>? msg, Wrapped<String?>? currencyId, Wrapped<String?>? currency, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<double?>? grossTotal, Wrapped<String?>? grossTotalString, Wrapped<double?>? discountAmount, Wrapped<String?>? discountAmountString, Wrapped<double?>? subTotal, Wrapped<String?>? subTotalString, Wrapped<double?>? tax1, Wrapped<String?>? tax1String, Wrapped<double?>? tax2, Wrapped<String?>? tax2String, Wrapped<double?>? tax, Wrapped<String?>? taxString, Wrapped<double?>? total, Wrapped<String?>? totalString}) WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponse

Available on WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponse, provided by the $WebApiModulesBillingBillingGetPreviewInvoiceTotalsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override