WebApiModulesBillingInvoiceInvoice class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesBillingInvoiceInvoice({String? invoiceId, String? invoiceNumber, String? invoiceDate, String? invoiceDueDate, String? invoiceType, String? billingStartDate, String? billingEndDate, String? usageStartDate, String? usageEndDate, String? orderId, String? orderNumber, String? orderDescription, String? orderDate, String? orderLocation, String? invoiceDescription, String? creditingInvoiceId, String? creditingInvoiceNumber, String? customerId, String? customer, String? customerTypeId, String? customerType, String? dealId, String? deal, String? dealNumber, String? dealTypeId, String? departmentId, String? department, String? purchaseOrderNumber, String? workAuthorizationNumber, String? status, String? statusDate, bool? isNoCharge, bool? isAdjusted, bool? isBilledHiatus, int? episodeNumber, bool? hasLockedTotal, bool? isAlteredDates, String? officeLocationId, String? officeLocation, String? invoiceCreationBatchId, int? invoiceCreationBatchNumber, String? invoiceGroupNumber, bool? rentalSale, bool? lossAndDamage, bool? repair, String? inputByUserId, String? flatPoId, String? orderType, String? rebateCustomerId, String? orbitsapchgmajor, String? orbitsapchgsub, String? orbitsapchgdetail, String? orbitsapchgdeal, String? orbitsapchgset, bool? excludeFromFlatPo, bool? isSplitRental, bool? isRebateRental, double? invoiceListTotal, double? invoiceGrossTotal, double? invoiceDiscountTotal, double? invoiceDaysPerWeekDiscountTotal, String? referenceNumber, String? agentId, String? agent, String? projectManagerId, String? projectManager, String? billToAddressId, String? billToName, String? billToAttention1, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountryId, String? billToCountry, String? invoiceClass, String? printNotes, String? paymentTermsId, String? paymentTerms, String? paymentTypeId, String? paymentType, String? taxId, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, String? taxItemCode, String? taxVendor, String? taxCountry, String? chargeBatchId, String? chargeBatchNumber, bool? quikPayDiscount, double? quikPayRentalTotal, double? quikPayTotal, double? receivedTotal, String? rateType, double? consignmentRevenue, bool? isNonBillable, String? currencyId, String? currencyCode, String? currencySymbol, String? officeLocationDefaultCurrencyId, String? divisionId, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, bool? exportTaxAsLineItem, String? invoiceNumberColor, String? statusColor, String? orderNumberColor, String? purchaseOrderNumberColor, String? dealColor, String? billingStartDateColor, String? invoiceTotalColor, String? descriptionColor, bool? hasRentalItem, bool? hasMeterItem, bool? hasSalesItem, bool? hasLaborItem, bool? hasMiscellaneousItem, bool? hasFacilityItem, bool? hasTransportationItem, bool? hasRentalSaleItem, bool? hasRepairItem, bool? hasConsignment, bool? hasLossAndDamageItem, double? rentalTotal, double? salesTotal, double? facilitiesTotal, double? miscellaneousTotal, double? laborTotal, double? partsTotal, double? assetSaleTotal, double? invoiceSubTotal, double? invoiceTax1, double? invoiceTax2, double? invoiceTax, double? invoiceTotal, double? remainingTotal, bool? isStandAloneInvoice, String? warehouseId, String? termsConditionsId, String? termsConditions, String? sourceId, String? sourceDate, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesBillingInvoiceInvoice.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agent → String?
-
final
- agentId → String?
-
final
- assetSaleTotal → double?
-
final
- auditNote → String?
-
final
- billingEndDate → String?
-
final
- billingStartDate → String?
-
final
- billingStartDateColor → String?
-
final
- billToAddress1 → String?
-
final
- billToAddress2 → String?
-
final
- billToAddressId → String?
-
final
- billToAttention1 → String?
-
final
- billToAttention2 → String?
-
final
- billToCity → String?
-
final
- billToCountry → String?
-
final
- billToCountryId → String?
-
final
- billToName → String?
-
final
- billToState → String?
-
final
- billToZipCode → String?
-
final
- chargeBatchId → String?
-
final
- chargeBatchNumber → String?
-
final
- consignmentRevenue → double?
-
final
- creditingInvoiceId → String?
-
final
- creditingInvoiceNumber → String?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerId → String?
-
final
- customerType → String?
-
final
- customerTypeId → String?
-
final
- deal → String?
-
final
- dealColor → String?
-
final
- dealId → String?
-
final
- dealNumber → String?
-
final
- dealTypeId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
- descriptionColor → String?
-
final
- divisionId → String?
-
final
- episodeNumber → int?
-
final
- excludeFromFlatPo → bool?
-
final
- exportTaxAsLineItem → bool?
-
final
- facilitiesTotal → double?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- flatPoId → String?
-
final
- hasConsignment → bool?
-
final
- hasFacilityItem → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasLaborItem → bool?
-
final
- hasLockedTotal → bool?
-
final
- hasLossAndDamageItem → bool?
-
final
- hasMeterItem → bool?
-
final
- hasMiscellaneousItem → bool?
-
final
- hasRentalItem → bool?
-
final
- hasRentalSaleItem → bool?
-
final
- hasRepairItem → bool?
-
final
- hasSalesItem → bool?
-
final
- hasTransportationItem → bool?
-
final
- inputByUserId → String?
-
final
- invoiceClass → String?
-
final
- invoiceCreationBatchId → String?
-
final
- invoiceCreationBatchNumber → int?
-
final
- invoiceDate → String?
-
final
- invoiceDaysPerWeekDiscountTotal → double?
-
final
- invoiceDescription → String?
-
final
- invoiceDiscountTotal → double?
-
final
- invoiceDueDate → String?
-
final
- invoiceGrossTotal → double?
-
final
- invoiceGroupNumber → String?
-
final
- invoiceId → String?
-
final
- invoiceListTotal → double?
-
final
- invoiceNumber → String?
-
final
- invoiceNumberColor → String?
-
final
- invoiceSubTotal → double?
-
final
- invoiceTax → double?
-
final
- invoiceTax1 → double?
-
final
- invoiceTax2 → double?
-
final
- invoiceTotal → double?
-
final
- invoiceTotalColor → String?
-
final
- invoiceType → String?
-
final
- isAdjusted → bool?
-
final
- isAlteredDates → bool?
-
final
- isBilledHiatus → bool?
-
final
- isNoCharge → bool?
-
final
- isNonBillable → bool?
-
final
- isRebateRental → bool?
-
final
- isSplitRental → bool?
-
final
- isStandAloneInvoice → bool?
-
final
- laborTaxRate1 → double?
-
final
- laborTaxRate2 → double?
-
final
- laborTotal → double?
-
final
- lossAndDamage → bool?
-
final
- miscellaneousTotal → double?
-
final
- officeLocation → String?
-
final
- officeLocationDefaultCurrencyId → String?
-
final
- officeLocationId → String?
-
final
- orbitsapchgdeal → String?
-
final
- orbitsapchgdetail → String?
-
final
- orbitsapchgmajor → String?
-
final
- orbitsapchgset → String?
-
final
- orbitsapchgsub → String?
-
final
- orderDate → String?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- orderLocation → String?
-
final
- orderNumber → String?
-
final
- orderNumberColor → String?
-
final
- orderType → String?
-
final
- outsideSalesRepresentative → String?
-
final
- outsideSalesRepresentativeId → String?
-
final
- partsTotal → double?
-
final
- paymentTerms → String?
-
final
- paymentTermsId → String?
-
final
- paymentType → String?
-
final
- paymentTypeId → String?
-
final
- printNotes → String?
-
final
- projectManager → String?
-
final
- projectManagerId → String?
-
final
- purchaseOrderNumber → String?
-
final
- purchaseOrderNumberColor → String?
-
final
- quikPayDiscount → bool?
-
final
- quikPayRentalTotal → double?
-
final
- quikPayTotal → double?
-
final
- rateType → String?
-
final
- rebateCustomerId → String?
-
final
- receivedTotal → double?
-
final
- recordTitle → String?
-
final
- referenceNumber → String?
-
final
- remainingTotal → double?
-
final
- rentalSale → bool?
-
final
- rentalTaxRate1 → double?
-
final
- rentalTaxRate2 → double?
-
final
- rentalTotal → double?
-
final
- repair → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesTaxRate1 → double?
-
final
- salesTaxRate2 → double?
-
final
- salesTotal → double?
-
final
- sourceDate → String?
-
final
- sourceId → String?
-
final
- status → String?
-
final
- statusColor → String?
-
final
- statusDate → String?
-
final
- tax1Name → String?
-
final
- tax2Name → String?
-
final
- taxCountry → String?
-
final
- taxId → String?
-
final
- taxItemCode → String?
-
final
- taxOption → String?
-
final
- taxOptionId → String?
-
final
- taxVendor → String?
-
final
- termsConditions → String?
-
final
- termsConditionsId → String?
-
final
- usageEndDate → String?
-
final
- usageStartDate → String?
-
final
- warehouseId → String?
-
final
- workAuthorizationNumber → String?
-
final
Methods
-
copyWith(
{String? invoiceId, String? invoiceNumber, String? invoiceDate, String? invoiceDueDate, String? invoiceType, String? billingStartDate, String? billingEndDate, String? usageStartDate, String? usageEndDate, String? orderId, String? orderNumber, String? orderDescription, String? orderDate, String? orderLocation, String? invoiceDescription, String? creditingInvoiceId, String? creditingInvoiceNumber, String? customerId, String? customer, String? customerTypeId, String? customerType, String? dealId, String? deal, String? dealNumber, String? dealTypeId, String? departmentId, String? department, String? purchaseOrderNumber, String? workAuthorizationNumber, String? status, String? statusDate, bool? isNoCharge, bool? isAdjusted, bool? isBilledHiatus, int? episodeNumber, bool? hasLockedTotal, bool? isAlteredDates, String? officeLocationId, String? officeLocation, String? invoiceCreationBatchId, int? invoiceCreationBatchNumber, String? invoiceGroupNumber, bool? rentalSale, bool? lossAndDamage, bool? repair, String? inputByUserId, String? flatPoId, String? orderType, String? rebateCustomerId, String? orbitsapchgmajor, String? orbitsapchgsub, String? orbitsapchgdetail, String? orbitsapchgdeal, String? orbitsapchgset, bool? excludeFromFlatPo, bool? isSplitRental, bool? isRebateRental, double? invoiceListTotal, double? invoiceGrossTotal, double? invoiceDiscountTotal, double? invoiceDaysPerWeekDiscountTotal, String? referenceNumber, String? agentId, String? agent, String? projectManagerId, String? projectManager, String? billToAddressId, String? billToName, String? billToAttention1, String? billToAttention2, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountryId, String? billToCountry, String? invoiceClass, String? printNotes, String? paymentTermsId, String? paymentTerms, String? paymentTypeId, String? paymentType, String? taxId, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, String? taxItemCode, String? taxVendor, String? taxCountry, String? chargeBatchId, String? chargeBatchNumber, bool? quikPayDiscount, double? quikPayRentalTotal, double? quikPayTotal, double? receivedTotal, String? rateType, double? consignmentRevenue, bool? isNonBillable, String? currencyId, String? currencyCode, String? currencySymbol, String? officeLocationDefaultCurrencyId, String? divisionId, String? outsideSalesRepresentativeId, String? outsideSalesRepresentative, bool? exportTaxAsLineItem, String? invoiceNumberColor, String? statusColor, String? orderNumberColor, String? purchaseOrderNumberColor, String? dealColor, String? billingStartDateColor, String? invoiceTotalColor, String? descriptionColor, bool? hasRentalItem, bool? hasMeterItem, bool? hasSalesItem, bool? hasLaborItem, bool? hasMiscellaneousItem, bool? hasFacilityItem, bool? hasTransportationItem, bool? hasRentalSaleItem, bool? hasRepairItem, bool? hasConsignment, bool? hasLossAndDamageItem, double? rentalTotal, double? salesTotal, double? facilitiesTotal, double? miscellaneousTotal, double? laborTotal, double? partsTotal, double? assetSaleTotal, double? invoiceSubTotal, double? invoiceTax1, double? invoiceTax2, double? invoiceTax, double? invoiceTotal, double? remainingTotal, bool? isStandAloneInvoice, String? warehouseId, String? termsConditionsId, String? termsConditions, String? sourceId, String? sourceDate, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesBillingInvoiceInvoice -
Available on WebApiModulesBillingInvoiceInvoice, provided by the $WebApiModulesBillingInvoiceInvoiceExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesBillingInvoiceInvoice Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesBillingInvoiceInvoice instance)