WebApiModulesBillingInvoiceInvoiceReceipt class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingInvoiceInvoiceReceipt({int? invoiceReceiptId, String? invoiceId, String? receiptId, String? receiptDate, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? checkNumber, String? recType, String? paymentBy, String? receiptCustomerId, String? receiptCustomer, String? receiptDealId, String? receiptDeal, String? invoiceNumber, String? invoiceDate, String? invoiceDescription, String? invoiceDealId, String? invoiceDeal, String? invoiceOrderId, String? invoiceOrderDescription, double? amount, double? appliedPaymentTypeFee, double? feePercent, double? remaining, String? appliedById, String? appliedBy, String? paymentMemo, String? currencyId, String? currencyCode, String? currencySymbol, String? creditCardName, String? creditCardExpirationDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingInvoiceInvoiceReceipt.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
appliedBy String?
final
appliedById String?
final
appliedPaymentTypeFee double?
final
auditNote String?
final
checkNumber String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
creditCardExpirationDate String?
final
creditCardName String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
feePercent double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
invoiceDate String?
final
invoiceDeal String?
final
invoiceDealId String?
final
invoiceDescription String?
final
invoiceId String?
final
invoiceNumber String?
final
invoiceOrderDescription String?
final
invoiceOrderId String?
final
invoiceReceiptId int?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentBy String?
final
paymentMemo String?
final
paymentType String?
final
paymentTypeId String?
final
paymentTypeType String?
final
receiptCustomer String?
final
receiptCustomerId String?
final
receiptDate String?
final
receiptDeal String?
final
receiptDealId String?
final
receiptId String?
final
recordTitle String?
final
recType String?
final
remaining double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? invoiceReceiptId, String? invoiceId, String? receiptId, String? receiptDate, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? checkNumber, String? recType, String? paymentBy, String? receiptCustomerId, String? receiptCustomer, String? receiptDealId, String? receiptDeal, String? invoiceNumber, String? invoiceDate, String? invoiceDescription, String? invoiceDealId, String? invoiceDeal, String? invoiceOrderId, String? invoiceOrderDescription, double? amount, double? appliedPaymentTypeFee, double? feePercent, double? remaining, String? appliedById, String? appliedBy, String? paymentMemo, String? currencyId, String? currencyCode, String? currencySymbol, String? creditCardName, String? creditCardExpirationDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingInvoiceInvoiceReceipt

Available on WebApiModulesBillingInvoiceInvoiceReceipt, provided by the $WebApiModulesBillingInvoiceInvoiceReceiptExtension extension

copyWithWrapped({Wrapped<int?>? invoiceReceiptId, Wrapped<String?>? invoiceId, Wrapped<String?>? receiptId, Wrapped<String?>? receiptDate, Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<String?>? paymentTypeType, Wrapped<String?>? checkNumber, Wrapped<String?>? recType, Wrapped<String?>? paymentBy, Wrapped<String?>? receiptCustomerId, Wrapped<String?>? receiptCustomer, Wrapped<String?>? receiptDealId, Wrapped<String?>? receiptDeal, Wrapped<String?>? invoiceNumber, Wrapped<String?>? invoiceDate, Wrapped<String?>? invoiceDescription, Wrapped<String?>? invoiceDealId, Wrapped<String?>? invoiceDeal, Wrapped<String?>? invoiceOrderId, Wrapped<String?>? invoiceOrderDescription, Wrapped<double?>? amount, Wrapped<double?>? appliedPaymentTypeFee, Wrapped<double?>? feePercent, Wrapped<double?>? remaining, Wrapped<String?>? appliedById, Wrapped<String?>? appliedBy, Wrapped<String?>? paymentMemo, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? creditCardName, Wrapped<String?>? creditCardExpirationDate, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingInvoiceInvoiceReceipt

Available on WebApiModulesBillingInvoiceInvoiceReceipt, provided by the $WebApiModulesBillingInvoiceInvoiceReceiptExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesBillingInvoiceInvoiceReceipt Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesBillingInvoiceInvoiceReceipt instance)