WebApiModulesBillingInvoiceNoteInvoiceNote class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingInvoiceNoteInvoiceNote({String? invoiceNoteId, String? invoiceId, String? orderId, String? orderNumber, String? noteDate, String? description, String? notesById, String? notesBy, String? notes, bool? printOnInvoice, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingInvoiceNoteInvoiceNote.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
invoiceId String?
final
invoiceNoteId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
noteDate String?
final
notes String?
final
notesBy String?
final
notesById String?
final
orderId String?
final
orderNumber String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
printOnInvoice bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? invoiceNoteId, String? invoiceId, String? orderId, String? orderNumber, String? noteDate, String? description, String? notesById, String? notesBy, String? notes, bool? printOnInvoice, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingInvoiceNoteInvoiceNote

Available on WebApiModulesBillingInvoiceNoteInvoiceNote, provided by the $WebApiModulesBillingInvoiceNoteInvoiceNoteExtension extension

copyWithWrapped({Wrapped<String?>? invoiceNoteId, Wrapped<String?>? invoiceId, Wrapped<String?>? orderId, Wrapped<String?>? orderNumber, Wrapped<String?>? noteDate, Wrapped<String?>? description, Wrapped<String?>? notesById, Wrapped<String?>? notesBy, Wrapped<String?>? notes, Wrapped<bool?>? printOnInvoice, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingInvoiceNoteInvoiceNote

Available on WebApiModulesBillingInvoiceNoteInvoiceNote, provided by the $WebApiModulesBillingInvoiceNoteInvoiceNoteExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesBillingInvoiceNoteInvoiceNote Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesBillingInvoiceNoteInvoiceNote instance)