WebApiModulesBillingInvoiceOrderInvoiceOrder class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingInvoiceOrderInvoiceOrder({String? orderInvoiceId, String? orderNumber, String? orderDescription, String? orderNumberAndDescription, String? referenceNumber, String? location, String? orderLocation, String? officeLocation, String? department, String? agentId, String? agent, String? agentEmail, String? agentPhoneAndExtension, String? agentPhone, String? agentExtension, String? agentFax, String? projectManagerId, String? projectManager, String? projectManagerEmail, String? projectManagerPhoneAndExtension, String? projectManagerPhone, String? projectManagerExtension, String? projectManagerFax, String? estimatedStartDate, String? estimatedStopDate, String? estimatedStartTime, String? estimatedStopTime, String? billingStartDate, String? billingEndDate, String? billingStopDate, String? usageStartDate, String? usageStopDate, String? billingCycleEvent, String? poNumber, String? purchaseOrderNumber, String? orderId, String? flatPoId, bool? excludeFromFlatPO, bool? billableFlat, String? invoiceId, double? summaryInvoiceOrderBy, double? rentalSubTotal, double? laborSubTotal, double? nonRentalSubTotal, double? orderInvoiceSubTotal, double? orderInvoiceTax, double? orderInvoiceTotal, String? currencyId, String? currencyCode, String? currencySymbol, String? currency, String? orderBy, String? customerId, String? customer, String? customerNumber, String? customerEmail, String? dealId, String? deal, String? dealNumber, String? dealAndDealNumber, String? dealEmail, String? paymentTerms, bool? hasRecurring, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingInvoiceOrderInvoiceOrder.fromJson(Map<String, dynamic> json)
factory

Properties

agent String?
final
agentEmail String?
final
agentExtension String?
final
agentFax String?
final
agentId String?
final
agentPhone String?
final
agentPhoneAndExtension String?
final
auditNote String?
final
billableFlat bool?
final
billingCycleEvent String?
final
billingEndDate String?
final
billingStartDate String?
final
billingStopDate String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currency String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
customer String?
final
customerEmail String?
final
customerId String?
final
customerNumber String?
final
deal String?
final
dealAndDealNumber String?
final
dealEmail String?
final
dealId String?
final
dealNumber String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
department String?
final
estimatedStartDate String?
final
estimatedStartTime String?
final
estimatedStopDate String?
final
estimatedStopTime String?
final
excludeFromFlatPO bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
flatPoId String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hasRecurring bool?
final
invoiceId String?
final
laborSubTotal double?
final
location String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
nonRentalSubTotal double?
final
officeLocation String?
final
orderBy String?
final
orderDescription String?
final
orderId String?
final
orderInvoiceId String?
final
orderInvoiceSubTotal double?
final
orderInvoiceTax double?
final
orderInvoiceTotal double?
final
orderLocation String?
final
orderNumber String?
final
orderNumberAndDescription String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentTerms String?
final
poNumber String?
final
projectManager String?
final
projectManagerEmail String?
final
projectManagerExtension String?
final
projectManagerFax String?
final
projectManagerId String?
final
projectManagerPhone String?
final
projectManagerPhoneAndExtension String?
final
purchaseOrderNumber String?
final
recordTitle String?
final
referenceNumber String?
final
rentalSubTotal double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summaryInvoiceOrderBy double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
usageStartDate String?
final
usageStopDate String?
final

Methods

copyWith({String? orderInvoiceId, String? orderNumber, String? orderDescription, String? orderNumberAndDescription, String? referenceNumber, String? location, String? orderLocation, String? officeLocation, String? department, String? agentId, String? agent, String? agentEmail, String? agentPhoneAndExtension, String? agentPhone, String? agentExtension, String? agentFax, String? projectManagerId, String? projectManager, String? projectManagerEmail, String? projectManagerPhoneAndExtension, String? projectManagerPhone, String? projectManagerExtension, String? projectManagerFax, String? estimatedStartDate, String? estimatedStopDate, String? estimatedStartTime, String? estimatedStopTime, String? billingStartDate, String? billingEndDate, String? billingStopDate, String? usageStartDate, String? usageStopDate, String? billingCycleEvent, String? poNumber, String? purchaseOrderNumber, String? orderId, String? flatPoId, bool? excludeFromFlatPO, bool? billableFlat, String? invoiceId, double? summaryInvoiceOrderBy, double? rentalSubTotal, double? laborSubTotal, double? nonRentalSubTotal, double? orderInvoiceSubTotal, double? orderInvoiceTax, double? orderInvoiceTotal, String? currencyId, String? currencyCode, String? currencySymbol, String? currency, String? orderBy, String? customerId, String? customer, String? customerNumber, String? customerEmail, String? dealId, String? deal, String? dealNumber, String? dealAndDealNumber, String? dealEmail, String? paymentTerms, bool? hasRecurring, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingInvoiceOrderInvoiceOrder

Available on WebApiModulesBillingInvoiceOrderInvoiceOrder, provided by the $WebApiModulesBillingInvoiceOrderInvoiceOrderExtension extension

copyWithWrapped({Wrapped<String?>? orderInvoiceId, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDescription, Wrapped<String?>? orderNumberAndDescription, Wrapped<String?>? referenceNumber, Wrapped<String?>? location, Wrapped<String?>? orderLocation, Wrapped<String?>? officeLocation, Wrapped<String?>? department, Wrapped<String?>? agentId, Wrapped<String?>? agent, Wrapped<String?>? agentEmail, Wrapped<String?>? agentPhoneAndExtension, Wrapped<String?>? agentPhone, Wrapped<String?>? agentExtension, Wrapped<String?>? agentFax, Wrapped<String?>? projectManagerId, Wrapped<String?>? projectManager, Wrapped<String?>? projectManagerEmail, Wrapped<String?>? projectManagerPhoneAndExtension, Wrapped<String?>? projectManagerPhone, Wrapped<String?>? projectManagerExtension, Wrapped<String?>? projectManagerFax, Wrapped<String?>? estimatedStartDate, Wrapped<String?>? estimatedStopDate, Wrapped<String?>? estimatedStartTime, Wrapped<String?>? estimatedStopTime, Wrapped<String?>? billingStartDate, Wrapped<String?>? billingEndDate, Wrapped<String?>? billingStopDate, Wrapped<String?>? usageStartDate, Wrapped<String?>? usageStopDate, Wrapped<String?>? billingCycleEvent, Wrapped<String?>? poNumber, Wrapped<String?>? purchaseOrderNumber, Wrapped<String?>? orderId, Wrapped<String?>? flatPoId, Wrapped<bool?>? excludeFromFlatPO, Wrapped<bool?>? billableFlat, Wrapped<String?>? invoiceId, Wrapped<double?>? summaryInvoiceOrderBy, Wrapped<double?>? rentalSubTotal, Wrapped<double?>? laborSubTotal, Wrapped<double?>? nonRentalSubTotal, Wrapped<double?>? orderInvoiceSubTotal, Wrapped<double?>? orderInvoiceTax, Wrapped<double?>? orderInvoiceTotal, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? currency, Wrapped<String?>? orderBy, Wrapped<String?>? customerId, Wrapped<String?>? customer, Wrapped<String?>? customerNumber, Wrapped<String?>? customerEmail, Wrapped<String?>? dealId, Wrapped<String?>? deal, Wrapped<String?>? dealNumber, Wrapped<String?>? dealAndDealNumber, Wrapped<String?>? dealEmail, Wrapped<String?>? paymentTerms, Wrapped<bool?>? hasRecurring, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingInvoiceOrderInvoiceOrder

Available on WebApiModulesBillingInvoiceOrderInvoiceOrder, provided by the $WebApiModulesBillingInvoiceOrderInvoiceOrderExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesBillingInvoiceOrderInvoiceOrder Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesBillingInvoiceOrderInvoiceOrder instance)