WebApiModulesBillingInvoicePaymentInvoicePayment class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingInvoicePaymentInvoicePayment({String? invoicePaymentId, String? paymentDate, String? paymentTypeId, String? paymentType, double? amount, String? checkNumber, String? receivedByUsersId, String? receivedBy, String? note, String? currencyId, String? currencyCode, String? currency, String? currencySymbol, String? officeLocationDefaultCurrencyId, String? invoiceId, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingInvoicePaymentInvoicePayment.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
auditNote String?
final
checkNumber String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currency String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
invoiceId String?
final
invoicePaymentId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
note String?
final
officeLocationDefaultCurrencyId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentDate String?
final
paymentType String?
final
paymentTypeId String?
final
receivedBy String?
final
receivedByUsersId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? invoicePaymentId, String? paymentDate, String? paymentTypeId, String? paymentType, double? amount, String? checkNumber, String? receivedByUsersId, String? receivedBy, String? note, String? currencyId, String? currencyCode, String? currency, String? currencySymbol, String? officeLocationDefaultCurrencyId, String? invoiceId, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingInvoicePaymentInvoicePayment

Available on WebApiModulesBillingInvoicePaymentInvoicePayment, provided by the $WebApiModulesBillingInvoicePaymentInvoicePaymentExtension extension

copyWithWrapped({Wrapped<String?>? invoicePaymentId, Wrapped<String?>? paymentDate, Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<double?>? amount, Wrapped<String?>? checkNumber, Wrapped<String?>? receivedByUsersId, Wrapped<String?>? receivedBy, Wrapped<String?>? note, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currency, Wrapped<String?>? currencySymbol, Wrapped<String?>? officeLocationDefaultCurrencyId, Wrapped<String?>? invoiceId, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingInvoicePaymentInvoicePayment

Available on WebApiModulesBillingInvoicePaymentInvoicePayment, provided by the $WebApiModulesBillingInvoicePaymentInvoicePaymentExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override