WebApiModulesBillingPaymentPayment class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingPaymentPayment({String? paymentId, String? paymentDate, String? locationId, String? departmentId, String? locationCode, String? location, String? vendorId, String? vendor, String? paymentTypeId, String? paymentType, int? bankAccountId, String? accountName, String? officeLocationDefaultCurrencyId, String? currencyId, String? currency, String? currencyCode, String? currencySymbol, String? checkNumber, String? paymentDocumentNumber, double? paymentAmount, String? appliedById, String? appliedBy, String? modifiedById, String? modifiedBy, String? paymentMemo, String? recType, String? chargeBatchId, String? chargeBatchNumber, List<WebApiModulesBillingPaymentPaymentVendorInvoice>? vendorInvoiceDataList, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingPaymentPayment.fromJson(Map<String, dynamic> json)
factory

Properties

accountName String?
final
appliedBy String?
final
appliedById String?
final
auditNote String?
final
bankAccountId int?
final
chargeBatchId String?
final
chargeBatchNumber String?
final
checkNumber String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currency String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
departmentId String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
location String?
final
locationCode String?
final
locationId String?
final
modifiedBy String?
final
modifiedById String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officeLocationDefaultCurrencyId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentAmount double?
final
paymentDate String?
final
paymentDocumentNumber String?
final
paymentId String?
final
paymentMemo String?
final
paymentType String?
final
paymentTypeId String?
final
recordTitle String?
final
recType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
vendor String?
final
vendorId String?
final
vendorInvoiceDataList List<WebApiModulesBillingPaymentPaymentVendorInvoice>?
final

Methods

copyWith({String? paymentId, String? paymentDate, String? locationId, String? departmentId, String? locationCode, String? location, String? vendorId, String? vendor, String? paymentTypeId, String? paymentType, int? bankAccountId, String? accountName, String? officeLocationDefaultCurrencyId, String? currencyId, String? currency, String? currencyCode, String? currencySymbol, String? checkNumber, String? paymentDocumentNumber, double? paymentAmount, String? appliedById, String? appliedBy, String? modifiedById, String? modifiedBy, String? paymentMemo, String? recType, String? chargeBatchId, String? chargeBatchNumber, List<WebApiModulesBillingPaymentPaymentVendorInvoice>? vendorInvoiceDataList, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingPaymentPayment

Available on WebApiModulesBillingPaymentPayment, provided by the $WebApiModulesBillingPaymentPaymentExtension extension

copyWithWrapped({Wrapped<String?>? paymentId, Wrapped<String?>? paymentDate, Wrapped<String?>? locationId, Wrapped<String?>? departmentId, Wrapped<String?>? locationCode, Wrapped<String?>? location, Wrapped<String?>? vendorId, Wrapped<String?>? vendor, Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<int?>? bankAccountId, Wrapped<String?>? accountName, Wrapped<String?>? officeLocationDefaultCurrencyId, Wrapped<String?>? currencyId, Wrapped<String?>? currency, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? checkNumber, Wrapped<String?>? paymentDocumentNumber, Wrapped<double?>? paymentAmount, Wrapped<String?>? appliedById, Wrapped<String?>? appliedBy, Wrapped<String?>? modifiedById, Wrapped<String?>? modifiedBy, Wrapped<String?>? paymentMemo, Wrapped<String?>? recType, Wrapped<String?>? chargeBatchId, Wrapped<String?>? chargeBatchNumber, Wrapped<List<WebApiModulesBillingPaymentPaymentVendorInvoice>?>? vendorInvoiceDataList, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingPaymentPayment

Available on WebApiModulesBillingPaymentPayment, provided by the $WebApiModulesBillingPaymentPaymentExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesBillingPaymentPayment Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesBillingPaymentPayment instance)