WebApiModulesBillingPaymentPaymentVendorInvoice class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingPaymentPaymentVendorInvoice({String? vendorInvoicePaymentId, String? vendorInvoiceId, double? amount})
const
WebApiModulesBillingPaymentPaymentVendorInvoice.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vendorInvoiceId String?
final
vendorInvoicePaymentId String?
final

Methods

copyWith({String? vendorInvoicePaymentId, String? vendorInvoiceId, double? amount}) WebApiModulesBillingPaymentPaymentVendorInvoice

Available on WebApiModulesBillingPaymentPaymentVendorInvoice, provided by the $WebApiModulesBillingPaymentPaymentVendorInvoiceExtension extension

copyWithWrapped({Wrapped<String?>? vendorInvoicePaymentId, Wrapped<String?>? vendorInvoiceId, Wrapped<double?>? amount}) WebApiModulesBillingPaymentPaymentVendorInvoice

Available on WebApiModulesBillingPaymentPaymentVendorInvoice, provided by the $WebApiModulesBillingPaymentPaymentVendorInvoiceExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override