WebApiModulesBillingReceiptAddDepletingDepositRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingReceiptAddDepletingDepositRequest({String? orderId, String? dealId, String? paymentTypeId, double? paymentAmount, String? locationId, String? currencyId, String? checkNumber, String? paymentMemo, double? feePercent, double? paymentTypeFee})
const
WebApiModulesBillingReceiptAddDepletingDepositRequest.fromJson(Map<String, dynamic> json)
factory

Properties

checkNumber String?
final
currencyId String?
final
dealId String?
final
feePercent double?
final
hashCode int
The hash code for this object.
no setteroverride
locationId String?
final
orderId String?
final
paymentAmount double?
final
paymentMemo String?
final
paymentTypeFee double?
final
paymentTypeId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? orderId, String? dealId, String? paymentTypeId, double? paymentAmount, String? locationId, String? currencyId, String? checkNumber, String? paymentMemo, double? feePercent, double? paymentTypeFee}) WebApiModulesBillingReceiptAddDepletingDepositRequest

Available on WebApiModulesBillingReceiptAddDepletingDepositRequest, provided by the $WebApiModulesBillingReceiptAddDepletingDepositRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? dealId, Wrapped<String?>? paymentTypeId, Wrapped<double?>? paymentAmount, Wrapped<String?>? locationId, Wrapped<String?>? currencyId, Wrapped<String?>? checkNumber, Wrapped<String?>? paymentMemo, Wrapped<double?>? feePercent, Wrapped<double?>? paymentTypeFee}) WebApiModulesBillingReceiptAddDepletingDepositRequest

Available on WebApiModulesBillingReceiptAddDepletingDepositRequest, provided by the $WebApiModulesBillingReceiptAddDepletingDepositRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override