WebApiModulesBillingReceiptInvoiceReceiptInvoice class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingReceiptInvoiceReceiptInvoice({int? invoiceReceiptId, String? invoiceId, String? invoiceNumber, String? invoiceDate, String? description, String? status, String? orderId, String? orderNumber, String? dealId, String? deal, double? total, double? fee, double? totalWithFee, bool? receiptId, String? invoiceType, double? applied, double? amount, double? due, String? customerId, String? customer, String? officeLocationId, String? departmentId, String? currencyId, String? currencyCode, String? currencySymbol, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingReceiptInvoiceReceiptInvoice.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
applied double?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
customer String?
final
customerId String?
final
deal String?
final
dealId String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
departmentId String?
final
description String?
final
due double?
final
fee double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
invoiceDate String?
final
invoiceId String?
final
invoiceNumber String?
final
invoiceReceiptId int?
final
invoiceType String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officeLocationId String?
final
orderId String?
final
orderNumber String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
receiptId bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
total double?
final
totalWithFee double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? invoiceReceiptId, String? invoiceId, String? invoiceNumber, String? invoiceDate, String? description, String? status, String? orderId, String? orderNumber, String? dealId, String? deal, double? total, double? fee, double? totalWithFee, bool? receiptId, String? invoiceType, double? applied, double? amount, double? due, String? customerId, String? customer, String? officeLocationId, String? departmentId, String? currencyId, String? currencyCode, String? currencySymbol, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingReceiptInvoiceReceiptInvoice

Available on WebApiModulesBillingReceiptInvoiceReceiptInvoice, provided by the $WebApiModulesBillingReceiptInvoiceReceiptInvoiceExtension extension

copyWithWrapped({Wrapped<int?>? invoiceReceiptId, Wrapped<String?>? invoiceId, Wrapped<String?>? invoiceNumber, Wrapped<String?>? invoiceDate, Wrapped<String?>? description, Wrapped<String?>? status, Wrapped<String?>? orderId, Wrapped<String?>? orderNumber, Wrapped<String?>? dealId, Wrapped<String?>? deal, Wrapped<double?>? total, Wrapped<double?>? fee, Wrapped<double?>? totalWithFee, Wrapped<bool?>? receiptId, Wrapped<String?>? invoiceType, Wrapped<double?>? applied, Wrapped<double?>? amount, Wrapped<double?>? due, Wrapped<String?>? customerId, Wrapped<String?>? customer, Wrapped<String?>? officeLocationId, Wrapped<String?>? departmentId, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingReceiptInvoiceReceiptInvoice

Available on WebApiModulesBillingReceiptInvoiceReceiptInvoice, provided by the $WebApiModulesBillingReceiptInvoiceReceiptInvoiceExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override