WebApiModulesBillingVendorInvoiceResetToDefaultRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingVendorInvoiceResetToDefaultRequest({String? vendorInvoiceId, String? purchaseOrderId, DateTime? billingStartDate, DateTime? billingEndDate, bool? showAll})
const
WebApiModulesBillingVendorInvoiceResetToDefaultRequest.fromJson(Map<String, dynamic> json)
factory

Properties

billingEndDate DateTime?
final
billingStartDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
purchaseOrderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAll bool?
final
vendorInvoiceId String?
final

Methods

copyWith({String? vendorInvoiceId, String? purchaseOrderId, DateTime? billingStartDate, DateTime? billingEndDate, bool? showAll}) WebApiModulesBillingVendorInvoiceResetToDefaultRequest

Available on WebApiModulesBillingVendorInvoiceResetToDefaultRequest, provided by the $WebApiModulesBillingVendorInvoiceResetToDefaultRequestExtension extension

copyWithWrapped({Wrapped<String?>? vendorInvoiceId, Wrapped<String?>? purchaseOrderId, Wrapped<DateTime?>? billingStartDate, Wrapped<DateTime?>? billingEndDate, Wrapped<bool?>? showAll}) WebApiModulesBillingVendorInvoiceResetToDefaultRequest

Available on WebApiModulesBillingVendorInvoiceResetToDefaultRequest, provided by the $WebApiModulesBillingVendorInvoiceResetToDefaultRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override