WebApiModulesBillingVendorInvoiceVendorInvoice class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingVendorInvoiceVendorInvoice({String? vendorInvoiceId, String? purchaseOrderId, String? purchaseOrderNumber, String? purchaseOrderDescription, String? purchaseOrderReferenceNumber, String? requistionNumber, String? vendor, String? vendorNumber, String? vendorId, String? invoiceBatchId, String? inputDate, String? invoiceNumber, String? invoiceDate, String? invoiceDueDate, String? billingStartDate, String? billingEndDate, String? status, String? statusDate, String? departmentId, String? department, String? orderNumber, String? orderDescription, String? purchaseOrderDealId, String? purchaseOrderDealNumber, String? purchaseOrderDeal, String? purchaseOrderDealNumberDeal, String? purchaseOrderDate, String? purchaseOrderEstimatedStopDate, String? purchaseOrderEstimatedStartDate, String? purchaseOrderBillingCycleId, String? purchaseOrderBillingCycle, String? purchaseOrderPaymentTermsId, String? purchaseOrderPaymentTerms, String? approvedDate, String? locationId, String? location, String? warehouseId, String? warehouse, double? invoiceSubTotal, double? invoiceTax, double? invoiceTotal, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountry, String? vendorPhone, String? vendorFax, String? invoiceClass, bool? printNotes, String? paymentTermsId, String? paymentTerms, String? paymentTermsColor, String? taxId, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, String? rentalTaxAlias, String? salesTaxAlias, String? laborTaxAlias, String? taxItemCode, String? notes, bool? billedHiatus, String? invoiceType, String? agentId, String? projectManagerId, String? currencyId, String? currencyCode, String? currencySymbol, String? officeLocationDefaultCurrencyId, double? dealBilledExtended, double? credit, String? vendorInvoiceModificationsPushToPo, String? chargeBatchId, String? chargeBatchNumber, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesBillingVendorInvoiceVendorInvoice.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String?
final
approvedDate String?
final
auditNote String?
final
billedHiatus bool?
final
billingEndDate String?
final
billingStartDate String?
final
billToAddress1 String?
final
billToAddress2 String?
final
billToCity String?
final
billToCountry String?
final
billToState String?
final
billToZipCode String?
final
chargeBatchId String?
final
chargeBatchNumber String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
credit double?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dealBilledExtended double?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
department String?
final
departmentId String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inputDate String?
final
invoiceBatchId String?
final
invoiceClass String?
final
invoiceDate String?
final
invoiceDueDate String?
final
invoiceNumber String?
final
invoiceSubTotal double?
final
invoiceTax double?
final
invoiceTotal double?
final
invoiceType String?
final
laborTaxAlias String?
final
laborTaxRate1 double?
final
laborTaxRate2 double?
final
location String?
final
locationId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
notes String?
final
officeLocationDefaultCurrencyId String?
final
orderDescription String?
final
orderNumber String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentTerms String?
final
paymentTermsColor String?
final
paymentTermsId String?
final
printNotes bool?
final
projectManagerId String?
final
purchaseOrderBillingCycle String?
final
purchaseOrderBillingCycleId String?
final
purchaseOrderDate String?
final
purchaseOrderDeal String?
final
purchaseOrderDealId String?
final
purchaseOrderDealNumber String?
final
purchaseOrderDealNumberDeal String?
final
purchaseOrderDescription String?
final
purchaseOrderEstimatedStartDate String?
final
purchaseOrderEstimatedStopDate String?
final
purchaseOrderId String?
final
purchaseOrderNumber String?
final
purchaseOrderPaymentTerms String?
final
purchaseOrderPaymentTermsId String?
final
purchaseOrderReferenceNumber String?
final
recordTitle String?
final
rentalTaxAlias String?
final
rentalTaxRate1 double?
final
rentalTaxRate2 double?
final
requistionNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesTaxAlias String?
final
salesTaxRate1 double?
final
salesTaxRate2 double?
final
status String?
final
statusDate String?
final
tax1Name String?
final
tax2Name String?
final
taxId String?
final
taxItemCode String?
final
taxOption String?
final
taxOptionId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
vendor String?
final
vendorFax String?
final
vendorId String?
final
vendorInvoiceId String?
final
vendorInvoiceModificationsPushToPo String?
final
vendorNumber String?
final
vendorPhone String?
final
warehouse String?
final
warehouseId String?
final

Methods

copyWith({String? vendorInvoiceId, String? purchaseOrderId, String? purchaseOrderNumber, String? purchaseOrderDescription, String? purchaseOrderReferenceNumber, String? requistionNumber, String? vendor, String? vendorNumber, String? vendorId, String? invoiceBatchId, String? inputDate, String? invoiceNumber, String? invoiceDate, String? invoiceDueDate, String? billingStartDate, String? billingEndDate, String? status, String? statusDate, String? departmentId, String? department, String? orderNumber, String? orderDescription, String? purchaseOrderDealId, String? purchaseOrderDealNumber, String? purchaseOrderDeal, String? purchaseOrderDealNumberDeal, String? purchaseOrderDate, String? purchaseOrderEstimatedStopDate, String? purchaseOrderEstimatedStartDate, String? purchaseOrderBillingCycleId, String? purchaseOrderBillingCycle, String? purchaseOrderPaymentTermsId, String? purchaseOrderPaymentTerms, String? approvedDate, String? locationId, String? location, String? warehouseId, String? warehouse, double? invoiceSubTotal, double? invoiceTax, double? invoiceTotal, String? billToAddress1, String? billToAddress2, String? billToCity, String? billToState, String? billToZipCode, String? billToCountry, String? vendorPhone, String? vendorFax, String? invoiceClass, bool? printNotes, String? paymentTermsId, String? paymentTerms, String? paymentTermsColor, String? taxId, double? rentalTaxRate1, double? salesTaxRate1, double? laborTaxRate1, double? rentalTaxRate2, double? salesTaxRate2, double? laborTaxRate2, String? taxOptionId, String? taxOption, String? tax1Name, String? tax2Name, String? rentalTaxAlias, String? salesTaxAlias, String? laborTaxAlias, String? taxItemCode, String? notes, bool? billedHiatus, String? invoiceType, String? agentId, String? projectManagerId, String? currencyId, String? currencyCode, String? currencySymbol, String? officeLocationDefaultCurrencyId, double? dealBilledExtended, double? credit, String? vendorInvoiceModificationsPushToPo, String? chargeBatchId, String? chargeBatchNumber, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesBillingVendorInvoiceVendorInvoice

Available on WebApiModulesBillingVendorInvoiceVendorInvoice, provided by the $WebApiModulesBillingVendorInvoiceVendorInvoiceExtension extension

copyWithWrapped({Wrapped<String?>? vendorInvoiceId, Wrapped<String?>? purchaseOrderId, Wrapped<String?>? purchaseOrderNumber, Wrapped<String?>? purchaseOrderDescription, Wrapped<String?>? purchaseOrderReferenceNumber, Wrapped<String?>? requistionNumber, Wrapped<String?>? vendor, Wrapped<String?>? vendorNumber, Wrapped<String?>? vendorId, Wrapped<String?>? invoiceBatchId, Wrapped<String?>? inputDate, Wrapped<String?>? invoiceNumber, Wrapped<String?>? invoiceDate, Wrapped<String?>? invoiceDueDate, Wrapped<String?>? billingStartDate, Wrapped<String?>? billingEndDate, Wrapped<String?>? status, Wrapped<String?>? statusDate, Wrapped<String?>? departmentId, Wrapped<String?>? department, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDescription, Wrapped<String?>? purchaseOrderDealId, Wrapped<String?>? purchaseOrderDealNumber, Wrapped<String?>? purchaseOrderDeal, Wrapped<String?>? purchaseOrderDealNumberDeal, Wrapped<String?>? purchaseOrderDate, Wrapped<String?>? purchaseOrderEstimatedStopDate, Wrapped<String?>? purchaseOrderEstimatedStartDate, Wrapped<String?>? purchaseOrderBillingCycleId, Wrapped<String?>? purchaseOrderBillingCycle, Wrapped<String?>? purchaseOrderPaymentTermsId, Wrapped<String?>? purchaseOrderPaymentTerms, Wrapped<String?>? approvedDate, Wrapped<String?>? locationId, Wrapped<String?>? location, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<double?>? invoiceSubTotal, Wrapped<double?>? invoiceTax, Wrapped<double?>? invoiceTotal, Wrapped<String?>? billToAddress1, Wrapped<String?>? billToAddress2, Wrapped<String?>? billToCity, Wrapped<String?>? billToState, Wrapped<String?>? billToZipCode, Wrapped<String?>? billToCountry, Wrapped<String?>? vendorPhone, Wrapped<String?>? vendorFax, Wrapped<String?>? invoiceClass, Wrapped<bool?>? printNotes, Wrapped<String?>? paymentTermsId, Wrapped<String?>? paymentTerms, Wrapped<String?>? paymentTermsColor, Wrapped<String?>? taxId, Wrapped<double?>? rentalTaxRate1, Wrapped<double?>? salesTaxRate1, Wrapped<double?>? laborTaxRate1, Wrapped<double?>? rentalTaxRate2, Wrapped<double?>? salesTaxRate2, Wrapped<double?>? laborTaxRate2, Wrapped<String?>? taxOptionId, Wrapped<String?>? taxOption, Wrapped<String?>? tax1Name, Wrapped<String?>? tax2Name, Wrapped<String?>? rentalTaxAlias, Wrapped<String?>? salesTaxAlias, Wrapped<String?>? laborTaxAlias, Wrapped<String?>? taxItemCode, Wrapped<String?>? notes, Wrapped<bool?>? billedHiatus, Wrapped<String?>? invoiceType, Wrapped<String?>? agentId, Wrapped<String?>? projectManagerId, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? officeLocationDefaultCurrencyId, Wrapped<double?>? dealBilledExtended, Wrapped<double?>? credit, Wrapped<String?>? vendorInvoiceModificationsPushToPo, Wrapped<String?>? chargeBatchId, Wrapped<String?>? chargeBatchNumber, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesBillingVendorInvoiceVendorInvoice

Available on WebApiModulesBillingVendorInvoiceVendorInvoice, provided by the $WebApiModulesBillingVendorInvoiceVendorInvoiceExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesBillingVendorInvoiceVendorInvoice Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesBillingVendorInvoiceVendorInvoice instance)