WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequest({String? vendorInvoiceId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath})
const
WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequest.fromJson(Map<String, dynamic> json)
factory

Properties

attachToEmail bool?
final
description String?
final
documentTypeId String?
final
fileDataUrl String?
final
fileIsModified bool?
final
filePath String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vendorInvoiceId String?
final

Methods

copyWith({String? vendorInvoiceId, String? documentTypeId, String? description, bool? attachToEmail, bool? inactive, bool? fileIsModified, String? fileDataUrl, String? filePath}) WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequest

Available on WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequest, provided by the $WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequestExtension extension

copyWithWrapped({Wrapped<String?>? vendorInvoiceId, Wrapped<String?>? documentTypeId, Wrapped<String?>? description, Wrapped<bool?>? attachToEmail, Wrapped<bool?>? inactive, Wrapped<bool?>? fileIsModified, Wrapped<String?>? fileDataUrl, Wrapped<String?>? filePath}) WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequest

Available on WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequest, provided by the $WebApiModulesBillingVendorInvoiceVendorInvoiceDocumentPostRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override