WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption({int? id, String? internalChar, String? companyId, String? locationId, String? location, String? taxOptionId, String? taxOption, String? taxCountry, String? taxRule, double? rentalTaxRate1, double? rentalTaxRate2, bool? rentalExempt, String? rentalTaxDisplay, double? salesTaxRate1, double? salesTaxRate2, bool? salesExempt, String? salesTaxDisplay, double? laborTaxRate1, double? laborTaxRate2, bool? laborExempt, String? laborTaxDisplay, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- companyId → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- id → int?
-
final
- internalChar → String?
-
final
- laborExempt → bool?
-
final
- laborTaxDisplay → String?
-
final
- laborTaxRate1 → double?
-
final
- laborTaxRate2 → double?
-
final
- location → String?
-
final
- locationId → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- rentalExempt → bool?
-
final
- rentalTaxDisplay → String?
-
final
- rentalTaxRate1 → double?
-
final
- rentalTaxRate2 → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesExempt → bool?
-
final
- salesTaxDisplay → String?
-
final
- salesTaxRate1 → double?
-
final
- salesTaxRate2 → double?
-
final
- taxCountry → String?
-
final
- taxOption → String?
-
final
- taxOptionId → String?
-
final
- taxRule → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{int? id, String? internalChar, String? companyId, String? locationId, String? location, String? taxOptionId, String? taxOption, String? taxCountry, String? taxRule, double? rentalTaxRate1, double? rentalTaxRate2, bool? rentalExempt, String? rentalTaxDisplay, double? salesTaxRate1, double? salesTaxRate2, bool? salesExempt, String? salesTaxDisplay, double? laborTaxRate1, double? laborTaxRate2, bool? laborExempt, String? laborTaxDisplay, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption -
Available on WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption, provided by the $WebApiModulesCompanyCompanyTaxOptionCompanyTaxOptionExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? id, Wrapped<String?> ? internalChar, Wrapped<String?> ? companyId, Wrapped<String?> ? locationId, Wrapped<String?> ? location, Wrapped<String?> ? taxOptionId, Wrapped<String?> ? taxOption, Wrapped<String?> ? taxCountry, Wrapped<String?> ? taxRule, Wrapped<double?> ? rentalTaxRate1, Wrapped<double?> ? rentalTaxRate2, Wrapped<bool?> ? rentalExempt, Wrapped<String?> ? rentalTaxDisplay, Wrapped<double?> ? salesTaxRate1, Wrapped<double?> ? salesTaxRate2, Wrapped<bool?> ? salesExempt, Wrapped<String?> ? salesTaxDisplay, Wrapped<double?> ? laborTaxRate1, Wrapped<double?> ? laborTaxRate2, Wrapped<bool?> ? laborExempt, Wrapped<String?> ? laborTaxDisplay, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption -
Available on WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption, provided by the $WebApiModulesCompanyCompanyTaxOptionCompanyTaxOptionExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesCompanyCompanyTaxOptionCompanyTaxOption instance)