WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectReason class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
rejectReasonDescription String?
final
rejectReasonId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? rejectReasonId, String? rejectReasonDescription}) WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectReason

Available on WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectReason, provided by the $WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectReasonExtension extension

copyWithWrapped({Wrapped<String?>? rejectReasonId, Wrapped<String?>? rejectReasonDescription}) WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectReason

Available on WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectReason, provided by the $WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectReasonExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override