WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
rejectReasonId String?
final
rejectReasonNote String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? rejectReasonId, String? rejectReasonNote}) WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectRequest

Available on WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectRequest, provided by the $WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectRequestExtension extension

copyWithWrapped({Wrapped<String?>? rejectReasonId, Wrapped<String?>? rejectReasonNote}) WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectRequest

Available on WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectRequest, provided by the $WebApiModulesHomeActiveLinkPurchaseOrderApprovalRejectRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override