WebApiModulesHomeAlternativeDescriptionAlternativeDescription class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeAlternativeDescriptionAlternativeDescription({int? alternativeDescriptionId, bool? internalChar, String? inventoryId, String? iCode, String? description, String? aka, bool? allowedOnInvoice, bool? isPrimary, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeAlternativeDescriptionAlternativeDescription.fromJson(Map<String, dynamic> json)
factory

Properties

aka String?
final
allowedOnInvoice bool?
final
alternativeDescriptionId int?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inactive bool?
final
internalChar bool?
final
inventoryId String?
final
isPrimary bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? alternativeDescriptionId, bool? internalChar, String? inventoryId, String? iCode, String? description, String? aka, bool? allowedOnInvoice, bool? isPrimary, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeAlternativeDescriptionAlternativeDescription

Available on WebApiModulesHomeAlternativeDescriptionAlternativeDescription, provided by the $WebApiModulesHomeAlternativeDescriptionAlternativeDescriptionExtension extension

copyWithWrapped({Wrapped<int?>? alternativeDescriptionId, Wrapped<bool?>? internalChar, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? aka, Wrapped<bool?>? allowedOnInvoice, Wrapped<bool?>? isPrimary, Wrapped<bool?>? inactive, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeAlternativeDescriptionAlternativeDescription

Available on WebApiModulesHomeAlternativeDescriptionAlternativeDescription, provided by the $WebApiModulesHomeAlternativeDescriptionAlternativeDescriptionExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override