WebApiModulesHomeControlsContactNoteContactNote class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsContactNoteContactNote({String? contactNoteId, String? contactId, String? companyId, String? companyContactId, String? noteDate, String? notesById, String? notesBy, String? description, String? notes, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesHomeControlsContactNoteContactNote.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
companyContactId String?
final
companyId String?
final
contactId String?
final
contactNoteId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
noteDate String?
final
notes String?
final
notesBy String?
final
notesById String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? contactNoteId, String? contactId, String? companyId, String? companyContactId, String? noteDate, String? notesById, String? notesBy, String? description, String? notes, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesHomeControlsContactNoteContactNote

Available on WebApiModulesHomeControlsContactNoteContactNote, provided by the $WebApiModulesHomeControlsContactNoteContactNoteExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override