WebApiModulesHomeControlsContainerItemContainerItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsContainerItemContainerItem({String? itemId, String? inventoryId, String? warehouseId, String? iCode, String? description, String? itemDescription, String? trackedBy, String? availableFor, String? availableForDisplay, double? unitValue, double? replacementCost, String? classification, bool? isContainer, String? containerId, String? containerInventoryId, String? containerICode, String? containerDescription, String? containerPackingListBehavior, String? containerStatus, String? containerStatusColor, String? containerItemId, String? containerItemItemId, String? containerBarCode, String? containerStatusDate, bool? fixedAsset, String? rank, String? statusType, String? statusDate, String? inventoryStatus, String? inventoryStatusId, String? color, String? textColor, String? barCode, String? barCodeForScanning, String? serialNumber, String? rfId, String? oldBarCode, String? oldSerialNumber, String? oldRfid, String? manufacturerPartNumber, String? manufactureDate, String? trackedByCode, int? availOwnershipSort, bool? isNegativeInventory, String? inspectionNo, String? inspectionVendorId, String? inspectionVendor, String? manufacturerModelNumber, String? purchaseId, String? rootOriginalPurchaseId, String? rootOriginalPurchase, String? aisleLocation, String? shelfLocation, String? spaceId, String? buildingRoom, String? itemNotes, String? physicalId, int? physicalItemId, String? physicalDate, String? physicalBy, String? warehouse, String? warehouseCode, String? dealId, String? orderId, String? orderNumber, String? orderDescription, String? currentLocation, String? inventoryTypeId, String? inventoryType, int? inventoryTypeOrderBy, String? categoryId, String? category, double? categoryOrderBy, String? subCategoryId, String? subCategory, double? subCategoryOrderBy, String? ownership, String? purchaseVendorId, String? purchaseVendor, String? outsidePurchaseOrderNumber, String? purchasePoId, String? purchaseDate, String? receiveDate, String? receiveContractDate, String? purchasePoNumber, double? purchaseCost, double? invoiceCost, String? purchaseInvoiceNumber, String? purchaseInvoiceDate, String? purchaseCurrencyId, String? purchaseCurrencyCode, String? purchaseCurrency, String? purchaseCurrencySymbol, String? purchaseWarehouseCurrencyId, String? purchaseWarehouseCurrencyCode, String? purchaseWarehouseCurrency, String? purchaseWarehouseCurrencySymbol, String? warehouseCurrencyId, String? warehouseCurrencyCode, String? warehouseCurrency, String? warehouseCurrencySymbol, double? purchaseCurrencyExchangeRate, double? unitCost, double? unitCostWithTax, double? additionalLoadCost, double? loadedUnitCost, double? unitCostCurrencyConverted, double? unitCostWithTaxCurrencyConverted, double? originalEquipmentCost, double? monthlyUnitDepreciation, double? depreciation, double? bookValue, double? salvageValue, String? consignorId, String? consignor, String? consignorAgreementId, String? consignorAgreementNumber, int? consignorPercent, String? manufacturerId, String? manufacturer, String? originalShowId, String? originalShow, String? conditionId, String? condition, String? surfaceId, String? surface, String? wallTypeId, String? wallType, String? openingId, String? opening, String? responsiblePersonId, String? responsiblePerson, String? buyerId, String? buyer, String? receiptNumber, int? depreciationMonths, int? monthsDepreciated, int? remainingMonthsOfDepreciation, String? repairId, String? repairNumber, bool? qcRequired, int? widthFt, int? widthIn, int? heightFt, int? heightIn, int? lengthFt, int? lengthIn, double? currentMeter, bool? trackAssetUsage, bool? trackLampUsage, bool? trackStrikes, bool? trackCandles, int? assetHours, int? lampCount, int? lampHours1, int? lampHours2, int? lampHours3, int? lampHours4, int? strikes, int? footCandles, int? minimumFootCandles, String? softwareVersion, String? softwareEffectiveDate, String? pattern, String? gender, String? label, String? material, String? period, double? cleaningFeeAmount, String? wardrobeSize, int? wardrobePieceCount, bool? inventoryTypeIsProps, bool? inventoryTypeIsWardrobe, String? orderLocationId, String? containerNumber, bool? isWardrobe, bool? isProps, double? dailyRate, double? weeklyRate, double? monthlyRate, String? location, String? retiredReason, String? warrantyExpiration, int? warrantyPeriod, String? countryOfOriginId, String? countryOfOrigin, String? shelfLifeExpirationDate, String? currentDealId, String? currentDeal, String? currentCustomerId, String? currentCustomer, String? currentOrderId, String? currentOrderNumber, String? currentOrderType, String? currentOrderDescription, String? currentOrderDate, String? currentOrderPickDate, String? currentOrderFromDate, String? currentOrderToDate, String? currentOrderAgent, String? lotNumber, String? lastOrderId, String? lastOrderNumber, String? lastOrderDescription, String? lastDealId, String? lastDeal, String? lastDealNumber, String? lastOutContractId, String? lastOutContractNumber, String? lastOutContractDate, String? lastOutUserId, String? lastOutUserName, String? lastInContractId, String? lastInContractNumber, String? lastInContractDate, String? lastInUserId, String? lastInUserName, String? depreciationStartDate, String? depreciationWarehouseId, String? depreciationWarehouse, String? depreciationWarehouseCode, String? depreciationCurrencyId, String? depreciationCurrencyCode, String? depreciationCurrency, String? depreciationCurrencySymbol, bool? inactive, String? inputDate, String? inputByUsersId, String? outOrderId, String? originalWarehouseId, bool? hasFixedAssetTransfer, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsContainerItemContainerItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- additionalLoadCost → double?
-
final
- aisleLocation → String?
-
final
- assetHours → int?
-
final
- auditNote → String?
-
final
- availableFor → String?
-
final
- availableForDisplay → String?
-
final
- availOwnershipSort → int?
-
final
- barCode → String?
-
final
- barCodeForScanning → String?
-
final
- bookValue → double?
-
final
- buildingRoom → String?
-
final
- buyer → String?
-
final
- buyerId → String?
-
final
- category → String?
-
final
- categoryId → String?
-
final
- categoryOrderBy → double?
-
final
- classification → String?
-
final
- cleaningFeeAmount → double?
-
final
- color → String?
-
final
- condition → String?
-
final
- conditionId → String?
-
final
- consignor → String?
-
final
- consignorAgreementId → String?
-
final
- consignorAgreementNumber → String?
-
final
- consignorId → String?
-
final
- consignorPercent → int?
-
final
- containerBarCode → String?
-
final
- containerDescription → String?
-
final
- containerICode → String?
-
final
- containerId → String?
-
final
- containerInventoryId → String?
-
final
- containerItemId → String?
-
final
- containerItemItemId → String?
-
final
- containerNumber → String?
-
final
- containerPackingListBehavior → String?
-
final
- containerStatus → String?
-
final
- containerStatusColor → String?
-
final
- containerStatusDate → String?
-
final
- countryOfOrigin → String?
-
final
- countryOfOriginId → String?
-
final
- currentCustomer → String?
-
final
- currentCustomerId → String?
-
final
- currentDeal → String?
-
final
- currentDealId → String?
-
final
- currentLocation → String?
-
final
- currentMeter → double?
-
final
- currentOrderAgent → String?
-
final
- currentOrderDate → String?
-
final
- currentOrderDescription → String?
-
final
- currentOrderFromDate → String?
-
final
- currentOrderId → String?
-
final
- currentOrderNumber → String?
-
final
- currentOrderPickDate → String?
-
final
- currentOrderToDate → String?
-
final
- currentOrderType → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dailyRate → double?
-
final
- dateStamp → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- depreciation → double?
-
final
- depreciationCurrency → String?
-
final
- depreciationCurrencyCode → String?
-
final
- depreciationCurrencyId → String?
-
final
- depreciationCurrencySymbol → String?
-
final
- depreciationMonths → int?
-
final
- depreciationStartDate → String?
-
final
- depreciationWarehouse → String?
-
final
- depreciationWarehouseCode → String?
-
final
- depreciationWarehouseId → String?
-
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fixedAsset → bool?
-
final
- footCandles → int?
-
final
- gender → String?
-
final
- hasFixedAssetTransfer → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- heightFt → int?
-
final
- heightIn → int?
-
final
- iCode → String?
-
final
- inactive → bool?
-
final
- inputByUsersId → String?
-
final
- inputDate → String?
-
final
- inspectionNo → String?
-
final
- inspectionVendor → String?
-
final
- inspectionVendorId → String?
-
final
- inventoryId → String?
-
final
- inventoryStatus → String?
-
final
- inventoryStatusId → String?
-
final
- inventoryType → String?
-
final
- inventoryTypeId → String?
-
final
- inventoryTypeIsProps → bool?
-
final
- inventoryTypeIsWardrobe → bool?
-
final
- inventoryTypeOrderBy → int?
-
final
- invoiceCost → double?
-
final
- isContainer → bool?
-
final
- isNegativeInventory → bool?
-
final
- isProps → bool?
-
final
- isWardrobe → bool?
-
final
- itemDescription → String?
-
final
- itemId → String?
-
final
- itemNotes → String?
-
final
- label → String?
-
final
- lampCount → int?
-
final
- lampHours1 → int?
-
final
- lampHours2 → int?
-
final
- lampHours3 → int?
-
final
- lampHours4 → int?
-
final
- lastDeal → String?
-
final
- lastDealId → String?
-
final
- lastDealNumber → String?
-
final
- lastInContractDate → String?
-
final
- lastInContractId → String?
-
final
- lastInContractNumber → String?
-
final
- lastInUserId → String?
-
final
- lastInUserName → String?
-
final
- lastOrderDescription → String?
-
final
- lastOrderId → String?
-
final
- lastOrderNumber → String?
-
final
- lastOutContractDate → String?
-
final
- lastOutContractId → String?
-
final
- lastOutContractNumber → String?
-
final
- lastOutUserId → String?
-
final
- lastOutUserName → String?
-
final
- lengthFt → int?
-
final
- lengthIn → int?
-
final
- loadedUnitCost → double?
-
final
- location → String?
-
final
- lotNumber → String?
-
final
- manufactureDate → String?
-
final
- manufacturer → String?
-
final
- manufacturerId → String?
-
final
- manufacturerModelNumber → String?
-
final
- manufacturerPartNumber → String?
-
final
- material → String?
-
final
- minimumFootCandles → int?
-
final
- monthlyRate → double?
-
final
- monthlyUnitDepreciation → double?
-
final
- monthsDepreciated → int?
-
final
- oldBarCode → String?
-
final
- oldRfid → String?
-
final
- oldSerialNumber → String?
-
final
- opening → String?
-
final
- openingId → String?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- orderLocationId → String?
-
final
- orderNumber → String?
-
final
- originalEquipmentCost → double?
-
final
- originalShow → String?
-
final
- originalShowId → String?
-
final
- originalWarehouseId → String?
-
final
- outOrderId → String?
-
final
- outsidePurchaseOrderNumber → String?
-
final
- ownership → String?
-
final
- pattern → String?
-
final
- period → String?
-
final
- physicalBy → String?
-
final
- physicalDate → String?
-
final
- physicalId → String?
-
final
- physicalItemId → int?
-
final
- purchaseCost → double?
-
final
- purchaseCurrency → String?
-
final
- purchaseCurrencyCode → String?
-
final
- purchaseCurrencyExchangeRate → double?
-
final
- purchaseCurrencyId → String?
-
final
- purchaseCurrencySymbol → String?
-
final
- purchaseDate → String?
-
final
- purchaseId → String?
-
final
- purchaseInvoiceDate → String?
-
final
- purchaseInvoiceNumber → String?
-
final
- purchasePoId → String?
-
final
- purchasePoNumber → String?
-
final
- purchaseVendor → String?
-
final
- purchaseVendorId → String?
-
final
- purchaseWarehouseCurrency → String?
-
final
- purchaseWarehouseCurrencyCode → String?
-
final
- purchaseWarehouseCurrencyId → String?
-
final
- purchaseWarehouseCurrencySymbol → String?
-
final
- qcRequired → bool?
-
final
- rank → String?
-
final
- receiptNumber → String?
-
final
- receiveContractDate → String?
-
final
- receiveDate → String?
-
final
- recordTitle → String?
-
final
- remainingMonthsOfDepreciation → int?
-
final
- repairId → String?
-
final
- repairNumber → String?
-
final
- replacementCost → double?
-
final
- responsiblePerson → String?
-
final
- responsiblePersonId → String?
-
final
- retiredReason → String?
-
final
- rfId → String?
-
final
- rootOriginalPurchase → String?
-
final
- rootOriginalPurchaseId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salvageValue → double?
-
final
- serialNumber → String?
-
final
- shelfLifeExpirationDate → String?
-
final
- shelfLocation → String?
-
final
- softwareEffectiveDate → String?
-
final
- softwareVersion → String?
-
final
- spaceId → String?
-
final
- statusDate → String?
-
final
- statusType → String?
-
final
- strikes → int?
-
final
- subCategory → String?
-
final
- subCategoryId → String?
-
final
- subCategoryOrderBy → double?
-
final
- surface → String?
-
final
- surfaceId → String?
-
final
- textColor → String?
-
final
- trackAssetUsage → bool?
-
final
- trackCandles → bool?
-
final
- trackedBy → String?
-
final
- trackedByCode → String?
-
final
- trackLampUsage → bool?
-
final
- trackStrikes → bool?
-
final
- unitCost → double?
-
final
- unitCostCurrencyConverted → double?
-
final
- unitCostWithTax → double?
-
final
- unitCostWithTaxCurrencyConverted → double?
-
final
- unitValue → double?
-
final
- wallType → String?
-
final
- wallTypeId → String?
-
final
- wardrobePieceCount → int?
-
final
- wardrobeSize → String?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseCurrency → String?
-
final
- warehouseCurrencyCode → String?
-
final
- warehouseCurrencyId → String?
-
final
- warehouseCurrencySymbol → String?
-
final
- warehouseId → String?
-
final
- warrantyExpiration → String?
-
final
- warrantyPeriod → int?
-
final
- weeklyRate → double?
-
final
- widthFt → int?
-
final
- widthIn → int?
-
final
Methods
-
copyWith(
{String? itemId, String? inventoryId, String? warehouseId, String? iCode, String? description, String? itemDescription, String? trackedBy, String? availableFor, String? availableForDisplay, double? unitValue, double? replacementCost, String? classification, bool? isContainer, String? containerId, String? containerInventoryId, String? containerICode, String? containerDescription, String? containerPackingListBehavior, String? containerStatus, String? containerStatusColor, String? containerItemId, String? containerItemItemId, String? containerBarCode, String? containerStatusDate, bool? fixedAsset, String? rank, String? statusType, String? statusDate, String? inventoryStatus, String? inventoryStatusId, String? color, String? textColor, String? barCode, String? barCodeForScanning, String? serialNumber, String? rfId, String? oldBarCode, String? oldSerialNumber, String? oldRfid, String? manufacturerPartNumber, String? manufactureDate, String? trackedByCode, int? availOwnershipSort, bool? isNegativeInventory, String? inspectionNo, String? inspectionVendorId, String? inspectionVendor, String? manufacturerModelNumber, String? purchaseId, String? rootOriginalPurchaseId, String? rootOriginalPurchase, String? aisleLocation, String? shelfLocation, String? spaceId, String? buildingRoom, String? itemNotes, String? physicalId, int? physicalItemId, String? physicalDate, String? physicalBy, String? warehouse, String? warehouseCode, String? dealId, String? orderId, String? orderNumber, String? orderDescription, String? currentLocation, String? inventoryTypeId, String? inventoryType, int? inventoryTypeOrderBy, String? categoryId, String? category, double? categoryOrderBy, String? subCategoryId, String? subCategory, double? subCategoryOrderBy, String? ownership, String? purchaseVendorId, String? purchaseVendor, String? outsidePurchaseOrderNumber, String? purchasePoId, String? purchaseDate, String? receiveDate, String? receiveContractDate, String? purchasePoNumber, double? purchaseCost, double? invoiceCost, String? purchaseInvoiceNumber, String? purchaseInvoiceDate, String? purchaseCurrencyId, String? purchaseCurrencyCode, String? purchaseCurrency, String? purchaseCurrencySymbol, String? purchaseWarehouseCurrencyId, String? purchaseWarehouseCurrencyCode, String? purchaseWarehouseCurrency, String? purchaseWarehouseCurrencySymbol, String? warehouseCurrencyId, String? warehouseCurrencyCode, String? warehouseCurrency, String? warehouseCurrencySymbol, double? purchaseCurrencyExchangeRate, double? unitCost, double? unitCostWithTax, double? additionalLoadCost, double? loadedUnitCost, double? unitCostCurrencyConverted, double? unitCostWithTaxCurrencyConverted, double? originalEquipmentCost, double? monthlyUnitDepreciation, double? depreciation, double? bookValue, double? salvageValue, String? consignorId, String? consignor, String? consignorAgreementId, String? consignorAgreementNumber, int? consignorPercent, String? manufacturerId, String? manufacturer, String? originalShowId, String? originalShow, String? conditionId, String? condition, String? surfaceId, String? surface, String? wallTypeId, String? wallType, String? openingId, String? opening, String? responsiblePersonId, String? responsiblePerson, String? buyerId, String? buyer, String? receiptNumber, int? depreciationMonths, int? monthsDepreciated, int? remainingMonthsOfDepreciation, String? repairId, String? repairNumber, bool? qcRequired, int? widthFt, int? widthIn, int? heightFt, int? heightIn, int? lengthFt, int? lengthIn, double? currentMeter, bool? trackAssetUsage, bool? trackLampUsage, bool? trackStrikes, bool? trackCandles, int? assetHours, int? lampCount, int? lampHours1, int? lampHours2, int? lampHours3, int? lampHours4, int? strikes, int? footCandles, int? minimumFootCandles, String? softwareVersion, String? softwareEffectiveDate, String? pattern, String? gender, String? label, String? material, String? period, double? cleaningFeeAmount, String? wardrobeSize, int? wardrobePieceCount, bool? inventoryTypeIsProps, bool? inventoryTypeIsWardrobe, String? orderLocationId, String? containerNumber, bool? isWardrobe, bool? isProps, double? dailyRate, double? weeklyRate, double? monthlyRate, String? location, String? retiredReason, String? warrantyExpiration, int? warrantyPeriod, String? countryOfOriginId, String? countryOfOrigin, String? shelfLifeExpirationDate, String? currentDealId, String? currentDeal, String? currentCustomerId, String? currentCustomer, String? currentOrderId, String? currentOrderNumber, String? currentOrderType, String? currentOrderDescription, String? currentOrderDate, String? currentOrderPickDate, String? currentOrderFromDate, String? currentOrderToDate, String? currentOrderAgent, String? lotNumber, String? lastOrderId, String? lastOrderNumber, String? lastOrderDescription, String? lastDealId, String? lastDeal, String? lastDealNumber, String? lastOutContractId, String? lastOutContractNumber, String? lastOutContractDate, String? lastOutUserId, String? lastOutUserName, String? lastInContractId, String? lastInContractNumber, String? lastInContractDate, String? lastInUserId, String? lastInUserName, String? depreciationStartDate, String? depreciationWarehouseId, String? depreciationWarehouse, String? depreciationWarehouseCode, String? depreciationCurrencyId, String? depreciationCurrencyCode, String? depreciationCurrency, String? depreciationCurrencySymbol, bool? inactive, String? inputDate, String? inputByUsersId, String? outOrderId, String? originalWarehouseId, bool? hasFixedAssetTransfer, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsContainerItemContainerItem -
Available on WebApiModulesHomeControlsContainerItemContainerItem, provided by the $WebApiModulesHomeControlsContainerItemContainerItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsContainerItemContainerItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsContainerItemContainerItem instance)