WebApiModulesHomeControlsContainerWarehouseContainerWarehouse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsContainerWarehouseContainerWarehouse({String? inventoryId, String? warehouseId, String? warehouseCode, String? warehouse, double? dailyRate, double? weeklyRate, double? monthlyRate, int? quantity, int? quantityReady, int? quantityIncomplete, int? warehouseOrderBy, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsContainerWarehouseContainerWarehouse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dailyRate → double?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inventoryId → String?
-
final
- monthlyRate → double?
-
final
- quantity → int?
-
final
- quantityIncomplete → int?
-
final
- quantityReady → int?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
- warehouseOrderBy → int?
-
final
- weeklyRate → double?
-
final
Methods
-
copyWith(
{String? inventoryId, String? warehouseId, String? warehouseCode, String? warehouse, double? dailyRate, double? weeklyRate, double? monthlyRate, int? quantity, int? quantityReady, int? quantityIncomplete, int? warehouseOrderBy, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsContainerWarehouseContainerWarehouse -
Available on WebApiModulesHomeControlsContainerWarehouseContainerWarehouse, provided by the $WebApiModulesHomeControlsContainerWarehouseContainerWarehouseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsContainerWarehouseContainerWarehouse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsContainerWarehouseContainerWarehouse instance)