WebApiModulesHomeControlsContractItemDetailContractItemDetail class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsContractItemDetailContractItemDetail({String? contractId, String? contractNumber, String? contractType, String? orderId, String? orderItemId, String? orderNumber, String? orderDescription, String? iCode, String? iCodeDisplay, String? iCodeColor, String? description, String? descriptionColor, double? quantity, String? barCode, String? serialNumber, String? rfId, String? codeForVoiding, String? itemId, String? manufacturerPartNumber, String? trackedBy, String? categoryId, String? vendorId, String? vendor, String? vendorColor, String? inventoryId, String? warehouseId, String? warehouseCode, String? warehouse, String? shippingCaseNumber, String? shippingCaseItemId, String? shippingCaseColor, String? primaryOrderItemId, String? itemClass, String? itemOrder, String? orderBy, String? notes, String? orderType, String? recType, String? recTypeDisplay, String? optionColor, String? usersId, String? userName, String? transactionDateTime, String? parentId, double? accessoryRatio, String? nestedOrderItemId, String? containerItemId, String? containerBarCode, bool? isConsignment, String? consignorId, String? consignor, String? consignorAgreementId, String? consignorAgreementNumber, bool? isVoid, int? nestingLevel, String? vendorConsignorId, String? vendorConsignor, String? exception, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeControlsContractItemDetailContractItemDetail.fromJson(Map<String, dynamic> json)
factory

Properties

accessoryRatio double?
final
auditNote String?
final
barCode String?
final
categoryId String?
final
codeForVoiding String?
final
consignor String?
final
consignorAgreementId String?
final
consignorAgreementNumber String?
final
consignorId String?
final
containerBarCode String?
final
containerItemId String?
final
contractId String?
final
contractNumber String?
final
contractType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
descriptionColor String?
final
exception String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
iCodeColor String?
final
iCodeDisplay String?
final
inventoryId String?
final
isConsignment bool?
final
isVoid bool?
final
itemClass String?
final
itemId String?
final
itemOrder String?
final
manufacturerPartNumber String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
nestedOrderItemId String?
final
nestingLevel int?
final
notes String?
final
optionColor String?
final
orderBy String?
final
orderDescription String?
final
orderId String?
final
orderItemId String?
final
orderNumber String?
final
orderType String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
parentId String?
final
primaryOrderItemId String?
final
quantity double?
final
recordTitle String?
final
recType String?
final
recTypeDisplay String?
final
rfId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
shippingCaseColor String?
final
shippingCaseItemId String?
final
shippingCaseNumber String?
final
trackedBy String?
final
transactionDateTime String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userName String?
final
usersId String?
final
vendor String?
final
vendorColor String?
final
vendorConsignor String?
final
vendorConsignorId String?
final
vendorId String?
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? contractId, String? contractNumber, String? contractType, String? orderId, String? orderItemId, String? orderNumber, String? orderDescription, String? iCode, String? iCodeDisplay, String? iCodeColor, String? description, String? descriptionColor, double? quantity, String? barCode, String? serialNumber, String? rfId, String? codeForVoiding, String? itemId, String? manufacturerPartNumber, String? trackedBy, String? categoryId, String? vendorId, String? vendor, String? vendorColor, String? inventoryId, String? warehouseId, String? warehouseCode, String? warehouse, String? shippingCaseNumber, String? shippingCaseItemId, String? shippingCaseColor, String? primaryOrderItemId, String? itemClass, String? itemOrder, String? orderBy, String? notes, String? orderType, String? recType, String? recTypeDisplay, String? optionColor, String? usersId, String? userName, String? transactionDateTime, String? parentId, double? accessoryRatio, String? nestedOrderItemId, String? containerItemId, String? containerBarCode, bool? isConsignment, String? consignorId, String? consignor, String? consignorAgreementId, String? consignorAgreementNumber, bool? isVoid, int? nestingLevel, String? vendorConsignorId, String? vendorConsignor, String? exception, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeControlsContractItemDetailContractItemDetail

Available on WebApiModulesHomeControlsContractItemDetailContractItemDetail, provided by the $WebApiModulesHomeControlsContractItemDetailContractItemDetailExtension extension

copyWithWrapped({Wrapped<String?>? contractId, Wrapped<String?>? contractNumber, Wrapped<String?>? contractType, Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDescription, Wrapped<String?>? iCode, Wrapped<String?>? iCodeDisplay, Wrapped<String?>? iCodeColor, Wrapped<String?>? description, Wrapped<String?>? descriptionColor, Wrapped<double?>? quantity, Wrapped<String?>? barCode, Wrapped<String?>? serialNumber, Wrapped<String?>? rfId, Wrapped<String?>? codeForVoiding, Wrapped<String?>? itemId, Wrapped<String?>? manufacturerPartNumber, Wrapped<String?>? trackedBy, Wrapped<String?>? categoryId, Wrapped<String?>? vendorId, Wrapped<String?>? vendor, Wrapped<String?>? vendorColor, Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouseCode, Wrapped<String?>? warehouse, Wrapped<String?>? shippingCaseNumber, Wrapped<String?>? shippingCaseItemId, Wrapped<String?>? shippingCaseColor, Wrapped<String?>? primaryOrderItemId, Wrapped<String?>? itemClass, Wrapped<String?>? itemOrder, Wrapped<String?>? orderBy, Wrapped<String?>? notes, Wrapped<String?>? orderType, Wrapped<String?>? recType, Wrapped<String?>? recTypeDisplay, Wrapped<String?>? optionColor, Wrapped<String?>? usersId, Wrapped<String?>? userName, Wrapped<String?>? transactionDateTime, Wrapped<String?>? parentId, Wrapped<double?>? accessoryRatio, Wrapped<String?>? nestedOrderItemId, Wrapped<String?>? containerItemId, Wrapped<String?>? containerBarCode, Wrapped<bool?>? isConsignment, Wrapped<String?>? consignorId, Wrapped<String?>? consignor, Wrapped<String?>? consignorAgreementId, Wrapped<String?>? consignorAgreementNumber, Wrapped<bool?>? isVoid, Wrapped<int?>? nestingLevel, Wrapped<String?>? vendorConsignorId, Wrapped<String?>? vendorConsignor, Wrapped<String?>? exception, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeControlsContractItemDetailContractItemDetail

Available on WebApiModulesHomeControlsContractItemDetailContractItemDetail, provided by the $WebApiModulesHomeControlsContractItemDetailContractItemDetailExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override