WebApiModulesHomeControlsDeliveryDelivery class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsDeliveryDelivery({String? deliveryId, String? orderId, String? deliveryType, String? requiredDate, String? requiredTime, String? targetShipDate, String? targetShipTime, String? direction, String? addressType, String? fromLocation, String? fromContact, String? fromContactPhone, String? fromAlternateContact, String? fromAlternateContactPhone, String? fromAttention, String? fromAddress1, String? fromAdd2ress, String? fromCity, String? fromState, String? fromZipCode, String? fromCountry, String? fromCountryId, String? fromCrossStreets, String? toLocation, String? toContact, String? toContactPhone, String? toAlternateContact, String? toAlternateContactPhone, String? toAttention, String? toAddress1, String? toAddress2, String? toCity, String? toState, String? toZipCode, String? toCountryId, String? toCountry, String? toContactFax, String? toCrossStreets, String? deliveryNotes, String? carrierId, String? carrier, String? carrierAccount, String? shipViaId, String? shipVia, String? invoiceId, String? vendorInvoiceId, double? estimatedFreight, double? freightInvoiceAmount, String? chargeType, String? freightTrackingNumber, bool? dropShip, String? packageCode, bool? billPoFreightOnOrder, String? onlineOrderNumber, String? onlineOrderStatus, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsDeliveryDelivery.fromJson(Map<
String, dynamic> json) -
factory
Properties
- addressType → String?
-
final
- auditNote → String?
-
final
- billPoFreightOnOrder → bool?
-
final
- carrier → String?
-
final
- carrierAccount → String?
-
final
- carrierId → String?
-
final
- chargeType → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- deliveryId → String?
-
final
- deliveryNotes → String?
-
final
- deliveryType → String?
-
final
- direction → String?
-
final
- dropShip → bool?
-
final
- estimatedFreight → double?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- freightInvoiceAmount → double?
-
final
- freightTrackingNumber → String?
-
final
- fromAdd2ress → String?
-
final
- fromAddress1 → String?
-
final
- fromAlternateContact → String?
-
final
- fromAlternateContactPhone → String?
-
final
- fromAttention → String?
-
final
- fromCity → String?
-
final
- fromContact → String?
-
final
- fromContactPhone → String?
-
final
- fromCountry → String?
-
final
- fromCountryId → String?
-
final
- fromCrossStreets → String?
-
final
- fromLocation → String?
-
final
- fromState → String?
-
final
- fromZipCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- invoiceId → String?
-
final
- onlineOrderNumber → String?
-
final
- onlineOrderStatus → String?
-
final
- orderId → String?
-
final
- packageCode → String?
-
final
- recordTitle → String?
-
final
- requiredDate → String?
-
final
- requiredTime → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shipVia → String?
-
final
- shipViaId → String?
-
final
- targetShipDate → String?
-
final
- targetShipTime → String?
-
final
- toAddress1 → String?
-
final
- toAddress2 → String?
-
final
- toAlternateContact → String?
-
final
- toAlternateContactPhone → String?
-
final
- toAttention → String?
-
final
- toCity → String?
-
final
- toContact → String?
-
final
- toContactFax → String?
-
final
- toContactPhone → String?
-
final
- toCountry → String?
-
final
- toCountryId → String?
-
final
- toCrossStreets → String?
-
final
- toLocation → String?
-
final
- toState → String?
-
final
- toZipCode → String?
-
final
- vendorInvoiceId → String?
-
final
Methods
-
copyWith(
{String? deliveryId, String? orderId, String? deliveryType, String? requiredDate, String? requiredTime, String? targetShipDate, String? targetShipTime, String? direction, String? addressType, String? fromLocation, String? fromContact, String? fromContactPhone, String? fromAlternateContact, String? fromAlternateContactPhone, String? fromAttention, String? fromAddress1, String? fromAdd2ress, String? fromCity, String? fromState, String? fromZipCode, String? fromCountry, String? fromCountryId, String? fromCrossStreets, String? toLocation, String? toContact, String? toContactPhone, String? toAlternateContact, String? toAlternateContactPhone, String? toAttention, String? toAddress1, String? toAddress2, String? toCity, String? toState, String? toZipCode, String? toCountryId, String? toCountry, String? toContactFax, String? toCrossStreets, String? deliveryNotes, String? carrierId, String? carrier, String? carrierAccount, String? shipViaId, String? shipVia, String? invoiceId, String? vendorInvoiceId, double? estimatedFreight, double? freightInvoiceAmount, String? chargeType, String? freightTrackingNumber, bool? dropShip, String? packageCode, bool? billPoFreightOnOrder, String? onlineOrderNumber, String? onlineOrderStatus, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsDeliveryDelivery -
Available on WebApiModulesHomeControlsDeliveryDelivery, provided by the $WebApiModulesHomeControlsDeliveryDeliveryExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsDeliveryDelivery Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsDeliveryDelivery instance)