WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequest({String? inventoryId, List<
String> ? warehouseId, String? regionId, DateTime? fromDate, DateTime? toDate, bool? includeHours, bool? yearView, String? sortReservationsBy, bool? excludeConsigned, bool? consignedOnly, List<String> ? filterReservationsBy}) -
WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- consignedOnly → bool?
-
final
- excludeConsigned → bool?
-
final
-
filterReservationsBy
→ List<
String> ? -
final
- fromDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeHours → bool?
-
final
- inventoryId → String?
-
final
- regionId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortReservationsBy → String?
-
final
- toDate → DateTime?
-
final
-
warehouseId
→ List<
String> ? -
final
- yearView → bool?
-
final
Methods
-
copyWith(
{String? inventoryId, List< String> ? warehouseId, String? regionId, DateTime? fromDate, DateTime? toDate, bool? includeHours, bool? yearView, String? sortReservationsBy, bool? excludeConsigned, bool? consignedOnly, List<String> ? filterReservationsBy}) → WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequest -
Available on WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequest, provided by the $WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsInventoryAvailabilityAvailabilityCalendarAndScheduleRequest instance)