WebApiModulesHomeControlsInventoryAvailabilityAvailabilityInventoryWarehouseRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
refreshIfNeeded bool?
final
regionId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate DateTime?
final
warehouseId String?
final

Methods

copyWith({String? inventoryId, String? warehouseId, String? regionId, DateTime? fromDate, DateTime? toDate, bool? refreshIfNeeded}) WebApiModulesHomeControlsInventoryAvailabilityAvailabilityInventoryWarehouseRequest

Available on WebApiModulesHomeControlsInventoryAvailabilityAvailabilityInventoryWarehouseRequest, provided by the $WebApiModulesHomeControlsInventoryAvailabilityAvailabilityInventoryWarehouseRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override