WebApiModulesHomeControlsInventoryAvailabilityTInventoryAvailabilityCalendarEvent class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

backColor String?
final
end String?
final
hashCode int
The hash code for this object.
no setteroverride
id String?
final
inventoryId String?
final
resource String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start String?
final
text String?
final
textColor String?
final
warehouseId String?
final

Methods

copyWith({String? inventoryId, String? warehouseId, String? start, String? end, String? text, String? backColor, String? textColor, String? id, String? resource}) WebApiModulesHomeControlsInventoryAvailabilityTInventoryAvailabilityCalendarEvent

Available on WebApiModulesHomeControlsInventoryAvailabilityTInventoryAvailabilityCalendarEvent, provided by the $WebApiModulesHomeControlsInventoryAvailabilityTInventoryAvailabilityCalendarEventExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override