WebApiModulesHomeControlsInventoryCompatibleInventoryCompatible class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsInventoryCompatibleInventoryCompatible({String? inventoryCompatibleId, String? inventoryId, String? iCode, String? description, String? compatibleWithInventoryId, String? compatibleWithICode, String? compatibleWithDescription, String? compatibleWithClassification, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesHomeControlsInventoryCompatibleInventoryCompatible.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
compatibleWithClassification String?
final
compatibleWithDescription String?
final
compatibleWithICode String?
final
compatibleWithInventoryId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
iCode String?
final
inventoryCompatibleId String?
final
inventoryId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inventoryCompatibleId, String? inventoryId, String? iCode, String? description, String? compatibleWithInventoryId, String? compatibleWithICode, String? compatibleWithDescription, String? compatibleWithClassification, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesHomeControlsInventoryCompatibleInventoryCompatible

Available on WebApiModulesHomeControlsInventoryCompatibleInventoryCompatible, provided by the $WebApiModulesHomeControlsInventoryCompatibleInventoryCompatibleExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override