WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKit class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKit({String? inventoryId, String? packageId, String? iCode, String? iCodeColor, String? description, String? descriptionColor, String? itemClass, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? warehouseId, String? warehouse, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKit.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- category → String?
-
final
- categoryId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
- descriptionColor → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- iCodeColor → String?
-
final
- inventoryId → String?
-
final
- inventoryType → String?
-
final
- inventoryTypeId → String?
-
final
- itemClass → String?
-
final
- packageId → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subCategory → String?
-
final
- subCategoryId → String?
-
final
- warehouse → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? inventoryId, String? packageId, String? iCode, String? iCodeColor, String? description, String? descriptionColor, String? itemClass, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? warehouseId, String? warehouse, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKit -
Available on WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKit, provided by the $WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKitExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKit Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsInventoryCompleteKitInventoryCompleteKit instance)