WebApiModulesHomeControlsInventoryConsignorInventoryConsignor class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsInventoryConsignorInventoryConsignor({String? consignorId, String? consignorAgreementId, String? consignor, String? agreementNumber, String? agreementDescription, String? inventoryId, String? iCode, String? description, String? trackedBy, bool? treatConsignedQtyAsOwned, int? qtyConsigned, int? consignorPercent, int? housePercent, bool? flatRate, double? flatRateAmount, String? itemId, String? barCode, String? serialNumber, String? inventoryStatusId, String? inventoryStatus, String? inventoryStatusType, String? warehouseId, String? warehouse, String? warehouseCode, String? textColor, String? color, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeControlsInventoryConsignorInventoryConsignor.fromJson(Map<String, dynamic> json)
factory

Properties

agreementDescription String?
final
agreementNumber String?
final
auditNote String?
final
barCode String?
final
color String?
final
consignor String?
final
consignorAgreementId String?
final
consignorId String?
final
consignorPercent int?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
flatRate bool?
final
flatRateAmount double?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
housePercent int?
final
iCode String?
final
inventoryId String?
final
inventoryStatus String?
final
inventoryStatusId String?
final
inventoryStatusType String?
final
itemId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
qtyConsigned int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
textColor String?
final
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
treatConsignedQtyAsOwned bool?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? consignorId, String? consignorAgreementId, String? consignor, String? agreementNumber, String? agreementDescription, String? inventoryId, String? iCode, String? description, String? trackedBy, bool? treatConsignedQtyAsOwned, int? qtyConsigned, int? consignorPercent, int? housePercent, bool? flatRate, double? flatRateAmount, String? itemId, String? barCode, String? serialNumber, String? inventoryStatusId, String? inventoryStatus, String? inventoryStatusType, String? warehouseId, String? warehouse, String? warehouseCode, String? textColor, String? color, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeControlsInventoryConsignorInventoryConsignor

Available on WebApiModulesHomeControlsInventoryConsignorInventoryConsignor, provided by the $WebApiModulesHomeControlsInventoryConsignorInventoryConsignorExtension extension

copyWithWrapped({Wrapped<String?>? consignorId, Wrapped<String?>? consignorAgreementId, Wrapped<String?>? consignor, Wrapped<String?>? agreementNumber, Wrapped<String?>? agreementDescription, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? trackedBy, Wrapped<bool?>? treatConsignedQtyAsOwned, Wrapped<int?>? qtyConsigned, Wrapped<int?>? consignorPercent, Wrapped<int?>? housePercent, Wrapped<bool?>? flatRate, Wrapped<double?>? flatRateAmount, Wrapped<String?>? itemId, Wrapped<String?>? barCode, Wrapped<String?>? serialNumber, Wrapped<String?>? inventoryStatusId, Wrapped<String?>? inventoryStatus, Wrapped<String?>? inventoryStatusType, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? warehouseCode, Wrapped<String?>? textColor, Wrapped<String?>? color, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeControlsInventoryConsignorInventoryConsignor

Available on WebApiModulesHomeControlsInventoryConsignorInventoryConsignor, provided by the $WebApiModulesHomeControlsInventoryConsignorInventoryConsignorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override