WebApiModulesHomeControlsInventorySearchInventorySearch class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsInventorySearchInventorySearch({String? sessionId, String? inventoryId, String? warehouseId, int? id, String? lineage, String? packageItemId, double? quantity, DateTime? fromDate, DateTime? toDate, double? quantityAvailable, DateTime? conflictDate, String? availabilityState, double? quantityAvailableRegion, DateTime? conflictDateRegion, String? availabilityStateRegion, double? quantityAvailableAllWarehouses, DateTime? conflictDateAllWarehouses, String? availabilityStateAllWarehouses, double? totalQuantityInSession, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsInventorySearchInventorySearch.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- availabilityState → String?
-
final
- availabilityStateAllWarehouses → String?
-
final
- availabilityStateRegion → String?
-
final
- conflictDate → DateTime?
-
final
- conflictDateAllWarehouses → DateTime?
-
final
- conflictDateRegion → DateTime?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fromDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- inventoryId → String?
-
final
- lineage → String?
-
final
- packageItemId → String?
-
final
- quantity → double?
-
final
- quantityAvailable → double?
-
final
- quantityAvailableAllWarehouses → double?
-
final
- quantityAvailableRegion → double?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- toDate → DateTime?
-
final
- totalQuantityInSession → double?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? sessionId, String? inventoryId, String? warehouseId, int? id, String? lineage, String? packageItemId, double? quantity, DateTime? fromDate, DateTime? toDate, double? quantityAvailable, DateTime? conflictDate, String? availabilityState, double? quantityAvailableRegion, DateTime? conflictDateRegion, String? availabilityStateRegion, double? quantityAvailableAllWarehouses, DateTime? conflictDateAllWarehouses, String? availabilityStateAllWarehouses, double? totalQuantityInSession, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsInventorySearchInventorySearch -
Available on WebApiModulesHomeControlsInventorySearchInventorySearch, provided by the $WebApiModulesHomeControlsInventorySearchInventorySearchExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsInventorySearchInventorySearch Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsInventorySearchInventorySearch instance)