WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequest({String? orderId, int? insertAtIndex, DateTime? pickDate, String? pickTime, DateTime? fromDate, String? fromTime, DateTime? toDate, String? toTime, String? insertAtItemOrder, bool? isLossAndDamage, String? sessionId})
const
WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequest.fromJson(Map<String, dynamic> json)
factory

Properties

fromDate DateTime?
final
fromTime String?
final
hashCode int
The hash code for this object.
no setteroverride
insertAtIndex int?
final
insertAtItemOrder String?
final
isLossAndDamage bool?
final
orderId String?
final
pickDate DateTime?
final
pickTime String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
toDate DateTime?
final
toTime String?
final

Methods

copyWith({String? orderId, int? insertAtIndex, DateTime? pickDate, String? pickTime, DateTime? fromDate, String? fromTime, DateTime? toDate, String? toTime, String? insertAtItemOrder, bool? isLossAndDamage, String? sessionId}) WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequest

Available on WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequest, provided by the $WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<int?>? insertAtIndex, Wrapped<DateTime?>? pickDate, Wrapped<String?>? pickTime, Wrapped<DateTime?>? fromDate, Wrapped<String?>? fromTime, Wrapped<DateTime?>? toDate, Wrapped<String?>? toTime, Wrapped<String?>? insertAtItemOrder, Wrapped<bool?>? isLossAndDamage, Wrapped<String?>? sessionId}) WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequest

Available on WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequest, provided by the $WebApiModulesHomeControlsInventorySearchInventorySearchAddToOrderRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override