WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse({String? inventoryId, String? currencyId, double? hourlyRate, double? hourlyCost, double? dailyRate, double? dailyCost, double? weeklyRate, double? weeklyCost, double? week2Rate, double? week3Rate, double? week4Rate, double? monthlyRate, double? monthlyCost, double? retail, double? price, double? defaultCost, double? averageCost, double? markupPercent, int? reorderPoint, int? reorderQuantity, double? maximumDiscount, double? minimumDaysPerWeek, bool? hasTieredCost, double? restockingFee, double? restockingPercent, String? dateOfLastPhysicalInventory, double? qty, double? qtyConsigned, double? qtyIn, double? qtyInContainer, int? qtyQcRequired, double? qtyStaged, double? qtyOut, double? qtyInRepair, double? qtyOnPo, double? qtyAllocated, String? aisleLocation, String? shelfLocation, bool? availabilityByHour, bool? availabilityByDeal, bool? availabilityByAsset, bool? qcRequired, int? availabilityQcDelay, bool? allowAllUsersAddToOrder, double? unitValue, double? replacementCost, bool? markupReplacementCost, double? replacementCostMarkupPercent, bool? isWarehouseSpecific, String? dateStamp, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aisleLocation → String?
-
final
- allowAllUsersAddToOrder → bool?
-
final
- auditNote → String?
-
final
- availabilityByAsset → bool?
-
final
- availabilityByDeal → bool?
-
final
- availabilityByHour → bool?
-
final
- availabilityQcDelay → int?
-
final
- averageCost → double?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
- currencyId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dailyCost → double?
-
final
- dailyRate → double?
-
final
- dateOfLastPhysicalInventory → String?
-
final
- dateStamp → String?
-
final
- defaultCost → double?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- hasTieredCost → bool?
-
final
- hourlyCost → double?
-
final
- hourlyRate → double?
-
final
- inventoryId → String?
-
final
- isWarehouseSpecific → bool?
-
final
- itemDescription → String?
-
final
- markupPercent → double?
-
final
- markupReplacementCost → bool?
-
final
- maximumDiscount → double?
-
final
- minimumDaysPerWeek → double?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- monthlyCost → double?
-
final
- monthlyRate → double?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- price → double?
-
final
- qcRequired → bool?
-
final
- qty → double?
-
final
- qtyAllocated → double?
-
final
- qtyConsigned → double?
-
final
- qtyIn → double?
-
final
- qtyInContainer → double?
-
final
- qtyInRepair → double?
-
final
- qtyOnPo → double?
-
final
- qtyOut → double?
-
final
- qtyQcRequired → int?
-
final
- qtyStaged → double?
-
final
- recordTitle → String?
-
final
- reorderPoint → int?
-
final
- reorderQuantity → int?
-
final
- replacementCost → double?
-
final
- replacementCostMarkupPercent → double?
-
final
- restockingFee → double?
-
final
- restockingPercent → double?
-
final
- retail → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shelfLocation → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- unitValue → double?
-
final
- urlIdentifier → dynamic
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
- warehouseOrderBy → int?
-
final
- week2Rate → double?
-
final
- week3Rate → double?
-
final
- week4Rate → double?
-
final
- weeklyCost → double?
-
final
- weeklyRate → double?
-
final
Methods
-
copyWith(
{String? inventoryId, String? currencyId, double? hourlyRate, double? hourlyCost, double? dailyRate, double? dailyCost, double? weeklyRate, double? weeklyCost, double? week2Rate, double? week3Rate, double? week4Rate, double? monthlyRate, double? monthlyCost, double? retail, double? price, double? defaultCost, double? averageCost, double? markupPercent, int? reorderPoint, int? reorderQuantity, double? maximumDiscount, double? minimumDaysPerWeek, bool? hasTieredCost, double? restockingFee, double? restockingPercent, String? dateOfLastPhysicalInventory, double? qty, double? qtyConsigned, double? qtyIn, double? qtyInContainer, int? qtyQcRequired, double? qtyStaged, double? qtyOut, double? qtyInRepair, double? qtyOnPo, double? qtyAllocated, String? aisleLocation, String? shelfLocation, bool? availabilityByHour, bool? availabilityByDeal, bool? availabilityByAsset, bool? qcRequired, int? availabilityQcDelay, bool? allowAllUsersAddToOrder, double? unitValue, double? replacementCost, bool? markupReplacementCost, double? replacementCostMarkupPercent, bool? isWarehouseSpecific, String? dateStamp, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse -
Available on WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse, provided by the $WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouseExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? inventoryId, Wrapped<String?> ? currencyId, Wrapped<double?> ? hourlyRate, Wrapped<double?> ? hourlyCost, Wrapped<double?> ? dailyRate, Wrapped<double?> ? dailyCost, Wrapped<double?> ? weeklyRate, Wrapped<double?> ? weeklyCost, Wrapped<double?> ? week2Rate, Wrapped<double?> ? week3Rate, Wrapped<double?> ? week4Rate, Wrapped<double?> ? monthlyRate, Wrapped<double?> ? monthlyCost, Wrapped<double?> ? retail, Wrapped<double?> ? price, Wrapped<double?> ? defaultCost, Wrapped<double?> ? averageCost, Wrapped<double?> ? markupPercent, Wrapped<int?> ? reorderPoint, Wrapped<int?> ? reorderQuantity, Wrapped<double?> ? maximumDiscount, Wrapped<double?> ? minimumDaysPerWeek, Wrapped<bool?> ? hasTieredCost, Wrapped<double?> ? restockingFee, Wrapped<double?> ? restockingPercent, Wrapped<String?> ? dateOfLastPhysicalInventory, Wrapped<double?> ? qty, Wrapped<double?> ? qtyConsigned, Wrapped<double?> ? qtyIn, Wrapped<double?> ? qtyInContainer, Wrapped<int?> ? qtyQcRequired, Wrapped<double?> ? qtyStaged, Wrapped<double?> ? qtyOut, Wrapped<double?> ? qtyInRepair, Wrapped<double?> ? qtyOnPo, Wrapped<double?> ? qtyAllocated, Wrapped<String?> ? aisleLocation, Wrapped<String?> ? shelfLocation, Wrapped<bool?> ? availabilityByHour, Wrapped<bool?> ? availabilityByDeal, Wrapped<bool?> ? availabilityByAsset, Wrapped<bool?> ? qcRequired, Wrapped<int?> ? availabilityQcDelay, Wrapped<bool?> ? allowAllUsersAddToOrder, Wrapped<double?> ? unitValue, Wrapped<double?> ? replacementCost, Wrapped<bool?> ? markupReplacementCost, Wrapped<double?> ? replacementCostMarkupPercent, Wrapped<bool?> ? isWarehouseSpecific, Wrapped<String?> ? dateStamp, Wrapped<String?> ? itemDescription, Wrapped<String?> ? warehouseId, Wrapped<String?> ? warehouseCode, Wrapped<String?> ? warehouse, Wrapped<int?> ? warehouseOrderBy, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse -
Available on WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse, provided by the $WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsInventoryWarehouseInventoryWarehouse instance)