WebApiModulesHomeControlsInvoiceOrderInvoiceOrder class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsInvoiceOrderInvoiceOrder({String? orderInvoiceId, String? orderNumber, String? orderDescription, String? orderNumberAndDescription, String? referenceNumber, String? location, String? orderLocation, String? officeLocation, String? department, String? agentId, String? agent, String? agentEmail, String? agentPhoneAndExtension, String? agentPhone, String? agentExtension, String? agentFax, String? projectManagerId, String? projectManager, String? projectManagerEmail, String? projectManagerPhoneAndExtension, String? projectManagerPhone, String? projectManagerExtension, String? projectManagerFax, String? estimatedStartDate, String? estimatedStopDate, String? estimatedStartTime, String? estimatedStopTime, String? billingStartDate, String? billingEndDate, String? billingStopDate, String? usageStartDate, String? usageStopDate, String? poNumber, String? purchaseOrderNumber, String? orderId, String? flatPoId, bool? excludeFromFlatPO, bool? billableFlat, String? invoiceId, double? summaryInvoiceOrderBy, double? rentalSubTotal, double? laborSubTotal, double? nonRentalSubTotal, double? orderInvoiceSubTotal, double? orderInvoiceTax, double? orderInvoiceTotal, String? currencyId, String? currencyCode, String? currencySymbol, String? currency, String? orderBy, String? customerId, String? customer, String? customerNumber, String? customerEmail, String? dealId, String? deal, String? dealNumber, String? dealAndDealNumber, String? dealEmail, String? paymentTerms, bool? hasRecurring, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsInvoiceOrderInvoiceOrder.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agent → String?
-
final
- agentEmail → String?
-
final
- agentExtension → String?
-
final
- agentFax → String?
-
final
- agentId → String?
-
final
- agentPhone → String?
-
final
- agentPhoneAndExtension → String?
-
final
- auditNote → String?
-
final
- billableFlat → bool?
-
final
- billingEndDate → String?
-
final
- billingStartDate → String?
-
final
- billingStopDate → String?
-
final
- currency → String?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerEmail → String?
-
final
- customerId → String?
-
final
- customerNumber → String?
-
final
- deal → String?
-
final
- dealAndDealNumber → String?
-
final
- dealEmail → String?
-
final
- dealId → String?
-
final
- dealNumber → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- estimatedStartDate → String?
-
final
- estimatedStartTime → String?
-
final
- estimatedStopDate → String?
-
final
- estimatedStopTime → String?
-
final
- excludeFromFlatPO → bool?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- flatPoId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasRecurring → bool?
-
final
- invoiceId → String?
-
final
- laborSubTotal → double?
-
final
- location → String?
-
final
- nonRentalSubTotal → double?
-
final
- officeLocation → String?
-
final
- orderBy → String?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- orderInvoiceId → String?
-
final
- orderInvoiceSubTotal → double?
-
final
- orderInvoiceTax → double?
-
final
- orderInvoiceTotal → double?
-
final
- orderLocation → String?
-
final
- orderNumber → String?
-
final
- orderNumberAndDescription → String?
-
final
- paymentTerms → String?
-
final
- poNumber → String?
-
final
- projectManager → String?
-
final
- projectManagerEmail → String?
-
final
- projectManagerExtension → String?
-
final
- projectManagerFax → String?
-
final
- projectManagerId → String?
-
final
- projectManagerPhone → String?
-
final
- projectManagerPhoneAndExtension → String?
-
final
- purchaseOrderNumber → String?
-
final
- recordTitle → String?
-
final
- referenceNumber → String?
-
final
- rentalSubTotal → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summaryInvoiceOrderBy → double?
-
final
- usageStartDate → String?
-
final
- usageStopDate → String?
-
final
Methods
-
copyWith(
{String? orderInvoiceId, String? orderNumber, String? orderDescription, String? orderNumberAndDescription, String? referenceNumber, String? location, String? orderLocation, String? officeLocation, String? department, String? agentId, String? agent, String? agentEmail, String? agentPhoneAndExtension, String? agentPhone, String? agentExtension, String? agentFax, String? projectManagerId, String? projectManager, String? projectManagerEmail, String? projectManagerPhoneAndExtension, String? projectManagerPhone, String? projectManagerExtension, String? projectManagerFax, String? estimatedStartDate, String? estimatedStopDate, String? estimatedStartTime, String? estimatedStopTime, String? billingStartDate, String? billingEndDate, String? billingStopDate, String? usageStartDate, String? usageStopDate, String? poNumber, String? purchaseOrderNumber, String? orderId, String? flatPoId, bool? excludeFromFlatPO, bool? billableFlat, String? invoiceId, double? summaryInvoiceOrderBy, double? rentalSubTotal, double? laborSubTotal, double? nonRentalSubTotal, double? orderInvoiceSubTotal, double? orderInvoiceTax, double? orderInvoiceTotal, String? currencyId, String? currencyCode, String? currencySymbol, String? currency, String? orderBy, String? customerId, String? customer, String? customerNumber, String? customerEmail, String? dealId, String? deal, String? dealNumber, String? dealAndDealNumber, String? dealEmail, String? paymentTerms, bool? hasRecurring, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsInvoiceOrderInvoiceOrder -
Available on WebApiModulesHomeControlsInvoiceOrderInvoiceOrder, provided by the $WebApiModulesHomeControlsInvoiceOrderInvoiceOrderExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsInvoiceOrderInvoiceOrder Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsInvoiceOrderInvoiceOrder instance)