WebApiModulesHomeControlsInvoiceReceiptInvoiceReceipt class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsInvoiceReceiptInvoiceReceipt({int? invoiceReceiptId, String? invoiceId, String? receiptId, String? receiptDate, String? paymentTypeId, String? paymentType, String? checkNumber, bool? recType, String? paymentBy, String? receiptCustomerId, String? receiptCustomer, String? receiptDealId, String? receiptDeal, String? invoiceNumber, String? invoiceDate, String? invoiceDescription, String? invoiceDealId, String? invoiceDeal, double? amount, String? appliedById, String? appliedBy, String? paymentMemo, String? currencyId, String? currencyCode, String? currencySymbol, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsInvoiceReceiptInvoiceReceipt.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → double?
-
final
- appliedBy → String?
-
final
- appliedById → String?
-
final
- auditNote → String?
-
final
- checkNumber → String?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- invoiceDate → String?
-
final
- invoiceDeal → String?
-
final
- invoiceDealId → String?
-
final
- invoiceDescription → String?
-
final
- invoiceId → String?
-
final
- invoiceNumber → String?
-
final
- invoiceReceiptId → int?
-
final
- paymentBy → String?
-
final
- paymentMemo → String?
-
final
- paymentType → String?
-
final
- paymentTypeId → String?
-
final
- receiptCustomer → String?
-
final
- receiptCustomerId → String?
-
final
- receiptDate → String?
-
final
- receiptDeal → String?
-
final
- receiptDealId → String?
-
final
- receiptId → String?
-
final
- recordTitle → String?
-
final
- recType → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? invoiceReceiptId, String? invoiceId, String? receiptId, String? receiptDate, String? paymentTypeId, String? paymentType, String? checkNumber, bool? recType, String? paymentBy, String? receiptCustomerId, String? receiptCustomer, String? receiptDealId, String? receiptDeal, String? invoiceNumber, String? invoiceDate, String? invoiceDescription, String? invoiceDealId, String? invoiceDeal, double? amount, String? appliedById, String? appliedBy, String? paymentMemo, String? currencyId, String? currencyCode, String? currencySymbol, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsInvoiceReceiptInvoiceReceipt -
Available on WebApiModulesHomeControlsInvoiceReceiptInvoiceReceipt, provided by the $WebApiModulesHomeControlsInvoiceReceiptInvoiceReceiptExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsInvoiceReceiptInvoiceReceipt Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsInvoiceReceiptInvoiceReceipt instance)