WebApiModulesHomeControlsLossAndDamageCompleteLossAndDamageSessionRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
sourceOrderId String?
final

Methods

copyWith({String? sourceOrderId, String? sessionId}) WebApiModulesHomeControlsLossAndDamageCompleteLossAndDamageSessionRequest

Available on WebApiModulesHomeControlsLossAndDamageCompleteLossAndDamageSessionRequest, provided by the $WebApiModulesHomeControlsLossAndDamageCompleteLossAndDamageSessionRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override