WebApiModulesHomeControlsOrderDatesOrderDates class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsOrderDatesOrderDates({String? orderId, String? orderTypeId, String? orderTypeDateTypeId, bool? isSystemType, String? activityTypeId, String? activityType, String? activity, String? activityDisplay, String? description, String? descriptionDisplay, String? descriptionDisplayTitleCase, bool? isEnabled, String? date, String? time, String? dateAndTime, String? dayOfWeek, String? actualDate, String? actualTime, String? actualDayOfWeek, bool? isRequired, bool? isProductionActivity, bool? isMilestone, double? orderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeControlsOrderDatesOrderDates.fromJson(Map<String, dynamic> json)
factory

Properties

activity String?
final
activityDisplay String?
final
activityType String?
final
activityTypeId String?
final
actualDate String?
final
actualDayOfWeek String?
final
actualTime String?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
date String?
final
dateAndTime String?
final
dayOfWeek String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
descriptionDisplay String?
final
descriptionDisplayTitleCase String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
isEnabled bool?
final
isMilestone bool?
final
isProductionActivity bool?
final
isRequired bool?
final
isSystemType bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderBy double?
final
orderId String?
final
orderTypeDateTypeId String?
final
orderTypeId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? orderId, String? orderTypeId, String? orderTypeDateTypeId, bool? isSystemType, String? activityTypeId, String? activityType, String? activity, String? activityDisplay, String? description, String? descriptionDisplay, String? descriptionDisplayTitleCase, bool? isEnabled, String? date, String? time, String? dateAndTime, String? dayOfWeek, String? actualDate, String? actualTime, String? actualDayOfWeek, bool? isRequired, bool? isProductionActivity, bool? isMilestone, double? orderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeControlsOrderDatesOrderDates

Available on WebApiModulesHomeControlsOrderDatesOrderDates, provided by the $WebApiModulesHomeControlsOrderDatesOrderDatesExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? orderTypeId, Wrapped<String?>? orderTypeDateTypeId, Wrapped<bool?>? isSystemType, Wrapped<String?>? activityTypeId, Wrapped<String?>? activityType, Wrapped<String?>? activity, Wrapped<String?>? activityDisplay, Wrapped<String?>? description, Wrapped<String?>? descriptionDisplay, Wrapped<String?>? descriptionDisplayTitleCase, Wrapped<bool?>? isEnabled, Wrapped<String?>? date, Wrapped<String?>? time, Wrapped<String?>? dateAndTime, Wrapped<String?>? dayOfWeek, Wrapped<String?>? actualDate, Wrapped<String?>? actualTime, Wrapped<String?>? actualDayOfWeek, Wrapped<bool?>? isRequired, Wrapped<bool?>? isProductionActivity, Wrapped<bool?>? isMilestone, Wrapped<double?>? orderBy, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeControlsOrderDatesOrderDates

Available on WebApiModulesHomeControlsOrderDatesOrderDates, provided by the $WebApiModulesHomeControlsOrderDatesOrderDatesExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesHomeControlsOrderDatesOrderDates Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesHomeControlsOrderDatesOrderDates instance)