WebApiModulesHomeControlsOrderItemOrderItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsOrderItemOrderItem({String? orderItemId, String? orderId, bool? rowsRolledUp, String? rolledUpIds, String? orderType, String? recType, String? recTypeDisplay, int? rowNumber, String? inventoryId, String? iCode, String? iCodeColor, String? description, String? descriptionColor, String? pickDate, String? pickTime, String? fromDate, String? fromTime, String? toDate, String? toTime, double? billablePeriods, double? quantityOrdered, String? quantityColor, double? subQuantity, String? subQuantityColor, int? consignQuantity, String? consignQuantityColor, String? containerColor, int? reservedItemQuantity, double? availableQuantity, String? availabilityState, double? availableAllWarehousesQuantity, String? conflictDate, String? conflictDateAllWarehouses, String? availabilityStateConsignment, double? availableQuantityConsignment, String? conflictDateConsignment, String? unitId, String? unit, String? unitType, double? unitCost, double? marginPercent, double? markupPercent, String? crewContactId, String? crewName, double? hours, double? hoursOvertime, double? hoursDoubletime, double? price, double? price2, double? price3, double? price4, double? price5, double? daysPerWeek, double? discountPercent, double? discountPercentDisplay, double? unitExtendedNoDiscount, double? unitDiscountAmount, double? unitExtended, double? weeklyExtendedNoDiscount, double? weeklyDiscountAmount, double? weeklyExtended, double? weeklyCostExtended, double? weeklyTax, double? weeklyTax1, double? weeklyTax2, double? weeklyTotal, double? week2Extended, double? week3Extended, double? weeks1Through3Extended, double? weeks4PlusExtended, double? week4Extended, double? averageWeekly, double? averageWeeklyExtended, double? averageWeeklyExtendedNoDiscount, double? averageWeeklyDiscountAmount, double? averageWeeklyTax, double? averageWeeklyTax1, double? averageWeeklyTax2, double? averageWeeklyTotal, int? episodes, double? monthlyExtendedNoDiscount, double? monthlyDiscountAmount, double? monthlyExtended, double? monthlyCostExtended, double? monthlyTax, double? monthlyTax1, double? monthlyTax2, double? monthlyTotal, double? periodExtendedNoDiscount, double? periodCostExtended, double? periodDiscountAmount, double? periodExtended, double? periodTax, double? periodTax1, double? periodTax2, double? periodTotal, double? periodVarianceExtended, double? variancePercent, double? minimumDaysPerWeek, bool? bold, bool? locked, bool? taxable, String? warehouseId, String? warehouseCode, String? warehouse, String? returnToWarehouseId, String? returnToWarehouseCode, String? notes, String? itemOrder, String? parentId, String? nestedOrderItemId, String? itemClass, String? inventoryClass, String? trackedBy, String? retiredReasonId, String? retiredReason, String? itemId, String? barCode, String? serialNumber, String? manufacturerPartNumber, String? poSubOrderId, String? poSubOrderItemId, String? poSubOrderNumber, String? lossAndDamageOrderId, String? lossAndDamageOrderItemId, String? lossAndDamageOrderNumber, bool? modifiedAtStaging, bool? mute, bool? availabilityByHour, bool? printNoteOnQuote, bool? printNoteOnOrder, bool? printNoteOnPickList, bool? printNoteOnOutContract, bool? printNoteOnInContract, bool? printNoteOnReturnList, bool? printNoteOnInvoice, bool? printNoteOnPurchaseOrder, bool? printNoteOnReceiveContract, bool? printNoteOnReturnContract, bool? printNoteOnVendorReceiveList, bool? printNoteOnVendorReturnList, double? defaultHourlyRate, double? defaultDailyRate, double? defaultWeeklyRate, double? defaultMonthlyRate, int? nestingLevel, String? repairId, String? repairNumber, String? subVendorId, String? subVendor, String? consignorId, String? consignor, String? consignorAgreementId, String? consignorAgreementNumber, String? vendorConsignorId, String? vendorConsignor, bool? availabilityExcludeConsigned, String? primaryOrderItemId, double? accessoryRatio, bool? isOption, String? optionColor, String? currencySymbol, int? transferAvailabilityDays, String? costOrderId, String? costOrderNumber, bool? includeInCost, double? loadedUnitCost, String? dateStamp, bool? inactive, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsOrderItemOrderItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessoryRatio → double?
-
final
- auditNote → String?
-
final
- availabilityByHour → bool?
-
final
- availabilityExcludeConsigned → bool?
-
final
- availabilityState → String?
-
final
- availabilityStateConsignment → String?
-
final
- availableAllWarehousesQuantity → double?
-
final
- availableQuantity → double?
-
final
- availableQuantityConsignment → double?
-
final
- averageWeekly → double?
-
final
- averageWeeklyDiscountAmount → double?
-
final
- averageWeeklyExtended → double?
-
final
- averageWeeklyExtendedNoDiscount → double?
-
final
- averageWeeklyTax → double?
-
final
- averageWeeklyTax1 → double?
-
final
- averageWeeklyTax2 → double?
-
final
- averageWeeklyTotal → double?
-
final
- barCode → String?
-
final
- billablePeriods → double?
-
final
- bold → bool?
-
final
- conflictDate → String?
-
final
- conflictDateAllWarehouses → String?
-
final
- conflictDateConsignment → String?
-
final
- consignor → String?
-
final
- consignorAgreementId → String?
-
final
- consignorAgreementNumber → String?
-
final
- consignorId → String?
-
final
- consignQuantity → int?
-
final
- consignQuantityColor → String?
-
final
- containerColor → String?
-
final
- costOrderId → String?
-
final
- costOrderNumber → String?
-
final
- crewContactId → String?
-
final
- crewName → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- daysPerWeek → double?
-
final
- defaultDailyRate → double?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultHourlyRate → double?
-
final
- defaultMonthlyRate → double?
-
final
- defaultWeeklyRate → double?
-
final
- description → String?
-
final
- descriptionColor → String?
-
final
- discountPercent → double?
-
final
- discountPercentDisplay → double?
-
final
- episodes → int?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fromDate → String?
-
final
- fromTime → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hours → double?
-
final
- hoursDoubletime → double?
-
final
- hoursOvertime → double?
-
final
- iCode → String?
-
final
- iCodeColor → String?
-
final
- inactive → bool?
-
final
- includeInCost → bool?
-
final
- inventoryClass → String?
-
final
- inventoryId → String?
-
final
- isOption → bool?
-
final
- itemClass → String?
-
final
- itemId → String?
-
final
- itemOrder → String?
-
final
- loadedUnitCost → double?
-
final
- locked → bool?
-
final
- lossAndDamageOrderId → String?
-
final
- lossAndDamageOrderItemId → String?
-
final
- lossAndDamageOrderNumber → String?
-
final
- manufacturerPartNumber → String?
-
final
- marginPercent → double?
-
final
- markupPercent → double?
-
final
- minimumDaysPerWeek → double?
-
final
- modifiedAtStaging → bool?
-
final
- monthlyCostExtended → double?
-
final
- monthlyDiscountAmount → double?
-
final
- monthlyExtended → double?
-
final
- monthlyExtendedNoDiscount → double?
-
final
- monthlyTax → double?
-
final
- monthlyTax1 → double?
-
final
- monthlyTax2 → double?
-
final
- monthlyTotal → double?
-
final
- mute → bool?
-
final
- nestedOrderItemId → String?
-
final
- nestingLevel → int?
-
final
- notes → String?
-
final
- optionColor → String?
-
final
- orderId → String?
-
final
- orderItemId → String?
-
final
- orderType → String?
-
final
- parentId → String?
-
final
- periodCostExtended → double?
-
final
- periodDiscountAmount → double?
-
final
- periodExtended → double?
-
final
- periodExtendedNoDiscount → double?
-
final
- periodTax → double?
-
final
- periodTax1 → double?
-
final
- periodTax2 → double?
-
final
- periodTotal → double?
-
final
- periodVarianceExtended → double?
-
final
- pickDate → String?
-
final
- pickTime → String?
-
final
- poSubOrderId → String?
-
final
- poSubOrderItemId → String?
-
final
- poSubOrderNumber → String?
-
final
-
final
- price → double?
-
final
- price2 → double?
-
final
- price3 → double?
-
final
- price4 → double?
-
final
- price5 → double?
-
final
- primaryOrderItemId → String?
-
final
- printNoteOnInContract → bool?
-
final
- printNoteOnInvoice → bool?
-
final
- printNoteOnOrder → bool?
-
final
- printNoteOnOutContract → bool?
-
final
- printNoteOnPickList → bool?
-
final
- printNoteOnPurchaseOrder → bool?
-
final
- printNoteOnQuote → bool?
-
final
- printNoteOnReceiveContract → bool?
-
final
- printNoteOnReturnContract → bool?
-
final
- printNoteOnReturnList → bool?
-
final
- printNoteOnVendorReceiveList → bool?
-
final
- printNoteOnVendorReturnList → bool?
-
final
- quantityColor → String?
-
final
- quantityOrdered → double?
-
final
- recordTitle → String?
-
final
- recType → String?
-
final
- recTypeDisplay → String?
-
final
- repairId → String?
-
final
- repairNumber → String?
-
final
- reservedItemQuantity → int?
-
final
- retiredReason → String?
-
final
- retiredReasonId → String?
-
final
- returnToWarehouseCode → String?
-
final
- returnToWarehouseId → String?
-
final
- rolledUpIds → String?
-
final
- rowNumber → int?
-
final
- rowsRolledUp → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber → String?
-
final
- subQuantity → double?
-
final
- subQuantityColor → String?
-
final
- subVendor → String?
-
final
- subVendorId → String?
-
final
- taxable → bool?
-
final
- toDate → String?
-
final
- toTime → String?
-
final
- trackedBy → String?
-
final
- transferAvailabilityDays → int?
-
final
- unit → String?
-
final
- unitCost → double?
-
final
- unitDiscountAmount → double?
-
final
- unitExtended → double?
-
final
- unitExtendedNoDiscount → double?
-
final
- unitId → String?
-
final
- unitType → String?
-
final
- variancePercent → double?
-
final
- vendorConsignor → String?
-
final
- vendorConsignorId → String?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
- week2Extended → double?
-
final
- week3Extended → double?
-
final
- week4Extended → double?
-
final
- weeklyCostExtended → double?
-
final
- weeklyDiscountAmount → double?
-
final
- weeklyExtended → double?
-
final
- weeklyExtendedNoDiscount → double?
-
final
- weeklyTax → double?
-
final
- weeklyTax1 → double?
-
final
- weeklyTax2 → double?
-
final
- weeklyTotal → double?
-
final
- weeks1Through3Extended → double?
-
final
- weeks4PlusExtended → double?
-
final
Methods
-
copyWith(
{String? orderItemId, String? orderId, bool? rowsRolledUp, String? rolledUpIds, String? orderType, String? recType, String? recTypeDisplay, int? rowNumber, String? inventoryId, String? iCode, String? iCodeColor, String? description, String? descriptionColor, String? pickDate, String? pickTime, String? fromDate, String? fromTime, String? toDate, String? toTime, double? billablePeriods, double? quantityOrdered, String? quantityColor, double? subQuantity, String? subQuantityColor, int? consignQuantity, String? consignQuantityColor, String? containerColor, int? reservedItemQuantity, double? availableQuantity, String? availabilityState, double? availableAllWarehousesQuantity, String? conflictDate, String? conflictDateAllWarehouses, String? availabilityStateConsignment, double? availableQuantityConsignment, String? conflictDateConsignment, String? unitId, String? unit, String? unitType, double? unitCost, double? marginPercent, double? markupPercent, String? crewContactId, String? crewName, double? hours, double? hoursOvertime, double? hoursDoubletime, double? price, double? price2, double? price3, double? price4, double? price5, double? daysPerWeek, double? discountPercent, double? discountPercentDisplay, double? unitExtendedNoDiscount, double? unitDiscountAmount, double? unitExtended, double? weeklyExtendedNoDiscount, double? weeklyDiscountAmount, double? weeklyExtended, double? weeklyCostExtended, double? weeklyTax, double? weeklyTax1, double? weeklyTax2, double? weeklyTotal, double? week2Extended, double? week3Extended, double? weeks1Through3Extended, double? weeks4PlusExtended, double? week4Extended, double? averageWeekly, double? averageWeeklyExtended, double? averageWeeklyExtendedNoDiscount, double? averageWeeklyDiscountAmount, double? averageWeeklyTax, double? averageWeeklyTax1, double? averageWeeklyTax2, double? averageWeeklyTotal, int? episodes, double? monthlyExtendedNoDiscount, double? monthlyDiscountAmount, double? monthlyExtended, double? monthlyCostExtended, double? monthlyTax, double? monthlyTax1, double? monthlyTax2, double? monthlyTotal, double? periodExtendedNoDiscount, double? periodCostExtended, double? periodDiscountAmount, double? periodExtended, double? periodTax, double? periodTax1, double? periodTax2, double? periodTotal, double? periodVarianceExtended, double? variancePercent, double? minimumDaysPerWeek, bool? bold, bool? locked, bool? taxable, String? warehouseId, String? warehouseCode, String? warehouse, String? returnToWarehouseId, String? returnToWarehouseCode, String? notes, String? itemOrder, String? parentId, String? nestedOrderItemId, String? itemClass, String? inventoryClass, String? trackedBy, String? retiredReasonId, String? retiredReason, String? itemId, String? barCode, String? serialNumber, String? manufacturerPartNumber, String? poSubOrderId, String? poSubOrderItemId, String? poSubOrderNumber, String? lossAndDamageOrderId, String? lossAndDamageOrderItemId, String? lossAndDamageOrderNumber, bool? modifiedAtStaging, bool? mute, bool? availabilityByHour, bool? printNoteOnQuote, bool? printNoteOnOrder, bool? printNoteOnPickList, bool? printNoteOnOutContract, bool? printNoteOnInContract, bool? printNoteOnReturnList, bool? printNoteOnInvoice, bool? printNoteOnPurchaseOrder, bool? printNoteOnReceiveContract, bool? printNoteOnReturnContract, bool? printNoteOnVendorReceiveList, bool? printNoteOnVendorReturnList, double? defaultHourlyRate, double? defaultDailyRate, double? defaultWeeklyRate, double? defaultMonthlyRate, int? nestingLevel, String? repairId, String? repairNumber, String? subVendorId, String? subVendor, String? consignorId, String? consignor, String? consignorAgreementId, String? consignorAgreementNumber, String? vendorConsignorId, String? vendorConsignor, bool? availabilityExcludeConsigned, String? primaryOrderItemId, double? accessoryRatio, bool? isOption, String? optionColor, String? currencySymbol, int? transferAvailabilityDays, String? costOrderId, String? costOrderNumber, bool? includeInCost, double? loadedUnitCost, String? dateStamp, bool? inactive, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsOrderItemOrderItem -
Available on WebApiModulesHomeControlsOrderItemOrderItem, provided by the $WebApiModulesHomeControlsOrderItemOrderItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsOrderItemOrderItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsOrderItemOrderItem instance)