WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory({int? id, String? physicalInventoryId, String? inventoryId, String? consignorId, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? iCode, String? description, String? availableFor, String? availableForDisplay, String? trackedBy, String? rank, String? aisleLocation, String? shelfLocation, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory.fromJson(Map<String, dynamic> json)
factory

Properties

aisleLocation String?
final
auditNote String?
final
availableFor String?
final
availableForDisplay String?
final
category String?
final
categoryId String?
final
consignorId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
id int?
final
inventoryId String?
final
inventoryType String?
final
inventoryTypeId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
physicalInventoryId String?
final
rank String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelfLocation String?
final
subCategory String?
final
subCategoryId String?
final
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? id, String? physicalInventoryId, String? inventoryId, String? consignorId, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? iCode, String? description, String? availableFor, String? availableForDisplay, String? trackedBy, String? rank, String? aisleLocation, String? shelfLocation, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory

Available on WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory, provided by the $WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventoryExtension extension

copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? physicalInventoryId, Wrapped<String?>? inventoryId, Wrapped<String?>? consignorId, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? inventoryType, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<String?>? subCategoryId, Wrapped<String?>? subCategory, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? availableFor, Wrapped<String?>? availableForDisplay, Wrapped<String?>? trackedBy, Wrapped<String?>? rank, Wrapped<String?>? aisleLocation, Wrapped<String?>? shelfLocation, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory

Available on WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory, provided by the $WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override