WebApiModulesHomeControlsPickListItemPickListItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsPickListItemPickListItem({String? pickListItemId, String? pickListId, String? orderId, String? orderNumber, String? masterItemId, String? usersId, int? pickQuantity, int? quantityOrdered, int? consignQuantity, int? stagedQuantity, int? outQuantity, int? inLocationQuantity, String? masterId, String? iCode, String? iCodeColor, String? description, String? descriptionColor, String? optionColor, String? itemClass, String? itemOrder, String? pickDate, String? pickTime, String? recType, String? vendorId, String? consignorId, String? vendorConsignorColor, String? vendorConsignor, String? inventoryTypeId, String? categoryId, String? warehouseId, bool? conflict, bool? bold, String? itemOrderPickList, String? notes, String? barCode, String? serialNumber, String? rfId, int? nestingLevel, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsPickListItemPickListItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- barCode → String?
-
final
- bold → bool?
-
final
- categoryId → String?
-
final
- conflict → bool?
-
final
- consignorId → String?
-
final
- consignQuantity → int?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
- descriptionColor → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- iCodeColor → String?
-
final
- inLocationQuantity → int?
-
final
- inventoryTypeId → String?
-
final
- itemClass → String?
-
final
- itemOrder → String?
-
final
- itemOrderPickList → String?
-
final
- masterId → String?
-
final
- masterItemId → String?
-
final
- nestingLevel → int?
-
final
- notes → String?
-
final
- optionColor → String?
-
final
- orderId → String?
-
final
- orderNumber → String?
-
final
- outQuantity → int?
-
final
- pickDate → String?
-
final
- pickListId → String?
-
final
- pickListItemId → String?
-
final
- pickQuantity → int?
-
final
- pickTime → String?
-
final
- quantityOrdered → int?
-
final
- recordTitle → String?
-
final
- recType → String?
-
final
- rfId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber → String?
-
final
- stagedQuantity → int?
-
final
- usersId → String?
-
final
- vendorConsignor → String?
-
final
- vendorConsignorColor → String?
-
final
- vendorId → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? pickListItemId, String? pickListId, String? orderId, String? orderNumber, String? masterItemId, String? usersId, int? pickQuantity, int? quantityOrdered, int? consignQuantity, int? stagedQuantity, int? outQuantity, int? inLocationQuantity, String? masterId, String? iCode, String? iCodeColor, String? description, String? descriptionColor, String? optionColor, String? itemClass, String? itemOrder, String? pickDate, String? pickTime, String? recType, String? vendorId, String? consignorId, String? vendorConsignorColor, String? vendorConsignor, String? inventoryTypeId, String? categoryId, String? warehouseId, bool? conflict, bool? bold, String? itemOrderPickList, String? notes, String? barCode, String? serialNumber, String? rfId, int? nestingLevel, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsPickListItemPickListItem -
Available on WebApiModulesHomeControlsPickListItemPickListItem, provided by the $WebApiModulesHomeControlsPickListItemPickListItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsPickListItemPickListItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsPickListItemPickListItem instance)