WebApiModulesHomeControlsProjectContactProjectContact class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsProjectContactProjectContact({int? projectContactId, String? projectId, String? contactId, String? nameFml, String? nameLfm, String? person, String? personColor, String? firstName, String? middleInitial, String? lastName, String? contactTitle, String? officePhone, String? officeExtension, String? mobilePhone, String? email, String? pager, String? pagerPin, String? jobTitle, String? contactTitleId, String? companyContactId, String? companyId, bool? isPrimary, String? countryId, bool? isProjectFor, bool? isProductionContact, bool? isPrintable, bool? contactOnProject, bool? inactive, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsProjectContactProjectContact.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- companyContactId → String?
-
final
- companyId → String?
-
final
- contactId → String?
-
final
- contactOnProject → bool?
-
final
- contactTitle → String?
-
final
- contactTitleId → String?
-
final
- countryId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- email → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactive → bool?
-
final
- isPrimary → bool?
-
final
- isPrintable → bool?
-
final
- isProductionContact → bool?
-
final
- isProjectFor → bool?
-
final
- jobTitle → String?
-
final
- lastName → String?
-
final
- middleInitial → String?
-
final
- mobilePhone → String?
-
final
- nameFml → String?
-
final
- nameLfm → String?
-
final
- officeExtension → String?
-
final
- officePhone → String?
-
final
- pager → String?
-
final
- pagerPin → String?
-
final
- person → String?
-
final
- personColor → String?
-
final
- projectContactId → int?
-
final
- projectId → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? projectContactId, String? projectId, String? contactId, String? nameFml, String? nameLfm, String? person, String? personColor, String? firstName, String? middleInitial, String? lastName, String? contactTitle, String? officePhone, String? officeExtension, String? mobilePhone, String? email, String? pager, String? pagerPin, String? jobTitle, String? contactTitleId, String? companyContactId, String? companyId, bool? isPrimary, String? countryId, bool? isProjectFor, bool? isProductionContact, bool? isPrintable, bool? contactOnProject, bool? inactive, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsProjectContactProjectContact -
Available on WebApiModulesHomeControlsProjectContactProjectContact, provided by the $WebApiModulesHomeControlsProjectContactProjectContactExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsProjectContactProjectContact Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsProjectContactProjectContact instance)