WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNote class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNote({String? vendorInvoiceNoteId, String? uniqueId1, String? uniqueId2, String? notes, String? noteDate, String? usersId, String? name, String? noteDescription, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNote.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
name String?
final
noteDate String?
final
noteDescription String?
final
notes String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
uniqueId1 String?
final
uniqueId2 String?
final
urlIdentifier → dynamic
final
usersId String?
final
vendorInvoiceNoteId String?
final

Methods

copyWith({String? vendorInvoiceNoteId, String? uniqueId1, String? uniqueId2, String? notes, String? noteDate, String? usersId, String? name, String? noteDescription, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNote

Available on WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNote, provided by the $WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNoteExtension extension

copyWithWrapped({Wrapped<String?>? vendorInvoiceNoteId, Wrapped<String?>? uniqueId1, Wrapped<String?>? uniqueId2, Wrapped<String?>? notes, Wrapped<String?>? noteDate, Wrapped<String?>? usersId, Wrapped<String?>? name, Wrapped<String?>? noteDescription, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNote

Available on WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNote, provided by the $WebApiModulesHomeControlsVendorInvoiceNoteVendorInvoiceNoteExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override