WebApiModulesHomeOrderApprovalOrderApproval class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeOrderApprovalOrderApproval({int? orderApprovalId, String? orderId, String? webUsersId, String? token, String? expireDate, String? createdDate, String? status, String? contactId, String? contactName, String? contactEmail, String? statusChangeDate, String? notes, String? paymentTermsId, String? paymentTypeId, double? amount, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeOrderApprovalOrderApproval.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
auditNote String?
final
contactEmail String?
final
contactId String?
final
contactName String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDate String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
expireDate String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
notes String?
final
orderApprovalId int?
final
orderId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentTermsId String?
final
paymentTypeId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
statusChangeDate String?
final
token String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
webUsersId String?
final

Methods

copyWith({int? orderApprovalId, String? orderId, String? webUsersId, String? token, String? expireDate, String? createdDate, String? status, String? contactId, String? contactName, String? contactEmail, String? statusChangeDate, String? notes, String? paymentTermsId, String? paymentTypeId, double? amount, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeOrderApprovalOrderApproval

Available on WebApiModulesHomeOrderApprovalOrderApproval, provided by the $WebApiModulesHomeOrderApprovalOrderApprovalExtension extension

copyWithWrapped({Wrapped<int?>? orderApprovalId, Wrapped<String?>? orderId, Wrapped<String?>? webUsersId, Wrapped<String?>? token, Wrapped<String?>? expireDate, Wrapped<String?>? createdDate, Wrapped<String?>? status, Wrapped<String?>? contactId, Wrapped<String?>? contactName, Wrapped<String?>? contactEmail, Wrapped<String?>? statusChangeDate, Wrapped<String?>? notes, Wrapped<String?>? paymentTermsId, Wrapped<String?>? paymentTypeId, Wrapped<double?>? amount, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeOrderApprovalOrderApproval

Available on WebApiModulesHomeOrderApprovalOrderApproval, provided by the $WebApiModulesHomeOrderApprovalOrderApprovalExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesHomeOrderApprovalOrderApproval Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesHomeOrderApprovalOrderApproval instance)