WebApiModulesHomeOrderConfirmationOrderConfirmation class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeOrderConfirmationOrderConfirmation({String? orderConfirmationId, String? orderId, String? webUsersId, String? date, String? time, String? activityType, String? note, String? person, String? payType, String? paymentTerms, String? purchaseOrderNumber, double? amount, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeOrderConfirmationOrderConfirmation.fromJson(Map<String, dynamic> json)
factory

Properties

activityType String?
final
amount double?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
date String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
note String?
final
orderConfirmationId String?
final
orderId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentTerms String?
final
payType String?
final
person String?
final
purchaseOrderNumber String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
webUsersId String?
final

Methods

copyWith({String? orderConfirmationId, String? orderId, String? webUsersId, String? date, String? time, String? activityType, String? note, String? person, String? payType, String? paymentTerms, String? purchaseOrderNumber, double? amount, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeOrderConfirmationOrderConfirmation

Available on WebApiModulesHomeOrderConfirmationOrderConfirmation, provided by the $WebApiModulesHomeOrderConfirmationOrderConfirmationExtension extension

copyWithWrapped({Wrapped<String?>? orderConfirmationId, Wrapped<String?>? orderId, Wrapped<String?>? webUsersId, Wrapped<String?>? date, Wrapped<String?>? time, Wrapped<String?>? activityType, Wrapped<String?>? note, Wrapped<String?>? person, Wrapped<String?>? payType, Wrapped<String?>? paymentTerms, Wrapped<String?>? purchaseOrderNumber, Wrapped<double?>? amount, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeOrderConfirmationOrderConfirmation

Available on WebApiModulesHomeOrderConfirmationOrderConfirmation, provided by the $WebApiModulesHomeOrderConfirmationOrderConfirmationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override