WebApiModulesHomeOrderDayOrderDay class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeOrderDayOrderDay({int? orderDayId, String? orderId, String? orderDate, String? dayName, String? activityHint, String? activityDescription, String? startTime, String? stopTime, double? hours, double? hoursOvertime, double? hoursDoubletime, String? break1StartTime, String? break1StopTime, String? break2StartTime, String? break2StopTime, String? break3StartTime, String? break3StopTime, String? breakTime, String? dailyTotalTime, String? venueId, String? venue, String? venueAddress1, String? venueAddress2, String? venueCity, String? venueState, String? venueCountryId, String? venueCountry, String? venueZipCode, bool? billable, bool? totalTimeEstimated, bool? break1PaId, bool? break2PaId, bool? break3PaId, bool? milestone, String? notes, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeOrderDayOrderDay.fromJson(Map<String, dynamic> json)
factory

Properties

activityDescription String?
final
activityHint String?
final
auditNote String?
final
billable bool?
final
break1PaId bool?
final
break1StartTime String?
final
break1StopTime String?
final
break2PaId bool?
final
break2StartTime String?
final
break2StopTime String?
final
break3PaId bool?
final
break3StartTime String?
final
break3StopTime String?
final
breakTime String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dailyTotalTime String?
final
dayName String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hours double?
final
hoursDoubletime double?
final
hoursOvertime double?
final
milestone bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
notes String?
final
orderDate String?
final
orderDayId int?
final
orderId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
final
stopTime String?
final
totalTimeEstimated bool?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
venue String?
final
venueAddress1 String?
final
venueAddress2 String?
final
venueCity String?
final
venueCountry String?
final
venueCountryId String?
final
venueId String?
final
venueState String?
final
venueZipCode String?
final

Methods

copyWith({int? orderDayId, String? orderId, String? orderDate, String? dayName, String? activityHint, String? activityDescription, String? startTime, String? stopTime, double? hours, double? hoursOvertime, double? hoursDoubletime, String? break1StartTime, String? break1StopTime, String? break2StartTime, String? break2StopTime, String? break3StartTime, String? break3StopTime, String? breakTime, String? dailyTotalTime, String? venueId, String? venue, String? venueAddress1, String? venueAddress2, String? venueCity, String? venueState, String? venueCountryId, String? venueCountry, String? venueZipCode, bool? billable, bool? totalTimeEstimated, bool? break1PaId, bool? break2PaId, bool? break3PaId, bool? milestone, String? notes, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeOrderDayOrderDay

Available on WebApiModulesHomeOrderDayOrderDay, provided by the $WebApiModulesHomeOrderDayOrderDayExtension extension

copyWithWrapped({Wrapped<int?>? orderDayId, Wrapped<String?>? orderId, Wrapped<String?>? orderDate, Wrapped<String?>? dayName, Wrapped<String?>? activityHint, Wrapped<String?>? activityDescription, Wrapped<String?>? startTime, Wrapped<String?>? stopTime, Wrapped<double?>? hours, Wrapped<double?>? hoursOvertime, Wrapped<double?>? hoursDoubletime, Wrapped<String?>? break1StartTime, Wrapped<String?>? break1StopTime, Wrapped<String?>? break2StartTime, Wrapped<String?>? break2StopTime, Wrapped<String?>? break3StartTime, Wrapped<String?>? break3StopTime, Wrapped<String?>? breakTime, Wrapped<String?>? dailyTotalTime, Wrapped<String?>? venueId, Wrapped<String?>? venue, Wrapped<String?>? venueAddress1, Wrapped<String?>? venueAddress2, Wrapped<String?>? venueCity, Wrapped<String?>? venueState, Wrapped<String?>? venueCountryId, Wrapped<String?>? venueCountry, Wrapped<String?>? venueZipCode, Wrapped<bool?>? billable, Wrapped<bool?>? totalTimeEstimated, Wrapped<bool?>? break1PaId, Wrapped<bool?>? break2PaId, Wrapped<bool?>? break3PaId, Wrapped<bool?>? milestone, Wrapped<String?>? notes, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeOrderDayOrderDay

Available on WebApiModulesHomeOrderDayOrderDay, provided by the $WebApiModulesHomeOrderDayOrderDayExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesHomeOrderDayOrderDay Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesHomeOrderDayOrderDay instance)