WebApiModulesHomeServiceOrderItemServiceOrderItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeServiceOrderItemServiceOrderItem({String? serviceOrderItemId, String? repairId, String? repairNumber, String? barCode, String? serialNumber, String? repairICode, String? trackedBy, String? repairDescription, double? quantity, double? rate, double? extended, String? repairInventoryId, String? warehouseId, String? warehouseCode, String? warehouse, String? repairCostId, String? repairPartId, String? itemOrder, String? notes, String? recType, String? recTypeDisplay, String? consignorId, String? consignorAgreementId, String? inventoryId, String? iCode, String? description, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeServiceOrderItemServiceOrderItem.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
barCode String?
final
consignorAgreementId String?
final
consignorId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
extended double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inventoryId String?
final
itemOrder String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
notes String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quantity double?
final
rate double?
final
recordTitle String?
final
recType String?
final
recTypeDisplay String?
final
repairCostId String?
final
repairDescription String?
final
repairICode String?
final
repairId String?
final
repairInventoryId String?
final
repairNumber String?
final
repairPartId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
serviceOrderItemId String?
final
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? serviceOrderItemId, String? repairId, String? repairNumber, String? barCode, String? serialNumber, String? repairICode, String? trackedBy, String? repairDescription, double? quantity, double? rate, double? extended, String? repairInventoryId, String? warehouseId, String? warehouseCode, String? warehouse, String? repairCostId, String? repairPartId, String? itemOrder, String? notes, String? recType, String? recTypeDisplay, String? consignorId, String? consignorAgreementId, String? inventoryId, String? iCode, String? description, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeServiceOrderItemServiceOrderItem

Available on WebApiModulesHomeServiceOrderItemServiceOrderItem, provided by the $WebApiModulesHomeServiceOrderItemServiceOrderItemExtension extension

copyWithWrapped({Wrapped<String?>? serviceOrderItemId, Wrapped<String?>? repairId, Wrapped<String?>? repairNumber, Wrapped<String?>? barCode, Wrapped<String?>? serialNumber, Wrapped<String?>? repairICode, Wrapped<String?>? trackedBy, Wrapped<String?>? repairDescription, Wrapped<double?>? quantity, Wrapped<double?>? rate, Wrapped<double?>? extended, Wrapped<String?>? repairInventoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouseCode, Wrapped<String?>? warehouse, Wrapped<String?>? repairCostId, Wrapped<String?>? repairPartId, Wrapped<String?>? itemOrder, Wrapped<String?>? notes, Wrapped<String?>? recType, Wrapped<String?>? recTypeDisplay, Wrapped<String?>? consignorId, Wrapped<String?>? consignorAgreementId, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeServiceOrderItemServiceOrderItem

Available on WebApiModulesHomeServiceOrderItemServiceOrderItem, provided by the $WebApiModulesHomeServiceOrderItemServiceOrderItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override