WebApiModulesHomeSuspendedSessionSuspendedSession class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeSuspendedSessionSuspendedSession({String? contractId, int? sessionNumber, String? deal, String? dealNumber, String? dealOrVendor, String? orderNumber, String? orderDescription, String? orderId, String? userName, String? userNameFirstMiddleLast, String? status, String? statusDate, String? usersId, String? contractDate, String? contractTime, String? dealId, String? departmentId, String? department, String? officeLocationId, String? warehouseId, String? warehouse, String? exchangeContractId, String? contractType, bool? isForcedSuspend, String? containerItemId, String? containerScannableItemId, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeSuspendedSessionSuspendedSession.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
containerItemId String?
final
containerScannableItemId String?
final
contractDate String?
final
contractId String?
final
contractTime String?
final
contractType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
deal String?
final
dealId String?
final
dealNumber String?
final
dealOrVendor String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
department String?
final
departmentId String?
final
exchangeContractId String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
isForcedSuspend bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officeLocationId String?
final
orderDescription String?
final
orderId String?
final
orderNumber String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionNumber int?
final
status String?
final
statusDate String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userName String?
final
userNameFirstMiddleLast String?
final
usersId String?
final
warehouse String?
final
warehouseId String?
final

Methods

copyWith({String? contractId, int? sessionNumber, String? deal, String? dealNumber, String? dealOrVendor, String? orderNumber, String? orderDescription, String? orderId, String? userName, String? userNameFirstMiddleLast, String? status, String? statusDate, String? usersId, String? contractDate, String? contractTime, String? dealId, String? departmentId, String? department, String? officeLocationId, String? warehouseId, String? warehouse, String? exchangeContractId, String? contractType, bool? isForcedSuspend, String? containerItemId, String? containerScannableItemId, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeSuspendedSessionSuspendedSession

Available on WebApiModulesHomeSuspendedSessionSuspendedSession, provided by the $WebApiModulesHomeSuspendedSessionSuspendedSessionExtension extension

copyWithWrapped({Wrapped<String?>? contractId, Wrapped<int?>? sessionNumber, Wrapped<String?>? deal, Wrapped<String?>? dealNumber, Wrapped<String?>? dealOrVendor, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDescription, Wrapped<String?>? orderId, Wrapped<String?>? userName, Wrapped<String?>? userNameFirstMiddleLast, Wrapped<String?>? status, Wrapped<String?>? statusDate, Wrapped<String?>? usersId, Wrapped<String?>? contractDate, Wrapped<String?>? contractTime, Wrapped<String?>? dealId, Wrapped<String?>? departmentId, Wrapped<String?>? department, Wrapped<String?>? officeLocationId, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? exchangeContractId, Wrapped<String?>? contractType, Wrapped<bool?>? isForcedSuspend, Wrapped<String?>? containerItemId, Wrapped<String?>? containerScannableItemId, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeSuspendedSessionSuspendedSession

Available on WebApiModulesHomeSuspendedSessionSuspendedSession, provided by the $WebApiModulesHomeSuspendedSessionSuspendedSessionExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override