WebApiModulesInventoryAssetCertificationAssetCertification class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryAssetCertificationAssetCertification({int? assetCertificationId, String? inventoryCertificationId, String? inventoryCertification, String? rentalItemId, String? certificationDate, String? expirationDate, String? usersId, String? userName, String? json, String? html, String? barCode, String? serialNumber, String? rfId, String? inventoryId, String? iCode, String? description, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryAssetCertificationAssetCertification.fromJson(Map<String, dynamic> json)
factory

Properties

assetCertificationId int?
final
auditNote String?
final
barCode String?
final
certificationDate String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
expirationDate String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
html String?
final
iCode String?
final
inventoryCertification String?
final
inventoryCertificationId String?
final
inventoryId String?
final
json String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
rentalItemId String?
final
rfId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userName String?
final
usersId String?
final

Methods

copyWith({int? assetCertificationId, String? inventoryCertificationId, String? inventoryCertification, String? rentalItemId, String? certificationDate, String? expirationDate, String? usersId, String? userName, String? json, String? html, String? barCode, String? serialNumber, String? rfId, String? inventoryId, String? iCode, String? description, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryAssetCertificationAssetCertification

Available on WebApiModulesInventoryAssetCertificationAssetCertification, provided by the $WebApiModulesInventoryAssetCertificationAssetCertificationExtension extension

copyWithWrapped({Wrapped<int?>? assetCertificationId, Wrapped<String?>? inventoryCertificationId, Wrapped<String?>? inventoryCertification, Wrapped<String?>? rentalItemId, Wrapped<String?>? certificationDate, Wrapped<String?>? expirationDate, Wrapped<String?>? usersId, Wrapped<String?>? userName, Wrapped<String?>? json, Wrapped<String?>? html, Wrapped<String?>? barCode, Wrapped<String?>? serialNumber, Wrapped<String?>? rfId, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryAssetCertificationAssetCertification

Available on WebApiModulesInventoryAssetCertificationAssetCertification, provided by the $WebApiModulesInventoryAssetCertificationAssetCertificationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override