WebApiModulesInventoryContainerItemCancelFillContainerRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
itemId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String?
final

Methods

copyWith({String? itemId, String? warehouseId}) WebApiModulesInventoryContainerItemCancelFillContainerRequest

Available on WebApiModulesInventoryContainerItemCancelFillContainerRequest, provided by the $WebApiModulesInventoryContainerItemCancelFillContainerRequestExtension extension

copyWithWrapped({Wrapped<String?>? itemId, Wrapped<String?>? warehouseId}) WebApiModulesInventoryContainerItemCancelFillContainerRequest

Available on WebApiModulesInventoryContainerItemCancelFillContainerRequest, provided by the $WebApiModulesInventoryContainerItemCancelFillContainerRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override