WebApiModulesInventoryContainerItemEmptyContainerRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryContainerItemEmptyContainerRequest({String? itemId, String? warehouseId, bool? deleteAll, bool? voidTheFill})
const
WebApiModulesInventoryContainerItemEmptyContainerRequest.fromJson(Map<String, dynamic> json)
factory

Properties

deleteAll bool?
final
hashCode int
The hash code for this object.
no setteroverride
itemId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voidTheFill bool?
final
warehouseId String?
final

Methods

copyWith({String? itemId, String? warehouseId, bool? deleteAll, bool? voidTheFill}) WebApiModulesInventoryContainerItemEmptyContainerRequest

Available on WebApiModulesInventoryContainerItemEmptyContainerRequest, provided by the $WebApiModulesInventoryContainerItemEmptyContainerRequestExtension extension

copyWithWrapped({Wrapped<String?>? itemId, Wrapped<String?>? warehouseId, Wrapped<bool?>? deleteAll, Wrapped<bool?>? voidTheFill}) WebApiModulesInventoryContainerItemEmptyContainerRequest

Available on WebApiModulesInventoryContainerItemEmptyContainerRequest, provided by the $WebApiModulesInventoryContainerItemEmptyContainerRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override