WebApiModulesInventoryContainerItemRemoveFromContainerRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryContainerItemRemoveFromContainerRequest({String? containerItemId, String? itemId, String? inventoryId, String? warehouseId, String? consignorId, String? consignorAgreementId, double? quantity})
const
WebApiModulesInventoryContainerItemRemoveFromContainerRequest.fromJson(Map<String, dynamic> json)
factory

Properties

consignorAgreementId String?
final
consignorId String?
final
containerItemId String?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
itemId String?
final
quantity double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String?
final

Methods

copyWith({String? containerItemId, String? itemId, String? inventoryId, String? warehouseId, String? consignorId, String? consignorAgreementId, double? quantity}) WebApiModulesInventoryContainerItemRemoveFromContainerRequest

Available on WebApiModulesInventoryContainerItemRemoveFromContainerRequest, provided by the $WebApiModulesInventoryContainerItemRemoveFromContainerRequestExtension extension

copyWithWrapped({Wrapped<String?>? containerItemId, Wrapped<String?>? itemId, Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? consignorId, Wrapped<String?>? consignorAgreementId, Wrapped<double?>? quantity}) WebApiModulesInventoryContainerItemRemoveFromContainerRequest

Available on WebApiModulesInventoryContainerItemRemoveFromContainerRequest, provided by the $WebApiModulesInventoryContainerItemRemoveFromContainerRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override