WebApiModulesInventoryInventoryContainerItemInventoryContainerItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventoryContainerItemInventoryContainerItem({String? containerItemId, String? packageId, String? containerId, int? rowNumber, String? iCode, String? description, String? trackedBy, double? quantityOrdered, double? price, String? notes, String? inventoryId, String? recType, String? itemClass, int? ident, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryInventoryContainerItemInventoryContainerItem.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
containerId String?
final
containerItemId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
ident int?
final
inventoryId String?
final
itemClass String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
notes String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
packageId String?
final
price double?
final
quantityOrdered double?
final
recordTitle String?
final
recType String?
final
rowNumber int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? containerItemId, String? packageId, String? containerId, int? rowNumber, String? iCode, String? description, String? trackedBy, double? quantityOrdered, double? price, String? notes, String? inventoryId, String? recType, String? itemClass, int? ident, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryInventoryContainerItemInventoryContainerItem

Available on WebApiModulesInventoryInventoryContainerItemInventoryContainerItem, provided by the $WebApiModulesInventoryInventoryContainerItemInventoryContainerItemExtension extension

copyWithWrapped({Wrapped<String?>? containerItemId, Wrapped<String?>? packageId, Wrapped<String?>? containerId, Wrapped<int?>? rowNumber, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? trackedBy, Wrapped<double?>? quantityOrdered, Wrapped<double?>? price, Wrapped<String?>? notes, Wrapped<String?>? inventoryId, Wrapped<String?>? recType, Wrapped<String?>? itemClass, Wrapped<int?>? ident, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryInventoryContainerItemInventoryContainerItem

Available on WebApiModulesInventoryInventoryContainerItemInventoryContainerItem, provided by the $WebApiModulesInventoryInventoryContainerItemInventoryContainerItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override