WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventory({bool? deletingWarehouseSpecific, String? inventoryPackageInventoryId, String? packageId, String? packageICode, String? inventoryId, String? iCode, String? iCodeColor, String? lineColor, String? description, bool? isPrimary, double? defaultQuantity, bool? isOption, bool? charge, bool? noChargePrint, bool? isRequired, String? optionColor, String? itemClass, String? itemTrackedBy, String? availFor, String? availFrom, double? categoryOrderBy, int? orderBy, int? itemColor, bool? isNestedComplete, bool? inactive, String? warehouseId, String? parentId, String? packageItemClass, bool? itemNonDiscountable, String? primaryInventoryId, String? unitId, double? dailyRate, double? weeklyRate, double? monthlyRate, double? dailyExtended, double? weeklyExtended, double? monthlyExtended, double? price, double? retail, String? currencyId, String? currencyCode, String? currencySymbol, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, String? pricingWarehouseId, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventory.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
availFor String?
final
availFrom String?
final
categoryOrderBy double?
final
charge bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dailyExtended double?
final
dailyRate double?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultQuantity double?
final
deletingWarehouseSpecific bool?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
iCodeColor String?
final
inactive bool?
final
inventoryId String?
final
inventoryPackageInventoryId String?
final
isNestedComplete bool?
final
isOption bool?
final
isPrimary bool?
final
isRequired bool?
final
itemClass String?
final
itemColor int?
final
itemNonDiscountable bool?
final
itemTrackedBy String?
final
lineColor String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
monthlyExtended double?
final
monthlyRate double?
final
noChargePrint bool?
final
optionColor String?
final
orderBy int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
packageICode String?
final
packageId String?
final
packageItemClass String?
final
parentId String?
final
price double?
final
pricingWarehouseId String?
final
primaryInventoryId String?
final
recordTitle String?
final
retail double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
unitId String?
final
urlIdentifier → dynamic
final
warehouseId String?
final
weeklyExtended double?
final
weeklyRate double?
final

Methods

copyWith({bool? deletingWarehouseSpecific, String? inventoryPackageInventoryId, String? packageId, String? packageICode, String? inventoryId, String? iCode, String? iCodeColor, String? lineColor, String? description, bool? isPrimary, double? defaultQuantity, bool? isOption, bool? charge, bool? noChargePrint, bool? isRequired, String? optionColor, String? itemClass, String? itemTrackedBy, String? availFor, String? availFrom, double? categoryOrderBy, int? orderBy, int? itemColor, bool? isNestedComplete, bool? inactive, String? warehouseId, String? parentId, String? packageItemClass, bool? itemNonDiscountable, String? primaryInventoryId, String? unitId, double? dailyRate, double? weeklyRate, double? monthlyRate, double? dailyExtended, double? weeklyExtended, double? monthlyExtended, double? price, double? retail, String? currencyId, String? currencyCode, String? currencySymbol, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, String? pricingWarehouseId, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventory

Available on WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventory, provided by the $WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventoryExtension extension

copyWithWrapped({Wrapped<bool?>? deletingWarehouseSpecific, Wrapped<String?>? inventoryPackageInventoryId, Wrapped<String?>? packageId, Wrapped<String?>? packageICode, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? iCodeColor, Wrapped<String?>? lineColor, Wrapped<String?>? description, Wrapped<bool?>? isPrimary, Wrapped<double?>? defaultQuantity, Wrapped<bool?>? isOption, Wrapped<bool?>? charge, Wrapped<bool?>? noChargePrint, Wrapped<bool?>? isRequired, Wrapped<String?>? optionColor, Wrapped<String?>? itemClass, Wrapped<String?>? itemTrackedBy, Wrapped<String?>? availFor, Wrapped<String?>? availFrom, Wrapped<double?>? categoryOrderBy, Wrapped<int?>? orderBy, Wrapped<int?>? itemColor, Wrapped<bool?>? isNestedComplete, Wrapped<bool?>? inactive, Wrapped<String?>? warehouseId, Wrapped<String?>? parentId, Wrapped<String?>? packageItemClass, Wrapped<bool?>? itemNonDiscountable, Wrapped<String?>? primaryInventoryId, Wrapped<String?>? unitId, Wrapped<double?>? dailyRate, Wrapped<double?>? weeklyRate, Wrapped<double?>? monthlyRate, Wrapped<double?>? dailyExtended, Wrapped<double?>? weeklyExtended, Wrapped<double?>? monthlyExtended, Wrapped<double?>? price, Wrapped<double?>? retail, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<String?>? pricingWarehouseId, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventory

Available on WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventory, provided by the $WebApiModulesInventoryInventoryPackageInventoryInventoryPackageInventoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override