WebApiModulesInventoryInventoryReceiptInventoryReceipt class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventoryReceiptInventoryReceipt({String? inventoryReceiptId, String? receiptNumber, String? receiptDate, String? receiptType, String? warehouseId, String? warehouse, String? originalShow, String? originalShowId, String? buyerId, String? buyer, String? vendorId, String? vendor, String? taxId, String? taxOption, double? taxOptionPercent, double? shippingCost, double? miscCost, double? discountPercent, double? discountAmount, double? taxRate, double? taxAmount, String? status, String? note, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryInventoryReceiptInventoryReceipt.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
buyer String?
final
buyerId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
discountAmount double?
final
discountPercent double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inventoryReceiptId String?
final
miscCost double?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
note String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
originalShow String?
final
originalShowId String?
final
receiptDate String?
final
receiptNumber String?
final
receiptType String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingCost double?
final
status String?
final
taxAmount double?
final
taxId String?
final
taxOption String?
final
taxOptionPercent double?
final
taxRate double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
vendor String?
final
vendorId String?
final
warehouse String?
final
warehouseId String?
final

Methods

copyWith({String? inventoryReceiptId, String? receiptNumber, String? receiptDate, String? receiptType, String? warehouseId, String? warehouse, String? originalShow, String? originalShowId, String? buyerId, String? buyer, String? vendorId, String? vendor, String? taxId, String? taxOption, double? taxOptionPercent, double? shippingCost, double? miscCost, double? discountPercent, double? discountAmount, double? taxRate, double? taxAmount, String? status, String? note, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryInventoryReceiptInventoryReceipt

Available on WebApiModulesInventoryInventoryReceiptInventoryReceipt, provided by the $WebApiModulesInventoryInventoryReceiptInventoryReceiptExtension extension

copyWithWrapped({Wrapped<String?>? inventoryReceiptId, Wrapped<String?>? receiptNumber, Wrapped<String?>? receiptDate, Wrapped<String?>? receiptType, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? originalShow, Wrapped<String?>? originalShowId, Wrapped<String?>? buyerId, Wrapped<String?>? buyer, Wrapped<String?>? vendorId, Wrapped<String?>? vendor, Wrapped<String?>? taxId, Wrapped<String?>? taxOption, Wrapped<double?>? taxOptionPercent, Wrapped<double?>? shippingCost, Wrapped<double?>? miscCost, Wrapped<double?>? discountPercent, Wrapped<double?>? discountAmount, Wrapped<double?>? taxRate, Wrapped<double?>? taxAmount, Wrapped<String?>? status, Wrapped<String?>? note, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryInventoryReceiptInventoryReceipt

Available on WebApiModulesInventoryInventoryReceiptInventoryReceipt, provided by the $WebApiModulesInventoryInventoryReceiptInventoryReceiptExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override