WebApiModulesInventoryInventoryReceiptInventoryReceiptItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventoryReceiptInventoryReceiptItem({String? inventoryReceiptItemId, String? inventoryReceiptId, String? inventoryId, String? iCode, String? description, int? quantity, double? cost, String? trackedBy, double? discountPercent, double? discountAmount, bool? taxable, double? taxRate, bool? assigned, int? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryInventoryReceiptInventoryReceiptItem.fromJson(Map<String, dynamic> json)
factory

Properties

assigned bool?
final
auditNote String?
final
cost double?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
discountAmount double?
final
discountPercent double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inventoryId String?
final
inventoryReceiptId String?
final
inventoryReceiptItemId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderBy int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quantity int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxable bool?
final
taxRate double?
final
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? inventoryReceiptItemId, String? inventoryReceiptId, String? inventoryId, String? iCode, String? description, int? quantity, double? cost, String? trackedBy, double? discountPercent, double? discountAmount, bool? taxable, double? taxRate, bool? assigned, int? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryInventoryReceiptInventoryReceiptItem

Available on WebApiModulesInventoryInventoryReceiptInventoryReceiptItem, provided by the $WebApiModulesInventoryInventoryReceiptInventoryReceiptItemExtension extension

copyWithWrapped({Wrapped<String?>? inventoryReceiptItemId, Wrapped<String?>? inventoryReceiptId, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<int?>? quantity, Wrapped<double?>? cost, Wrapped<String?>? trackedBy, Wrapped<double?>? discountPercent, Wrapped<double?>? discountAmount, Wrapped<bool?>? taxable, Wrapped<double?>? taxRate, Wrapped<bool?>? assigned, Wrapped<int?>? orderBy, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryInventoryReceiptInventoryReceiptItem

Available on WebApiModulesInventoryInventoryReceiptInventoryReceiptItem, provided by the $WebApiModulesInventoryInventoryReceiptInventoryReceiptItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override