WebApiModulesInventoryInventoryReceiptItemDetailsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventoryReceiptItemDetailsResponse({String? previousItemId, String? nextItemId, bool? assignBarcodes, bool? addItems, bool? print, String? inventoryId, String? iCode, String? description, String? trackedBy, int? quantity, String? inventoryTypeId, String? inventoryType, String? originalShowId, String? originalShow, String? categoryId, String? category, int? subCategoryCount, String? subCategoryId, String? subCategory, double? dailyRate, double? weeklyRate, double? monthlyRate, String? aisle, String? shelf, double? replacementCost, double? unitValue, String? warehouseId, String? conditionId, String? condition, String? patternId, String? pattern, String? periodId, String? period, String? genderId, String? gender, double? cleaningFee, String? labelId, String? label, String? size, bool? dyed, int? pieceCount, String? careId, String? care, String? sourceId, String? source, bool? assigned, String? detailedDescription, int? addToInventoryQuantity, WebApiModulesInventoryInventoryReceiptItemBarcodeEnableResponse? barcodeData})
const
WebApiModulesInventoryInventoryReceiptItemDetailsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

addItems bool?
final
addToInventoryQuantity int?
final
aisle String?
final
assignBarcodes bool?
final
assigned bool?
final
barcodeData WebApiModulesInventoryInventoryReceiptItemBarcodeEnableResponse?
final
care String?
final
careId String?
final
category String?
final
categoryId String?
final
cleaningFee double?
final
condition String?
final
conditionId String?
final
dailyRate double?
final
description String?
final
detailedDescription String?
final
dyed bool?
final
gender String?
final
genderId String?
final
hashCode int
The hash code for this object.
no setteroverride
iCode String?
final
inventoryId String?
final
inventoryType String?
final
inventoryTypeId String?
final
label String?
final
labelId String?
final
monthlyRate double?
final
nextItemId String?
final
originalShow String?
final
originalShowId String?
final
pattern String?
final
patternId String?
final
period String?
final
periodId String?
final
pieceCount int?
final
previousItemId String?
final
print bool?
final
quantity int?
final
replacementCost double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelf String?
final
size String?
final
source String?
final
sourceId String?
final
subCategory String?
final
subCategoryCount int?
final
subCategoryId String?
final
trackedBy String?
final
unitValue double?
final
warehouseId String?
final
weeklyRate double?
final

Methods

copyWith({String? previousItemId, String? nextItemId, bool? assignBarcodes, bool? addItems, bool? print, String? inventoryId, String? iCode, String? description, String? trackedBy, int? quantity, String? inventoryTypeId, String? inventoryType, String? originalShowId, String? originalShow, String? categoryId, String? category, int? subCategoryCount, String? subCategoryId, String? subCategory, double? dailyRate, double? weeklyRate, double? monthlyRate, String? aisle, String? shelf, double? replacementCost, double? unitValue, String? warehouseId, String? conditionId, String? condition, String? patternId, String? pattern, String? periodId, String? period, String? genderId, String? gender, double? cleaningFee, String? labelId, String? label, String? size, bool? dyed, int? pieceCount, String? careId, String? care, String? sourceId, String? source, bool? assigned, String? detailedDescription, int? addToInventoryQuantity, WebApiModulesInventoryInventoryReceiptItemBarcodeEnableResponse? barcodeData}) WebApiModulesInventoryInventoryReceiptItemDetailsResponse

Available on WebApiModulesInventoryInventoryReceiptItemDetailsResponse, provided by the $WebApiModulesInventoryInventoryReceiptItemDetailsResponseExtension extension

copyWithWrapped({Wrapped<String?>? previousItemId, Wrapped<String?>? nextItemId, Wrapped<bool?>? assignBarcodes, Wrapped<bool?>? addItems, Wrapped<bool?>? print, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? trackedBy, Wrapped<int?>? quantity, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? inventoryType, Wrapped<String?>? originalShowId, Wrapped<String?>? originalShow, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<int?>? subCategoryCount, Wrapped<String?>? subCategoryId, Wrapped<String?>? subCategory, Wrapped<double?>? dailyRate, Wrapped<double?>? weeklyRate, Wrapped<double?>? monthlyRate, Wrapped<String?>? aisle, Wrapped<String?>? shelf, Wrapped<double?>? replacementCost, Wrapped<double?>? unitValue, Wrapped<String?>? warehouseId, Wrapped<String?>? conditionId, Wrapped<String?>? condition, Wrapped<String?>? patternId, Wrapped<String?>? pattern, Wrapped<String?>? periodId, Wrapped<String?>? period, Wrapped<String?>? genderId, Wrapped<String?>? gender, Wrapped<double?>? cleaningFee, Wrapped<String?>? labelId, Wrapped<String?>? label, Wrapped<String?>? size, Wrapped<bool?>? dyed, Wrapped<int?>? pieceCount, Wrapped<String?>? careId, Wrapped<String?>? care, Wrapped<String?>? sourceId, Wrapped<String?>? source, Wrapped<bool?>? assigned, Wrapped<String?>? detailedDescription, Wrapped<int?>? addToInventoryQuantity, Wrapped<WebApiModulesInventoryInventoryReceiptItemBarcodeEnableResponse?>? barcodeData}) WebApiModulesInventoryInventoryReceiptItemDetailsResponse

Available on WebApiModulesInventoryInventoryReceiptItemDetailsResponse, provided by the $WebApiModulesInventoryInventoryReceiptItemDetailsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override