WebApiModulesInventoryInventoryReceiptUnassignItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventoryReceiptUnassignItem({String? inventoryReceiptId, String? inventoryReceiptItemId, String? description, int? quantity})
const
WebApiModulesInventoryInventoryReceiptUnassignItem.fromJson(Map<String, dynamic> json)
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryReceiptId String?
final
inventoryReceiptItemId String?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inventoryReceiptId, String? inventoryReceiptItemId, String? description, int? quantity}) WebApiModulesInventoryInventoryReceiptUnassignItem

Available on WebApiModulesInventoryInventoryReceiptUnassignItem, provided by the $WebApiModulesInventoryInventoryReceiptUnassignItemExtension extension

copyWithWrapped({Wrapped<String?>? inventoryReceiptId, Wrapped<String?>? inventoryReceiptItemId, Wrapped<String?>? description, Wrapped<int?>? quantity}) WebApiModulesInventoryInventoryReceiptUnassignItem

Available on WebApiModulesInventoryInventoryReceiptUnassignItem, provided by the $WebApiModulesInventoryInventoryReceiptUnassignItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override