WebApiModulesInventoryInventoryReceiptUnassignItemsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesInventoryInventoryReceiptUnassignItemsResponse({List<
WebApiModulesInventoryInventoryReceiptUnassignItemResponse> ? items, bool? success}) -
const
-
WebApiModulesInventoryInventoryReceiptUnassignItemsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
WebApiModulesInventoryInventoryReceiptUnassignItemResponse> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool?
-
final
Methods
-
copyWith(
{List< WebApiModulesInventoryInventoryReceiptUnassignItemResponse> ? items, bool? success}) → WebApiModulesInventoryInventoryReceiptUnassignItemsResponse -
Available on WebApiModulesInventoryInventoryReceiptUnassignItemsResponse, provided by the $WebApiModulesInventoryInventoryReceiptUnassignItemsResponseExtension extension
-
copyWithWrapped(
{Wrapped< List< ? items, Wrapped<WebApiModulesInventoryInventoryReceiptUnassignItemResponse> ?>bool?> ? success}) → WebApiModulesInventoryInventoryReceiptUnassignItemsResponse -
Available on WebApiModulesInventoryInventoryReceiptUnassignItemsResponse, provided by the $WebApiModulesInventoryInventoryReceiptUnassignItemsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryInventoryReceiptUnassignItemsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryInventoryReceiptUnassignItemsResponse instance)