WebApiModulesInventoryInventorySearchInventorySearch class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventorySearchInventorySearch({String? sessionId, String? inventoryId, String? warehouseId, int? id, String? lineage, String? packageItemId, double? quantity, DateTime? fromDate, DateTime? toDate, double? quantityAvailable, DateTime? conflictDate, String? availabilityState, double? quantityAvailableRegion, DateTime? conflictDateRegion, String? availabilityStateRegion, double? quantityAvailableAllWarehouses, DateTime? conflictDateAllWarehouses, String? availabilityStateAllWarehouses, bool? printableNote, String? noteId, double? totalQuantityInSession, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryInventorySearchInventorySearch.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
availabilityState String?
final
availabilityStateAllWarehouses String?
final
availabilityStateRegion String?
final
conflictDate DateTime?
final
conflictDateAllWarehouses DateTime?
final
conflictDateRegion DateTime?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fromDate DateTime?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
id int?
final
inventoryId String?
final
lineage String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
noteId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
packageItemId String?
final
printableNote bool?
final
quantity double?
final
quantityAvailable double?
final
quantityAvailableAllWarehouses double?
final
quantityAvailableRegion double?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
toDate DateTime?
final
totalQuantityInSession double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouseId String?
final

Methods

copyWith({String? sessionId, String? inventoryId, String? warehouseId, int? id, String? lineage, String? packageItemId, double? quantity, DateTime? fromDate, DateTime? toDate, double? quantityAvailable, DateTime? conflictDate, String? availabilityState, double? quantityAvailableRegion, DateTime? conflictDateRegion, String? availabilityStateRegion, double? quantityAvailableAllWarehouses, DateTime? conflictDateAllWarehouses, String? availabilityStateAllWarehouses, bool? printableNote, String? noteId, double? totalQuantityInSession, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryInventorySearchInventorySearch

Available on WebApiModulesInventoryInventorySearchInventorySearch, provided by the $WebApiModulesInventoryInventorySearchInventorySearchExtension extension

copyWithWrapped({Wrapped<String?>? sessionId, Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<int?>? id, Wrapped<String?>? lineage, Wrapped<String?>? packageItemId, Wrapped<double?>? quantity, Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<double?>? quantityAvailable, Wrapped<DateTime?>? conflictDate, Wrapped<String?>? availabilityState, Wrapped<double?>? quantityAvailableRegion, Wrapped<DateTime?>? conflictDateRegion, Wrapped<String?>? availabilityStateRegion, Wrapped<double?>? quantityAvailableAllWarehouses, Wrapped<DateTime?>? conflictDateAllWarehouses, Wrapped<String?>? availabilityStateAllWarehouses, Wrapped<bool?>? printableNote, Wrapped<String?>? noteId, Wrapped<double?>? totalQuantityInSession, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryInventorySearchInventorySearch

Available on WebApiModulesInventoryInventorySearchInventorySearch, provided by the $WebApiModulesInventoryInventorySearchInventorySearchExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override