WebApiModulesInventoryInventorySearchInventorySearchResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesInventoryInventorySearchInventorySearchResponse({FwStandardSqlServerFwJsonDataTable? data, int? recordsHidden})
-
const
-
WebApiModulesInventoryInventorySearchInventorySearchResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data → FwStandardSqlServerFwJsonDataTable?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- recordsHidden → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{FwStandardSqlServerFwJsonDataTable? data, int? recordsHidden}) → WebApiModulesInventoryInventorySearchInventorySearchResponse -
Available on WebApiModulesInventoryInventorySearchInventorySearchResponse, provided by the $WebApiModulesInventoryInventorySearchInventorySearchResponseExtension extension
-
copyWithWrapped(
{Wrapped< FwStandardSqlServerFwJsonDataTable?> ? data, Wrapped<int?> ? recordsHidden}) → WebApiModulesInventoryInventorySearchInventorySearchResponse -
Available on WebApiModulesInventoryInventorySearchInventorySearchResponse, provided by the $WebApiModulesInventoryInventorySearchInventorySearchResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryInventorySearchInventorySearchResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryInventorySearchInventorySearchResponse instance)