WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequest({String? sessionId, String? quikSearchId, String? note, String? warehouseId, String? inventoryId, int? quantity, bool? printableNote})
const
WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
note String?
final
printableNote bool?
final
quantity int?
final
quikSearchId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
warehouseId String?
final

Methods

copyWith({String? sessionId, String? quikSearchId, String? note, String? warehouseId, String? inventoryId, int? quantity, bool? printableNote}) WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequest

Available on WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequest, provided by the $WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequestExtension extension

copyWithWrapped({Wrapped<String?>? sessionId, Wrapped<String?>? quikSearchId, Wrapped<String?>? note, Wrapped<String?>? warehouseId, Wrapped<String?>? inventoryId, Wrapped<int?>? quantity, Wrapped<bool?>? printableNote}) WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequest

Available on WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequest, provided by the $WebApiModulesInventoryInventorySearchInventorySearchSaveNoteRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override