WebApiModulesInventoryInventorySearchPreviewInventorySearchPreview class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventorySearchPreviewInventorySearchPreview({int? id, String? sessionId, String? parentId, String? grandParentId, String? inventoryId, String? warehouseId, double? quantity, bool? printableNote, String? note, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryInventorySearchPreviewInventorySearchPreview.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
grandParentId String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
id int?
final
inventoryId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
note String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
parentId String?
final
printableNote bool?
final
quantity double?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouseId String?
final

Methods

copyWith({int? id, String? sessionId, String? parentId, String? grandParentId, String? inventoryId, String? warehouseId, double? quantity, bool? printableNote, String? note, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryInventorySearchPreviewInventorySearchPreview

Available on WebApiModulesInventoryInventorySearchPreviewInventorySearchPreview, provided by the $WebApiModulesInventoryInventorySearchPreviewInventorySearchPreviewExtension extension

copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? sessionId, Wrapped<String?>? parentId, Wrapped<String?>? grandParentId, Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<double?>? quantity, Wrapped<bool?>? printableNote, Wrapped<String?>? note, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryInventorySearchPreviewInventorySearchPreview

Available on WebApiModulesInventoryInventorySearchPreviewInventorySearchPreview, provided by the $WebApiModulesInventoryInventorySearchPreviewInventorySearchPreviewExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override