WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory({int? id, String? physicalInventoryId, String? inventoryId, String? iCode, String? description, String? availableFor, String? availableForDisplay, double? quantityOwned, String? trackedBy, double? unitCost, bool? isRecount, String? aisleLocation, String? shelfLocation, int? isNegativeInventory, double? quantityAdded, double? quantityRetired, double? lastPurchaseUnitCost, double? newUnitCost, String? currentSpaceId, String? consignorId, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory.fromJson(Map<String, dynamic> json)
factory

Properties

aisleLocation String?
final
auditNote String?
final
availableFor String?
final
availableForDisplay String?
final
consignorId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currentSpaceId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
id int?
final
inventoryId String?
final
isNegativeInventory int?
final
isRecount bool?
final
lastPurchaseUnitCost double?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
newUnitCost double?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
physicalInventoryId String?
final
quantityAdded double?
final
quantityOwned double?
final
quantityRetired double?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelfLocation String?
final
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
unitCost double?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? id, String? physicalInventoryId, String? inventoryId, String? iCode, String? description, String? availableFor, String? availableForDisplay, double? quantityOwned, String? trackedBy, double? unitCost, bool? isRecount, String? aisleLocation, String? shelfLocation, int? isNegativeInventory, double? quantityAdded, double? quantityRetired, double? lastPurchaseUnitCost, double? newUnitCost, String? currentSpaceId, String? consignorId, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory

Available on WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory, provided by the $WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryExtension extension

copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? physicalInventoryId, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? availableFor, Wrapped<String?>? availableForDisplay, Wrapped<double?>? quantityOwned, Wrapped<String?>? trackedBy, Wrapped<double?>? unitCost, Wrapped<bool?>? isRecount, Wrapped<String?>? aisleLocation, Wrapped<String?>? shelfLocation, Wrapped<int?>? isNegativeInventory, Wrapped<double?>? quantityAdded, Wrapped<double?>? quantityRetired, Wrapped<double?>? lastPurchaseUnitCost, Wrapped<double?>? newUnitCost, Wrapped<String?>? currentSpaceId, Wrapped<String?>? consignorId, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory

Available on WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventory, provided by the $WebApiModulesInventoryPhysicalInventoryInventoryPhysicalInventoryInventoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override