WebApiModulesInventoryPhysicalInventoryPhysicalInventory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryPhysicalInventoryPhysicalInventory({String? physicalInventoryId, String? officeLocationId, String? officeLocation, String? officeLocationCode, String? dealId, String? scheduleDate, String? preScanDateTime, String? initiateDateTime, String? physicalInventoryNumber, String? description, String? countType, String? warehouseId, String? warehouseCode, String? warehouse, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? recType, String? recTypeDisplay, int? stepPreScan, bool? allowStepPreScan, int? stepInitiate, bool? allowStepInitiate, int? stepPrintCountSheets, bool? allowStepPrintCountSheets, bool? allowStepPrintPrescanProgress, int? stepCount, bool? allowStepCount, int? stepPrintExceptionReport, bool? allowStepPrintExceptionReport, int? stepPrintDiscrepancyReport, bool? allowStepPrintDiscrepancyReport, int? stepRecount, bool? allowStepRecount, int? stepPrintRecountAnalysisReport, bool? allowStepPrintRecountAnalysisReport, int? stepPrintReconciliationReport, bool? allowStepPrintReconciliationReport, int? stepItemsAdded, bool? allowStepItemsAdded, int? stepApproveCounts, bool? allowStepApproveCounts, int? stepClose, bool? allowStepClose, int? stepCloseWithoutAdjustments, bool? allowStepCloseWithoutAdjustments, bool? closedWithAdjustments, bool? closedWithOutAdjustments, bool? allowStepPrintResults, String? status, String? cycleLastCounted, String? cycleTrackedBy, String? cycleAisle, String? cycleShelf, bool? cycleOnlyIncludeInventoryWithNonZeroQuantity, bool? approvedPurchaseCost, bool? countInventoryThatIsOut, bool? facilitiesInventory, bool? presInitializeAutomaticallyCountInventoryThatIsOut, bool? cycleIncludeOwned, bool? cycleIncludeConsigned, bool? hideConsigned, bool? selectitemsbyNotUsed, bool? excludeInventoryWithNoAvailabilityCheck, String? approvedByUserId, String? approvedByUser, String? approveDate, String? approveTime, String? inputByUserId, String? inputDate, String? inputTime, bool? inactive, bool? replaceCounts, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryPhysicalInventoryPhysicalInventory.fromJson(Map<String, dynamic> json)
factory

Properties

allowStepApproveCounts bool?
final
allowStepClose bool?
final
allowStepCloseWithoutAdjustments bool?
final
allowStepCount bool?
final
allowStepInitiate bool?
final
allowStepItemsAdded bool?
final
allowStepPreScan bool?
final
allowStepPrintCountSheets bool?
final
allowStepPrintDiscrepancyReport bool?
final
allowStepPrintExceptionReport bool?
final
allowStepPrintPrescanProgress bool?
final
allowStepPrintReconciliationReport bool?
final
allowStepPrintRecountAnalysisReport bool?
final
allowStepPrintResults bool?
final
allowStepRecount bool?
final
approveDate String?
final
approvedByUser String?
final
approvedByUserId String?
final
approvedPurchaseCost bool?
final
approveTime String?
final
auditNote String?
final
category String?
final
categoryId String?
final
closedWithAdjustments bool?
final
closedWithOutAdjustments bool?
final
countInventoryThatIsOut bool?
final
countType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
cycleAisle String?
final
cycleIncludeConsigned bool?
final
cycleIncludeOwned bool?
final
cycleLastCounted String?
final
cycleOnlyIncludeInventoryWithNonZeroQuantity bool?
final
cycleShelf String?
final
cycleTrackedBy String?
final
dateStamp String?
final
dealId String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
excludeInventoryWithNoAvailabilityCheck bool?
final
facilitiesInventory bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hideConsigned bool?
final
inactive bool?
final
initiateDateTime String?
final
inputByUserId String?
final
inputDate String?
final
inputTime String?
final
inventoryType String?
final
inventoryTypeId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officeLocation String?
final
officeLocationCode String?
final
officeLocationId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
physicalInventoryId String?
final
physicalInventoryNumber String?
final
preScanDateTime String?
final
presInitializeAutomaticallyCountInventoryThatIsOut bool?
final
recordTitle String?
final
recType String?
final
recTypeDisplay String?
final
replaceCounts bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleDate String?
final
selectitemsbyNotUsed bool?
final
status String?
final
stepApproveCounts int?
final
stepClose int?
final
stepCloseWithoutAdjustments int?
final
stepCount int?
final
stepInitiate int?
final
stepItemsAdded int?
final
stepPreScan int?
final
stepPrintCountSheets int?
final
stepPrintDiscrepancyReport int?
final
stepPrintExceptionReport int?
final
stepPrintReconciliationReport int?
final
stepPrintRecountAnalysisReport int?
final
stepRecount int?
final
subCategory String?
final
subCategoryId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? physicalInventoryId, String? officeLocationId, String? officeLocation, String? officeLocationCode, String? dealId, String? scheduleDate, String? preScanDateTime, String? initiateDateTime, String? physicalInventoryNumber, String? description, String? countType, String? warehouseId, String? warehouseCode, String? warehouse, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? recType, String? recTypeDisplay, int? stepPreScan, bool? allowStepPreScan, int? stepInitiate, bool? allowStepInitiate, int? stepPrintCountSheets, bool? allowStepPrintCountSheets, bool? allowStepPrintPrescanProgress, int? stepCount, bool? allowStepCount, int? stepPrintExceptionReport, bool? allowStepPrintExceptionReport, int? stepPrintDiscrepancyReport, bool? allowStepPrintDiscrepancyReport, int? stepRecount, bool? allowStepRecount, int? stepPrintRecountAnalysisReport, bool? allowStepPrintRecountAnalysisReport, int? stepPrintReconciliationReport, bool? allowStepPrintReconciliationReport, int? stepItemsAdded, bool? allowStepItemsAdded, int? stepApproveCounts, bool? allowStepApproveCounts, int? stepClose, bool? allowStepClose, int? stepCloseWithoutAdjustments, bool? allowStepCloseWithoutAdjustments, bool? closedWithAdjustments, bool? closedWithOutAdjustments, bool? allowStepPrintResults, String? status, String? cycleLastCounted, String? cycleTrackedBy, String? cycleAisle, String? cycleShelf, bool? cycleOnlyIncludeInventoryWithNonZeroQuantity, bool? approvedPurchaseCost, bool? countInventoryThatIsOut, bool? facilitiesInventory, bool? presInitializeAutomaticallyCountInventoryThatIsOut, bool? cycleIncludeOwned, bool? cycleIncludeConsigned, bool? hideConsigned, bool? selectitemsbyNotUsed, bool? excludeInventoryWithNoAvailabilityCheck, String? approvedByUserId, String? approvedByUser, String? approveDate, String? approveTime, String? inputByUserId, String? inputDate, String? inputTime, bool? inactive, bool? replaceCounts, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryPhysicalInventory

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventory, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExtension extension

copyWithWrapped({Wrapped<String?>? physicalInventoryId, Wrapped<String?>? officeLocationId, Wrapped<String?>? officeLocation, Wrapped<String?>? officeLocationCode, Wrapped<String?>? dealId, Wrapped<String?>? scheduleDate, Wrapped<String?>? preScanDateTime, Wrapped<String?>? initiateDateTime, Wrapped<String?>? physicalInventoryNumber, Wrapped<String?>? description, Wrapped<String?>? countType, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouseCode, Wrapped<String?>? warehouse, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? inventoryType, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<String?>? subCategoryId, Wrapped<String?>? subCategory, Wrapped<String?>? recType, Wrapped<String?>? recTypeDisplay, Wrapped<int?>? stepPreScan, Wrapped<bool?>? allowStepPreScan, Wrapped<int?>? stepInitiate, Wrapped<bool?>? allowStepInitiate, Wrapped<int?>? stepPrintCountSheets, Wrapped<bool?>? allowStepPrintCountSheets, Wrapped<bool?>? allowStepPrintPrescanProgress, Wrapped<int?>? stepCount, Wrapped<bool?>? allowStepCount, Wrapped<int?>? stepPrintExceptionReport, Wrapped<bool?>? allowStepPrintExceptionReport, Wrapped<int?>? stepPrintDiscrepancyReport, Wrapped<bool?>? allowStepPrintDiscrepancyReport, Wrapped<int?>? stepRecount, Wrapped<bool?>? allowStepRecount, Wrapped<int?>? stepPrintRecountAnalysisReport, Wrapped<bool?>? allowStepPrintRecountAnalysisReport, Wrapped<int?>? stepPrintReconciliationReport, Wrapped<bool?>? allowStepPrintReconciliationReport, Wrapped<int?>? stepItemsAdded, Wrapped<bool?>? allowStepItemsAdded, Wrapped<int?>? stepApproveCounts, Wrapped<bool?>? allowStepApproveCounts, Wrapped<int?>? stepClose, Wrapped<bool?>? allowStepClose, Wrapped<int?>? stepCloseWithoutAdjustments, Wrapped<bool?>? allowStepCloseWithoutAdjustments, Wrapped<bool?>? closedWithAdjustments, Wrapped<bool?>? closedWithOutAdjustments, Wrapped<bool?>? allowStepPrintResults, Wrapped<String?>? status, Wrapped<String?>? cycleLastCounted, Wrapped<String?>? cycleTrackedBy, Wrapped<String?>? cycleAisle, Wrapped<String?>? cycleShelf, Wrapped<bool?>? cycleOnlyIncludeInventoryWithNonZeroQuantity, Wrapped<bool?>? approvedPurchaseCost, Wrapped<bool?>? countInventoryThatIsOut, Wrapped<bool?>? facilitiesInventory, Wrapped<bool?>? presInitializeAutomaticallyCountInventoryThatIsOut, Wrapped<bool?>? cycleIncludeOwned, Wrapped<bool?>? cycleIncludeConsigned, Wrapped<bool?>? hideConsigned, Wrapped<bool?>? selectitemsbyNotUsed, Wrapped<bool?>? excludeInventoryWithNoAvailabilityCheck, Wrapped<String?>? approvedByUserId, Wrapped<String?>? approvedByUser, Wrapped<String?>? approveDate, Wrapped<String?>? approveTime, Wrapped<String?>? inputByUserId, Wrapped<String?>? inputDate, Wrapped<String?>? inputTime, Wrapped<bool?>? inactive, Wrapped<bool?>? replaceCounts, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryPhysicalInventory

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventory, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override