WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountItemRequest({String? physicalInventoryId, String? code, double? quantity, bool? replace, String? consignorId, String? countedSpaceId})
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

code String?
final
consignorId String?
final
countedSpaceId String?
final
hashCode int
The hash code for this object.
no setteroverride
physicalInventoryId String?
final
quantity double?
final
replace bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? physicalInventoryId, String? code, double? quantity, bool? replace, String? consignorId, String? countedSpaceId}) WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountItemRequest

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountItemRequest, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override