WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAdded class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAdded({String? physicalInventoryId, String? inventoryId, String? iCode, String? description, int? orderBy, int? owned, int? counted, int? qty, double? extended, double? newPurchaseCost, double? lastPurchaseCost, String? purchaseCurrencyCode, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAdded.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
counted int?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
extended double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inventoryId String?
final
lastPurchaseCost double?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
newPurchaseCost double?
final
orderBy int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
owned int?
final
physicalInventoryId String?
final
purchaseCurrencyCode String?
final
qty int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? physicalInventoryId, String? inventoryId, String? iCode, String? description, int? orderBy, int? owned, int? counted, int? qty, double? extended, double? newPurchaseCost, double? lastPurchaseCost, String? purchaseCurrencyCode, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAdded

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAdded, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAddedExtension extension

copyWithWrapped({Wrapped<String?>? physicalInventoryId, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<int?>? orderBy, Wrapped<int?>? owned, Wrapped<int?>? counted, Wrapped<int?>? qty, Wrapped<double?>? extended, Wrapped<double?>? newPurchaseCost, Wrapped<double?>? lastPurchaseCost, Wrapped<String?>? purchaseCurrencyCode, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAdded

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAdded, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryItemsAddedExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override