WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecount class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecount({int? physicalMasterId, String? physicalInventoryId, String? inventoryId, String? iCode, String? description, String? categoryId, String? category, double? categoryOrderBy, String? inventoryTypeId, String? inventoryType, int? inventoryTypeOrderBy, String? currentSpaceId, String? unitId, String? unit, String? aisleLocation, String? shelfLocation, bool? isRecount, int? owned, int? onOrder, int? inRepair, int? counted, int? variance, String? consignorId, String? consignor, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecount.fromJson(Map<String, dynamic> json)
factory

Properties

aisleLocation String?
final
auditNote String?
final
category String?
final
categoryId String?
final
categoryOrderBy double?
final
consignor String?
final
consignorId String?
final
counted int?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currentSpaceId String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inRepair int?
final
inventoryId String?
final
inventoryType String?
final
inventoryTypeId String?
final
inventoryTypeOrderBy int?
final
isRecount bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
onOrder int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
owned int?
final
physicalInventoryId String?
final
physicalMasterId int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelfLocation String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
unit String?
final
unitId String?
final
urlIdentifier → dynamic
final
variance int?
final

Methods

copyWith({int? physicalMasterId, String? physicalInventoryId, String? inventoryId, String? iCode, String? description, String? categoryId, String? category, double? categoryOrderBy, String? inventoryTypeId, String? inventoryType, int? inventoryTypeOrderBy, String? currentSpaceId, String? unitId, String? unit, String? aisleLocation, String? shelfLocation, bool? isRecount, int? owned, int? onOrder, int? inRepair, int? counted, int? variance, String? consignorId, String? consignor, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecount

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecount, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecountExtension extension

copyWithWrapped({Wrapped<int?>? physicalMasterId, Wrapped<String?>? physicalInventoryId, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<double?>? categoryOrderBy, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? inventoryType, Wrapped<int?>? inventoryTypeOrderBy, Wrapped<String?>? currentSpaceId, Wrapped<String?>? unitId, Wrapped<String?>? unit, Wrapped<String?>? aisleLocation, Wrapped<String?>? shelfLocation, Wrapped<bool?>? isRecount, Wrapped<int?>? owned, Wrapped<int?>? onOrder, Wrapped<int?>? inRepair, Wrapped<int?>? counted, Wrapped<int?>? variance, Wrapped<String?>? consignorId, Wrapped<String?>? consignor, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecount

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecount, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryRecountExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override