WebApiModulesInventoryRentalInventoryRentalInventoryWalls class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryRentalInventoryRentalInventoryWalls({String? setId, String? inventoryId, String? barcode, String? iCode, String? description, int? quantity, String? trackedBy, bool? inactive, String? aisle, String? shelf, int? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryRentalInventoryRentalInventoryWalls.fromJson(Map<String, dynamic> json)
factory

Properties

aisle String?
final
auditNote String?
final
barcode String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inactive bool?
final
inventoryId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderBy int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quantity int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setId String?
final
shelf String?
final
trackedBy String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? setId, String? inventoryId, String? barcode, String? iCode, String? description, int? quantity, String? trackedBy, bool? inactive, String? aisle, String? shelf, int? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryRentalInventoryRentalInventoryWalls

Available on WebApiModulesInventoryRentalInventoryRentalInventoryWalls, provided by the $WebApiModulesInventoryRentalInventoryRentalInventoryWallsExtension extension

copyWithWrapped({Wrapped<String?>? setId, Wrapped<String?>? inventoryId, Wrapped<String?>? barcode, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<int?>? quantity, Wrapped<String?>? trackedBy, Wrapped<bool?>? inactive, Wrapped<String?>? aisle, Wrapped<String?>? shelf, Wrapped<int?>? orderBy, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryRentalInventoryRentalInventoryWalls

Available on WebApiModulesInventoryRentalInventoryRentalInventoryWalls, provided by the $WebApiModulesInventoryRentalInventoryRentalInventoryWallsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override