WebApiModulesInventoryRepairCostRepairCost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryRepairCostRepairCost({String? repairCostId, String? repairId, String? rateId, String? iCode, String? description, double? quantity, String? unit, double? rate, double? grossTotal, double? discountAmount, double? extended, bool? taxable, double? tax, double? total, bool? billable, String? note, String? currencySymbol, String? orderId, String? orderItemId, String? orderNumber, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryRepairCostRepairCost.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
billable bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
discountAmount double?
final
extended double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
grossTotal double?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
note String?
final
orderId String?
final
orderItemId String?
final
orderNumber String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quantity double?
final
rate double?
final
rateId String?
final
recordTitle String?
final
repairCostId String?
final
repairId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tax double?
final
taxable bool?
final
total double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
unit String?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? repairCostId, String? repairId, String? rateId, String? iCode, String? description, double? quantity, String? unit, double? rate, double? grossTotal, double? discountAmount, double? extended, bool? taxable, double? tax, double? total, bool? billable, String? note, String? currencySymbol, String? orderId, String? orderItemId, String? orderNumber, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryRepairCostRepairCost

Available on WebApiModulesInventoryRepairCostRepairCost, provided by the $WebApiModulesInventoryRepairCostRepairCostExtension extension

copyWithWrapped({Wrapped<String?>? repairCostId, Wrapped<String?>? repairId, Wrapped<String?>? rateId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<double?>? quantity, Wrapped<String?>? unit, Wrapped<double?>? rate, Wrapped<double?>? grossTotal, Wrapped<double?>? discountAmount, Wrapped<double?>? extended, Wrapped<bool?>? taxable, Wrapped<double?>? tax, Wrapped<double?>? total, Wrapped<bool?>? billable, Wrapped<String?>? note, Wrapped<String?>? currencySymbol, Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<String?>? orderNumber, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryRepairCostRepairCost

Available on WebApiModulesInventoryRepairCostRepairCost, provided by the $WebApiModulesInventoryRepairCostRepairCostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesInventoryRepairCostRepairCost Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesInventoryRepairCostRepairCost instance)