WebApiModulesInventoryRepairKissFlowUpdateRepairOrderPoRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
purchaseOrderNumber String?
final
repairNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? repairNumber, String? purchaseOrderNumber}) WebApiModulesInventoryRepairKissFlowUpdateRepairOrderPoRequest

Available on WebApiModulesInventoryRepairKissFlowUpdateRepairOrderPoRequest, provided by the $WebApiModulesInventoryRepairKissFlowUpdateRepairOrderPoRequestExtension extension

copyWithWrapped({Wrapped<String?>? repairNumber, Wrapped<String?>? purchaseOrderNumber}) WebApiModulesInventoryRepairKissFlowUpdateRepairOrderPoRequest

Available on WebApiModulesInventoryRepairKissFlowUpdateRepairOrderPoRequest, provided by the $WebApiModulesInventoryRepairKissFlowUpdateRepairOrderPoRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override