WebApiModulesInventoryRepairPartRepairPart class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryRepairPartRepairPart({String? repairPartId, String? repairId, String? inventoryId, String? warehouseId, String? warehouseCode, String? warehouse, String? iCode, String? iCodeColor, String? description, String? descriptionColor, double? quantity, String? unit, double? price, double? grossTotal, double? discountAmount, double? extended, bool? taxable, double? tax, double? total, bool? billable, String? itemClass, String? itemOrder, String? currencySymbol, String? orderId, String? orderItemId, String? orderNumber, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryRepairPartRepairPart.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
billable bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
descriptionColor String?
final
discountAmount double?
final
extended double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
grossTotal double?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
iCodeColor String?
final
inventoryId String?
final
itemClass String?
final
itemOrder String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderId String?
final
orderItemId String?
final
orderNumber String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
price double?
final
quantity double?
final
recordTitle String?
final
repairId String?
final
repairPartId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tax double?
final
taxable bool?
final
total double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
unit String?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? repairPartId, String? repairId, String? inventoryId, String? warehouseId, String? warehouseCode, String? warehouse, String? iCode, String? iCodeColor, String? description, String? descriptionColor, double? quantity, String? unit, double? price, double? grossTotal, double? discountAmount, double? extended, bool? taxable, double? tax, double? total, bool? billable, String? itemClass, String? itemOrder, String? currencySymbol, String? orderId, String? orderItemId, String? orderNumber, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryRepairPartRepairPart

Available on WebApiModulesInventoryRepairPartRepairPart, provided by the $WebApiModulesInventoryRepairPartRepairPartExtension extension

copyWithWrapped({Wrapped<String?>? repairPartId, Wrapped<String?>? repairId, Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouseCode, Wrapped<String?>? warehouse, Wrapped<String?>? iCode, Wrapped<String?>? iCodeColor, Wrapped<String?>? description, Wrapped<String?>? descriptionColor, Wrapped<double?>? quantity, Wrapped<String?>? unit, Wrapped<double?>? price, Wrapped<double?>? grossTotal, Wrapped<double?>? discountAmount, Wrapped<double?>? extended, Wrapped<bool?>? taxable, Wrapped<double?>? tax, Wrapped<double?>? total, Wrapped<bool?>? billable, Wrapped<String?>? itemClass, Wrapped<String?>? itemOrder, Wrapped<String?>? currencySymbol, Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<String?>? orderNumber, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryRepairPartRepairPart

Available on WebApiModulesInventoryRepairPartRepairPart, provided by the $WebApiModulesInventoryRepairPartRepairPartExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesInventoryRepairPartRepairPart Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesInventoryRepairPartRepairPart instance)