WebApiModulesInventoryRetiredRetired class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesInventoryRetiredRetired({String? retiredId, String? inventoryId, String? iCode, String? description, String? barCode, String? itemId, String? serialNumber, String? warehouseId, String? warehouseCode, String? warehouse, String? consignorId, String? consignor, String? consignorAgreementId, String? agreementNumber, String? retiredDate, String? retiredReason, String? retiredReasonType, String? retiredBy, String? retiredReasonId, String? retiredByUserId, String? retiredNotes, double? retiredQuantity, double? unretiredQuantity, String? lostOrderId, String? lostOrderNumber, String? lostName, String? lostAddress1, String? lostAddress2, String? lostCity, String? lostState, String? lostZipCode, String? lostPhone, String? lostCountryId, String? lostCountry, String? soldToOrderDescription, String? soldToOrderReferenceNumber, String? soldToOrderId, String? soldToOrderItemId, String? soldToOrderNumber, String? soldDate, double? soldAmount, String? soldToName, String? soldToAddress1, String? soldToAddress2, String? soldToCity, String? soldToState, String? soldToZipCode, String? soldToPhone, String? soldToCountryId, String? soldToCountry, String? soldCurrencyId, String? soldCurrency, String? soldCurrencyCode, String? soldCurrencySymbol, String? inventoryTypeId, String? replacementInventoryId, String? replacementItemId, String? replacementItemICode, String? replacementItemDescription, String? replacementItemBarCode, String? replacementItemSerialNumber, bool? changeICode, String? donatedOrderId, String? donatedOrderNumber, String? donatedDate, String? donatedToName, String? donatedToAddress1, String? donatedToAddress2, String? donatedToCity, String? donatedToState, String? donatedToZipCode, String? donatedToPhone, String? donatedToCountryId, String? donatedToCountry, String? donatedCurrencyId, String? donatedCurrency, String? donatedCurrencyCode, String? donatedCurrencySymbol, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesInventoryRetiredRetired.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agreementNumber → String?
-
final
- auditNote → String?
-
final
- barCode → String?
-
final
- changeICode → bool?
-
final
- consignor → String?
-
final
- consignorAgreementId → String?
-
final
- consignorId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
- donatedCurrency → String?
-
final
- donatedCurrencyCode → String?
-
final
- donatedCurrencyId → String?
-
final
- donatedCurrencySymbol → String?
-
final
- donatedDate → String?
-
final
- donatedOrderId → String?
-
final
- donatedOrderNumber → String?
-
final
- donatedToAddress1 → String?
-
final
- donatedToAddress2 → String?
-
final
- donatedToCity → String?
-
final
- donatedToCountry → String?
-
final
- donatedToCountryId → String?
-
final
- donatedToName → String?
-
final
- donatedToPhone → String?
-
final
- donatedToState → String?
-
final
- donatedToZipCode → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- inventoryId → String?
-
final
- inventoryTypeId → String?
-
final
- itemId → String?
-
final
- lostAddress1 → String?
-
final
- lostAddress2 → String?
-
final
- lostCity → String?
-
final
- lostCountry → String?
-
final
- lostCountryId → String?
-
final
- lostName → String?
-
final
- lostOrderId → String?
-
final
- lostOrderNumber → String?
-
final
- lostPhone → String?
-
final
- lostState → String?
-
final
- lostZipCode → String?
-
final
- recordTitle → String?
-
final
- replacementInventoryId → String?
-
final
- replacementItemBarCode → String?
-
final
- replacementItemDescription → String?
-
final
- replacementItemICode → String?
-
final
- replacementItemId → String?
-
final
- replacementItemSerialNumber → String?
-
final
- retiredBy → String?
-
final
- retiredByUserId → String?
-
final
- retiredDate → String?
-
final
- retiredId → String?
-
final
- retiredNotes → String?
-
final
- retiredQuantity → double?
-
final
- retiredReason → String?
-
final
- retiredReasonId → String?
-
final
- retiredReasonType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber → String?
-
final
- soldAmount → double?
-
final
- soldCurrency → String?
-
final
- soldCurrencyCode → String?
-
final
- soldCurrencyId → String?
-
final
- soldCurrencySymbol → String?
-
final
- soldDate → String?
-
final
- soldToAddress1 → String?
-
final
- soldToAddress2 → String?
-
final
- soldToCity → String?
-
final
- soldToCountry → String?
-
final
- soldToCountryId → String?
-
final
- soldToName → String?
-
final
- soldToOrderDescription → String?
-
final
- soldToOrderId → String?
-
final
- soldToOrderItemId → String?
-
final
- soldToOrderNumber → String?
-
final
- soldToOrderReferenceNumber → String?
-
final
- soldToPhone → String?
-
final
- soldToState → String?
-
final
- soldToZipCode → String?
-
final
- unretiredQuantity → double?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? retiredId, String? inventoryId, String? iCode, String? description, String? barCode, String? itemId, String? serialNumber, String? warehouseId, String? warehouseCode, String? warehouse, String? consignorId, String? consignor, String? consignorAgreementId, String? agreementNumber, String? retiredDate, String? retiredReason, String? retiredReasonType, String? retiredBy, String? retiredReasonId, String? retiredByUserId, String? retiredNotes, double? retiredQuantity, double? unretiredQuantity, String? lostOrderId, String? lostOrderNumber, String? lostName, String? lostAddress1, String? lostAddress2, String? lostCity, String? lostState, String? lostZipCode, String? lostPhone, String? lostCountryId, String? lostCountry, String? soldToOrderDescription, String? soldToOrderReferenceNumber, String? soldToOrderId, String? soldToOrderItemId, String? soldToOrderNumber, String? soldDate, double? soldAmount, String? soldToName, String? soldToAddress1, String? soldToAddress2, String? soldToCity, String? soldToState, String? soldToZipCode, String? soldToPhone, String? soldToCountryId, String? soldToCountry, String? soldCurrencyId, String? soldCurrency, String? soldCurrencyCode, String? soldCurrencySymbol, String? inventoryTypeId, String? replacementInventoryId, String? replacementItemId, String? replacementItemICode, String? replacementItemDescription, String? replacementItemBarCode, String? replacementItemSerialNumber, bool? changeICode, String? donatedOrderId, String? donatedOrderNumber, String? donatedDate, String? donatedToName, String? donatedToAddress1, String? donatedToAddress2, String? donatedToCity, String? donatedToState, String? donatedToZipCode, String? donatedToPhone, String? donatedToCountryId, String? donatedToCountry, String? donatedCurrencyId, String? donatedCurrency, String? donatedCurrencyCode, String? donatedCurrencySymbol, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesInventoryRetiredRetired -
Available on WebApiModulesInventoryRetiredRetired, provided by the $WebApiModulesInventoryRetiredRetiredExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryRetiredRetired Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryRetiredRetired instance)