WebApiModulesInventorySetImageHistorySetImageHistoryItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventorySetImageHistorySetImageHistoryItem({String? inventoryId, bool? copying, String? documentId, String? documentTypeId, String? uniqueId1, String? uniqueId2, int? uniqueId1Int, String? description, String? inputByUsersId, String? attachDate, String? attachTime, bool? attachToEmail, bool? inactive, String? dateStamp, String? extension, String? fileExtension, String? documentType, String? inputBy, bool? hasImage, bool? hasFile, int? imageDocumentCount, bool? fileIsModified, String? fileDataUrl, String? filePath, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventorySetImageHistorySetImageHistoryItem.fromJson(Map<String, dynamic> json)
factory

Properties

attachDate String?
final
attachTime String?
final
attachToEmail bool?
final
auditNote String?
final
copying bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
documentId String?
final
documentType String?
final
documentTypeId String?
final
extension String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fileDataUrl String?
final
fileExtension String?
final
fileIsModified bool?
final
filePath String?
final
hasDocuments bool?
final
hasFile bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImage bool?
final
hasImport bool?
final
imageDocumentCount int?
final
inactive bool?
final
inputBy String?
final
inputByUsersId String?
final
inventoryId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
uniqueId1 String?
final
uniqueId1Int int?
final
uniqueId2 String?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? inventoryId, bool? copying, String? documentId, String? documentTypeId, String? uniqueId1, String? uniqueId2, int? uniqueId1Int, String? description, String? inputByUsersId, String? attachDate, String? attachTime, bool? attachToEmail, bool? inactive, String? dateStamp, String? extension, String? fileExtension, String? documentType, String? inputBy, bool? hasImage, bool? hasFile, int? imageDocumentCount, bool? fileIsModified, String? fileDataUrl, String? filePath, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventorySetImageHistorySetImageHistoryItem

Available on WebApiModulesInventorySetImageHistorySetImageHistoryItem, provided by the $WebApiModulesInventorySetImageHistorySetImageHistoryItemExtension extension

copyWithWrapped({Wrapped<String?>? inventoryId, Wrapped<bool?>? copying, Wrapped<String?>? documentId, Wrapped<String?>? documentTypeId, Wrapped<String?>? uniqueId1, Wrapped<String?>? uniqueId2, Wrapped<int?>? uniqueId1Int, Wrapped<String?>? description, Wrapped<String?>? inputByUsersId, Wrapped<String?>? attachDate, Wrapped<String?>? attachTime, Wrapped<bool?>? attachToEmail, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? extension, Wrapped<String?>? fileExtension, Wrapped<String?>? documentType, Wrapped<String?>? inputBy, Wrapped<bool?>? hasImage, Wrapped<bool?>? hasFile, Wrapped<int?>? imageDocumentCount, Wrapped<bool?>? fileIsModified, Wrapped<String?>? fileDataUrl, Wrapped<String?>? filePath, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventorySetImageHistorySetImageHistoryItem

Available on WebApiModulesInventorySetImageHistorySetImageHistoryItem, provided by the $WebApiModulesInventorySetImageHistorySetImageHistoryItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override