WebApiModulesInventorySetQcSetQcItemResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventorySetQcSetQcItemResponse({int? status, bool? success, String? msg, List<String>? itemIds, List<String>? descriptions, List<String>? iCodes, List<bool>? setQcReqds, List<String>? inventoryIds, int? successCount, int? failCount})
const
WebApiModulesInventorySetQcSetQcItemResponse.fromJson(Map<String, dynamic> json)
factory

Properties

descriptions List<String>?
final
failCount int?
final
hashCode int
The hash code for this object.
no setteroverride
iCodes List<String>?
final
inventoryIds List<String>?
final
itemIds List<String>?
final
msg String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setQcReqds List<bool>?
final
status int?
final
success bool?
final
successCount int?
final

Methods

copyWith({int? status, bool? success, String? msg, List<String>? itemIds, List<String>? descriptions, List<String>? iCodes, List<bool>? setQcReqds, List<String>? inventoryIds, int? successCount, int? failCount}) WebApiModulesInventorySetQcSetQcItemResponse

Available on WebApiModulesInventorySetQcSetQcItemResponse, provided by the $WebApiModulesInventorySetQcSetQcItemResponseExtension extension

copyWithWrapped({Wrapped<int?>? status, Wrapped<bool?>? success, Wrapped<String?>? msg, Wrapped<List<String>?>? itemIds, Wrapped<List<String>?>? descriptions, Wrapped<List<String>?>? iCodes, Wrapped<List<bool>?>? setQcReqds, Wrapped<List<String>?>? inventoryIds, Wrapped<int?>? successCount, Wrapped<int?>? failCount}) WebApiModulesInventorySetQcSetQcItemResponse

Available on WebApiModulesInventorySetQcSetQcItemResponse, provided by the $WebApiModulesInventorySetQcSetQcItemResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesInventorySetQcSetQcItemResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesInventorySetQcSetQcItemResponse instance)