WebApiModulesPluginsTeamupTeamupRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsTeamupTeamupRequest({String? goToUrl, String? orderId})
const
WebApiModulesPluginsTeamupTeamupRequest.fromJson(Map<String, dynamic> json)
factory

Properties

goToUrl String?
final
hashCode int
The hash code for this object.
no setteroverride
orderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? goToUrl, String? orderId}) WebApiModulesPluginsTeamupTeamupRequest

Available on WebApiModulesPluginsTeamupTeamupRequest, provided by the $WebApiModulesPluginsTeamupTeamupRequestExtension extension

copyWithWrapped({Wrapped<String?>? goToUrl, Wrapped<String?>? orderId}) WebApiModulesPluginsTeamupTeamupRequest

Available on WebApiModulesPluginsTeamupTeamupRequest, provided by the $WebApiModulesPluginsTeamupTeamupRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesPluginsTeamupTeamupRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesPluginsTeamupTeamupRequest instance)