WebApiModulesUtilitiesGLDistributionGLDistribution class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesGLDistributionGLDistribution({String? date, String? glAccountNo, String? glAccountDescription, double? debit, double? credit, String? glAccountId, String? groupHeading, int? orderBy, int? groupHeadingOrder, String? currencyId, String? currencyCode, String? currency, String? currencySymbol, String? officeLocationId, String? officeLocation, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesGLDistributionGLDistribution.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
credit double?
final
currency String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
date String?
final
debit double?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
glAccountDescription String?
final
glAccountId String?
final
glAccountNo String?
final
groupHeading String?
final
groupHeadingOrder int?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officeLocation String?
final
officeLocationId String?
final
orderBy int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? date, String? glAccountNo, String? glAccountDescription, double? debit, double? credit, String? glAccountId, String? groupHeading, int? orderBy, int? groupHeadingOrder, String? currencyId, String? currencyCode, String? currency, String? currencySymbol, String? officeLocationId, String? officeLocation, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesGLDistributionGLDistribution

Available on WebApiModulesUtilitiesGLDistributionGLDistribution, provided by the $WebApiModulesUtilitiesGLDistributionGLDistributionExtension extension

copyWithWrapped({Wrapped<String?>? date, Wrapped<String?>? glAccountNo, Wrapped<String?>? glAccountDescription, Wrapped<double?>? debit, Wrapped<double?>? credit, Wrapped<String?>? glAccountId, Wrapped<String?>? groupHeading, Wrapped<int?>? orderBy, Wrapped<int?>? groupHeadingOrder, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currency, Wrapped<String?>? currencySymbol, Wrapped<String?>? officeLocationId, Wrapped<String?>? officeLocation, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesGLDistributionGLDistribution

Available on WebApiModulesUtilitiesGLDistributionGLDistribution, provided by the $WebApiModulesUtilitiesGLDistributionGLDistributionExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override