WebApiModulesWarehouseCheckInCheckInItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesWarehouseCheckInCheckInItem({bool? addOrderToContract, String? aisle, String? availFromDateTime, String? availToDateTime, String? barcode, String? consignorId, String? consignorAgreementId, bool? canSwap, String? containerNo, String? contractType, String? dealId, String? departmentId, String? description, bool? doSwap, String? exchangeContractId, int? errorNumber, String? errorMessage, String? facilitiesTypeId, String? hasMultipleContainers, String? itemClass, String? inventoryId, bool? isBarcode, bool? isContainer, bool? itemInContainer, String? internalChar, String? location, String? moduleType, String? masterId, String? message, String? iCode, bool? newOrder, String? nestedMasteritemId, bool? newContainerInstantiated, int? orderTranId, String? outOrderId, String? orderNo, String? orderId, String? orderItemId, String? orderBy, String? packageId, String? parentId, String? pendingRepairId, String? pendingOrderId, String? pendingMasterItemId, String? pONo, bool? pending, String? pOId, bool? qcRequired, int? quantity, String? quikinContractId, int? quikinItemId, String? quikinInternalChar, String? quantityOrdered, String? rentalItemId, String? inQuantity, String? scannableMasterId, String? shelf, String? spaceId, String? spaceTypeId, String? spaceLocation, String? stillOut, int? status, String? statusType, bool? swapItem, String? subQuantity, String? totalIn, String? tranType, String? trackedBy, bool? useContainerNo, bool? unretireSalesItem, String? vendorId, String? vendor, String? warehouseId, String? wHCode})
-
WebApiModulesWarehouseCheckInCheckInItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- addOrderToContract → bool?
-
final
- aisle → String?
-
final
- availFromDateTime → String?
-
final
- availToDateTime → String?
-
final
- barcode → String?
-
final
- canSwap → bool?
-
final
- consignorAgreementId → String?
-
final
- consignorId → String?
-
final
- containerNo → String?
-
final
- contractType → String?
-
final
- dealId → String?
-
final
- departmentId → String?
-
final
- description → String?
-
final
- doSwap → bool?
-
final
- errorMessage → String?
-
final
- errorNumber → int?
-
final
- exchangeContractId → String?
-
final
- facilitiesTypeId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasMultipleContainers → String?
-
final
- iCode → String?
-
final
- inQuantity → String?
-
final
- internalChar → String?
-
final
- inventoryId → String?
-
final
- isBarcode → bool?
-
final
- isContainer → bool?
-
final
- itemClass → String?
-
final
- itemInContainer → bool?
-
final
- location → String?
-
final
- masterId → String?
-
final
- message → String?
-
final
- moduleType → String?
-
final
- nestedMasteritemId → String?
-
final
- newContainerInstantiated → bool?
-
final
- newOrder → bool?
-
final
- orderBy → String?
-
final
- orderId → String?
-
final
- orderItemId → String?
-
final
- orderNo → String?
-
final
- orderTranId → int?
-
final
- outOrderId → String?
-
final
- packageId → String?
-
final
- parentId → String?
-
final
- pending → bool?
-
final
- pendingMasterItemId → String?
-
final
- pendingOrderId → String?
-
final
- pendingRepairId → String?
-
final
- pOId → String?
-
final
- pONo → String?
-
final
- qcRequired → bool?
-
final
- quantity → int?
-
final
- quantityOrdered → String?
-
final
- quikinContractId → String?
-
final
- quikinInternalChar → String?
-
final
- quikinItemId → int?
-
final
- rentalItemId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannableMasterId → String?
-
final
- shelf → String?
-
final
- spaceId → String?
-
final
- spaceLocation → String?
-
final
- spaceTypeId → String?
-
final
- status → int?
-
final
- statusType → String?
-
final
- stillOut → String?
-
final
- subQuantity → String?
-
final
- swapItem → bool?
-
final
- totalIn → String?
-
final
- trackedBy → String?
-
final
- tranType → String?
-
final
- unretireSalesItem → bool?
-
final
- useContainerNo → bool?
-
final
- vendor → String?
-
final
- vendorId → String?
-
final
- warehouseId → String?
-
final
- wHCode → String?
-
final
Methods
-
copyWith(
{bool? addOrderToContract, String? aisle, String? availFromDateTime, String? availToDateTime, String? barcode, String? consignorId, String? consignorAgreementId, bool? canSwap, String? containerNo, String? contractType, String? dealId, String? departmentId, String? description, bool? doSwap, String? exchangeContractId, int? errorNumber, String? errorMessage, String? facilitiesTypeId, String? hasMultipleContainers, String? itemClass, String? inventoryId, bool? isBarcode, bool? isContainer, bool? itemInContainer, String? internalChar, String? location, String? moduleType, String? masterId, String? message, String? iCode, bool? newOrder, String? nestedMasteritemId, bool? newContainerInstantiated, int? orderTranId, String? outOrderId, String? orderNo, String? orderId, String? orderItemId, String? orderBy, String? packageId, String? parentId, String? pendingRepairId, String? pendingOrderId, String? pendingMasterItemId, String? pONo, bool? pending, String? pOId, bool? qcRequired, int? quantity, String? quikinContractId, int? quikinItemId, String? quikinInternalChar, String? quantityOrdered, String? rentalItemId, String? inQuantity, String? scannableMasterId, String? shelf, String? spaceId, String? spaceTypeId, String? spaceLocation, String? stillOut, int? status, String? statusType, bool? swapItem, String? subQuantity, String? totalIn, String? tranType, String? trackedBy, bool? useContainerNo, bool? unretireSalesItem, String? vendorId, String? vendor, String? warehouseId, String? wHCode}) → WebApiModulesWarehouseCheckInCheckInItem -
Available on WebApiModulesWarehouseCheckInCheckInItem, provided by the $WebApiModulesWarehouseCheckInCheckInItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseCheckInCheckInItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseCheckInCheckInItem instance)