WebApiModulesWarehouseCheckInCheckInItemsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

forceNewSession bool?
final
hashCode int
The hash code for this object.
no setteroverride
items List<WebApiModulesWarehouseCheckInCheckInItem>?
final
message String?
final
orders WebApiModulesWarehouseCheckInCheckInAddOrderResponse?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionInfo WebApiModulesWarehouseCheckInCheckInSessionInfo?
final
status int?
final
suspendedSessions List<WebApiModulesWarehouseCheckInSuspendedSession>?
final

Methods

copyWith({WebApiModulesWarehouseCheckInCheckInSessionInfo? sessionInfo, int? status, String? message, bool? forceNewSession, List<WebApiModulesWarehouseCheckInCheckInItem>? items, WebApiModulesWarehouseCheckInCheckInAddOrderResponse? orders, List<WebApiModulesWarehouseCheckInSuspendedSession>? suspendedSessions}) WebApiModulesWarehouseCheckInCheckInItemsResponse

Available on WebApiModulesWarehouseCheckInCheckInItemsResponse, provided by the $WebApiModulesWarehouseCheckInCheckInItemsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override