WebApiModulesWarehouseCheckInReconcileReconcileOrder class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseCheckInReconcileReconcileOrder({String? orderNumber, String? description, String? dueDate, int? count, int? stillOut, String? vendor, String? orderId, String? vendorId, int? quantity})
WebApiModulesWarehouseCheckInReconcileReconcileOrder.fromJson(Map<String, dynamic> json)
factory

Properties

count int?
final
description String?
final
dueDate String?
final
hashCode int
The hash code for this object.
no setteroverride
orderId String?
final
orderNumber String?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stillOut int?
final
vendor String?
final
vendorId String?
final

Methods

copyWith({String? orderNumber, String? description, String? dueDate, int? count, int? stillOut, String? vendor, String? orderId, String? vendorId, int? quantity}) WebApiModulesWarehouseCheckInReconcileReconcileOrder

Available on WebApiModulesWarehouseCheckInReconcileReconcileOrder, provided by the $WebApiModulesWarehouseCheckInReconcileReconcileOrderExtension extension

copyWithWrapped({Wrapped<String?>? orderNumber, Wrapped<String?>? description, Wrapped<String?>? dueDate, Wrapped<int?>? count, Wrapped<int?>? stillOut, Wrapped<String?>? vendor, Wrapped<String?>? orderId, Wrapped<String?>? vendorId, Wrapped<int?>? quantity}) WebApiModulesWarehouseCheckInReconcileReconcileOrder

Available on WebApiModulesWarehouseCheckInReconcileReconcileOrder, provided by the $WebApiModulesWarehouseCheckInReconcileReconcileOrderExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override