WebApiModulesWarehouseCheckInSelectedItemsRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesWarehouseCheckInSelectedItemsRequest({List<
WebApiModulesWarehouseCheckInSelectedItemRequest> ? items, String? officeLocationId, String? warehouseId}) -
const
-
WebApiModulesWarehouseCheckInSelectedItemsRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
WebApiModulesWarehouseCheckInSelectedItemRequest> ? -
final
- officeLocationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warehouseId → String?
-
final
Methods
-
copyWith(
{List< WebApiModulesWarehouseCheckInSelectedItemRequest> ? items, String? officeLocationId, String? warehouseId}) → WebApiModulesWarehouseCheckInSelectedItemsRequest -
Available on WebApiModulesWarehouseCheckInSelectedItemsRequest, provided by the $WebApiModulesWarehouseCheckInSelectedItemsRequestExtension extension
-
copyWithWrapped(
{Wrapped< List< ? items, Wrapped<WebApiModulesWarehouseCheckInSelectedItemRequest> ?>String?> ? officeLocationId, Wrapped<String?> ? warehouseId}) → WebApiModulesWarehouseCheckInSelectedItemsRequest -
Available on WebApiModulesWarehouseCheckInSelectedItemsRequest, provided by the $WebApiModulesWarehouseCheckInSelectedItemsRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseCheckInSelectedItemsRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseCheckInSelectedItemsRequest instance)