WebApiModulesWarehouseCheckInSelectedItemsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<WebApiModulesWarehouseCheckInSelectedItemResponse>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool?
final

Methods

copyWith({bool? success, List<WebApiModulesWarehouseCheckInSelectedItemResponse>? items}) WebApiModulesWarehouseCheckInSelectedItemsResponse

Available on WebApiModulesWarehouseCheckInSelectedItemsResponse, provided by the $WebApiModulesWarehouseCheckInSelectedItemsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override