WebApiModulesWarehouseCheckInSessionSettingsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseCheckInSessionSettingsResponse({String? dealId, String? departmentId, String? locationId, String? warehouseId, bool? hasPendingExchange, bool? hasException, String? notes, List<WebApiModulesWarehouseCheckInCheckInOrder>? orders})
const
WebApiModulesWarehouseCheckInSessionSettingsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

dealId String?
final
departmentId String?
final
hasException bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasPendingExchange bool?
final
locationId String?
final
notes String?
final
orders List<WebApiModulesWarehouseCheckInCheckInOrder>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String?
final

Methods

copyWith({String? dealId, String? departmentId, String? locationId, String? warehouseId, bool? hasPendingExchange, bool? hasException, String? notes, List<WebApiModulesWarehouseCheckInCheckInOrder>? orders}) WebApiModulesWarehouseCheckInSessionSettingsResponse

Available on WebApiModulesWarehouseCheckInSessionSettingsResponse, provided by the $WebApiModulesWarehouseCheckInSessionSettingsResponseExtension extension

copyWithWrapped({Wrapped<String?>? dealId, Wrapped<String?>? departmentId, Wrapped<String?>? locationId, Wrapped<String?>? warehouseId, Wrapped<bool?>? hasPendingExchange, Wrapped<bool?>? hasException, Wrapped<String?>? notes, Wrapped<List<WebApiModulesWarehouseCheckInCheckInOrder>?>? orders}) WebApiModulesWarehouseCheckInSessionSettingsResponse

Available on WebApiModulesWarehouseCheckInSessionSettingsResponse, provided by the $WebApiModulesWarehouseCheckInSessionSettingsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override