WebApiModulesWarehouseCheckOutAddMiscItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseCheckOutAddMiscItemRequest({String? orderId, String? warehouseId, String? inventoryId, int? quantity, String? description})
const
WebApiModulesWarehouseCheckOutAddMiscItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
orderId String?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String?
final

Methods

copyWith({String? orderId, String? warehouseId, String? inventoryId, int? quantity, String? description}) WebApiModulesWarehouseCheckOutAddMiscItemRequest

Available on WebApiModulesWarehouseCheckOutAddMiscItemRequest, provided by the $WebApiModulesWarehouseCheckOutAddMiscItemRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? warehouseId, Wrapped<String?>? inventoryId, Wrapped<int?>? quantity, Wrapped<String?>? description}) WebApiModulesWarehouseCheckOutAddMiscItemRequest

Available on WebApiModulesWarehouseCheckOutAddMiscItemRequest, provided by the $WebApiModulesWarehouseCheckOutAddMiscItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override