WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequest({String? orderId, String? orderItemId, String? inventoryId, String? warehouseId, int? quantity})
const
WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
orderId String?
final
orderItemId String?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String?
final

Methods

copyWith({String? orderId, String? orderItemId, String? inventoryId, String? warehouseId, int? quantity}) WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequest

Available on WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequest, provided by the $WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<int?>? quantity}) WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequest

Available on WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequest, provided by the $WebApiModulesWarehouseCheckOutDecreaseOrderQuantityRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override