WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequest({required String orderId, required String warehouseId, String? shippingCaseItemId})
const
WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
orderId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingCaseItemId String?
final
warehouseId String
final

Methods

copyWith({String? orderId, String? warehouseId, String? shippingCaseItemId}) WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequest

Available on WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequest, provided by the $WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequestExtension extension

copyWithWrapped({Wrapped<String>? orderId, Wrapped<String>? warehouseId, Wrapped<String?>? shippingCaseItemId}) WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequest

Available on WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequest, provided by the $WebApiModulesWarehouseCheckOutSelectAllNoneStageQuantityItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override