WebApiModulesWarehouseCheckOutStageSerialNumber class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseCheckOutStageSerialNumber({String? orderId, String? orderItemId, String? inventoryId, String? rentalItemId, String? warehouseId, String? serialNumber, double? currentMeter, String? inventoryStatus, String? statusType, bool? isStaged, String? color, String? textColor, String? ownership, String? consignorId, String? consignor, String? consignorColor, String? consignorAgreementId, String? consignorAgreementNumber, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesWarehouseCheckOutStageSerialNumber.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
color String?
final
consignor String?
final
consignorAgreementId String?
final
consignorAgreementNumber String?
final
consignorColor String?
final
consignorId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currentMeter double?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inventoryId String?
final
inventoryStatus String?
final
isStaged bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderId String?
final
orderItemId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
ownership String?
final
recordTitle String?
final
rentalItemId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
statusType String?
final
textColor String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouseId String?
final

Methods

copyWith({String? orderId, String? orderItemId, String? inventoryId, String? rentalItemId, String? warehouseId, String? serialNumber, double? currentMeter, String? inventoryStatus, String? statusType, bool? isStaged, String? color, String? textColor, String? ownership, String? consignorId, String? consignor, String? consignorColor, String? consignorAgreementId, String? consignorAgreementNumber, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesWarehouseCheckOutStageSerialNumber

Available on WebApiModulesWarehouseCheckOutStageSerialNumber, provided by the $WebApiModulesWarehouseCheckOutStageSerialNumberExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<String?>? inventoryId, Wrapped<String?>? rentalItemId, Wrapped<String?>? warehouseId, Wrapped<String?>? serialNumber, Wrapped<double?>? currentMeter, Wrapped<String?>? inventoryStatus, Wrapped<String?>? statusType, Wrapped<bool?>? isStaged, Wrapped<String?>? color, Wrapped<String?>? textColor, Wrapped<String?>? ownership, Wrapped<String?>? consignorId, Wrapped<String?>? consignor, Wrapped<String?>? consignorColor, Wrapped<String?>? consignorAgreementId, Wrapped<String?>? consignorAgreementNumber, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesWarehouseCheckOutStageSerialNumber

Available on WebApiModulesWarehouseCheckOutStageSerialNumber, provided by the $WebApiModulesWarehouseCheckOutStageSerialNumberExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override