WebApiModulesWarehouseCheckOutStagingAddSubstituteItemToSessionRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

code String?
final
hashCode int
The hash code for this object.
no setteroverride
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
warehouseId String?
final

Methods

copyWith({String? sessionId, String? code, String? warehouseId, int? quantity}) WebApiModulesWarehouseCheckOutStagingAddSubstituteItemToSessionRequest

Available on WebApiModulesWarehouseCheckOutStagingAddSubstituteItemToSessionRequest, provided by the $WebApiModulesWarehouseCheckOutStagingAddSubstituteItemToSessionRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override