WebApiModulesWarehouseContractSessionRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseContractSessionRequest({String? orderId, String? dealId, String? departmentId, String? locationId, String? warehouseId, String? notes, String? contractType})
const
WebApiModulesWarehouseContractSessionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

contractType String?
final
dealId String?
final
departmentId String?
final
hashCode int
The hash code for this object.
no setteroverride
locationId String?
final
notes String?
final
orderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String?
final

Methods

copyWith({String? orderId, String? dealId, String? departmentId, String? locationId, String? warehouseId, String? notes, String? contractType}) WebApiModulesWarehouseContractSessionRequest

Available on WebApiModulesWarehouseContractSessionRequest, provided by the $WebApiModulesWarehouseContractSessionRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? dealId, Wrapped<String?>? departmentId, Wrapped<String?>? locationId, Wrapped<String?>? warehouseId, Wrapped<String?>? notes, Wrapped<String?>? contractType}) WebApiModulesWarehouseContractSessionRequest

Available on WebApiModulesWarehouseContractSessionRequest, provided by the $WebApiModulesWarehouseContractSessionRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesWarehouseContractSessionRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesWarehouseContractSessionRequest instance)