WebApiModulesWarehouseExchangeExchangeContractRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseExchangeExchangeContractRequest({String? orderId, String? dealId, String? departmentId, String? warehouseId})
const
WebApiModulesWarehouseExchangeExchangeContractRequest.fromJson(Map<String, dynamic> json)
factory

Properties

dealId String?
final
departmentId String?
final
hashCode int
The hash code for this object.
no setteroverride
orderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String?
final

Methods

copyWith({String? orderId, String? dealId, String? departmentId, String? warehouseId}) WebApiModulesWarehouseExchangeExchangeContractRequest

Available on WebApiModulesWarehouseExchangeExchangeContractRequest, provided by the $WebApiModulesWarehouseExchangeExchangeContractRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? dealId, Wrapped<String?>? departmentId, Wrapped<String?>? warehouseId}) WebApiModulesWarehouseExchangeExchangeContractRequest

Available on WebApiModulesWarehouseExchangeExchangeContractRequest, provided by the $WebApiModulesWarehouseExchangeExchangeContractRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override