WebApiModulesWarehouseOrderStatusStorageContainerGrid class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseOrderStatusStorageContainerGrid({int? storageContainerId, int? storageContainerItemId, String? description, String? pickUpLocation, String? storageContainerBarcode, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesWarehouseOrderStatusStorageContainerGrid.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
pickUpLocation String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageContainerBarcode String?
final
storageContainerId int?
final
storageContainerItemId int?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? storageContainerId, int? storageContainerItemId, String? description, String? pickUpLocation, String? storageContainerBarcode, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesWarehouseOrderStatusStorageContainerGrid

Available on WebApiModulesWarehouseOrderStatusStorageContainerGrid, provided by the $WebApiModulesWarehouseOrderStatusStorageContainerGridExtension extension

copyWithWrapped({Wrapped<int?>? storageContainerId, Wrapped<int?>? storageContainerItemId, Wrapped<String?>? description, Wrapped<String?>? pickUpLocation, Wrapped<String?>? storageContainerBarcode, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesWarehouseOrderStatusStorageContainerGrid

Available on WebApiModulesWarehouseOrderStatusStorageContainerGrid, provided by the $WebApiModulesWarehouseOrderStatusStorageContainerGridExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override