WebApiModulesWarehousePickListUtilityItemPickListUtilityItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehousePickListUtilityItemPickListUtilityItem({String? sessionId, String? orderId, String? orderItemId, String? parentId, String? parentParentId, double? accessoryRatio, String? inventoryTypeId, String? inventoryType, String? inventoryTypeIdNoParent, String? orderNumber, String? locationId, String? departmentId, String? dealId, String? orderType, String? orderStatus, String? iCode, String? description, double? quantityOrdered, double? subQuantity, double? consignQuantity, double? quantityInLocation, String? pickDate, double? pickQuantity, double? stagedQuantity, double? outQuantity, double? remainingQuantity, double? pickedQuantity, String? inventoryId, String? warehouseId, String? warehouse, String? warehouseCode, String? recType, String? recTypeDisplay, String? itemClass, String? itemOrder, bool? optionColor, String? itemId, String? barCode, String? serialNumber, String? subVendorId, String? consignorId, String? vendor, String? nestedOrderItemId, int? nestingLevel, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesWarehousePickListUtilityItemPickListUtilityItem.fromJson(Map<String, dynamic> json)
factory

Properties

accessoryRatio double?
final
auditNote String?
final
barCode String?
final
consignorId String?
final
consignQuantity double?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dealId String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
departmentId String?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inventoryId String?
final
inventoryType String?
final
inventoryTypeId String?
final
inventoryTypeIdNoParent String?
final
itemClass String?
final
itemId String?
final
itemOrder String?
final
locationId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
nestedOrderItemId String?
final
nestingLevel int?
final
optionColor bool?
final
orderId String?
final
orderItemId String?
final
orderNumber String?
final
orderStatus String?
final
orderType String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
outQuantity double?
final
parentId String?
final
parentParentId String?
final
pickDate String?
final
pickedQuantity double?
final
pickQuantity double?
final
quantityInLocation double?
final
quantityOrdered double?
final
recordTitle String?
final
recType String?
final
recTypeDisplay String?
final
remainingQuantity double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
sessionId String?
final
stagedQuantity double?
final
subQuantity double?
final
subVendorId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
vendor String?
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? sessionId, String? orderId, String? orderItemId, String? parentId, String? parentParentId, double? accessoryRatio, String? inventoryTypeId, String? inventoryType, String? inventoryTypeIdNoParent, String? orderNumber, String? locationId, String? departmentId, String? dealId, String? orderType, String? orderStatus, String? iCode, String? description, double? quantityOrdered, double? subQuantity, double? consignQuantity, double? quantityInLocation, String? pickDate, double? pickQuantity, double? stagedQuantity, double? outQuantity, double? remainingQuantity, double? pickedQuantity, String? inventoryId, String? warehouseId, String? warehouse, String? warehouseCode, String? recType, String? recTypeDisplay, String? itemClass, String? itemOrder, bool? optionColor, String? itemId, String? barCode, String? serialNumber, String? subVendorId, String? consignorId, String? vendor, String? nestedOrderItemId, int? nestingLevel, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesWarehousePickListUtilityItemPickListUtilityItem

Available on WebApiModulesWarehousePickListUtilityItemPickListUtilityItem, provided by the $WebApiModulesWarehousePickListUtilityItemPickListUtilityItemExtension extension

copyWithWrapped({Wrapped<String?>? sessionId, Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<String?>? parentId, Wrapped<String?>? parentParentId, Wrapped<double?>? accessoryRatio, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? inventoryType, Wrapped<String?>? inventoryTypeIdNoParent, Wrapped<String?>? orderNumber, Wrapped<String?>? locationId, Wrapped<String?>? departmentId, Wrapped<String?>? dealId, Wrapped<String?>? orderType, Wrapped<String?>? orderStatus, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<double?>? quantityOrdered, Wrapped<double?>? subQuantity, Wrapped<double?>? consignQuantity, Wrapped<double?>? quantityInLocation, Wrapped<String?>? pickDate, Wrapped<double?>? pickQuantity, Wrapped<double?>? stagedQuantity, Wrapped<double?>? outQuantity, Wrapped<double?>? remainingQuantity, Wrapped<double?>? pickedQuantity, Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? warehouseCode, Wrapped<String?>? recType, Wrapped<String?>? recTypeDisplay, Wrapped<String?>? itemClass, Wrapped<String?>? itemOrder, Wrapped<bool?>? optionColor, Wrapped<String?>? itemId, Wrapped<String?>? barCode, Wrapped<String?>? serialNumber, Wrapped<String?>? subVendorId, Wrapped<String?>? consignorId, Wrapped<String?>? vendor, Wrapped<String?>? nestedOrderItemId, Wrapped<int?>? nestingLevel, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesWarehousePickListUtilityItemPickListUtilityItem

Available on WebApiModulesWarehousePickListUtilityItemPickListUtilityItem, provided by the $WebApiModulesWarehousePickListUtilityItemPickListUtilityItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override