WebApiModulesWarehouseQuikReceiptQuikReceiptGrid class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseQuikReceiptQuikReceiptGrid({int? quikReceiptId, String? receiptNumber, String? receiptStatus, FwStandardSqlServerFwDateTime? receiptAsOfDate, String? receiptAsOfTime, String? note, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesWarehouseQuikReceiptQuikReceiptGrid.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
note String?
final
quikReceiptId int?
final
receiptAsOfDate FwStandardSqlServerFwDateTime?
final
receiptAsOfTime String?
final
receiptNumber String?
final
receiptStatus String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? quikReceiptId, String? receiptNumber, String? receiptStatus, FwStandardSqlServerFwDateTime? receiptAsOfDate, String? receiptAsOfTime, String? note, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesWarehouseQuikReceiptQuikReceiptGrid

Available on WebApiModulesWarehouseQuikReceiptQuikReceiptGrid, provided by the $WebApiModulesWarehouseQuikReceiptQuikReceiptGridExtension extension

copyWithWrapped({Wrapped<int?>? quikReceiptId, Wrapped<String?>? receiptNumber, Wrapped<String?>? receiptStatus, Wrapped<FwStandardSqlServerFwDateTime?>? receiptAsOfDate, Wrapped<String?>? receiptAsOfTime, Wrapped<String?>? note, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes}) WebApiModulesWarehouseQuikReceiptQuikReceiptGrid

Available on WebApiModulesWarehouseQuikReceiptQuikReceiptGrid, provided by the $WebApiModulesWarehouseQuikReceiptQuikReceiptGridExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override