WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponse({String? orderId, String? orderdescription, String? contractId, int? inSessionNumber, int? qrSessionNumber, int? quikReceiptId, int? status, String? message})
WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

contractId String?
final
hashCode int
The hash code for this object.
no setteroverride
inSessionNumber int?
final
message String?
final
orderdescription String?
final
orderId String?
final
qrSessionNumber int?
final
quikReceiptId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final

Methods

copyWith({String? orderId, String? orderdescription, String? contractId, int? inSessionNumber, int? qrSessionNumber, int? quikReceiptId, int? status, String? message}) WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponse

Available on WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponse, provided by the $WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponseExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? orderdescription, Wrapped<String?>? contractId, Wrapped<int?>? inSessionNumber, Wrapped<int?>? qrSessionNumber, Wrapped<int?>? quikReceiptId, Wrapped<int?>? status, Wrapped<String?>? message}) WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponse

Available on WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponse, provided by the $WebApiModulesWarehouseQuikReceiptQuikReceiptSessionResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override