WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecord class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecord({String? orderNo, String? deal, String? warehouse, int? receiptNumber, String? receiptStatus, String? contractId, String? checkinSessionDate, String? asOfDate, String? asOfTime, String? checkinSessionStatus, int? checkinSessionNo, String? owner, String? orderDescription, String? note, int? quikReceiptId})
const
WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecord.fromJson(Map<String, dynamic> json)
factory

Properties

asOfDate String?
final
asOfTime String?
final
checkinSessionDate String?
final
checkinSessionNo int?
final
checkinSessionStatus String?
final
contractId String?
final
deal String?
final
hashCode int
The hash code for this object.
no setteroverride
note String?
final
orderDescription String?
final
orderNo String?
final
owner String?
final
quikReceiptId int?
final
receiptNumber int?
final
receiptStatus String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouse String?
final

Methods

copyWith({String? orderNo, String? deal, String? warehouse, int? receiptNumber, String? receiptStatus, String? contractId, String? checkinSessionDate, String? asOfDate, String? asOfTime, String? checkinSessionStatus, int? checkinSessionNo, String? owner, String? orderDescription, String? note, int? quikReceiptId}) WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecord

Available on WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecord, provided by the $WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecordExtension extension

copyWithWrapped({Wrapped<String?>? orderNo, Wrapped<String?>? deal, Wrapped<String?>? warehouse, Wrapped<int?>? receiptNumber, Wrapped<String?>? receiptStatus, Wrapped<String?>? contractId, Wrapped<String?>? checkinSessionDate, Wrapped<String?>? asOfDate, Wrapped<String?>? asOfTime, Wrapped<String?>? checkinSessionStatus, Wrapped<int?>? checkinSessionNo, Wrapped<String?>? owner, Wrapped<String?>? orderDescription, Wrapped<String?>? note, Wrapped<int?>? quikReceiptId}) WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecord

Available on WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecord, provided by the $WebApiModulesWarehouseQuikReceiptQuikReceiptSuspendedSessionRecordExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override