WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequest({String? inventoryId, String? warehouseId, String? regionId, DateTime? fromDate, DateTime? toDate, bool? refreshIfNeeded})
const
WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequest.fromJson(Map<String, dynamic> json)
factory

Properties

fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
refreshIfNeeded bool?
final
regionId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate DateTime?
final
warehouseId String?
final

Methods

copyWith({String? inventoryId, String? warehouseId, String? regionId, DateTime? fromDate, DateTime? toDate, bool? refreshIfNeeded}) WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequest

Available on WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequest, provided by the $WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequestExtension extension

copyWithWrapped({Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? regionId, Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<bool?>? refreshIfNeeded}) WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequest

Available on WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequest, provided by the $WebApiServicesAvailabilityServiceAvailabilityInventoryWarehouseRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override