WebApiServicesAvailabilityServiceTInventoryWarehouse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiServicesAvailabilityServiceTInventoryWarehouse({String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? inventoryId, String? warehouseId, String? regionId, String? availableFor, String? iCode, String? description, String? warehouseCode, String? warehouse, String? classification, bool? hourlyAvailability, bool? assetAvailability, bool? noAvailabilityCheck, int? lowAvailabilityPercent, int? lowAvailabilityQuantity, String? dailyRate, String? weeklyRate, String? week2Rate, String? week3Rate, String? week4Rate, String? monthlyRate, List<
WebApiServicesAvailabilityServiceTPackageAccessory> ? accessories, bool? availabilityIncludePurchaseOrders, int? availabilityPurchaseOrderLateDays, String? combinedKey}) -
WebApiServicesAvailabilityServiceTInventoryWarehouse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
accessories
→ List<
WebApiServicesAvailabilityServiceTPackageAccessory> ? -
final
- assetAvailability → bool?
-
final
- availabilityIncludePurchaseOrders → bool?
-
final
- availabilityPurchaseOrderLateDays → int?
-
final
- availableFor → String?
-
final
- category → String?
-
final
- categoryId → String?
-
final
- classification → String?
-
final
- combinedKey → String?
-
final
- dailyRate → String?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hourlyAvailability → bool?
-
final
- iCode → String?
-
final
- inventoryId → String?
-
final
- inventoryType → String?
-
final
- inventoryTypeId → String?
-
final
- lowAvailabilityPercent → int?
-
final
- lowAvailabilityQuantity → int?
-
final
- monthlyRate → String?
-
final
- noAvailabilityCheck → bool?
-
final
- regionId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subCategory → String?
-
final
- subCategoryId → String?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
- week2Rate → String?
-
final
- week3Rate → String?
-
final
- week4Rate → String?
-
final
- weeklyRate → String?
-
final
Methods
-
copyWith(
{String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? inventoryId, String? warehouseId, String? regionId, String? availableFor, String? iCode, String? description, String? warehouseCode, String? warehouse, String? classification, bool? hourlyAvailability, bool? assetAvailability, bool? noAvailabilityCheck, int? lowAvailabilityPercent, int? lowAvailabilityQuantity, String? dailyRate, String? weeklyRate, String? week2Rate, String? week3Rate, String? week4Rate, String? monthlyRate, List< WebApiServicesAvailabilityServiceTPackageAccessory> ? accessories, bool? availabilityIncludePurchaseOrders, int? availabilityPurchaseOrderLateDays, String? combinedKey}) → WebApiServicesAvailabilityServiceTInventoryWarehouse -
Available on WebApiServicesAvailabilityServiceTInventoryWarehouse, provided by the $WebApiServicesAvailabilityServiceTInventoryWarehouseExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? inventoryTypeId, Wrapped<String?> ? inventoryType, Wrapped<String?> ? categoryId, Wrapped<String?> ? category, Wrapped<String?> ? subCategoryId, Wrapped<String?> ? subCategory, Wrapped<String?> ? inventoryId, Wrapped<String?> ? warehouseId, Wrapped<String?> ? regionId, Wrapped<String?> ? availableFor, Wrapped<String?> ? iCode, Wrapped<String?> ? description, Wrapped<String?> ? warehouseCode, Wrapped<String?> ? warehouse, Wrapped<String?> ? classification, Wrapped<bool?> ? hourlyAvailability, Wrapped<bool?> ? assetAvailability, Wrapped<bool?> ? noAvailabilityCheck, Wrapped<int?> ? lowAvailabilityPercent, Wrapped<int?> ? lowAvailabilityQuantity, Wrapped<String?> ? dailyRate, Wrapped<String?> ? weeklyRate, Wrapped<String?> ? week2Rate, Wrapped<String?> ? week3Rate, Wrapped<String?> ? week4Rate, Wrapped<String?> ? monthlyRate, Wrapped<List< ? accessories, Wrapped<WebApiServicesAvailabilityServiceTPackageAccessory> ?>bool?> ? availabilityIncludePurchaseOrders, Wrapped<int?> ? availabilityPurchaseOrderLateDays, Wrapped<String?> ? combinedKey}) → WebApiServicesAvailabilityServiceTInventoryWarehouse -
Available on WebApiServicesAvailabilityServiceTInventoryWarehouse, provided by the $WebApiServicesAvailabilityServiceTInventoryWarehouseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiServicesAvailabilityServiceTInventoryWarehouse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiServicesAvailabilityServiceTInventoryWarehouse instance)