WebApiServicesAvailabilityServiceTPackageAccessory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiServicesAvailabilityServiceTPackageAccessory({String? inventoryId, String? classification, double? defaultQuantity})
const
WebApiServicesAvailabilityServiceTPackageAccessory.fromJson(Map<String, dynamic> json)
factory

Properties

classification String?
final
defaultQuantity double?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inventoryId, String? classification, double? defaultQuantity}) WebApiServicesAvailabilityServiceTPackageAccessory

Available on WebApiServicesAvailabilityServiceTPackageAccessory, provided by the $WebApiServicesAvailabilityServiceTPackageAccessoryExtension extension

copyWithWrapped({Wrapped<String?>? inventoryId, Wrapped<String?>? classification, Wrapped<double?>? defaultQuantity}) WebApiServicesAvailabilityServiceTPackageAccessory

Available on WebApiServicesAvailabilityServiceTPackageAccessory, provided by the $WebApiServicesAvailabilityServiceTPackageAccessoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override