ShopifySharpClientDetails class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpClientDetails({String? acceptLanguage, int? browserHeight, String? browserIp, int? browserWidth, String? sessionHash, String? userAgent})
-
const
-
ShopifySharpClientDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- acceptLanguage → String?
-
final
- browserHeight → int?
-
final
- browserIp → String?
-
final
- browserWidth → int?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionHash → String?
-
final
- userAgent → String?
-
final
Methods
-
copyWith(
{String? acceptLanguage, int? browserHeight, String? browserIp, int? browserWidth, String? sessionHash, String? userAgent}) → ShopifySharpClientDetails -
Available on ShopifySharpClientDetails, provided by the $ShopifySharpClientDetailsExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? acceptLanguage, Wrapped<int?> ? browserHeight, Wrapped<String?> ? browserIp, Wrapped<int?> ? browserWidth, Wrapped<String?> ? sessionHash, Wrapped<String?> ? userAgent}) → ShopifySharpClientDetails -
Available on ShopifySharpClientDetails, provided by the $ShopifySharpClientDetailsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpClientDetails Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpClientDetails instance)