ShopifySharpCustomer class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpCustomer({List<ShopifySharpAddress>? addresses, DateTime? createdAt, String? currency, ShopifySharpAddress? defaultAddress, String? email, String? firstName, String? multipassIdentifier, String? lastName, int? lastOrderId, String? lastOrderName, String? note, int? ordersCount, String? phone, String? state, String? tags, bool? taxExempt, List<String>? taxExemptions, double? totalSpent, DateTime? updatedAt, bool? verifiedEmail, ShopifySharpCustomerSmsMarketingConsent? smsMarketingConsent, List<ShopifySharpMetaField>? metafields, ShopifySharpCustomerEmailMarketingConsent? emailMarketingConsent, int? id, String? adminGraphqlApiId})
const
ShopifySharpCustomer.fromJson(Map<String, dynamic> json)
factory

Properties

addresses List<ShopifySharpAddress>?
final
adminGraphqlApiId String?
final
createdAt DateTime?
final
currency String?
final
defaultAddress ShopifySharpAddress?
final
email String?
final
emailMarketingConsent ShopifySharpCustomerEmailMarketingConsent?
final
firstName String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
lastName String?
final
lastOrderId int?
final
lastOrderName String?
final
metafields List<ShopifySharpMetaField>?
final
multipassIdentifier String?
final
note String?
final
ordersCount int?
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smsMarketingConsent ShopifySharpCustomerSmsMarketingConsent?
final
state String?
final
tags String?
final
taxExempt bool?
final
taxExemptions List<String>?
final
totalSpent double?
final
updatedAt DateTime?
final
verifiedEmail bool?
final

Methods

copyWith({List<ShopifySharpAddress>? addresses, DateTime? createdAt, String? currency, ShopifySharpAddress? defaultAddress, String? email, String? firstName, String? multipassIdentifier, String? lastName, int? lastOrderId, String? lastOrderName, String? note, int? ordersCount, String? phone, String? state, String? tags, bool? taxExempt, List<String>? taxExemptions, double? totalSpent, DateTime? updatedAt, bool? verifiedEmail, ShopifySharpCustomerSmsMarketingConsent? smsMarketingConsent, List<ShopifySharpMetaField>? metafields, ShopifySharpCustomerEmailMarketingConsent? emailMarketingConsent, int? id, String? adminGraphqlApiId}) ShopifySharpCustomer

Available on ShopifySharpCustomer, provided by the $ShopifySharpCustomerExtension extension

copyWithWrapped({Wrapped<List<ShopifySharpAddress>?>? addresses, Wrapped<DateTime?>? createdAt, Wrapped<String?>? currency, Wrapped<ShopifySharpAddress?>? defaultAddress, Wrapped<String?>? email, Wrapped<String?>? firstName, Wrapped<String?>? multipassIdentifier, Wrapped<String?>? lastName, Wrapped<int?>? lastOrderId, Wrapped<String?>? lastOrderName, Wrapped<String?>? note, Wrapped<int?>? ordersCount, Wrapped<String?>? phone, Wrapped<String?>? state, Wrapped<String?>? tags, Wrapped<bool?>? taxExempt, Wrapped<List<String>?>? taxExemptions, Wrapped<double?>? totalSpent, Wrapped<DateTime?>? updatedAt, Wrapped<bool?>? verifiedEmail, Wrapped<ShopifySharpCustomerSmsMarketingConsent?>? smsMarketingConsent, Wrapped<List<ShopifySharpMetaField>?>? metafields, Wrapped<ShopifySharpCustomerEmailMarketingConsent?>? emailMarketingConsent, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpCustomer

Available on ShopifySharpCustomer, provided by the $ShopifySharpCustomerExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpCustomer Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpCustomer instance)