ShopifySharpCustomerEmailMarketingConsent class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpCustomerEmailMarketingConsent({String? state, String? optInLevel, DateTime? consentUpdatedAt})
-
const
-
ShopifySharpCustomerEmailMarketingConsent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- consentUpdatedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- optInLevel → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
final
Methods
-
copyWith(
{String? state, String? optInLevel, DateTime? consentUpdatedAt}) → ShopifySharpCustomerEmailMarketingConsent -
Available on ShopifySharpCustomerEmailMarketingConsent, provided by the $ShopifySharpCustomerEmailMarketingConsentExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? state, Wrapped<String?> ? optInLevel, Wrapped<DateTime?> ? consentUpdatedAt}) → ShopifySharpCustomerEmailMarketingConsent -
Available on ShopifySharpCustomerEmailMarketingConsent, provided by the $ShopifySharpCustomerEmailMarketingConsentExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpCustomerEmailMarketingConsent Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpCustomerEmailMarketingConsent instance)