ShopifySharpDiscountApplication class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpDiscountApplication({String? type, String? code, String? title, String? description, String? value, String? valueType, String? allocationMethod, String? targetSelection, String? targetType})
const
ShopifySharpDiscountApplication.fromJson(Map<String, dynamic> json)
factory

Properties

allocationMethod String?
final
code String?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSelection String?
final
targetType String?
final
title String?
final
type String?
final
value String?
final
valueType String?
final

Methods

copyWith({String? type, String? code, String? title, String? description, String? value, String? valueType, String? allocationMethod, String? targetSelection, String? targetType}) ShopifySharpDiscountApplication

Available on ShopifySharpDiscountApplication, provided by the $ShopifySharpDiscountApplicationExtension extension

copyWithWrapped({Wrapped<String?>? type, Wrapped<String?>? code, Wrapped<String?>? title, Wrapped<String?>? description, Wrapped<String?>? value, Wrapped<String?>? valueType, Wrapped<String?>? allocationMethod, Wrapped<String?>? targetSelection, Wrapped<String?>? targetType}) ShopifySharpDiscountApplication

Available on ShopifySharpDiscountApplication, provided by the $ShopifySharpDiscountApplicationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpDiscountApplication Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpDiscountApplication instance)