ShopifySharpDiscountCode class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpDiscountCode({String? amount, String? code, String? type, int? id, String? adminGraphqlApiId})
const
ShopifySharpDiscountCode.fromJson(Map<String, dynamic> json)
factory

Properties

adminGraphqlApiId String?
final
amount String?
final
code String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

copyWith({String? amount, String? code, String? type, int? id, String? adminGraphqlApiId}) ShopifySharpDiscountCode

Available on ShopifySharpDiscountCode, provided by the $ShopifySharpDiscountCodeExtension extension

copyWithWrapped({Wrapped<String?>? amount, Wrapped<String?>? code, Wrapped<String?>? type, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpDiscountCode

Available on ShopifySharpDiscountCode, provided by the $ShopifySharpDiscountCodeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpDiscountCode Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpDiscountCode instance)