ShopifySharpFulfillment class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpFulfillment({DateTime? createdAt, List<ShopifySharpLineItem>? lineItems, int? orderId, dynamic receipt, String? status, int? locationId, String? email, bool? notifyCustomer, ShopifySharpAddress? destination, String? trackingCompany, String? trackingNumber, List<String>? trackingNumbers, String? trackingUrl, List<String>? trackingUrls, DateTime? updatedAt, String? variantInventoryManagement, String? service, String? shipmentStatus, String? name, ShopifySharpFulfillmentOriginAddress? originAddress, int? id, String? adminGraphqlApiId})
const
ShopifySharpFulfillment.fromJson(Map<String, dynamic> json)
factory

Properties

adminGraphqlApiId String?
final
createdAt DateTime?
final
destination ShopifySharpAddress?
final
email String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
lineItems List<ShopifySharpLineItem>?
final
locationId int?
final
name String?
final
notifyCustomer bool?
final
orderId int?
final
originAddress ShopifySharpFulfillmentOriginAddress?
final
receipt → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String?
final
shipmentStatus String?
final
status String?
final
trackingCompany String?
final
trackingNumber String?
final
trackingNumbers List<String>?
final
trackingUrl String?
final
trackingUrls List<String>?
final
updatedAt DateTime?
final
variantInventoryManagement String?
final

Methods

copyWith({DateTime? createdAt, List<ShopifySharpLineItem>? lineItems, int? orderId, dynamic receipt, String? status, int? locationId, String? email, bool? notifyCustomer, ShopifySharpAddress? destination, String? trackingCompany, String? trackingNumber, List<String>? trackingNumbers, String? trackingUrl, List<String>? trackingUrls, DateTime? updatedAt, String? variantInventoryManagement, String? service, String? shipmentStatus, String? name, ShopifySharpFulfillmentOriginAddress? originAddress, int? id, String? adminGraphqlApiId}) ShopifySharpFulfillment

Available on ShopifySharpFulfillment, provided by the $ShopifySharpFulfillmentExtension extension

copyWithWrapped({Wrapped<DateTime?>? createdAt, Wrapped<List<ShopifySharpLineItem>?>? lineItems, Wrapped<int?>? orderId, Wrapped? receipt, Wrapped<String?>? status, Wrapped<int?>? locationId, Wrapped<String?>? email, Wrapped<bool?>? notifyCustomer, Wrapped<ShopifySharpAddress?>? destination, Wrapped<String?>? trackingCompany, Wrapped<String?>? trackingNumber, Wrapped<List<String>?>? trackingNumbers, Wrapped<String?>? trackingUrl, Wrapped<List<String>?>? trackingUrls, Wrapped<DateTime?>? updatedAt, Wrapped<String?>? variantInventoryManagement, Wrapped<String?>? service, Wrapped<String?>? shipmentStatus, Wrapped<String?>? name, Wrapped<ShopifySharpFulfillmentOriginAddress?>? originAddress, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpFulfillment

Available on ShopifySharpFulfillment, provided by the $ShopifySharpFulfillmentExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpFulfillment Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpFulfillment instance)