ShopifySharpFulfillmentOriginAddress class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpFulfillmentOriginAddress({String? address1, String? address2, String? city, String? countryCode, String? provinceCode, String? zip})
const
ShopifySharpFulfillmentOriginAddress.fromJson(Map<String, dynamic> json)
factory

Properties

address1 String?
final
address2 String?
final
city String?
final
countryCode String?
final
hashCode int
The hash code for this object.
no setteroverride
provinceCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zip String?
final

Methods

copyWith({String? address1, String? address2, String? city, String? countryCode, String? provinceCode, String? zip}) ShopifySharpFulfillmentOriginAddress

Available on ShopifySharpFulfillmentOriginAddress, provided by the $ShopifySharpFulfillmentOriginAddressExtension extension

copyWithWrapped({Wrapped<String?>? address1, Wrapped<String?>? address2, Wrapped<String?>? city, Wrapped<String?>? countryCode, Wrapped<String?>? provinceCode, Wrapped<String?>? zip}) ShopifySharpFulfillmentOriginAddress

Available on ShopifySharpFulfillmentOriginAddress, provided by the $ShopifySharpFulfillmentOriginAddressExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpFulfillmentOriginAddress Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpFulfillmentOriginAddress instance)