ShopifySharpLineItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpLineItem({int? fulfillableQuantity, String? fulfillmentService, String? fulfillmentStatus, int? grams, double? price, int? productId, int? quantity, bool? requiresShipping, String? sku, String? title, int? variantId, String? variantTitle, String? name, String? vendor, bool? giftCard, bool? taxable, List<ShopifySharpTaxLine>? taxLines, String? tipPaymentGateway, String? tipPaymentMethod, double? totalDiscount, ShopifySharpPriceSet? totalDiscountSet, List<ShopifySharpDiscountAllocation>? discountAllocations, List<ShopifySharpLineItemProperty>? properties, String? variantInventoryManagement, bool? productExists, ShopifySharpPriceSet? priceSet, double? preTaxPrice, ShopifySharpPriceSet? preTaxPriceSet, List<ShopifySharpLineItemDuty>? duties, int? fulfillmentLineItemId, List<ShopifySharpLineItemAttributedStaff>? attributedStaffs, int? id, String? adminGraphqlApiId})
const
ShopifySharpLineItem.fromJson(Map<String, dynamic> json)
factory

Properties

adminGraphqlApiId String?
final
attributedStaffs List<ShopifySharpLineItemAttributedStaff>?
final
discountAllocations List<ShopifySharpDiscountAllocation>?
final
duties List<ShopifySharpLineItemDuty>?
final
fulfillableQuantity int?
final
fulfillmentLineItemId int?
final
fulfillmentService String?
final
fulfillmentStatus String?
final
giftCard bool?
final
grams int?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
name String?
final
preTaxPrice double?
final
preTaxPriceSet ShopifySharpPriceSet?
final
price double?
final
priceSet ShopifySharpPriceSet?
final
productExists bool?
final
productId int?
final
properties List<ShopifySharpLineItemProperty>?
final
quantity int?
final
requiresShipping bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sku String?
final
taxable bool?
final
taxLines List<ShopifySharpTaxLine>?
final
tipPaymentGateway String?
final
tipPaymentMethod String?
final
title String?
final
totalDiscount double?
final
totalDiscountSet ShopifySharpPriceSet?
final
variantId int?
final
variantInventoryManagement String?
final
variantTitle String?
final
vendor String?
final

Methods

copyWith({int? fulfillableQuantity, String? fulfillmentService, String? fulfillmentStatus, int? grams, double? price, int? productId, int? quantity, bool? requiresShipping, String? sku, String? title, int? variantId, String? variantTitle, String? name, String? vendor, bool? giftCard, bool? taxable, List<ShopifySharpTaxLine>? taxLines, String? tipPaymentGateway, String? tipPaymentMethod, double? totalDiscount, ShopifySharpPriceSet? totalDiscountSet, List<ShopifySharpDiscountAllocation>? discountAllocations, List<ShopifySharpLineItemProperty>? properties, String? variantInventoryManagement, bool? productExists, ShopifySharpPriceSet? priceSet, double? preTaxPrice, ShopifySharpPriceSet? preTaxPriceSet, List<ShopifySharpLineItemDuty>? duties, int? fulfillmentLineItemId, List<ShopifySharpLineItemAttributedStaff>? attributedStaffs, int? id, String? adminGraphqlApiId}) ShopifySharpLineItem

Available on ShopifySharpLineItem, provided by the $ShopifySharpLineItemExtension extension

copyWithWrapped({Wrapped<int?>? fulfillableQuantity, Wrapped<String?>? fulfillmentService, Wrapped<String?>? fulfillmentStatus, Wrapped<int?>? grams, Wrapped<double?>? price, Wrapped<int?>? productId, Wrapped<int?>? quantity, Wrapped<bool?>? requiresShipping, Wrapped<String?>? sku, Wrapped<String?>? title, Wrapped<int?>? variantId, Wrapped<String?>? variantTitle, Wrapped<String?>? name, Wrapped<String?>? vendor, Wrapped<bool?>? giftCard, Wrapped<bool?>? taxable, Wrapped<List<ShopifySharpTaxLine>?>? taxLines, Wrapped<String?>? tipPaymentGateway, Wrapped<String?>? tipPaymentMethod, Wrapped<double?>? totalDiscount, Wrapped<ShopifySharpPriceSet?>? totalDiscountSet, Wrapped<List<ShopifySharpDiscountAllocation>?>? discountAllocations, Wrapped<List<ShopifySharpLineItemProperty>?>? properties, Wrapped<String?>? variantInventoryManagement, Wrapped<bool?>? productExists, Wrapped<ShopifySharpPriceSet?>? priceSet, Wrapped<double?>? preTaxPrice, Wrapped<ShopifySharpPriceSet?>? preTaxPriceSet, Wrapped<List<ShopifySharpLineItemDuty>?>? duties, Wrapped<int?>? fulfillmentLineItemId, Wrapped<List<ShopifySharpLineItemAttributedStaff>?>? attributedStaffs, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpLineItem

Available on ShopifySharpLineItem, provided by the $ShopifySharpLineItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpLineItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpLineItem instance)