ShopifySharpLineItemDuty class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpLineItemDuty({String? harmonizedSystemCode, String? countryCodeOfOrigin, ShopifySharpPriceSet? priceSet, List<ShopifySharpTaxLine>? taxLines, int? id, String? adminGraphqlApiId})
const
ShopifySharpLineItemDuty.fromJson(Map<String, dynamic> json)
factory

Properties

adminGraphqlApiId String?
final
countryCodeOfOrigin String?
final
harmonizedSystemCode String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
priceSet ShopifySharpPriceSet?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxLines List<ShopifySharpTaxLine>?
final

Methods

copyWith({String? harmonizedSystemCode, String? countryCodeOfOrigin, ShopifySharpPriceSet? priceSet, List<ShopifySharpTaxLine>? taxLines, int? id, String? adminGraphqlApiId}) ShopifySharpLineItemDuty

Available on ShopifySharpLineItemDuty, provided by the $ShopifySharpLineItemDutyExtension extension

copyWithWrapped({Wrapped<String?>? harmonizedSystemCode, Wrapped<String?>? countryCodeOfOrigin, Wrapped<ShopifySharpPriceSet?>? priceSet, Wrapped<List<ShopifySharpTaxLine>?>? taxLines, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpLineItemDuty

Available on ShopifySharpLineItemDuty, provided by the $ShopifySharpLineItemDutyExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpLineItemDuty Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpLineItemDuty instance)