ShopifySharpLineItemProperty class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpLineItemProperty({dynamic name, dynamic value})
const
ShopifySharpLineItemProperty.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
final

Methods

copyWith({dynamic name, dynamic value}) ShopifySharpLineItemProperty

Available on ShopifySharpLineItemProperty, provided by the $ShopifySharpLineItemPropertyExtension extension

copyWithWrapped({Wrapped? name, Wrapped? value}) ShopifySharpLineItemProperty

Available on ShopifySharpLineItemProperty, provided by the $ShopifySharpLineItemPropertyExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpLineItemProperty Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpLineItemProperty instance)