ShopifySharpMetaField class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpMetaField({DateTime? createdAt, DateTime? updatedAt, String? key, dynamic value, String? type, String? namespace, String? description, int? ownerId, String? ownerResource, int? id, String? adminGraphqlApiId})
const
ShopifySharpMetaField.fromJson(Map<String, dynamic> json)
factory

Properties

adminGraphqlApiId String?
final
createdAt DateTime?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
key String?
final
namespace String?
final
ownerId int?
final
ownerResource String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final
updatedAt DateTime?
final
value → dynamic
final

Methods

copyWith({DateTime? createdAt, DateTime? updatedAt, String? key, dynamic value, String? type, String? namespace, String? description, int? ownerId, String? ownerResource, int? id, String? adminGraphqlApiId}) ShopifySharpMetaField

Available on ShopifySharpMetaField, provided by the $ShopifySharpMetaFieldExtension extension

copyWithWrapped({Wrapped<DateTime?>? createdAt, Wrapped<DateTime?>? updatedAt, Wrapped<String?>? key, Wrapped? value, Wrapped<String?>? type, Wrapped<String?>? namespace, Wrapped<String?>? description, Wrapped<int?>? ownerId, Wrapped<String?>? ownerResource, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpMetaField

Available on ShopifySharpMetaField, provided by the $ShopifySharpMetaFieldExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpMetaField Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpMetaField instance)