ShopifySharpOrder class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpOrder({int? appId, ShopifySharpAddress? billingAddress, String? browserIp, bool? buyerAcceptsMarketing, String? cancelReason, DateTime? cancelledAt, String? cartToken, String? checkoutToken, int? checkoutId, ShopifySharpClientDetails? clientDetails, DateTime? closedAt, bool? confirmed, DateTime? createdAt, String? currency, ShopifySharpCustomer? customer, String? customerLocale, int? deviceId, List<ShopifySharpDiscountCode>? discountCodes, List<ShopifySharpDiscountApplication>? discountApplications, String? email, String? financialStatus, List<ShopifySharpFulfillment>? fulfillments, String? fulfillmentStatus, String? phone, String? tags, String? landingSite, List<ShopifySharpLineItem>? lineItems, int? locationId, String? name, String? note, List<ShopifySharpNoteAttribute>? noteAttributes, int? number, int? orderNumber, String? orderStatusUrl, List<String>? paymentGatewayNames, DateTime? processedAt, String? processingMethod, String? referringSite, List<ShopifySharpRefund>? refunds, ShopifySharpAddress? shippingAddress, List<ShopifySharpShippingLine>? shippingLines, String? sourceIdentifier, String? sourceName, double? subtotalPrice, List<ShopifySharpTaxLine>? taxLines, bool? taxesIncluded, bool? test, String? token, double? totalDiscounts, double? totalLineItemsPrice, double? totalTipReceived, double? totalPrice, double? totalTax, int? totalWeight, DateTime? updatedAt, int? userId, List<ShopifySharpTransaction>? transactions, List<ShopifySharpMetaField>? metafields, ShopifySharpPriceSet? currentTotalDutiesSet, ShopifySharpPriceSet? originalTotalDutiesSet, String? presentmentCurrency, ShopifySharpPriceSet? totalLineItemsPriceSet, ShopifySharpPriceSet? totalDiscountsSet, ShopifySharpPriceSet? totalShippingPriceSet, ShopifySharpPriceSet? subtotalPriceSet, ShopifySharpPriceSet? totalPriceSet, String? totalOutstanding, ShopifySharpPriceSet? totalTaxSet, bool? estimatedTaxes, double? currentSubtotalPrice, ShopifySharpPriceSet? currentSubtotalPriceSet, double? currentTotalDiscounts, ShopifySharpPriceSet? currentTotalDiscountsSet, double? currentTotalPrice, ShopifySharpPriceSet? currentTotalPriceSet, double? currentTotalTax, ShopifySharpPriceSet? currentTotalTaxSet, ShopifySharpPaymentTerms? paymentTerms, ShopifySharpPriceSet? currentTotalAdditionalFeesSet, ShopifySharpPriceSet? originalTotalAdditionalFeesSet, String? poNumber, bool? taxExempt, ShopifySharpOrderCompany? company, int? id, String? adminGraphqlApiId})
const
ShopifySharpOrder.fromJson(Map<String, dynamic> json)
factory

Properties

adminGraphqlApiId String?
final
appId int?
final
billingAddress ShopifySharpAddress?
final
browserIp String?
final
buyerAcceptsMarketing bool?
final
cancelledAt DateTime?
final
cancelReason String?
final
cartToken String?
final
checkoutId int?
final
checkoutToken String?
final
clientDetails ShopifySharpClientDetails?
final
closedAt DateTime?
final
company ShopifySharpOrderCompany?
final
confirmed bool?
final
createdAt DateTime?
final
currency String?
final
currentSubtotalPrice double?
final
currentSubtotalPriceSet ShopifySharpPriceSet?
final
currentTotalAdditionalFeesSet ShopifySharpPriceSet?
final
currentTotalDiscounts double?
final
currentTotalDiscountsSet ShopifySharpPriceSet?
final
currentTotalDutiesSet ShopifySharpPriceSet?
final
currentTotalPrice double?
final
currentTotalPriceSet ShopifySharpPriceSet?
final
currentTotalTax double?
final
currentTotalTaxSet ShopifySharpPriceSet?
final
customer ShopifySharpCustomer?
final
customerLocale String?
final
deviceId int?
final
discountApplications List<ShopifySharpDiscountApplication>?
final
discountCodes List<ShopifySharpDiscountCode>?
final
email String?
final
estimatedTaxes bool?
final
financialStatus String?
final
fulfillments List<ShopifySharpFulfillment>?
final
fulfillmentStatus String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
landingSite String?
final
lineItems List<ShopifySharpLineItem>?
final
locationId int?
final
metafields List<ShopifySharpMetaField>?
final
name String?
final
note String?
final
noteAttributes List<ShopifySharpNoteAttribute>?
final
number int?
final
orderNumber int?
final
orderStatusUrl String?
final
originalTotalAdditionalFeesSet ShopifySharpPriceSet?
final
originalTotalDutiesSet ShopifySharpPriceSet?
final
paymentGatewayNames List<String>?
final
paymentTerms ShopifySharpPaymentTerms?
final
phone String?
final
poNumber String?
final
presentmentCurrency String?
final
processedAt DateTime?
final
processingMethod String?
final
referringSite String?
final
refunds List<ShopifySharpRefund>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress ShopifySharpAddress?
final
shippingLines List<ShopifySharpShippingLine>?
final
sourceIdentifier String?
final
sourceName String?
final
subtotalPrice double?
final
subtotalPriceSet ShopifySharpPriceSet?
final
tags String?
final
taxesIncluded bool?
final
taxExempt bool?
final
taxLines List<ShopifySharpTaxLine>?
final
test bool?
final
token String?
final
totalDiscounts double?
final
totalDiscountsSet ShopifySharpPriceSet?
final
totalLineItemsPrice double?
final
totalLineItemsPriceSet ShopifySharpPriceSet?
final
totalOutstanding String?
final
totalPrice double?
final
totalPriceSet ShopifySharpPriceSet?
final
totalShippingPriceSet ShopifySharpPriceSet?
final
totalTax double?
final
totalTaxSet ShopifySharpPriceSet?
final
totalTipReceived double?
final
totalWeight int?
final
transactions List<ShopifySharpTransaction>?
final
updatedAt DateTime?
final
userId int?
final

Methods

copyWith({int? appId, ShopifySharpAddress? billingAddress, String? browserIp, bool? buyerAcceptsMarketing, String? cancelReason, DateTime? cancelledAt, String? cartToken, String? checkoutToken, int? checkoutId, ShopifySharpClientDetails? clientDetails, DateTime? closedAt, bool? confirmed, DateTime? createdAt, String? currency, ShopifySharpCustomer? customer, String? customerLocale, int? deviceId, List<ShopifySharpDiscountCode>? discountCodes, List<ShopifySharpDiscountApplication>? discountApplications, String? email, String? financialStatus, List<ShopifySharpFulfillment>? fulfillments, String? fulfillmentStatus, String? phone, String? tags, String? landingSite, List<ShopifySharpLineItem>? lineItems, int? locationId, String? name, String? note, List<ShopifySharpNoteAttribute>? noteAttributes, int? number, int? orderNumber, String? orderStatusUrl, List<String>? paymentGatewayNames, DateTime? processedAt, String? processingMethod, String? referringSite, List<ShopifySharpRefund>? refunds, ShopifySharpAddress? shippingAddress, List<ShopifySharpShippingLine>? shippingLines, String? sourceIdentifier, String? sourceName, double? subtotalPrice, List<ShopifySharpTaxLine>? taxLines, bool? taxesIncluded, bool? test, String? token, double? totalDiscounts, double? totalLineItemsPrice, double? totalTipReceived, double? totalPrice, double? totalTax, int? totalWeight, DateTime? updatedAt, int? userId, List<ShopifySharpTransaction>? transactions, List<ShopifySharpMetaField>? metafields, ShopifySharpPriceSet? currentTotalDutiesSet, ShopifySharpPriceSet? originalTotalDutiesSet, String? presentmentCurrency, ShopifySharpPriceSet? totalLineItemsPriceSet, ShopifySharpPriceSet? totalDiscountsSet, ShopifySharpPriceSet? totalShippingPriceSet, ShopifySharpPriceSet? subtotalPriceSet, ShopifySharpPriceSet? totalPriceSet, String? totalOutstanding, ShopifySharpPriceSet? totalTaxSet, bool? estimatedTaxes, double? currentSubtotalPrice, ShopifySharpPriceSet? currentSubtotalPriceSet, double? currentTotalDiscounts, ShopifySharpPriceSet? currentTotalDiscountsSet, double? currentTotalPrice, ShopifySharpPriceSet? currentTotalPriceSet, double? currentTotalTax, ShopifySharpPriceSet? currentTotalTaxSet, ShopifySharpPaymentTerms? paymentTerms, ShopifySharpPriceSet? currentTotalAdditionalFeesSet, ShopifySharpPriceSet? originalTotalAdditionalFeesSet, String? poNumber, bool? taxExempt, ShopifySharpOrderCompany? company, int? id, String? adminGraphqlApiId}) ShopifySharpOrder

Available on ShopifySharpOrder, provided by the $ShopifySharpOrderExtension extension

copyWithWrapped({Wrapped<int?>? appId, Wrapped<ShopifySharpAddress?>? billingAddress, Wrapped<String?>? browserIp, Wrapped<bool?>? buyerAcceptsMarketing, Wrapped<String?>? cancelReason, Wrapped<DateTime?>? cancelledAt, Wrapped<String?>? cartToken, Wrapped<String?>? checkoutToken, Wrapped<int?>? checkoutId, Wrapped<ShopifySharpClientDetails?>? clientDetails, Wrapped<DateTime?>? closedAt, Wrapped<bool?>? confirmed, Wrapped<DateTime?>? createdAt, Wrapped<String?>? currency, Wrapped<ShopifySharpCustomer?>? customer, Wrapped<String?>? customerLocale, Wrapped<int?>? deviceId, Wrapped<List<ShopifySharpDiscountCode>?>? discountCodes, Wrapped<List<ShopifySharpDiscountApplication>?>? discountApplications, Wrapped<String?>? email, Wrapped<String?>? financialStatus, Wrapped<List<ShopifySharpFulfillment>?>? fulfillments, Wrapped<String?>? fulfillmentStatus, Wrapped<String?>? phone, Wrapped<String?>? tags, Wrapped<String?>? landingSite, Wrapped<List<ShopifySharpLineItem>?>? lineItems, Wrapped<int?>? locationId, Wrapped<String?>? name, Wrapped<String?>? note, Wrapped<List<ShopifySharpNoteAttribute>?>? noteAttributes, Wrapped<int?>? number, Wrapped<int?>? orderNumber, Wrapped<String?>? orderStatusUrl, Wrapped<List<String>?>? paymentGatewayNames, Wrapped<DateTime?>? processedAt, Wrapped<String?>? processingMethod, Wrapped<String?>? referringSite, Wrapped<List<ShopifySharpRefund>?>? refunds, Wrapped<ShopifySharpAddress?>? shippingAddress, Wrapped<List<ShopifySharpShippingLine>?>? shippingLines, Wrapped<String?>? sourceIdentifier, Wrapped<String?>? sourceName, Wrapped<double?>? subtotalPrice, Wrapped<List<ShopifySharpTaxLine>?>? taxLines, Wrapped<bool?>? taxesIncluded, Wrapped<bool?>? test, Wrapped<String?>? token, Wrapped<double?>? totalDiscounts, Wrapped<double?>? totalLineItemsPrice, Wrapped<double?>? totalTipReceived, Wrapped<double?>? totalPrice, Wrapped<double?>? totalTax, Wrapped<int?>? totalWeight, Wrapped<DateTime?>? updatedAt, Wrapped<int?>? userId, Wrapped<List<ShopifySharpTransaction>?>? transactions, Wrapped<List<ShopifySharpMetaField>?>? metafields, Wrapped<ShopifySharpPriceSet?>? currentTotalDutiesSet, Wrapped<ShopifySharpPriceSet?>? originalTotalDutiesSet, Wrapped<String?>? presentmentCurrency, Wrapped<ShopifySharpPriceSet?>? totalLineItemsPriceSet, Wrapped<ShopifySharpPriceSet?>? totalDiscountsSet, Wrapped<ShopifySharpPriceSet?>? totalShippingPriceSet, Wrapped<ShopifySharpPriceSet?>? subtotalPriceSet, Wrapped<ShopifySharpPriceSet?>? totalPriceSet, Wrapped<String?>? totalOutstanding, Wrapped<ShopifySharpPriceSet?>? totalTaxSet, Wrapped<bool?>? estimatedTaxes, Wrapped<double?>? currentSubtotalPrice, Wrapped<ShopifySharpPriceSet?>? currentSubtotalPriceSet, Wrapped<double?>? currentTotalDiscounts, Wrapped<ShopifySharpPriceSet?>? currentTotalDiscountsSet, Wrapped<double?>? currentTotalPrice, Wrapped<ShopifySharpPriceSet?>? currentTotalPriceSet, Wrapped<double?>? currentTotalTax, Wrapped<ShopifySharpPriceSet?>? currentTotalTaxSet, Wrapped<ShopifySharpPaymentTerms?>? paymentTerms, Wrapped<ShopifySharpPriceSet?>? currentTotalAdditionalFeesSet, Wrapped<ShopifySharpPriceSet?>? originalTotalAdditionalFeesSet, Wrapped<String?>? poNumber, Wrapped<bool?>? taxExempt, Wrapped<ShopifySharpOrderCompany?>? company, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpOrder

Available on ShopifySharpOrder, provided by the $ShopifySharpOrderExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpOrder Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpOrder instance)