ShopifySharpPaymentDetails class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpPaymentDetails({String? avsResultCode, String? creditCardBin, String? cvvResultCode, String? creditCardNumber, String? creditCardCompany, String? creditCardName, String? creditCardWallet, int? creditCardExpirationMonth, int? creditCardExpirationYear, String? paymentMethodName, dynamic buyerActionInfo})
-
const
-
ShopifySharpPaymentDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- avsResultCode → String?
-
final
- buyerActionInfo → dynamic
-
final
- creditCardBin → String?
-
final
- creditCardCompany → String?
-
final
- creditCardExpirationMonth → int?
-
final
- creditCardExpirationYear → int?
-
final
- creditCardName → String?
-
final
- creditCardNumber → String?
-
final
- creditCardWallet → String?
-
final
- cvvResultCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- paymentMethodName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? avsResultCode, String? creditCardBin, String? cvvResultCode, String? creditCardNumber, String? creditCardCompany, String? creditCardName, String? creditCardWallet, int? creditCardExpirationMonth, int? creditCardExpirationYear, String? paymentMethodName, dynamic buyerActionInfo}) → ShopifySharpPaymentDetails -
Available on ShopifySharpPaymentDetails, provided by the $ShopifySharpPaymentDetailsExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? avsResultCode, Wrapped<String?> ? creditCardBin, Wrapped<String?> ? cvvResultCode, Wrapped<String?> ? creditCardNumber, Wrapped<String?> ? creditCardCompany, Wrapped<String?> ? creditCardName, Wrapped<String?> ? creditCardWallet, Wrapped<int?> ? creditCardExpirationMonth, Wrapped<int?> ? creditCardExpirationYear, Wrapped<String?> ? paymentMethodName, Wrapped? buyerActionInfo}) → ShopifySharpPaymentDetails -
Available on ShopifySharpPaymentDetails, provided by the $ShopifySharpPaymentDetailsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpPaymentDetails Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpPaymentDetails instance)