ShopifySharpPaymentSchedule class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpPaymentSchedule({double? amount, String? currency, DateTime? issuedAt, DateTime? dueAt, DateTime? completedAt, String? expectedPaymentMethod})
const
ShopifySharpPaymentSchedule.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
completedAt DateTime?
final
currency String?
final
dueAt DateTime?
final
expectedPaymentMethod String?
final
hashCode int
The hash code for this object.
no setteroverride
issuedAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? amount, String? currency, DateTime? issuedAt, DateTime? dueAt, DateTime? completedAt, String? expectedPaymentMethod}) ShopifySharpPaymentSchedule

Available on ShopifySharpPaymentSchedule, provided by the $ShopifySharpPaymentScheduleExtension extension

copyWithWrapped({Wrapped<double?>? amount, Wrapped<String?>? currency, Wrapped<DateTime?>? issuedAt, Wrapped<DateTime?>? dueAt, Wrapped<DateTime?>? completedAt, Wrapped<String?>? expectedPaymentMethod}) ShopifySharpPaymentSchedule

Available on ShopifySharpPaymentSchedule, provided by the $ShopifySharpPaymentScheduleExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpPaymentSchedule Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpPaymentSchedule instance)