ShopifySharpPaymentTerms class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpPaymentTerms({double? amount, String? currency, int? dueInDays, String? paymentTermsName, String? paymentTermsType, List<ShopifySharpPaymentSchedule>? paymentSchedules})
const
ShopifySharpPaymentTerms.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
currency String?
final
dueInDays int?
final
hashCode int
The hash code for this object.
no setteroverride
paymentSchedules List<ShopifySharpPaymentSchedule>?
final
paymentTermsName String?
final
paymentTermsType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? amount, String? currency, int? dueInDays, String? paymentTermsName, String? paymentTermsType, List<ShopifySharpPaymentSchedule>? paymentSchedules}) ShopifySharpPaymentTerms

Available on ShopifySharpPaymentTerms, provided by the $ShopifySharpPaymentTermsExtension extension

copyWithWrapped({Wrapped<double?>? amount, Wrapped<String?>? currency, Wrapped<int?>? dueInDays, Wrapped<String?>? paymentTermsName, Wrapped<String?>? paymentTermsType, Wrapped<List<ShopifySharpPaymentSchedule>?>? paymentSchedules}) ShopifySharpPaymentTerms

Available on ShopifySharpPaymentTerms, provided by the $ShopifySharpPaymentTermsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpPaymentTerms Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpPaymentTerms instance)