ShopifySharpPaymentsRefundAttributes class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpPaymentsRefundAttributes({String? status, String? acquirerReferenceNumber})
const
ShopifySharpPaymentsRefundAttributes.fromJson(Map<String, dynamic> json)
factory

Properties

acquirerReferenceNumber String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

copyWith({String? status, String? acquirerReferenceNumber}) ShopifySharpPaymentsRefundAttributes

Available on ShopifySharpPaymentsRefundAttributes, provided by the $ShopifySharpPaymentsRefundAttributesExtension extension

copyWithWrapped({Wrapped<String?>? status, Wrapped<String?>? acquirerReferenceNumber}) ShopifySharpPaymentsRefundAttributes

Available on ShopifySharpPaymentsRefundAttributes, provided by the $ShopifySharpPaymentsRefundAttributesExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpPaymentsRefundAttributes Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpPaymentsRefundAttributes instance)