ShopifySharpPriceSet class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpPriceSet({ShopifySharpPrice? shopMoney, ShopifySharpPrice? presentmentMoney})
const
ShopifySharpPriceSet.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
presentmentMoney ShopifySharpPrice?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shopMoney ShopifySharpPrice?
final

Methods

copyWith({ShopifySharpPrice? shopMoney, ShopifySharpPrice? presentmentMoney}) ShopifySharpPriceSet

Available on ShopifySharpPriceSet, provided by the $ShopifySharpPriceSetExtension extension

copyWithWrapped({Wrapped<ShopifySharpPrice?>? shopMoney, Wrapped<ShopifySharpPrice?>? presentmentMoney}) ShopifySharpPriceSet

Available on ShopifySharpPriceSet, provided by the $ShopifySharpPriceSetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpPriceSet Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpPriceSet instance)