ShopifySharpRefund class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ShopifySharpRefund({int? orderId, DateTime? createdAt, bool? notify, ShopifySharpShipping? shipping, String? currency, List<
ShopifySharpRefundOrderAdjustment> ? orderAdjustments, DateTime? processedAt, String? note, String? discrepancyReason, List<ShopifySharpRefundLineItem> ? refundLineItems, List<ShopifySharpTransaction> ? transactions, int? userId, List<ShopifySharpRefundDuty> ? duties, List<ShopifySharpRefundDutyType> ? refundDuties, ShopifySharpEntitiesReturn? $return, int? id, String? adminGraphqlApiId}) -
const
-
ShopifySharpRefund.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $return → ShopifySharpEntitiesReturn?
-
final
- adminGraphqlApiId → String?
-
final
- createdAt → DateTime?
-
final
- currency → String?
-
final
- discrepancyReason → String?
-
final
-
duties
→ List<
ShopifySharpRefundDuty> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- note → String?
-
final
- notify → bool?
-
final
-
orderAdjustments
→ List<
ShopifySharpRefundOrderAdjustment> ? -
final
- orderId → int?
-
final
- processedAt → DateTime?
-
final
-
refundDuties
→ List<
ShopifySharpRefundDutyType> ? -
final
-
refundLineItems
→ List<
ShopifySharpRefundLineItem> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shipping → ShopifySharpShipping?
-
final
-
transactions
→ List<
ShopifySharpTransaction> ? -
final
- userId → int?
-
final
Methods
-
copyWith(
{int? orderId, DateTime? createdAt, bool? notify, ShopifySharpShipping? shipping, String? currency, List< ShopifySharpRefundOrderAdjustment> ? orderAdjustments, DateTime? processedAt, String? note, String? discrepancyReason, List<ShopifySharpRefundLineItem> ? refundLineItems, List<ShopifySharpTransaction> ? transactions, int? userId, List<ShopifySharpRefundDuty> ? duties, List<ShopifySharpRefundDutyType> ? refundDuties, ShopifySharpEntitiesReturn? $return, int? id, String? adminGraphqlApiId}) → ShopifySharpRefund -
Available on ShopifySharpRefund, provided by the $ShopifySharpRefundExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? orderId, Wrapped<DateTime?> ? createdAt, Wrapped<bool?> ? notify, Wrapped<ShopifySharpShipping?> ? shipping, Wrapped<String?> ? currency, Wrapped<List< ? orderAdjustments, Wrapped<ShopifySharpRefundOrderAdjustment> ?>DateTime?> ? processedAt, Wrapped<String?> ? note, Wrapped<String?> ? discrepancyReason, Wrapped<List< ? refundLineItems, Wrapped<ShopifySharpRefundLineItem> ?>List< ? transactions, Wrapped<ShopifySharpTransaction> ?>int?> ? userId, Wrapped<List< ? duties, Wrapped<ShopifySharpRefundDuty> ?>List< ? refundDuties, Wrapped<ShopifySharpRefundDutyType> ?>ShopifySharpEntitiesReturn?> ? $return, Wrapped<int?> ? id, Wrapped<String?> ? adminGraphqlApiId}) → ShopifySharpRefund -
Available on ShopifySharpRefund, provided by the $ShopifySharpRefundExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpRefund Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpRefund instance)