ShopifySharpRefundDuty class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpRefundDuty({int? dutyId, ShopifySharpPriceSet? amountSet})
-
const
-
ShopifySharpRefundDuty.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amountSet → ShopifySharpPriceSet?
-
final
- dutyId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? dutyId, ShopifySharpPriceSet? amountSet}) → ShopifySharpRefundDuty -
Available on ShopifySharpRefundDuty, provided by the $ShopifySharpRefundDutyExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? dutyId, Wrapped<ShopifySharpPriceSet?> ? amountSet}) → ShopifySharpRefundDuty -
Available on ShopifySharpRefundDuty, provided by the $ShopifySharpRefundDutyExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpRefundDuty Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpRefundDuty instance)