ShopifySharpRefundOrderAdjustment class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpRefundOrderAdjustment({int? orderId, int? refundId, double? amount, double? taxAmount, String? kind, String? reason, ShopifySharpPriceSet? amountSet, ShopifySharpPriceSet? taxAmountSet, int? id, String? adminGraphqlApiId})
-
const
-
ShopifySharpRefundOrderAdjustment.fromJson(Map<
String, dynamic> json) -
factory
Properties
- adminGraphqlApiId → String?
-
final
- amount → double?
-
final
- amountSet → ShopifySharpPriceSet?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- kind → String?
-
final
- orderId → int?
-
final
- reason → String?
-
final
- refundId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxAmount → double?
-
final
- taxAmountSet → ShopifySharpPriceSet?
-
final
Methods
-
copyWith(
{int? orderId, int? refundId, double? amount, double? taxAmount, String? kind, String? reason, ShopifySharpPriceSet? amountSet, ShopifySharpPriceSet? taxAmountSet, int? id, String? adminGraphqlApiId}) → ShopifySharpRefundOrderAdjustment -
Available on ShopifySharpRefundOrderAdjustment, provided by the $ShopifySharpRefundOrderAdjustmentExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? orderId, Wrapped<int?> ? refundId, Wrapped<double?> ? amount, Wrapped<double?> ? taxAmount, Wrapped<String?> ? kind, Wrapped<String?> ? reason, Wrapped<ShopifySharpPriceSet?> ? amountSet, Wrapped<ShopifySharpPriceSet?> ? taxAmountSet, Wrapped<int?> ? id, Wrapped<String?> ? adminGraphqlApiId}) → ShopifySharpRefundOrderAdjustment -
Available on ShopifySharpRefundOrderAdjustment, provided by the $ShopifySharpRefundOrderAdjustmentExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpRefundOrderAdjustment Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpRefundOrderAdjustment instance)