ShopifySharpShipping class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpShipping({bool? fullRefund, double? amount, double? maximumRefundable})
const
ShopifySharpShipping.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
fullRefund bool?
final
hashCode int
The hash code for this object.
no setteroverride
maximumRefundable double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? fullRefund, double? amount, double? maximumRefundable}) ShopifySharpShipping

Available on ShopifySharpShipping, provided by the $ShopifySharpShippingExtension extension

copyWithWrapped({Wrapped<bool?>? fullRefund, Wrapped<double?>? amount, Wrapped<double?>? maximumRefundable}) ShopifySharpShipping

Available on ShopifySharpShipping, provided by the $ShopifySharpShippingExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpShipping Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpShipping instance)