ShopifySharpTaxLine class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpTaxLine({double? price, double? rate, String? title, ShopifySharpPriceSet? priceSet})
const
ShopifySharpTaxLine.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
price double?
final
priceSet ShopifySharpPriceSet?
final
rate double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

copyWith({double? price, double? rate, String? title, ShopifySharpPriceSet? priceSet}) ShopifySharpTaxLine

Available on ShopifySharpTaxLine, provided by the $ShopifySharpTaxLineExtension extension

copyWithWrapped({Wrapped<double?>? price, Wrapped<double?>? rate, Wrapped<String?>? title, Wrapped<ShopifySharpPriceSet?>? priceSet}) ShopifySharpTaxLine

Available on ShopifySharpTaxLine, provided by the $ShopifySharpTaxLineExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpTaxLine Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpTaxLine instance)