ShopifySharpTransaction class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpTransaction({double? amount, String? authorization, DateTime? authorizationExpiresAt, DateTime? createdAt, int? deviceId, String? gateway, String? sourceName, String? source, ShopifySharpPaymentDetails? paymentDetails, String? kind, int? orderId, dynamic receipt, String? errorCode, String? status, bool? test, int? userId, String? currency, String? message, int? locationId, int? parentId, DateTime? processedAt, double? maximumRefundable, ShopifySharpCurrencyExchangeAdjustment? currencyExchangeAdjustment, ShopifySharpPaymentsRefundAttributes? paymentsRefundAttributes, String? paymentId, ShopifySharpPriceSet? totalUnsettledSet, int? id, String? adminGraphqlApiId})
-
const
-
ShopifySharpTransaction.fromJson(Map<
String, dynamic> json) -
factory
Properties
- adminGraphqlApiId → String?
-
final
- amount → double?
-
final
-
final
-
final
- createdAt → DateTime?
-
final
- currency → String?
-
final
- currencyExchangeAdjustment → ShopifySharpCurrencyExchangeAdjustment?
-
final
- deviceId → int?
-
final
- errorCode → String?
-
final
- gateway → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- kind → String?
-
final
- locationId → int?
-
final
- maximumRefundable → double?
-
final
- message → String?
-
final
- orderId → int?
-
final
- parentId → int?
-
final
- paymentDetails → ShopifySharpPaymentDetails?
-
final
- paymentId → String?
-
final
- paymentsRefundAttributes → ShopifySharpPaymentsRefundAttributes?
-
final
- processedAt → DateTime?
-
final
- receipt → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
final
- sourceName → String?
-
final
- status → String?
-
final
- test → bool?
-
final
- totalUnsettledSet → ShopifySharpPriceSet?
-
final
- userId → int?
-
final
Methods
-
copyWith(
{double? amount, String? authorization, DateTime? authorizationExpiresAt, DateTime? createdAt, int? deviceId, String? gateway, String? sourceName, String? source, ShopifySharpPaymentDetails? paymentDetails, String? kind, int? orderId, dynamic receipt, String? errorCode, String? status, bool? test, int? userId, String? currency, String? message, int? locationId, int? parentId, DateTime? processedAt, double? maximumRefundable, ShopifySharpCurrencyExchangeAdjustment? currencyExchangeAdjustment, ShopifySharpPaymentsRefundAttributes? paymentsRefundAttributes, String? paymentId, ShopifySharpPriceSet? totalUnsettledSet, int? id, String? adminGraphqlApiId}) → ShopifySharpTransaction -
Available on ShopifySharpTransaction, provided by the $ShopifySharpTransactionExtension extension
-
copyWithWrapped(
{Wrapped< double?> ? amount, Wrapped<String?> ? authorization, Wrapped<DateTime?> ? authorizationExpiresAt, Wrapped<DateTime?> ? createdAt, Wrapped<int?> ? deviceId, Wrapped<String?> ? gateway, Wrapped<String?> ? sourceName, Wrapped<String?> ? source, Wrapped<ShopifySharpPaymentDetails?> ? paymentDetails, Wrapped<String?> ? kind, Wrapped<int?> ? orderId, Wrapped? receipt, Wrapped<String?> ? errorCode, Wrapped<String?> ? status, Wrapped<bool?> ? test, Wrapped<int?> ? userId, Wrapped<String?> ? currency, Wrapped<String?> ? message, Wrapped<int?> ? locationId, Wrapped<int?> ? parentId, Wrapped<DateTime?> ? processedAt, Wrapped<double?> ? maximumRefundable, Wrapped<ShopifySharpCurrencyExchangeAdjustment?> ? currencyExchangeAdjustment, Wrapped<ShopifySharpPaymentsRefundAttributes?> ? paymentsRefundAttributes, Wrapped<String?> ? paymentId, Wrapped<ShopifySharpPriceSet?> ? totalUnsettledSet, Wrapped<int?> ? id, Wrapped<String?> ? adminGraphqlApiId}) → ShopifySharpTransaction -
Available on ShopifySharpTransaction, provided by the $ShopifySharpTransactionExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpTransaction Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpTransaction instance)