StorefrontPackageItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

StorefrontPackageItem({List<WebApiModulesIntegrationsStorefrontProductImage>? images, int? productId, String? inventoryPackageInventoryId, String? iCode, String? description, String? inventoryId, bool? isPrimary, double? defaultQuantity, String? defaultQuantityColor, bool? isOption, bool? charge, bool? noChargePrint, bool? isRequired, String? optionColor, String? itemClass, String? itemTrackedBy, String? availFor, String? availFrom, double? orderBy, String? itemColor, String? isNestedComplete, String? inactive, String? warehouseId, String? parentId, String? packageItemClass, String? itemNonDiscountable, String? primaryInventoryId, String? unitId, String? packageId, WebApiModulesIntegrationsStorefrontProductAvailability? availability, double? dailyRate, double? weeklyRate, double? monthlyRate, double? dailyExtended, double? weeklyExtended, double? monthlyExtended, double? salesPrice, double? retail, String? currencyId, String? currencyCode, String? currencySymbol, String? dateStamp})
const
StorefrontPackageItem.fromJson(Map<String, dynamic> json)
factory

Properties

availability WebApiModulesIntegrationsStorefrontProductAvailability?
final
availFor String?
final
availFrom String?
final
charge bool?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
dailyExtended double?
final
dailyRate double?
final
dateStamp String?
final
defaultQuantity double?
final
defaultQuantityColor String?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
iCode String?
final
images List<WebApiModulesIntegrationsStorefrontProductImage>?
final
inactive String?
final
inventoryId String?
final
inventoryPackageInventoryId String?
final
isNestedComplete String?
final
isOption bool?
final
isPrimary bool?
final
isRequired bool?
final
itemClass String?
final
itemColor String?
final
itemNonDiscountable String?
final
itemTrackedBy String?
final
monthlyExtended double?
final
monthlyRate double?
final
noChargePrint bool?
final
optionColor String?
final
orderBy double?
final
packageId String?
final
packageItemClass String?
final
parentId String?
final
primaryInventoryId String?
final
productId int?
final
retail double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesPrice double?
final
unitId String?
final
warehouseId String?
final
weeklyExtended double?
final
weeklyRate double?
final

Methods

copyWith({List<WebApiModulesIntegrationsStorefrontProductImage>? images, int? productId, String? inventoryPackageInventoryId, String? iCode, String? description, String? inventoryId, bool? isPrimary, double? defaultQuantity, String? defaultQuantityColor, bool? isOption, bool? charge, bool? noChargePrint, bool? isRequired, String? optionColor, String? itemClass, String? itemTrackedBy, String? availFor, String? availFrom, double? orderBy, String? itemColor, String? isNestedComplete, String? inactive, String? warehouseId, String? parentId, String? packageItemClass, String? itemNonDiscountable, String? primaryInventoryId, String? unitId, String? packageId, WebApiModulesIntegrationsStorefrontProductAvailability? availability, double? dailyRate, double? weeklyRate, double? monthlyRate, double? dailyExtended, double? weeklyExtended, double? monthlyExtended, double? salesPrice, double? retail, String? currencyId, String? currencyCode, String? currencySymbol, String? dateStamp}) StorefrontPackageItem

Available on StorefrontPackageItem, provided by the $StorefrontPackageItemExtension extension

copyWithWrapped({Wrapped<List<WebApiModulesIntegrationsStorefrontProductImage>?>? images, Wrapped<int?>? productId, Wrapped<String?>? inventoryPackageInventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? inventoryId, Wrapped<bool?>? isPrimary, Wrapped<double?>? defaultQuantity, Wrapped<String?>? defaultQuantityColor, Wrapped<bool?>? isOption, Wrapped<bool?>? charge, Wrapped<bool?>? noChargePrint, Wrapped<bool?>? isRequired, Wrapped<String?>? optionColor, Wrapped<String?>? itemClass, Wrapped<String?>? itemTrackedBy, Wrapped<String?>? availFor, Wrapped<String?>? availFrom, Wrapped<double?>? orderBy, Wrapped<String?>? itemColor, Wrapped<String?>? isNestedComplete, Wrapped<String?>? inactive, Wrapped<String?>? warehouseId, Wrapped<String?>? parentId, Wrapped<String?>? packageItemClass, Wrapped<String?>? itemNonDiscountable, Wrapped<String?>? primaryInventoryId, Wrapped<String?>? unitId, Wrapped<String?>? packageId, Wrapped<WebApiModulesIntegrationsStorefrontProductAvailability?>? availability, Wrapped<double?>? dailyRate, Wrapped<double?>? weeklyRate, Wrapped<double?>? monthlyRate, Wrapped<double?>? dailyExtended, Wrapped<double?>? weeklyExtended, Wrapped<double?>? monthlyExtended, Wrapped<double?>? salesPrice, Wrapped<double?>? retail, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? dateStamp}) StorefrontPackageItem

Available on StorefrontPackageItem, provided by the $StorefrontPackageItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const StorefrontPackageItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(StorefrontPackageItem instance)