WebApiModulesIntegrationsStorefrontContactRegistrationRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontContactRegistrationRequest({String? language, required String firstName, required String lastName, String? phone, required String email, String? studentId})
const
WebApiModulesIntegrationsStorefrontContactRegistrationRequest.fromJson(Map<String, dynamic> json)
factory

Properties

email String
final
firstName String
final
hashCode int
The hash code for this object.
no setteroverride
language String?
final
lastName String
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
studentId String?
final

Methods

copyWith({String? language, String? firstName, String? lastName, String? phone, String? email, String? studentId}) WebApiModulesIntegrationsStorefrontContactRegistrationRequest

Available on WebApiModulesIntegrationsStorefrontContactRegistrationRequest, provided by the $WebApiModulesIntegrationsStorefrontContactRegistrationRequestExtension extension

copyWithWrapped({Wrapped<String?>? language, Wrapped<String>? firstName, Wrapped<String>? lastName, Wrapped<String?>? phone, Wrapped<String>? email, Wrapped<String?>? studentId}) WebApiModulesIntegrationsStorefrontContactRegistrationRequest

Available on WebApiModulesIntegrationsStorefrontContactRegistrationRequest, provided by the $WebApiModulesIntegrationsStorefrontContactRegistrationRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override