WebApiModulesIntegrationsStorefrontLocationModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontLocationModel({String? locationId, String? location, String? warehouseId, String? warehouse})
const
WebApiModulesIntegrationsStorefrontLocationModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
location String?
final
locationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouse String?
final
warehouseId String?
final

Methods

copyWith({String? locationId, String? location, String? warehouseId, String? warehouse}) WebApiModulesIntegrationsStorefrontLocationModel

Available on WebApiModulesIntegrationsStorefrontLocationModel, provided by the $WebApiModulesIntegrationsStorefrontLocationModelExtension extension

copyWithWrapped({Wrapped<String?>? locationId, Wrapped<String?>? location, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse}) WebApiModulesIntegrationsStorefrontLocationModel

Available on WebApiModulesIntegrationsStorefrontLocationModel, provided by the $WebApiModulesIntegrationsStorefrontLocationModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override