WebApiModulesIntegrationsStorefrontLoginResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

authToken String?
final
fullName String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? authToken, String? fullName}) WebApiModulesIntegrationsStorefrontLoginResponse

Available on WebApiModulesIntegrationsStorefrontLoginResponse, provided by the $WebApiModulesIntegrationsStorefrontLoginResponseExtension extension

copyWithWrapped({Wrapped<String?>? authToken, Wrapped<String?>? fullName}) WebApiModulesIntegrationsStorefrontLoginResponse

Available on WebApiModulesIntegrationsStorefrontLoginResponse, provided by the $WebApiModulesIntegrationsStorefrontLoginResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override