WebApiModulesIntegrationsStorefrontProductAvailability class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total double?
final
totalIn double?
final

Methods

copyWith({double? totalIn, double? total}) WebApiModulesIntegrationsStorefrontProductAvailability

Available on WebApiModulesIntegrationsStorefrontProductAvailability, provided by the $WebApiModulesIntegrationsStorefrontProductAvailabilityExtension extension

copyWithWrapped({Wrapped<double?>? totalIn, Wrapped<double?>? total}) WebApiModulesIntegrationsStorefrontProductAvailability

Available on WebApiModulesIntegrationsStorefrontProductAvailability, provided by the $WebApiModulesIntegrationsStorefrontProductAvailabilityExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override