WebApiModulesIntegrationsStorefrontProductCategory class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesIntegrationsStorefrontProductCategory({String? id, String? name, String? urlName, String? linkUrl, List<
WebApiModulesIntegrationsStorefrontProductSubCategory> ? subCategories}) -
const
-
WebApiModulesIntegrationsStorefrontProductCategory.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String?
-
final
- linkUrl → String?
-
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subCategories
→ List<
WebApiModulesIntegrationsStorefrontProductSubCategory> ? -
final
- urlName → String?
-
final
Methods
-
copyWith(
{String? id, String? name, String? urlName, String? linkUrl, List< WebApiModulesIntegrationsStorefrontProductSubCategory> ? subCategories}) → WebApiModulesIntegrationsStorefrontProductCategory -
Available on WebApiModulesIntegrationsStorefrontProductCategory, provided by the $WebApiModulesIntegrationsStorefrontProductCategoryExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? id, Wrapped<String?> ? name, Wrapped<String?> ? urlName, Wrapped<String?> ? linkUrl, Wrapped<List< ? subCategories}) → WebApiModulesIntegrationsStorefrontProductCategoryWebApiModulesIntegrationsStorefrontProductSubCategory> ?> -
Available on WebApiModulesIntegrationsStorefrontProductCategory, provided by the $WebApiModulesIntegrationsStorefrontProductCategoryExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontProductCategory Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontProductCategory instance)