WebApiModulesIntegrationsStorefrontProductImage class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

copyWith({String? id, String? url}) WebApiModulesIntegrationsStorefrontProductImage

Available on WebApiModulesIntegrationsStorefrontProductImage, provided by the $WebApiModulesIntegrationsStorefrontProductImageExtension extension

copyWithWrapped({Wrapped<String?>? id, Wrapped<String?>? url}) WebApiModulesIntegrationsStorefrontProductImage

Available on WebApiModulesIntegrationsStorefrontProductImage, provided by the $WebApiModulesIntegrationsStorefrontProductImageExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override