WebApiModulesIntegrationsStorefrontQuoteRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontQuoteRequest({String? webCatalogId, String? language, required String departmentId, required String locationId, required String warehouseId, String? dealId, String? quoteDescription, String? jobName, required String startDate, required String stopDate, String? notes, required List<WebApiModulesIntegrationsStorefrontQuoteRequestItem> items})
const
WebApiModulesIntegrationsStorefrontQuoteRequest.fromJson(Map<String, dynamic> json)
factory

Properties

dealId String?
final
departmentId String
final
hashCode int
The hash code for this object.
no setteroverride
items List<WebApiModulesIntegrationsStorefrontQuoteRequestItem>
final
jobName String?
final
language String?
final
locationId String
final
notes String?
final
quoteDescription String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate String
final
stopDate String
final
warehouseId String
final
webCatalogId String?
final

Methods

copyWith({String? webCatalogId, String? language, String? departmentId, String? locationId, String? warehouseId, String? dealId, String? quoteDescription, String? jobName, String? startDate, String? stopDate, String? notes, List<WebApiModulesIntegrationsStorefrontQuoteRequestItem>? items}) WebApiModulesIntegrationsStorefrontQuoteRequest

Available on WebApiModulesIntegrationsStorefrontQuoteRequest, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestExtension extension

copyWithWrapped({Wrapped<String?>? webCatalogId, Wrapped<String?>? language, Wrapped<String>? departmentId, Wrapped<String>? locationId, Wrapped<String>? warehouseId, Wrapped<String?>? dealId, Wrapped<String?>? quoteDescription, Wrapped<String?>? jobName, Wrapped<String>? startDate, Wrapped<String>? stopDate, Wrapped<String?>? notes, Wrapped<List<WebApiModulesIntegrationsStorefrontQuoteRequestItem>>? items}) WebApiModulesIntegrationsStorefrontQuoteRequest

Available on WebApiModulesIntegrationsStorefrontQuoteRequest, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override