WebApiModulesIntegrationsStorefrontQuoteRequestItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
inventoryId String
final
packageItems List<WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem>?
final
qty double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webCatalogId String
final

Methods

copyWith({String? inventoryId, String? webCatalogId, double? qty, List<WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem>? packageItems}) WebApiModulesIntegrationsStorefrontQuoteRequestItem

Available on WebApiModulesIntegrationsStorefrontQuoteRequestItem, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestItemExtension extension

copyWithWrapped({Wrapped<String>? inventoryId, Wrapped<String>? webCatalogId, Wrapped<double>? qty, Wrapped<List<WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem>?>? packageItems}) WebApiModulesIntegrationsStorefrontQuoteRequestItem

Available on WebApiModulesIntegrationsStorefrontQuoteRequestItem, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override