WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem({required String inventoryId, required String inventoryPackageInventoryId, required double qty})
const
WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
inventoryId String
final
inventoryPackageInventoryId String
final
qty double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inventoryId, String? inventoryPackageInventoryId, double? qty}) WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem

Available on WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestPackageItemExtension extension

copyWithWrapped({Wrapped<String>? inventoryId, Wrapped<String>? inventoryPackageInventoryId, Wrapped<double>? qty}) WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem

Available on WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestPackageItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override