WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequest({required String email, required String temporaryPassword, required String newPassword})
const
WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequest.fromJson(Map<String, dynamic> json)
factory

Properties

email String
final
hashCode int
The hash code for this object.
no setteroverride
newPassword String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporaryPassword String
final

Methods

copyWith({String? email, String? temporaryPassword, String? newPassword}) WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequest

Available on WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequest, provided by the $WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequestExtension extension

copyWithWrapped({Wrapped<String>? email, Wrapped<String>? temporaryPassword, Wrapped<String>? newPassword}) WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequest

Available on WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequest, provided by the $WebApiModulesIntegrationsStorefrontResetPasswordFromEmailRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override