WebApiModulesIntegrationsStorefrontSendInquiryEmailRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontSendInquiryEmailRequest({required String catalogProductId, required String warehouseId, required String locationId, required String firstName, required String lastName, required String phone, required String email, required String message})
const
WebApiModulesIntegrationsStorefrontSendInquiryEmailRequest.fromJson(Map<String, dynamic> json)
factory

Properties

catalogProductId String
final
email String
final
firstName String
final
hashCode int
The hash code for this object.
no setteroverride
lastName String
final
locationId String
final
message String
final
phone String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouseId String
final

Methods

copyWith({String? catalogProductId, String? warehouseId, String? locationId, String? firstName, String? lastName, String? phone, String? email, String? message}) WebApiModulesIntegrationsStorefrontSendInquiryEmailRequest

Available on WebApiModulesIntegrationsStorefrontSendInquiryEmailRequest, provided by the $WebApiModulesIntegrationsStorefrontSendInquiryEmailRequestExtension extension

copyWithWrapped({Wrapped<String>? catalogProductId, Wrapped<String>? warehouseId, Wrapped<String>? locationId, Wrapped<String>? firstName, Wrapped<String>? lastName, Wrapped<String>? phone, Wrapped<String>? email, Wrapped<String>? message}) WebApiModulesIntegrationsStorefrontSendInquiryEmailRequest

Available on WebApiModulesIntegrationsStorefrontSendInquiryEmailRequest, provided by the $WebApiModulesIntegrationsStorefrontSendInquiryEmailRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override