WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse({bool? success, String? failureMessage})
-
const
-
WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- failureMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool?
-
final
Methods
-
copyWith(
{bool? success, String? failureMessage}) → WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse -
Available on WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse, provided by the $WebApiModulesIntegrationsStorefrontSendInquiryEmailResponseExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? success, Wrapped<String?> ? failureMessage}) → WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse -
Available on WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse, provided by the $WebApiModulesIntegrationsStorefrontSendInquiryEmailResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontSendInquiryEmailResponse instance)