WebApiModulesIntegrationsStorefrontStorefrontSettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesIntegrationsStorefrontStorefrontSettings({bool? isStorefrontEnabled, bool? isAnonymousAccessEnabled, bool? registerEnabled, bool? separateQuoteRequestsByCatalog, bool? makeQuoteRequestIntoOrderOnSubmission, bool? filterCatalogsByLocation, bool? phoneNoRequiredOnRegistrationForm, bool? isUniversity, bool? studentIdRequiredOnRegistrationForm, double? autoplaySpeed, bool? autoplayImagesOnLandingPage, bool? autoplayImagesOnProductBrowser, bool? autoplayImagesOnProductDetails, String? imagesTransitionEffect, String? imagesTransitionSpeed, bool? homepageShowHeroSection, WebApiModulesIntegrationsStorefrontStorefrontTranslatedText? homepageHeroSectionHeading1, WebApiModulesIntegrationsStorefrontStorefrontTranslatedText? homepageHeroSectionHeading2, WebApiModulesIntegrationsStorefrontStorefrontTranslatedText? homepageHeroSectionHeading3, String? homepageCatalogItemWidth, String? homepageCatalogItemHeight, bool? landingPageShowCategoryBrowser, String? landingPageCategoryBrowserItemWidth})
-
const
-
WebApiModulesIntegrationsStorefrontStorefrontSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- autoplayImagesOnLandingPage → bool?
-
final
- autoplayImagesOnProductBrowser → bool?
-
final
- autoplayImagesOnProductDetails → bool?
-
final
- autoplaySpeed → double?
-
final
- filterCatalogsByLocation → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- homepageCatalogItemHeight → String?
-
final
- homepageCatalogItemWidth → String?
-
final
-
final
- homepageHeroSectionHeading1 → WebApiModulesIntegrationsStorefrontStorefrontTranslatedText?
-
final
- homepageHeroSectionHeading2 → WebApiModulesIntegrationsStorefrontStorefrontTranslatedText?
-
final
- homepageHeroSectionHeading3 → WebApiModulesIntegrationsStorefrontStorefrontTranslatedText?
-
final
-
final
- homepageShowHeroSection → bool?
-
final
- imagesTransitionEffect → String?
-
final
- imagesTransitionSpeed → String?
-
final
- isAnonymousAccessEnabled → bool?
-
final
- isStorefrontEnabled → bool?
-
final
- isUniversity → bool?
-
final
- landingPageCategoryBrowserItemWidth → String?
-
final
- landingPageShowCategoryBrowser → bool?
-
final
- makeQuoteRequestIntoOrderOnSubmission → bool?
-
final
- phoneNoRequiredOnRegistrationForm → bool?
-
final
- registerEnabled → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separateQuoteRequestsByCatalog → bool?
-
final
- studentIdRequiredOnRegistrationForm → bool?
-
final
Methods
-
copyWith(
{bool? isStorefrontEnabled, bool? isAnonymousAccessEnabled, bool? registerEnabled, bool? separateQuoteRequestsByCatalog, bool? makeQuoteRequestIntoOrderOnSubmission, bool? filterCatalogsByLocation, bool? phoneNoRequiredOnRegistrationForm, bool? isUniversity, bool? studentIdRequiredOnRegistrationForm, double? autoplaySpeed, bool? autoplayImagesOnLandingPage, bool? autoplayImagesOnProductBrowser, bool? autoplayImagesOnProductDetails, String? imagesTransitionEffect, String? imagesTransitionSpeed, bool? homepageShowHeroSection, WebApiModulesIntegrationsStorefrontStorefrontTranslatedText? homepageHeroSectionHeading1, WebApiModulesIntegrationsStorefrontStorefrontTranslatedText? homepageHeroSectionHeading2, WebApiModulesIntegrationsStorefrontStorefrontTranslatedText? homepageHeroSectionHeading3, String? homepageCatalogItemWidth, String? homepageCatalogItemHeight, bool? landingPageShowCategoryBrowser, String? landingPageCategoryBrowserItemWidth}) → WebApiModulesIntegrationsStorefrontStorefrontSettings -
Available on WebApiModulesIntegrationsStorefrontStorefrontSettings, provided by the $WebApiModulesIntegrationsStorefrontStorefrontSettingsExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? isStorefrontEnabled, Wrapped<bool?> ? isAnonymousAccessEnabled, Wrapped<bool?> ? registerEnabled, Wrapped<bool?> ? separateQuoteRequestsByCatalog, Wrapped<bool?> ? makeQuoteRequestIntoOrderOnSubmission, Wrapped<bool?> ? filterCatalogsByLocation, Wrapped<bool?> ? phoneNoRequiredOnRegistrationForm, Wrapped<bool?> ? isUniversity, Wrapped<bool?> ? studentIdRequiredOnRegistrationForm, Wrapped<double?> ? autoplaySpeed, Wrapped<bool?> ? autoplayImagesOnLandingPage, Wrapped<bool?> ? autoplayImagesOnProductBrowser, Wrapped<bool?> ? autoplayImagesOnProductDetails, Wrapped<String?> ? imagesTransitionEffect, Wrapped<String?> ? imagesTransitionSpeed, Wrapped<bool?> ? homepageShowHeroSection, Wrapped<WebApiModulesIntegrationsStorefrontStorefrontTranslatedText?> ? homepageHeroSectionHeading1, Wrapped<WebApiModulesIntegrationsStorefrontStorefrontTranslatedText?> ? homepageHeroSectionHeading2, Wrapped<WebApiModulesIntegrationsStorefrontStorefrontTranslatedText?> ? homepageHeroSectionHeading3, Wrapped<String?> ? homepageCatalogItemWidth, Wrapped<String?> ? homepageCatalogItemHeight, Wrapped<bool?> ? landingPageShowCategoryBrowser, Wrapped<String?> ? landingPageCategoryBrowserItemWidth}) → WebApiModulesIntegrationsStorefrontStorefrontSettings -
Available on WebApiModulesIntegrationsStorefrontStorefrontSettings, provided by the $WebApiModulesIntegrationsStorefrontStorefrontSettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontStorefrontSettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontStorefrontSettings instance)