WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema({String? group, String? caption, String? propertyName, WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertyDataTypes? dataType, String? description})
-
const
-
WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema.fromJson(Map<
String, dynamic> json) -
factory
Properties
- caption → String?
-
final
- dataType → WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertyDataTypes?
-
final
- description → String?
-
final
- group → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- propertyName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? group, String? caption, String? propertyName, WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertyDataTypes? dataType, String? description}) → WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema -
Available on WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema, provided by the $WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchemaExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? group, Wrapped<String?> ? caption, Wrapped<String?> ? propertyName, Wrapped<WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertyDataTypes?> ? dataType, Wrapped<String?> ? description}) → WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema -
Available on WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema, provided by the $WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchemaExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontStorefrontSettingsPropertySchema instance)