WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse({bool? success, String? failureMessage, String? progressMeterSessionId})
-
const
-
WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- failureMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- progressMeterSessionId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool?
-
final
Methods
-
copyWith(
{bool? success, String? failureMessage, String? progressMeterSessionId}) → WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse -
Available on WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse, provided by the $WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponseExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? success, Wrapped<String?> ? failureMessage, Wrapped<String?> ? progressMeterSessionId}) → WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse -
Available on WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse, provided by the $WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontSubmitQuoteRequestResponse instance)