WebApiModulesIntegrationsStorefrontWebCatalog class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesIntegrationsStorefrontWebCatalog({String? id, String? name, String? urlName, String? dealId, String? departmentId, String? locationId, String? warehouseId, bool? hasRental, bool? hasSales, List<
WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? gridFields, List<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? listFields, List<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? detailFields, List<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? shoppingCartFields, String? images, String? landingPageHtml, List<WebApiModulesIntegrationsStorefrontProductDepartment> ? departments, List<WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto> ? warehousesQtys}) -
const
-
WebApiModulesIntegrationsStorefrontWebCatalog.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
final
- dealId → String?
-
final
- departmentId → String?
-
final
-
departments
→ List<
WebApiModulesIntegrationsStorefrontProductDepartment> ? -
final
-
detailFields
→ List<
WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? -
final
-
gridFields
→ List<
WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasRental → bool?
-
final
- hasSales → bool?
-
final
- id → String?
-
final
- images → String?
-
final
- landingPageHtml → String?
-
final
-
listFields
→ List<
WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? -
final
- locationId → String?
-
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shoppingCartFields
→ List<
WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? -
final
- urlName → String?
-
final
- warehouseId → String?
-
final
-
warehousesQtys
→ List<
WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto> ? -
final
Methods
-
copyWith(
{String? id, String? name, String? urlName, String? dealId, String? departmentId, String? locationId, String? warehouseId, bool? hasRental, bool? hasSales, List< WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? gridFields, List<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? listFields, List<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? detailFields, List<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ? shoppingCartFields, String? images, String? landingPageHtml, List<WebApiModulesIntegrationsStorefrontProductDepartment> ? departments, List<WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto> ? warehousesQtys}) → WebApiModulesIntegrationsStorefrontWebCatalog -
Available on WebApiModulesIntegrationsStorefrontWebCatalog, provided by the $WebApiModulesIntegrationsStorefrontWebCatalogExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? id, Wrapped<String?> ? name, Wrapped<String?> ? urlName, Wrapped<String?> ? dealId, Wrapped<String?> ? departmentId, Wrapped<String?> ? locationId, Wrapped<String?> ? warehouseId, Wrapped<bool?> ? hasRental, Wrapped<bool?> ? hasSales, Wrapped<List< ? gridFields, Wrapped<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ?>List< ? listFields, Wrapped<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ?>List< ? detailFields, Wrapped<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ?>List< ? shoppingCartFields, Wrapped<WebApiModulesIntegrationsStorefrontWebCatalogResponseField> ?>String?> ? images, Wrapped<String?> ? landingPageHtml, Wrapped<List< ? departments, Wrapped<WebApiModulesIntegrationsStorefrontProductDepartment> ?>List< ? warehousesQtys}) → WebApiModulesIntegrationsStorefrontWebCatalogWebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto> ?> -
Available on WebApiModulesIntegrationsStorefrontWebCatalog, provided by the $WebApiModulesIntegrationsStorefrontWebCatalogExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontWebCatalog Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontWebCatalog instance)