WebApiModulesIntegrationsStorefrontWebCatalogResponseField class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
final
text String?
final
value String?
final

Methods

copyWith({String? value, String? text, bool? selected}) WebApiModulesIntegrationsStorefrontWebCatalogResponseField

Available on WebApiModulesIntegrationsStorefrontWebCatalogResponseField, provided by the $WebApiModulesIntegrationsStorefrontWebCatalogResponseFieldExtension extension

copyWithWrapped({Wrapped<String?>? value, Wrapped<String?>? text, Wrapped<bool?>? selected}) WebApiModulesIntegrationsStorefrontWebCatalogResponseField

Available on WebApiModulesIntegrationsStorefrontWebCatalogResponseField, provided by the $WebApiModulesIntegrationsStorefrontWebCatalogResponseFieldExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override