WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalItems double?
final
warehouseId String?
final

Methods

copyWith({String? warehouseId, double? totalItems}) WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto

Available on WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto, provided by the $WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDtoExtension extension

copyWithWrapped({Wrapped<String?>? warehouseId, Wrapped<double?>? totalItems}) WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto

Available on WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDto, provided by the $WebApiModulesIntegrationsStorefrontWebCatalogWarehouseQtyDtoExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override