FwStandardSqlServerFwJsonDataTable class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardSqlServerFwJsonDataTable({Map<
String, dynamic> ? columnIndex, Map<String, dynamic> ? totals, List<FwStandardSqlServerFwJsonDataTableColumn> ? columns, List<List< ? rows, int? pageNo, int? pageSize, int? totalPages, int? totalRows, List<Object> >String> ? dateFields, Map<String, dynamic> ? columnNameByIndex}) -
FwStandardSqlServerFwJsonDataTable.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
columnIndex
→ Map<
String, dynamic> ? -
final
-
columnNameByIndex
→ Map<
String, dynamic> ? -
final
-
columns
→ List<
FwStandardSqlServerFwJsonDataTableColumn> ? -
final
-
dateFields
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- pageNo → int?
-
final
- pageSize → int?
-
final
-
rows
→ List<
List< ?Object> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPages → int?
-
final
- totalRows → int?
-
final
-
totals
→ Map<
String, dynamic> ? -
final
Methods
-
copyWith(
{Map< String, dynamic> ? columnIndex, Map<String, dynamic> ? totals, List<FwStandardSqlServerFwJsonDataTableColumn> ? columns, List<List< ? rows, int? pageNo, int? pageSize, int? totalPages, int? totalRows, List<Object> >String> ? dateFields, Map<String, dynamic> ? columnNameByIndex}) → FwStandardSqlServerFwJsonDataTable -
Available on FwStandardSqlServerFwJsonDataTable, provided by the $FwStandardSqlServerFwJsonDataTableExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardSqlServerFwJsonDataTable Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardSqlServerFwJsonDataTable instance)