WebApiModulesHomeControlsInventoryPurchaseItemInventoryPurchaseItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsInventoryPurchaseItemInventoryPurchaseItem({int? inventoryPurchaseItemId, String? sessionId, String? barCode, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, bool? serialNumberIsMixedCase, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesHomeControlsInventoryPurchaseItemInventoryPurchaseItem.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
barCode String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryPurchaseItemId int?
final
manufactureDate String?
final
printQuantity int?
final
recordTitle String?
final
rfId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
serialNumberIsMixedCase bool?
final
sessionId String?
final

Methods

copyWith({int? inventoryPurchaseItemId, String? sessionId, String? barCode, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, bool? serialNumberIsMixedCase, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesHomeControlsInventoryPurchaseItemInventoryPurchaseItem

Available on WebApiModulesHomeControlsInventoryPurchaseItemInventoryPurchaseItem, provided by the $WebApiModulesHomeControlsInventoryPurchaseItemInventoryPurchaseItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override