WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest({String? searchValue, String? warehouseId, String? departmentId})
-
const
-
WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- departmentId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchValue → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? searchValue, String? warehouseId, String? departmentId}) → WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest -
Available on WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest, provided by the $WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? searchValue, Wrapped<String?> ? warehouseId, Wrapped<String?> ? departmentId}) → WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest -
Available on WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest, provided by the $WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesMobileQuikAssetQuikAssetFuncSearchItemsByDescriptionRequest instance)