WebApiModulesMobileQuikAssetQuikAssetFuncUpdateUnitValueRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unitValue double?
final
warehouseId String?
final

Methods

copyWith({String? warehouseId, String? inventoryId, double? unitValue}) WebApiModulesMobileQuikAssetQuikAssetFuncUpdateUnitValueRequest

Available on WebApiModulesMobileQuikAssetQuikAssetFuncUpdateUnitValueRequest, provided by the $WebApiModulesMobileQuikAssetQuikAssetFuncUpdateUnitValueRequestExtension extension

copyWithWrapped({Wrapped<String?>? warehouseId, Wrapped<String?>? inventoryId, Wrapped<double?>? unitValue}) WebApiModulesMobileQuikAssetQuikAssetFuncUpdateUnitValueRequest

Available on WebApiModulesMobileQuikAssetQuikAssetFuncUpdateUnitValueRequest, provided by the $WebApiModulesMobileQuikAssetQuikAssetFuncUpdateUnitValueRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override