WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItem({int? inventoryPurchaseItemId, String? sessionId, String? barCode, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, bool? serialNumberIsMixedCase, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItem.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
barCode String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inventoryPurchaseItemId int?
final
manufactureDate String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
printQuantity int?
final
recordTitle String?
final
rfId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
serialNumberIsMixedCase bool?
final
sessionId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? inventoryPurchaseItemId, String? sessionId, String? barCode, String? manufactureDate, int? printQuantity, String? serialNumber, String? rfId, bool? serialNumberIsMixedCase, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItem

Available on WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItem, provided by the $WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItemExtension extension

copyWithWrapped({Wrapped<int?>? inventoryPurchaseItemId, Wrapped<String?>? sessionId, Wrapped<String?>? barCode, Wrapped<String?>? manufactureDate, Wrapped<int?>? printQuantity, Wrapped<String?>? serialNumber, Wrapped<String?>? rfId, Wrapped<bool?>? serialNumberIsMixedCase, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItem

Available on WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItem, provided by the $WebApiModulesUtilitiesInventoryPurchaseUtilityInventoryPurchaseItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override