Pages class abstract

Annotations
  • @ChopperApi.new()

Constructors

Pages()

Properties

client ↔ ChopperClient
getter/setter pairinherited
definitionType Type
Used internally to retrieve the service from ChopperClient.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cardpointepaymentactivelinkGet({required String? activeLinkToken}) Future<Response<WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse>>
@param ActiveLinkToken
cardpointetokenizerGet() Future<Response<WebApiModulesPagesPluginsCardPointeTokenizerGetCardPointeTokenizerResponse>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({ChopperClient? client, Authenticator? authenticator, Uri? baseUrl, Iterable? interceptors}) Pages