WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkAuthorizeRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

account String?
final
activeLinkToken String?
final
capture bool?
final
expirationDate String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? activeLinkToken, String? account, String? expirationDate, bool? capture}) WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkAuthorizeRequest

Available on WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkAuthorizeRequest, provided by the $WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkAuthorizeRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override