WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse({String? company, String? orderDescription, String? dealDescription, String? officeLocation, double? amountToPay, String? statusCode, String? cardPointeSite, String? message})
-
WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amountToPay → double?
-
final
- cardPointeSite → String?
-
final
- company → String?
-
final
- dealDescription → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String?
-
final
- officeLocation → String?
-
final
- orderDescription → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → String?
-
final
Methods
-
copyWith(
{String? company, String? orderDescription, String? dealDescription, String? officeLocation, double? amountToPay, String? statusCode, String? cardPointeSite, String? message}) → WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse -
Available on WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse, provided by the $WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponseExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? company, Wrapped<String?> ? orderDescription, Wrapped<String?> ? dealDescription, Wrapped<String?> ? officeLocation, Wrapped<double?> ? amountToPay, Wrapped<String?> ? statusCode, Wrapped<String?> ? cardPointeSite, Wrapped<String?> ? message}) → WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse -
Available on WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse, provided by the $WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse instance)