FwStandardDataFwCustomValue class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardDataFwCustomValue({String? moduleName, String? fieldName, String? fieldValue, String? fieldType, String? validationModule, String? validationFieldName, String? validationFieldId, String? listFieldAllowedValues})
const
FwStandardDataFwCustomValue.fromJson(Map<String, dynamic> json)
factory

Properties

fieldName String?
final
fieldType String?
final
fieldValue String?
final
hashCode int
The hash code for this object.
no setteroverride
listFieldAllowedValues String?
final
moduleName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validationFieldId String?
final
validationFieldName String?
final
validationModule String?
final

Methods

copyWith({String? moduleName, String? fieldName, String? fieldValue, String? fieldType, String? validationModule, String? validationFieldName, String? validationFieldId, String? listFieldAllowedValues}) FwStandardDataFwCustomValue

Available on FwStandardDataFwCustomValue, provided by the $FwStandardDataFwCustomValueExtension extension

copyWithWrapped({Wrapped<String?>? moduleName, Wrapped<String?>? fieldName, Wrapped<String?>? fieldValue, Wrapped<String?>? fieldType, Wrapped<String?>? validationModule, Wrapped<String?>? validationFieldName, Wrapped<String?>? validationFieldId, Wrapped<String?>? listFieldAllowedValues}) FwStandardDataFwCustomValue

Available on FwStandardDataFwCustomValue, provided by the $FwStandardDataFwCustomValueExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const FwStandardDataFwCustomValue Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(FwStandardDataFwCustomValue instance)