creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidCustomerCustomeridAccountidAccountidPostalcodePostalcodeAmountAmountGet method

Future<Response<WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse>> creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidCustomerCustomeridAccountidAccountidPostalcodePostalcodeAmountAmountGet({
  1. required String? locationid,
  2. required String? customerid,
  3. required String? accountid,
  4. required String? postalcode,
  5. required num? amount,
})

Calls the Cardpointe Gateway API Surcharge endpoint to determine if there is a surcharge for this postal code. Accountid should be the saved card number from the proifle. If so, then calls CardPointe Gateway API InquireMerchant to determine the surcharge percent and returns the percentages and totals. @param locationid @param customerid @param accountid @param postalcode @param amount

Implementation

Future<
  chopper.Response<
    WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse
  >
>
creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidCustomerCustomeridAccountidAccountidPostalcodePostalcodeAmountAmountGet({
  required String? locationid,
  required String? customerid,
  required String? accountid,
  required String? postalcode,
  required num? amount,
}) {
  generatedMapping.putIfAbsent(
    WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse,
    () =>
        WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse
            .fromJsonFactory,
  );

  return _creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidCustomerCustomeridAccountidAccountidPostalcodePostalcodeAmountAmountGet(
    locationid: locationid,
    customerid: customerid,
    accountid: accountid,
    postalcode: postalcode,
    amount: amount,
  );
}