creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidDealDealidAccountidAccountidPostalcodePostalcodeAmountAmountGet method

Future<Response<WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse>> creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidDealDealidAccountidAccountidPostalcodePostalcodeAmountAmountGet({
  1. required String? locationid,
  2. required String? dealid,
  3. required String? accountid,
  4. required String? postalcode,
  5. required num? amount,
})

Calls the Cardpointe Gateway API Surcharge endpoint to determine if there is a surcharge for this postal code. If so, then calls CardPointe Gateway API InquireMerchant to determine the surcharge percent and returns the percentages and totals. @param locationid @param dealid @param accountid @param postalcode @param amount

Implementation

Future<
  chopper.Response<
    WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse
  >
>
creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidDealDealidAccountidAccountidPostalcodePostalcodeAmountAmountGet({
  required String? locationid,
  required String? dealid,
  required String? accountid,
  required String? postalcode,
  required num? amount,
}) {
  generatedMapping.putIfAbsent(
    WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse,
    () =>
        WebApiModulesPluginsCreditCardCreditCardPluginGetDefaultSurchargeAmountResponse
            .fromJsonFactory,
  );

  return _creditcardpluginCardpointeGatewayapiSurchargefeeLocationLocationidDealDealidAccountidAccountidPostalcodePostalcodeAmountAmountGet(
    locationid: locationid,
    dealid: dealid,
    accountid: accountid,
    postalcode: postalcode,
    amount: amount,
  );
}