WebApiModulesBillingReceiptReceipt class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesBillingReceiptReceipt({String? receiptId, String? receiptDate, String? locationId, String? locationCode, String? location, String? customerId, String? customer, String? dealId, String? deal, String? paymentBy, String? customerDealId, String? customerDeal, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? paymentTypeExportPaymentMethod, String? checkNumber, double? paymentAmount, String? appliedById, String? appliedBy, String? modifiedById, String? modifiedBy, String? paymentMemo, String? recType, String? chargeBatchId, String? chargeBatchNumber, String? currencyId, String? currencyCode, String? currencySymbol, String? officeLocationDefaultCurrencyId, String? overPaymentId, List<
WebApiModulesBillingReceiptReceiptInvoice> ? invoiceDataList, List<WebApiModulesBillingReceiptReceiptCredit> ? creditDataList, bool? createOverpayment, bool? createDepletingDeposit, String? dealDepositId, String? dealDepositCheckNumber, String? customerDepositId, String? customerDepositCheckNumber, String? orderId, String? orderDescription, String? transactionId, String? refundingTransactionId, String? creditCardNumber, String? creditCardExpirationDate, String? creditCardName, String? creditCardAccountId, String? creditCardPaymentMode, int? creditCardPinPadId, String? newCreditCardAccountToken, String? newCreditCardExpirationDate, String? newCreditCardCardholderName, bool? newCreditCardSaveCreditCard, bool? creditCardDefaultAccount, bool? newCreditCardAuthorizationOnFile, String? newCreditCardAddress, String? newCreditCardAddress2, String? newCreditCardCity, String? newCreditCardRegion, String? newCreditCardPostalCode, String? newCreditCardCountryId, DateTime? dateStamp, String? refundingReceiptId, bool? isCreditCardReceiptVoided, double? feePercent, double? paymentTypeFee, double? totalWithPaymentTypeFee, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesBillingReceiptReceipt.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appliedBy → String?
-
final
- appliedById → String?
-
final
- auditNote → String?
-
final
- chargeBatchId → String?
-
final
- chargeBatchNumber → String?
-
final
- checkNumber → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
- createDepletingDeposit → bool?
-
final
- createOverpayment → bool?
-
final
- creditCardAccountId → String?
-
final
- creditCardDefaultAccount → bool?
-
final
- creditCardExpirationDate → String?
-
final
- creditCardName → String?
-
final
- creditCardNumber → String?
-
final
- creditCardPaymentMode → String?
-
final
- creditCardPinPadId → int?
-
final
-
creditDataList
→ List<
WebApiModulesBillingReceiptReceiptCredit> ? -
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerDeal → String?
-
final
- customerDealId → String?
-
final
- customerDepositCheckNumber → String?
-
final
- customerDepositId → String?
-
final
- customerId → String?
-
final
- dateStamp → DateTime?
-
final
- deal → String?
-
final
- dealDepositCheckNumber → String?
-
final
- dealDepositId → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- feePercent → double?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
-
invoiceDataList
→ List<
WebApiModulesBillingReceiptReceiptInvoice> ? -
final
- isCreditCardReceiptVoided → bool?
-
final
- location → String?
-
final
- locationCode → String?
-
final
- locationId → String?
-
final
- modifiedBy → String?
-
final
- modifiedById → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- newCreditCardAccountToken → String?
-
final
- newCreditCardAddress → String?
-
final
- newCreditCardAddress2 → String?
-
final
- newCreditCardAuthorizationOnFile → bool?
-
final
- newCreditCardCardholderName → String?
-
final
- newCreditCardCity → String?
-
final
- newCreditCardCountryId → String?
-
final
- newCreditCardExpirationDate → String?
-
final
- newCreditCardPostalCode → String?
-
final
- newCreditCardRegion → String?
-
final
- newCreditCardSaveCreditCard → bool?
-
final
- officeLocationDefaultCurrencyId → String?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- overPaymentId → String?
-
final
- paymentAmount → double?
-
final
- paymentBy → String?
-
final
- paymentMemo → String?
-
final
- paymentType → String?
-
final
- paymentTypeExportPaymentMethod → String?
-
final
- paymentTypeFee → double?
-
final
- paymentTypeId → String?
-
final
- paymentTypeType → String?
-
final
- receiptDate → String?
-
final
- receiptId → String?
-
final
- recordTitle → String?
-
final
- recType → String?
-
final
- refundingReceiptId → String?
-
final
- refundingTransactionId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalWithPaymentTypeFee → double?
-
final
- transactionId → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? receiptId, String? receiptDate, String? locationId, String? locationCode, String? location, String? customerId, String? customer, String? dealId, String? deal, String? paymentBy, String? customerDealId, String? customerDeal, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? paymentTypeExportPaymentMethod, String? checkNumber, double? paymentAmount, String? appliedById, String? appliedBy, String? modifiedById, String? modifiedBy, String? paymentMemo, String? recType, String? chargeBatchId, String? chargeBatchNumber, String? currencyId, String? currencyCode, String? currencySymbol, String? officeLocationDefaultCurrencyId, String? overPaymentId, List< WebApiModulesBillingReceiptReceiptInvoice> ? invoiceDataList, List<WebApiModulesBillingReceiptReceiptCredit> ? creditDataList, bool? createOverpayment, bool? createDepletingDeposit, String? dealDepositId, String? dealDepositCheckNumber, String? customerDepositId, String? customerDepositCheckNumber, String? orderId, String? orderDescription, String? transactionId, String? refundingTransactionId, String? creditCardNumber, String? creditCardExpirationDate, String? creditCardName, String? creditCardAccountId, String? creditCardPaymentMode, int? creditCardPinPadId, String? newCreditCardAccountToken, String? newCreditCardExpirationDate, String? newCreditCardCardholderName, bool? newCreditCardSaveCreditCard, bool? creditCardDefaultAccount, bool? newCreditCardAuthorizationOnFile, String? newCreditCardAddress, String? newCreditCardAddress2, String? newCreditCardCity, String? newCreditCardRegion, String? newCreditCardPostalCode, String? newCreditCardCountryId, DateTime? dateStamp, String? refundingReceiptId, bool? isCreditCardReceiptVoided, double? feePercent, double? paymentTypeFee, double? totalWithPaymentTypeFee, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesBillingReceiptReceipt -
Available on WebApiModulesBillingReceiptReceipt, provided by the $WebApiModulesBillingReceiptReceiptExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? receiptId, Wrapped<String?> ? receiptDate, Wrapped<String?> ? locationId, Wrapped<String?> ? locationCode, Wrapped<String?> ? location, Wrapped<String?> ? customerId, Wrapped<String?> ? customer, Wrapped<String?> ? dealId, Wrapped<String?> ? deal, Wrapped<String?> ? paymentBy, Wrapped<String?> ? customerDealId, Wrapped<String?> ? customerDeal, Wrapped<String?> ? paymentTypeId, Wrapped<String?> ? paymentType, Wrapped<String?> ? paymentTypeType, Wrapped<String?> ? paymentTypeExportPaymentMethod, Wrapped<String?> ? checkNumber, Wrapped<double?> ? paymentAmount, Wrapped<String?> ? appliedById, Wrapped<String?> ? appliedBy, Wrapped<String?> ? modifiedById, Wrapped<String?> ? modifiedBy, Wrapped<String?> ? paymentMemo, Wrapped<String?> ? recType, Wrapped<String?> ? chargeBatchId, Wrapped<String?> ? chargeBatchNumber, Wrapped<String?> ? currencyId, Wrapped<String?> ? currencyCode, Wrapped<String?> ? currencySymbol, Wrapped<String?> ? officeLocationDefaultCurrencyId, Wrapped<String?> ? overPaymentId, Wrapped<List< ? invoiceDataList, Wrapped<WebApiModulesBillingReceiptReceiptInvoice> ?>List< ? creditDataList, Wrapped<WebApiModulesBillingReceiptReceiptCredit> ?>bool?> ? createOverpayment, Wrapped<bool?> ? createDepletingDeposit, Wrapped<String?> ? dealDepositId, Wrapped<String?> ? dealDepositCheckNumber, Wrapped<String?> ? customerDepositId, Wrapped<String?> ? customerDepositCheckNumber, Wrapped<String?> ? orderId, Wrapped<String?> ? orderDescription, Wrapped<String?> ? transactionId, Wrapped<String?> ? refundingTransactionId, Wrapped<String?> ? creditCardNumber, Wrapped<String?> ? creditCardExpirationDate, Wrapped<String?> ? creditCardName, Wrapped<String?> ? creditCardAccountId, Wrapped<String?> ? creditCardPaymentMode, Wrapped<int?> ? creditCardPinPadId, Wrapped<String?> ? newCreditCardAccountToken, Wrapped<String?> ? newCreditCardExpirationDate, Wrapped<String?> ? newCreditCardCardholderName, Wrapped<bool?> ? newCreditCardSaveCreditCard, Wrapped<bool?> ? creditCardDefaultAccount, Wrapped<bool?> ? newCreditCardAuthorizationOnFile, Wrapped<String?> ? newCreditCardAddress, Wrapped<String?> ? newCreditCardAddress2, Wrapped<String?> ? newCreditCardCity, Wrapped<String?> ? newCreditCardRegion, Wrapped<String?> ? newCreditCardPostalCode, Wrapped<String?> ? newCreditCardCountryId, Wrapped<DateTime?> ? dateStamp, Wrapped<String?> ? refundingReceiptId, Wrapped<bool?> ? isCreditCardReceiptVoided, Wrapped<double?> ? feePercent, Wrapped<double?> ? paymentTypeFee, Wrapped<double?> ? totalWithPaymentTypeFee, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesBillingReceiptReceipt -
Available on WebApiModulesBillingReceiptReceipt, provided by the $WebApiModulesBillingReceiptReceiptExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesBillingReceiptReceipt Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesBillingReceiptReceipt instance)