WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricing class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricing({int? id, String? orderId, int? rank, String? tierName, int? weeks, int? startWeek, int? stopWeek, bool? percentOfTier1, bool? percentOfReplacement, bool? percentOfValue, double? tierPercent, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricing.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
id int?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
percentOfReplacement bool?
final
percentOfTier1 bool?
final
percentOfValue bool?
final
rank int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startWeek int?
final
stopWeek int?
final
tierName String?
final
tierPercent double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
weeks int?
final

Methods

copyWith({int? id, String? orderId, int? rank, String? tierName, int? weeks, int? startWeek, int? stopWeek, bool? percentOfTier1, bool? percentOfReplacement, bool? percentOfValue, double? tierPercent, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricing

Available on WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricing, provided by the $WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricingExtension extension

copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? orderId, Wrapped<int?>? rank, Wrapped<String?>? tierName, Wrapped<int?>? weeks, Wrapped<int?>? startWeek, Wrapped<int?>? stopWeek, Wrapped<bool?>? percentOfTier1, Wrapped<bool?>? percentOfReplacement, Wrapped<bool?>? percentOfValue, Wrapped<double?>? tierPercent, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricing

Available on WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricing, provided by the $WebApiModulesHomeDealOrderTieredPricingDealOrderTieredPricingExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override