WebApiModulesPluginsCreditCardCreditCardCapturePreAuthorizationForOrderResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

capturePreAuthorizationResults List<WebApiModulesPluginsCreditCardCreditCardPluginCaptureResponse>?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<WebApiModulesPluginsCreditCardCreditCardPluginCaptureResponse>? capturePreAuthorizationResults}) WebApiModulesPluginsCreditCardCreditCardCapturePreAuthorizationForOrderResponse

Available on WebApiModulesPluginsCreditCardCreditCardCapturePreAuthorizationForOrderResponse, provided by the $WebApiModulesPluginsCreditCardCreditCardCapturePreAuthorizationForOrderResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override