WebApiModulesPluginsCreditCardCreditCardPluginAuthorizeResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

amount double?
final
cardEntryMode String?
final
cardType WebApiModulesPluginsCreditCardProcessCreditCardPaymentCardTypes?
final
hashCode int
The hash code for this object.
no setteroverride
receipt WebApiModulesBillingReceiptReceipt?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status WebApiModulesPluginsCreditCardCreditCardPluginAuthorizeResponseStatusCodes?
final
statusText String?
final
success bool?
final
transactionId String?
final

Methods

copyWith({double? amount, WebApiModulesBillingReceiptReceipt? receipt, bool? success, WebApiModulesPluginsCreditCardCreditCardPluginAuthorizeResponseStatusCodes? status, WebApiModulesPluginsCreditCardProcessCreditCardPaymentCardTypes? cardType, String? cardEntryMode, String? statusText, String? transactionId}) WebApiModulesPluginsCreditCardCreditCardPluginAuthorizeResponse

Available on WebApiModulesPluginsCreditCardCreditCardPluginAuthorizeResponse, provided by the $WebApiModulesPluginsCreditCardCreditCardPluginAuthorizeResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override