WebApiModulesPluginsCreditCardCreditCardPluginLocation class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsCreditCardCreditCardPluginLocation({String? locationId, String? location})
-
const
-
WebApiModulesPluginsCreditCardCreditCardPluginLocation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → String?
-
final
- locationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? locationId, String? location}) → WebApiModulesPluginsCreditCardCreditCardPluginLocation -
Available on WebApiModulesPluginsCreditCardCreditCardPluginLocation, provided by the $WebApiModulesPluginsCreditCardCreditCardPluginLocationExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? locationId, Wrapped<String?> ? location}) → WebApiModulesPluginsCreditCardCreditCardPluginLocation -
Available on WebApiModulesPluginsCreditCardCreditCardPluginLocation, provided by the $WebApiModulesPluginsCreditCardCreditCardPluginLocationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsCreditCardCreditCardPluginLocation Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsCreditCardCreditCardPluginLocation instance)