WebApiModulesPluginsCreditCardCreditCardPluginRefundResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

amount double?
final
cardEntryMode String?
final
cardType WebApiModulesPluginsCreditCardProcessCreditCardPaymentCardTypes?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status WebApiModulesPluginsCreditCardCreditCardPluginRefundResponseStatusCodes?
final
statusText String?
final
success bool?
final
transactionId String?
final

Methods

copyWith({bool? success, WebApiModulesPluginsCreditCardCreditCardPluginRefundResponseStatusCodes? status, String? statusText, String? transactionId, String? cardEntryMode, WebApiModulesPluginsCreditCardProcessCreditCardPaymentCardTypes? cardType, double? amount}) WebApiModulesPluginsCreditCardCreditCardPluginRefundResponse

Available on WebApiModulesPluginsCreditCardCreditCardPluginRefundResponse, provided by the $WebApiModulesPluginsCreditCardCreditCardPluginRefundResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override