WebApiModulesPluginsCreditCardCreditCardPreAuthorization class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsCreditCardCreditCardPreAuthorization({int? creditCardPreAuthorizationId, String? transactionId, String? orderId, DateTime? transactionDate, DateTime? expirationDate, int? holdDays, int? holdDaysRemaining, double? amount, double? feePercent, double? feeAmount, double? amountWithFee, double? capturedAmount, String? status, int? creditCardPinPadId, String? creditCardPinPadCode, String? creditCardPinPadDescription, String? creditCardNumber, String? creditCardExpirationDate, String? creditCardName, DateTime? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesPluginsCreditCardCreditCardPreAuthorization.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
amountWithFee double?
final
auditNote String?
final
capturedAmount double?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
creditCardExpirationDate String?
final
creditCardName String?
final
creditCardNumber String?
final
creditCardPinPadCode String?
final
creditCardPinPadDescription String?
final
creditCardPinPadId int?
final
creditCardPreAuthorizationId int?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp DateTime?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
expirationDate DateTime?
final
feeAmount double?
final
feePercent double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
holdDays int?
final
holdDaysRemaining int?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
transactionDate DateTime?
final
transactionId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? creditCardPreAuthorizationId, String? transactionId, String? orderId, DateTime? transactionDate, DateTime? expirationDate, int? holdDays, int? holdDaysRemaining, double? amount, double? feePercent, double? feeAmount, double? amountWithFee, double? capturedAmount, String? status, int? creditCardPinPadId, String? creditCardPinPadCode, String? creditCardPinPadDescription, String? creditCardNumber, String? creditCardExpirationDate, String? creditCardName, DateTime? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesPluginsCreditCardCreditCardPreAuthorization

Available on WebApiModulesPluginsCreditCardCreditCardPreAuthorization, provided by the $WebApiModulesPluginsCreditCardCreditCardPreAuthorizationExtension extension

copyWithWrapped({Wrapped<int?>? creditCardPreAuthorizationId, Wrapped<String?>? transactionId, Wrapped<String?>? orderId, Wrapped<DateTime?>? transactionDate, Wrapped<DateTime?>? expirationDate, Wrapped<int?>? holdDays, Wrapped<int?>? holdDaysRemaining, Wrapped<double?>? amount, Wrapped<double?>? feePercent, Wrapped<double?>? feeAmount, Wrapped<double?>? amountWithFee, Wrapped<double?>? capturedAmount, Wrapped<String?>? status, Wrapped<int?>? creditCardPinPadId, Wrapped<String?>? creditCardPinPadCode, Wrapped<String?>? creditCardPinPadDescription, Wrapped<String?>? creditCardNumber, Wrapped<String?>? creditCardExpirationDate, Wrapped<String?>? creditCardName, Wrapped<DateTime?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesPluginsCreditCardCreditCardPreAuthorization

Available on WebApiModulesPluginsCreditCardCreditCardPreAuthorization, provided by the $WebApiModulesPluginsCreditCardCreditCardPreAuthorizationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override