WebApiModulesPluginsCreditCardCreditCardRefundResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
pluginResponse WebApiModulesPluginsCreditCardCreditCardPluginRefundResponse?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status WebApiModulesPluginsCreditCardCreditCardPluginRefundResponseStatusCodes?
final
statusText String?
final
success bool?
final

Methods

copyWith({WebApiModulesPluginsCreditCardCreditCardPluginRefundResponse? pluginResponse, bool? success, WebApiModulesPluginsCreditCardCreditCardPluginRefundResponseStatusCodes? status, String? statusText}) WebApiModulesPluginsCreditCardCreditCardRefundResponse

Available on WebApiModulesPluginsCreditCardCreditCardRefundResponse, provided by the $WebApiModulesPluginsCreditCardCreditCardRefundResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override