WebApiModulesPluginsCreditCardOrderDeposit class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsCreditCardOrderDeposit({String? orderId, DateTime? transactionDate, String? payType, String? checkOrReferenceNumber, double? amount, double? feePercent, double? paymentTypeFee, double? amountWithFee, String? creditCardName, String? creditCardExpiration, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesPluginsCreditCardOrderDeposit.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
amountWithFee double?
final
auditNote String?
final
checkOrReferenceNumber String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
creditCardExpiration String?
final
creditCardName String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
feePercent double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentTypeFee double?
final
payType String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionDate DateTime?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? orderId, DateTime? transactionDate, String? payType, String? checkOrReferenceNumber, double? amount, double? feePercent, double? paymentTypeFee, double? amountWithFee, String? creditCardName, String? creditCardExpiration, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesPluginsCreditCardOrderDeposit

Available on WebApiModulesPluginsCreditCardOrderDeposit, provided by the $WebApiModulesPluginsCreditCardOrderDepositExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<DateTime?>? transactionDate, Wrapped<String?>? payType, Wrapped<String?>? checkOrReferenceNumber, Wrapped<double?>? amount, Wrapped<double?>? feePercent, Wrapped<double?>? paymentTypeFee, Wrapped<double?>? amountWithFee, Wrapped<String?>? creditCardName, Wrapped<String?>? creditCardExpiration, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesPluginsCreditCardOrderDeposit

Available on WebApiModulesPluginsCreditCardOrderDeposit, provided by the $WebApiModulesPluginsCreditCardOrderDepositExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesPluginsCreditCardOrderDeposit Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesPluginsCreditCardOrderDeposit instance)