WebApiModulesPluginsCreditCardProcessCreditCardInfo class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsCreditCardProcessCreditCardInfo({String? recordTitle, String? orderId, String? orderNumber, String? orderDescription, String? orderStatus, String? dealId, String? dealNumber, String? deal, String? customerId, String? customerNumber, String? customer, double? totalsWeeklyGrossTotal, double? totalsWeeklyDiscount, double? totalsWeeklySubTotal, double? totalsWeeklyTax, double? totalsWeeklyGrandTotal, double? totalsPeriodGrossTotal, double? totalsPeriodDiscount, double? totalsPeriodSubTotal, double? totalsPeriodTax, double? totalsPeriodGrandTotal, double? totalsReplacementReplacementCost, double? totalsReplacementDepositPercentage, double? totalsReplacementDepositDue, double? totalsReplacementPreAuthorizationRequiredAmount, double? totalsReplacementPreAuthorizationCurrentTotal, double? totalsReplacementPreAuthorizationAmountDue, double? paymentTotalAmount, double? paymentAmountToPay, String? pINPadCode, String? pINPadDescription, String? locationCode, String? agentBarcode, String? currencyId, String? currencyCode, String? locationId, String? auditNote, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesPluginsCreditCardProcessCreditCardInfo.fromJson(Map<String, dynamic> json)
factory

Properties

agentBarcode String?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currencyCode String?
final
currencyId String?
final
custom List<FwStandardDataFwCustomValue>?
final
customer String?
final
customerId String?
final
customerNumber String?
final
deal String?
final
dealId String?
final
dealNumber String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
locationCode String?
final
locationId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderDescription String?
final
orderId String?
final
orderNumber String?
final
orderStatus String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentAmountToPay double?
final
paymentTotalAmount double?
final
pINPadCode String?
final
pINPadDescription String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalsPeriodDiscount double?
final
totalsPeriodGrandTotal double?
final
totalsPeriodGrossTotal double?
final
totalsPeriodSubTotal double?
final
totalsPeriodTax double?
final
totalsReplacementDepositDue double?
final
totalsReplacementDepositPercentage double?
final
totalsReplacementPreAuthorizationAmountDue double?
final
totalsReplacementPreAuthorizationCurrentTotal double?
final
totalsReplacementPreAuthorizationRequiredAmount double?
final
totalsReplacementReplacementCost double?
final
totalsWeeklyDiscount double?
final
totalsWeeklyGrandTotal double?
final
totalsWeeklyGrossTotal double?
final
totalsWeeklySubTotal double?
final
totalsWeeklyTax double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? recordTitle, String? orderId, String? orderNumber, String? orderDescription, String? orderStatus, String? dealId, String? dealNumber, String? deal, String? customerId, String? customerNumber, String? customer, double? totalsWeeklyGrossTotal, double? totalsWeeklyDiscount, double? totalsWeeklySubTotal, double? totalsWeeklyTax, double? totalsWeeklyGrandTotal, double? totalsPeriodGrossTotal, double? totalsPeriodDiscount, double? totalsPeriodSubTotal, double? totalsPeriodTax, double? totalsPeriodGrandTotal, double? totalsReplacementReplacementCost, double? totalsReplacementDepositPercentage, double? totalsReplacementDepositDue, double? totalsReplacementPreAuthorizationRequiredAmount, double? totalsReplacementPreAuthorizationCurrentTotal, double? totalsReplacementPreAuthorizationAmountDue, double? paymentTotalAmount, double? paymentAmountToPay, String? pINPadCode, String? pINPadDescription, String? locationCode, String? agentBarcode, String? currencyId, String? currencyCode, String? locationId, String? auditNote, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesPluginsCreditCardProcessCreditCardInfo

Available on WebApiModulesPluginsCreditCardProcessCreditCardInfo, provided by the $WebApiModulesPluginsCreditCardProcessCreditCardInfoExtension extension

copyWithWrapped({Wrapped<String?>? recordTitle, Wrapped<String?>? orderId, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDescription, Wrapped<String?>? orderStatus, Wrapped<String?>? dealId, Wrapped<String?>? dealNumber, Wrapped<String?>? deal, Wrapped<String?>? customerId, Wrapped<String?>? customerNumber, Wrapped<String?>? customer, Wrapped<double?>? totalsWeeklyGrossTotal, Wrapped<double?>? totalsWeeklyDiscount, Wrapped<double?>? totalsWeeklySubTotal, Wrapped<double?>? totalsWeeklyTax, Wrapped<double?>? totalsWeeklyGrandTotal, Wrapped<double?>? totalsPeriodGrossTotal, Wrapped<double?>? totalsPeriodDiscount, Wrapped<double?>? totalsPeriodSubTotal, Wrapped<double?>? totalsPeriodTax, Wrapped<double?>? totalsPeriodGrandTotal, Wrapped<double?>? totalsReplacementReplacementCost, Wrapped<double?>? totalsReplacementDepositPercentage, Wrapped<double?>? totalsReplacementDepositDue, Wrapped<double?>? totalsReplacementPreAuthorizationRequiredAmount, Wrapped<double?>? totalsReplacementPreAuthorizationCurrentTotal, Wrapped<double?>? totalsReplacementPreAuthorizationAmountDue, Wrapped<double?>? paymentTotalAmount, Wrapped<double?>? paymentAmountToPay, Wrapped<String?>? pINPadCode, Wrapped<String?>? pINPadDescription, Wrapped<String?>? locationCode, Wrapped<String?>? agentBarcode, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? locationId, Wrapped<String?>? auditNote, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesPluginsCreditCardProcessCreditCardInfo

Available on WebApiModulesPluginsCreditCardProcessCreditCardInfo, provided by the $WebApiModulesPluginsCreditCardProcessCreditCardInfoExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override