WebApiModulesPluginsFreightPopFreightPopPluginLocation class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsFreightPopFreightPopPluginLocation({String? locationId, String? location})
-
const
-
WebApiModulesPluginsFreightPopFreightPopPluginLocation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → String?
-
final
- locationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? locationId, String? location}) → WebApiModulesPluginsFreightPopFreightPopPluginLocation -
Available on WebApiModulesPluginsFreightPopFreightPopPluginLocation, provided by the $WebApiModulesPluginsFreightPopFreightPopPluginLocationExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? locationId, Wrapped<String?> ? location}) → WebApiModulesPluginsFreightPopFreightPopPluginLocation -
Available on WebApiModulesPluginsFreightPopFreightPopPluginLocation, provided by the $WebApiModulesPluginsFreightPopFreightPopPluginLocationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsFreightPopFreightPopPluginLocation Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsFreightPopFreightPopPluginLocation instance)