WebApiModulesPluginsFreightPopFreightPopShipmentRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsFreightPopFreightPopShipmentRequest({String? orderNumber, String? trackingNumber, String? carrierName})
-
const
-
WebApiModulesPluginsFreightPopFreightPopShipmentRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- carrierName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- orderNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackingNumber → String?
-
final
Methods
-
copyWith(
{String? orderNumber, String? trackingNumber, String? carrierName}) → WebApiModulesPluginsFreightPopFreightPopShipmentRequest -
Available on WebApiModulesPluginsFreightPopFreightPopShipmentRequest, provided by the $WebApiModulesPluginsFreightPopFreightPopShipmentRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? orderNumber, Wrapped<String?> ? trackingNumber, Wrapped<String?> ? carrierName}) → WebApiModulesPluginsFreightPopFreightPopShipmentRequest -
Available on WebApiModulesPluginsFreightPopFreightPopShipmentRequest, provided by the $WebApiModulesPluginsFreightPopFreightPopShipmentRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsFreightPopFreightPopShipmentRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsFreightPopFreightPopShipmentRequest instance)