WebApiModulesPluginsKissFlowOrderResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsKissFlowOrderResponse({int? status, bool? success, String? msg, WebApiModulesAgentOrderOrder? order, String? orderUrl, String? agentEmail, String? projectManagerEmail, String? outsideSalesRepresentativeEmail})
const
WebApiModulesPluginsKissFlowOrderResponse.fromJson(Map<String, dynamic> json)
factory

Properties

agentEmail String?
final
hashCode int
The hash code for this object.
no setteroverride
msg String?
final
order WebApiModulesAgentOrderOrder?
final
orderUrl String?
final
outsideSalesRepresentativeEmail String?
final
projectManagerEmail String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
success bool?
final

Methods

copyWith({int? status, bool? success, String? msg, WebApiModulesAgentOrderOrder? order, String? orderUrl, String? agentEmail, String? projectManagerEmail, String? outsideSalesRepresentativeEmail}) WebApiModulesPluginsKissFlowOrderResponse

Available on WebApiModulesPluginsKissFlowOrderResponse, provided by the $WebApiModulesPluginsKissFlowOrderResponseExtension extension

copyWithWrapped({Wrapped<int?>? status, Wrapped<bool?>? success, Wrapped<String?>? msg, Wrapped<WebApiModulesAgentOrderOrder?>? order, Wrapped<String?>? orderUrl, Wrapped<String?>? agentEmail, Wrapped<String?>? projectManagerEmail, Wrapped<String?>? outsideSalesRepresentativeEmail}) WebApiModulesPluginsKissFlowOrderResponse

Available on WebApiModulesPluginsKissFlowOrderResponse, provided by the $WebApiModulesPluginsKissFlowOrderResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesPluginsKissFlowOrderResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesPluginsKissFlowOrderResponse instance)