WebApiModulesPluginsKissFlowQuoteResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsKissFlowQuoteResponse({int? status, bool? success, String? msg, WebApiModulesAgentQuoteQuote? quote, String? quoteUrl, String? agentEmail, String? projectManagerEmail, String? outsideSalesRepresentativeEmail})
const
WebApiModulesPluginsKissFlowQuoteResponse.fromJson(Map<String, dynamic> json)
factory

Properties

agentEmail String?
final
hashCode int
The hash code for this object.
no setteroverride
msg String?
final
outsideSalesRepresentativeEmail String?
final
projectManagerEmail String?
final
quote WebApiModulesAgentQuoteQuote?
final
quoteUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
success bool?
final

Methods

copyWith({int? status, bool? success, String? msg, WebApiModulesAgentQuoteQuote? quote, String? quoteUrl, String? agentEmail, String? projectManagerEmail, String? outsideSalesRepresentativeEmail}) WebApiModulesPluginsKissFlowQuoteResponse

Available on WebApiModulesPluginsKissFlowQuoteResponse, provided by the $WebApiModulesPluginsKissFlowQuoteResponseExtension extension

copyWithWrapped({Wrapped<int?>? status, Wrapped<bool?>? success, Wrapped<String?>? msg, Wrapped<WebApiModulesAgentQuoteQuote?>? quote, Wrapped<String?>? quoteUrl, Wrapped<String?>? agentEmail, Wrapped<String?>? projectManagerEmail, Wrapped<String?>? outsideSalesRepresentativeEmail}) WebApiModulesPluginsKissFlowQuoteResponse

Available on WebApiModulesPluginsKissFlowQuoteResponse, provided by the $WebApiModulesPluginsKissFlowQuoteResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesPluginsKissFlowQuoteResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesPluginsKissFlowQuoteResponse instance)