WebApiModulesPluginsShopifyLocation class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsShopifyLocation({String? locationId, String? locationName, String? storeURL, String? adminAPIAccessToken, String? secretKey, String? shopifyStoreId})
const
WebApiModulesPluginsShopifyLocation.fromJson(Map<String, dynamic> json)
factory

Properties

adminAPIAccessToken String?
final
hashCode int
The hash code for this object.
no setteroverride
locationId String?
final
locationName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String?
final
shopifyStoreId String?
final
storeURL String?
final

Methods

copyWith({String? locationId, String? locationName, String? storeURL, String? adminAPIAccessToken, String? secretKey, String? shopifyStoreId}) WebApiModulesPluginsShopifyLocation

Available on WebApiModulesPluginsShopifyLocation, provided by the $WebApiModulesPluginsShopifyLocationExtension extension

copyWithWrapped({Wrapped<String?>? locationId, Wrapped<String?>? locationName, Wrapped<String?>? storeURL, Wrapped<String?>? adminAPIAccessToken, Wrapped<String?>? secretKey, Wrapped<String?>? shopifyStoreId}) WebApiModulesPluginsShopifyLocation

Available on WebApiModulesPluginsShopifyLocation, provided by the $WebApiModulesPluginsShopifyLocationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesPluginsShopifyLocation Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesPluginsShopifyLocation instance)