WebApiModulesPluginsShopifyShopifyIntegrationStatusValue class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
installed bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

copyWith({bool? installed, String? status}) WebApiModulesPluginsShopifyShopifyIntegrationStatusValue

Available on WebApiModulesPluginsShopifyShopifyIntegrationStatusValue, provided by the $WebApiModulesPluginsShopifyShopifyIntegrationStatusValueExtension extension

copyWithWrapped({Wrapped<bool?>? installed, Wrapped<String?>? status}) WebApiModulesPluginsShopifyShopifyIntegrationStatusValue

Available on WebApiModulesPluginsShopifyShopifyIntegrationStatusValue, provided by the $WebApiModulesPluginsShopifyShopifyIntegrationStatusValueExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override