WebApiModulesPluginsTeamupTeamupPlugin class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsTeamupTeamupPlugin({bool? enabled, WebApiModulesPluginsTeamupTeamupSettings? settings})
-
const
-
WebApiModulesPluginsTeamupTeamupPlugin.fromJson(Map<
String, dynamic> json) -
factory
Properties
- enabled → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → WebApiModulesPluginsTeamupTeamupSettings?
-
final
Methods
-
copyWith(
{bool? enabled, WebApiModulesPluginsTeamupTeamupSettings? settings}) → WebApiModulesPluginsTeamupTeamupPlugin -
Available on WebApiModulesPluginsTeamupTeamupPlugin, provided by the $WebApiModulesPluginsTeamupTeamupPluginExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? enabled, Wrapped<WebApiModulesPluginsTeamupTeamupSettings?> ? settings}) → WebApiModulesPluginsTeamupTeamupPlugin -
Available on WebApiModulesPluginsTeamupTeamupPlugin, provided by the $WebApiModulesPluginsTeamupTeamupPluginExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsTeamupTeamupPlugin Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsTeamupTeamupPlugin instance)