WebApiModulesPluginsTeamupTeamupPluginLocationSettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsTeamupTeamupPluginLocationSettings({int? status, bool? success, String? msg, String? locationId, String? location, String? teamupCalendarKey, String? teamupDeliveryEventCalendarId, String? teamupPickupEventCalendarId})
-
const
-
WebApiModulesPluginsTeamupTeamupPluginLocationSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → String?
-
final
- locationId → String?
-
final
- msg → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- success → bool?
-
final
- teamupCalendarKey → String?
-
final
- teamupDeliveryEventCalendarId → String?
-
final
- teamupPickupEventCalendarId → String?
-
final
Methods
-
copyWith(
{int? status, bool? success, String? msg, String? locationId, String? location, String? teamupCalendarKey, String? teamupDeliveryEventCalendarId, String? teamupPickupEventCalendarId}) → WebApiModulesPluginsTeamupTeamupPluginLocationSettings -
Available on WebApiModulesPluginsTeamupTeamupPluginLocationSettings, provided by the $WebApiModulesPluginsTeamupTeamupPluginLocationSettingsExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? status, Wrapped<bool?> ? success, Wrapped<String?> ? msg, Wrapped<String?> ? locationId, Wrapped<String?> ? location, Wrapped<String?> ? teamupCalendarKey, Wrapped<String?> ? teamupDeliveryEventCalendarId, Wrapped<String?> ? teamupPickupEventCalendarId}) → WebApiModulesPluginsTeamupTeamupPluginLocationSettings -
Available on WebApiModulesPluginsTeamupTeamupPluginLocationSettings, provided by the $WebApiModulesPluginsTeamupTeamupPluginLocationSettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsTeamupTeamupPluginLocationSettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsTeamupTeamupPluginLocationSettings instance)