FwStandardModelsBrowseRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardModelsBrowseRequest({dynamic miscfields, String? module, dynamic options, String? orderby, String? orderbydirection, int? top, int? pageno, int? pagesize, List<
String> ? searchfieldoperators, List<String> ? searchfields, List<String> ? searchfieldvalues, List<String> ? searchfieldtypes, List<String> ? searchseparators, List<String> ? searchcondition, List<String> ? searchconjunctions, dynamic uniqueids, dynamic boundids, Map<String, dynamic> ? filterfields, String? activeview, bool? emptyobject, bool? forexcel, List<FwStandardModelsCheckBoxListItem> ? excelfields, List<String> ? totalfields, Map<String, dynamic> ? activeviewfields}) -
FwStandardModelsBrowseRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeview → String?
-
final
-
activeviewfields
→ Map<
String, dynamic> ? -
final
- boundids → dynamic
-
final
- emptyobject → bool?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
-
filterfields
→ Map<
String, dynamic> ? -
final
- forexcel → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- miscfields → dynamic
-
final
- module → String?
-
final
- options → dynamic
-
final
- orderby → String?
-
final
- orderbydirection → String?
-
final
- pageno → int?
-
final
- pagesize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchcondition
→ List<
String> ? -
final
-
searchconjunctions
→ List<
String> ? -
final
-
searchfieldoperators
→ List<
String> ? -
final
-
searchfields
→ List<
String> ? -
final
-
searchfieldtypes
→ List<
String> ? -
final
-
searchfieldvalues
→ List<
String> ? -
final
-
searchseparators
→ List<
String> ? -
final
- top → int?
-
final
-
totalfields
→ List<
String> ? -
final
- uniqueids → dynamic
-
final
Methods
-
copyWith(
{dynamic miscfields, String? module, dynamic options, String? orderby, String? orderbydirection, int? top, int? pageno, int? pagesize, List< String> ? searchfieldoperators, List<String> ? searchfields, List<String> ? searchfieldvalues, List<String> ? searchfieldtypes, List<String> ? searchseparators, List<String> ? searchcondition, List<String> ? searchconjunctions, dynamic uniqueids, dynamic boundids, Map<String, dynamic> ? filterfields, String? activeview, bool? emptyobject, bool? forexcel, List<FwStandardModelsCheckBoxListItem> ? excelfields, List<String> ? totalfields, Map<String, dynamic> ? activeviewfields}) → FwStandardModelsBrowseRequest -
Available on FwStandardModelsBrowseRequest, provided by the $FwStandardModelsBrowseRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModelsBrowseRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModelsBrowseRequest instance)