FwStandardModulesAdministratorCustomReportCssCustomReportCssLoader class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorCustomReportCssCustomReportCssLoader({int? customReportCssId, String? description, String? css, bool? isGlobal, bool? inactive, bool? active, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
FwStandardModulesAdministratorCustomReportCssCustomReportCssLoader.fromJson(Map<String, dynamic> json)
factory

Properties

active bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
css String?
final
custom List<FwStandardDataFwCustomValue>?
final
customReportCssId int?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
isGlobal bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final

Methods

copyWith({int? customReportCssId, String? description, String? css, bool? isGlobal, bool? inactive, bool? active, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) FwStandardModulesAdministratorCustomReportCssCustomReportCssLoader

Available on FwStandardModulesAdministratorCustomReportCssCustomReportCssLoader, provided by the $FwStandardModulesAdministratorCustomReportCssCustomReportCssLoaderExtension extension

copyWithWrapped({Wrapped<int?>? customReportCssId, Wrapped<String?>? description, Wrapped<String?>? css, Wrapped<bool?>? isGlobal, Wrapped<bool?>? inactive, Wrapped<bool?>? active, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) FwStandardModulesAdministratorCustomReportCssCustomReportCssLoader

Available on FwStandardModulesAdministratorCustomReportCssCustomReportCssLoader, provided by the $FwStandardModulesAdministratorCustomReportCssCustomReportCssLoaderExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override