WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequest({DateTime? asOfDate, String? officeLocationId, String? customerId, String? dealCsrId, String? dealTypeId, String? dealId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

asOfDate DateTime?
final
customerId String?
final
customReportLayoutId String?
final
dealCsrId String?
final
dealId String?
final
dealTypeId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
officeLocationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DateTime? asOfDate, String? officeLocationId, String? customerId, String? dealCsrId, String? dealTypeId, String? dealId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequest

Available on WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequest, provided by the $WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? asOfDate, Wrapped<String?>? officeLocationId, Wrapped<String?>? customerId, Wrapped<String?>? dealCsrId, Wrapped<String?>? dealTypeId, Wrapped<String?>? dealId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields}) WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequest

Available on WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequest, provided by the $WebApiModulesReportsAccountingReportsArAgingReportArAgingReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override