WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequest({DateTime? asOfDate, String? officeLocationId, String? customerId, String? dealCsrId, String? dealTypeId, String? dealId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

asOfDate DateTime?
final
customerId String?
final
customReportLayoutId String?
final
dealCsrId String?
final
dealId String?
final
dealTypeId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
officeLocationId String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final

Methods

copyWith({DateTime? asOfDate, String? officeLocationId, String? customerId, String? dealCsrId, String? dealTypeId, String? dealId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequest

Available on WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequest, provided by the $WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? asOfDate, Wrapped<String?>? officeLocationId, Wrapped<String?>? customerId, Wrapped<String?>? dealCsrId, Wrapped<String?>? dealTypeId, Wrapped<String?>? dealId, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequest

Available on WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequest, provided by the $WebApiModulesReportsAccountingReportsArAgingSummaryReportArAgingSummaryReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override