WebApiModulesReportsAccountingReportsGlDistributionReportGlDistributionReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsAccountingReportsGlDistributionReportGlDistributionReportRequest({DateTime? fromDate, DateTime? toDate, String? officeLocationId, String? glAccountId, String? excludeGlAccountId, String? dealId, bool? isSomeDetail, bool? isFullDetail, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsAccountingReportsGlDistributionReportGlDistributionReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
dealId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
excludeGlAccountId String?
final
fromDate DateTime?
final
glAccountId String?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isFullDetail bool?
final
isSomeDetail bool?
final
isSummary bool?
final
locale String?
final
officeLocationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate DateTime?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? officeLocationId, String? glAccountId, String? excludeGlAccountId, String? dealId, bool? isSomeDetail, bool? isFullDetail, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsAccountingReportsGlDistributionReportGlDistributionReportRequest

Available on WebApiModulesReportsAccountingReportsGlDistributionReportGlDistributionReportRequest, provided by the $WebApiModulesReportsAccountingReportsGlDistributionReportGlDistributionReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override