WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequest({bool? shelfLifeExpired, bool? shelfLifeWillExpire, int? numberOfDays, String? warehouseId, String? inventoryTypeId, String? categoryId, String? inventoryId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

categoryId String?
final
customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
inventoryId String?
final
inventoryTypeId String?
final
isSummary bool?
final
locale String?
final
numberOfDays int?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelfLifeExpired bool?
final
shelfLifeWillExpire bool?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final
warehouseId String?
final

Methods

copyWith({bool? shelfLifeExpired, bool? shelfLifeWillExpire, int? numberOfDays, String? warehouseId, String? inventoryTypeId, String? categoryId, String? inventoryId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequest

Available on WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequest, provided by the $WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequestExtension extension

copyWithWrapped({Wrapped<bool?>? shelfLifeExpired, Wrapped<bool?>? shelfLifeWillExpire, Wrapped<int?>? numberOfDays, Wrapped<String?>? warehouseId, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? categoryId, Wrapped<String?>? inventoryId, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequest

Available on WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequest, provided by the $WebApiModulesReportsAssetShelfLifeExpirationReportAssetShelfLifeExpirationReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override