WebApiModulesReportsBillingBillingAnalysisReportBillingAnalysisReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsBillingBillingAnalysisReportBillingAnalysisReportRequest({DateTime? fromDate, DateTime? toDate, String? dateType, String? officeLocationId, String? customerId, String? dealId, String? projectId, String? agentId, List<FwStandardModelsSelectedCheckBoxListItem>? status, List<FwStandardModelsSelectedCheckBoxListItem>? includeFilter, List<FwStandardModelsSelectedCheckBoxListItem>? includeTaxFilter, bool? excludeOrdersBilledInTotal, bool? includeProjectStatus, bool? includeCreditsInvoiced, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsBillingBillingAnalysisReportBillingAnalysisReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String?
final
customerId String?
final
customReportLayoutId String?
final
dateType String?
final
dealId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
excludeOrdersBilledInTotal bool?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
includeCreditsInvoiced bool?
final
includeFilter List<FwStandardModelsSelectedCheckBoxListItem>?
final
includeIdColumns bool?
final
includeProjectStatus bool?
final
includeSubHeadingsAndSubTotals bool?
final
includeTaxFilter List<FwStandardModelsSelectedCheckBoxListItem>?
final
isSummary bool?
final
locale String?
final
officeLocationId String?
final
projectId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status List<FwStandardModelsSelectedCheckBoxListItem>?
final
toDate DateTime?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? dateType, String? officeLocationId, String? customerId, String? dealId, String? projectId, String? agentId, List<FwStandardModelsSelectedCheckBoxListItem>? status, List<FwStandardModelsSelectedCheckBoxListItem>? includeFilter, List<FwStandardModelsSelectedCheckBoxListItem>? includeTaxFilter, bool? excludeOrdersBilledInTotal, bool? includeProjectStatus, bool? includeCreditsInvoiced, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsBillingBillingAnalysisReportBillingAnalysisReportRequest

Available on WebApiModulesReportsBillingBillingAnalysisReportBillingAnalysisReportRequest, provided by the $WebApiModulesReportsBillingBillingAnalysisReportBillingAnalysisReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override