WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequest({DateTime? fromDate, DateTime? toDate, String? dateType, int? discountPercent, String? officeLocationId, String? departmentId, String? customerId, String? dealId, String? discountReasonId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customerId String?
final
customReportLayoutId String?
final
dateType String?
final
dealId String?
final
departmentId String?
final
discountPercent int?
final
discountReasonId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
officeLocationId String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate DateTime?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? dateType, int? discountPercent, String? officeLocationId, String? departmentId, String? customerId, String? dealId, String? discountReasonId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequest

Available on WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequest, provided by the $WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<String?>? dateType, Wrapped<int?>? discountPercent, Wrapped<String?>? officeLocationId, Wrapped<String?>? departmentId, Wrapped<String?>? customerId, Wrapped<String?>? dealId, Wrapped<String?>? discountReasonId, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequest

Available on WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequest, provided by the $WebApiModulesReportsBillingInvoiceDiscountReportInvoiceDiscountReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override