WebApiModulesReportsBillingInvoiceReportInvoiceReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesReportsBillingInvoiceReportInvoiceReportRequest({String? invoiceId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<
FwStandardModelsCheckBoxListItem> ? excelfields}) -
WebApiModulesReportsBillingInvoiceReportInvoiceReportRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- customReportLayoutId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- invoiceId → String?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? invoiceId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List< FwStandardModelsCheckBoxListItem> ? excelfields}) → WebApiModulesReportsBillingInvoiceReportInvoiceReportRequest -
Available on WebApiModulesReportsBillingInvoiceReportInvoiceReportRequest, provided by the $WebApiModulesReportsBillingInvoiceReportInvoiceReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesReportsBillingInvoiceReportInvoiceReportRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesReportsBillingInvoiceReportInvoiceReportRequest instance)