WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest({DateTime? fromDate, DateTime? toDate, int? hoursOffsetFromUTC, String? moduleName, String? webUsersId, String? keyword, List<FwStandardModelsSelectedCheckBoxListItem>? auditType, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

auditType List<FwStandardModelsSelectedCheckBoxListItem>?
final
customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
hoursOffsetFromUTC int?
final
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
keyword String?
final
locale String?
final
moduleName String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate DateTime?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final
webUsersId String?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, int? hoursOffsetFromUTC, String? moduleName, String? webUsersId, String? keyword, List<FwStandardModelsSelectedCheckBoxListItem>? auditType, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest

Available on WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest, provided by the $WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<int?>? hoursOffsetFromUTC, Wrapped<String?>? moduleName, Wrapped<String?>? webUsersId, Wrapped<String?>? keyword, Wrapped<List<FwStandardModelsSelectedCheckBoxListItem>?>? auditType, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest

Available on WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest, provided by the $WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override