WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest({String? batchId, String? fromBatchNumber, String? toBatchNumber, DateTime? batchFromDate, DateTime? batchToDate, String? batchRange, String? locationId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

batchFromDate DateTime?
final
batchId String?
final
batchRange String?
final
batchToDate DateTime?
final
customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
fromBatchNumber String?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
locationId String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toBatchNumber String?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final

Methods

copyWith({String? batchId, String? fromBatchNumber, String? toBatchNumber, DateTime? batchFromDate, DateTime? batchToDate, String? batchRange, String? locationId, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest

Available on WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest, provided by the $WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequestExtension extension

copyWithWrapped({Wrapped<String?>? batchId, Wrapped<String?>? fromBatchNumber, Wrapped<String?>? toBatchNumber, Wrapped<DateTime?>? batchFromDate, Wrapped<DateTime?>? batchToDate, Wrapped<String?>? batchRange, Wrapped<String?>? locationId, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest

Available on WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest, provided by the $WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override