WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequest({DateTime? fromDate, DateTime? toDate, bool? filterDates, int? daysChanged, String? officeLocationId, String? departmentId, String? userId, String? dealId, List<
FwStandardModelsSelectedCheckBoxListItem> ? revisionTypes, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) -
WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- customReportLayoutId → String?
-
final
- daysChanged → int?
-
final
- dealId → String?
-
final
- departmentId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- filterDates → bool?
-
final
- fromDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
- officeLocationId → String?
-
final
-
revisionTypes
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toDate → DateTime?
-
final
- userId → String?
-
final
Methods
-
copyWith(
{DateTime? fromDate, DateTime? toDate, bool? filterDates, int? daysChanged, String? officeLocationId, String? departmentId, String? userId, String? dealId, List< FwStandardModelsSelectedCheckBoxListItem> ? revisionTypes, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) → WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequest -
Available on WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequest, provided by the $WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesReportsContractReportsContractRevisionReportContractRevisionReportRequest instance)