WebApiModulesReportsContractReportsOutContractReportOutContractReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsContractReportsOutContractReportOutContractReportRequest({String? contractId, String? appLanguageId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsContractReportsOutContractReportOutContractReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

appLanguageId String?
final
contractId String?
final
customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? contractId, String? appLanguageId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsContractReportsOutContractReportOutContractReportRequest

Available on WebApiModulesReportsContractReportsOutContractReportOutContractReportRequest, provided by the $WebApiModulesReportsContractReportsOutContractReportOutContractReportRequestExtension extension

copyWithWrapped({Wrapped<String?>? contractId, Wrapped<String?>? appLanguageId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields}) WebApiModulesReportsContractReportsOutContractReportOutContractReportRequest

Available on WebApiModulesReportsContractReportsOutContractReportOutContractReportRequest, provided by the $WebApiModulesReportsContractReportsOutContractReportOutContractReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override