WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequest({DateTime? fromDate, DateTime? toDate, String? dateType, String? fromWarehouseId, String? toWarehouseId, String? departmentId, String? transferId, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, List<
FwStandardModelsSelectedCheckBoxListItem> ? statuses, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) -
WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- categoryId → String?
-
final
- customReportLayoutId → String?
-
final
- dateType → String?
-
final
- departmentId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- fromDate → DateTime?
-
final
- fromWarehouseId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- inventoryId → String?
-
final
- inventoryTypeId → String?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statuses
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- subCategoryId → String?
-
final
- toDate → DateTime?
-
final
- toWarehouseId → String?
-
final
- transferId → String?
-
final
Methods
-
copyWith(
{DateTime? fromDate, DateTime? toDate, String? dateType, String? fromWarehouseId, String? toWarehouseId, String? departmentId, String? transferId, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, List< FwStandardModelsSelectedCheckBoxListItem> ? statuses, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) → WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequest -
Available on WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequest, provided by the $WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesReportsMultiLocationReportsTransferReportTransferReportRequest instance)