WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequest({DateTime? fromDate, DateTime? toDate, String? availableFor, String? conflictType, String? warehouseId, String? departmentId, String? dealId, String? orderId, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, List<FwStandardModelsSelectedCheckBoxListItem>? classifications, String? ranks, List<FwStandardModelsSelectedCheckBoxListItem>? trackedBys, bool? refreshIfNeeded, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

availableFor String?
final
categoryId String?
final
classifications List<FwStandardModelsSelectedCheckBoxListItem>?
final
conflictType String?
final
customReportLayoutId String?
final
dealId String?
final
departmentId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
inventoryId String?
final
inventoryTypeId String?
final
isSummary bool?
final
locale String?
final
orderId String?
final
ranks String?
final
refreshIfNeeded bool?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategoryId String?
final
toDate DateTime?
final
trackedBys List<FwStandardModelsSelectedCheckBoxListItem>?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final
warehouseId String?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? availableFor, String? conflictType, String? warehouseId, String? departmentId, String? dealId, String? orderId, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, List<FwStandardModelsSelectedCheckBoxListItem>? classifications, String? ranks, List<FwStandardModelsSelectedCheckBoxListItem>? trackedBys, bool? refreshIfNeeded, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequest

Available on WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequest, provided by the $WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<String?>? availableFor, Wrapped<String?>? conflictType, Wrapped<String?>? warehouseId, Wrapped<String?>? departmentId, Wrapped<String?>? dealId, Wrapped<String?>? orderId, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? categoryId, Wrapped<String?>? subCategoryId, Wrapped<String?>? inventoryId, Wrapped<List<FwStandardModelsSelectedCheckBoxListItem>?>? classifications, Wrapped<String?>? ranks, Wrapped<List<FwStandardModelsSelectedCheckBoxListItem>?>? trackedBys, Wrapped<bool?>? refreshIfNeeded, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequest

Available on WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequest, provided by the $WebApiModulesReportsOrderReportsOrderConflictReportOrderConflictReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override