WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequest({String? orderId, String? shippingCaseId, String? weightInCase, bool? groupByShippingCase, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
groupByShippingCase bool?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
orderId String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingCaseId String?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final
weightInCase String?
final

Methods

copyWith({String? orderId, String? shippingCaseId, String? weightInCase, bool? groupByShippingCase, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequest

Available on WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequest, provided by the $WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? shippingCaseId, Wrapped<String?>? weightInCase, Wrapped<bool?>? groupByShippingCase, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequest

Available on WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequest, provided by the $WebApiModulesReportsOrderReportsOutgoingShippingLabelOutgoingShippingLabelRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override