WebApiModulesReportsOrderReportsProjectReportProjectReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsOrderReportsProjectReportProjectReportRequest({String? projectId, String? id, WebApiModulesReportsOrderReportsOrderReportReportViewType? reportView, bool? printEntireGroup, bool? printInventoryType, bool? printCategory, bool? printTotalReplacementCost, bool? printInventoryTypeSubTotal, bool? printCategorySubTotal, bool? printZeroExtended, bool? printLineItemNotes, bool? printSplitLines, bool? printGrandTotal, bool? printGrossTotal, bool? printGrandDiscount, bool? printGrandWeekly, bool? printGrandMonthly, bool? printGrandPeriod, bool? printGrandHiatus, bool? printActivityWeekly, bool? printActivityMonthly, bool? printActivityPeriod, String? languageId, bool? filterRentalAndSaleItems, String? rentalAndSaleItemsToInclude, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsOrderReportsProjectReportProjectReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
filterRentalAndSaleItems bool?
final
hashCode int
The hash code for this object.
no setteroverride
id String?
final
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
languageId String?
final
locale String?
final
printActivityMonthly bool?
final
printActivityPeriod bool?
final
printActivityWeekly bool?
final
printCategory bool?
final
printCategorySubTotal bool?
final
printEntireGroup bool?
final
printGrandDiscount bool?
final
printGrandHiatus bool?
final
printGrandMonthly bool?
final
printGrandPeriod bool?
final
printGrandTotal bool?
final
printGrandWeekly bool?
final
printGrossTotal bool?
final
printInventoryType bool?
final
printInventoryTypeSubTotal bool?
final
printLineItemNotes bool?
final
printSplitLines bool?
final
printTotalReplacementCost bool?
final
printZeroExtended bool?
final
projectId String?
final
rentalAndSaleItemsToInclude String?
final
reportName String?
final
reportView WebApiModulesReportsOrderReportsOrderReportReportViewType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final

Methods

copyWith({String? projectId, String? id, WebApiModulesReportsOrderReportsOrderReportReportViewType? reportView, bool? printEntireGroup, bool? printInventoryType, bool? printCategory, bool? printTotalReplacementCost, bool? printInventoryTypeSubTotal, bool? printCategorySubTotal, bool? printZeroExtended, bool? printLineItemNotes, bool? printSplitLines, bool? printGrandTotal, bool? printGrossTotal, bool? printGrandDiscount, bool? printGrandWeekly, bool? printGrandMonthly, bool? printGrandPeriod, bool? printGrandHiatus, bool? printActivityWeekly, bool? printActivityMonthly, bool? printActivityPeriod, String? languageId, bool? filterRentalAndSaleItems, String? rentalAndSaleItemsToInclude, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsOrderReportsProjectReportProjectReportRequest

Available on WebApiModulesReportsOrderReportsProjectReportProjectReportRequest, provided by the $WebApiModulesReportsOrderReportsProjectReportProjectReportRequestExtension extension

copyWithWrapped({Wrapped<String?>? projectId, Wrapped<String?>? id, Wrapped<WebApiModulesReportsOrderReportsOrderReportReportViewType?>? reportView, Wrapped<bool?>? printEntireGroup, Wrapped<bool?>? printInventoryType, Wrapped<bool?>? printCategory, Wrapped<bool?>? printTotalReplacementCost, Wrapped<bool?>? printInventoryTypeSubTotal, Wrapped<bool?>? printCategorySubTotal, Wrapped<bool?>? printZeroExtended, Wrapped<bool?>? printLineItemNotes, Wrapped<bool?>? printSplitLines, Wrapped<bool?>? printGrandTotal, Wrapped<bool?>? printGrossTotal, Wrapped<bool?>? printGrandDiscount, Wrapped<bool?>? printGrandWeekly, Wrapped<bool?>? printGrandMonthly, Wrapped<bool?>? printGrandPeriod, Wrapped<bool?>? printGrandHiatus, Wrapped<bool?>? printActivityWeekly, Wrapped<bool?>? printActivityMonthly, Wrapped<bool?>? printActivityPeriod, Wrapped<String?>? languageId, Wrapped<bool?>? filterRentalAndSaleItems, Wrapped<String?>? rentalAndSaleItemsToInclude, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsOrderReportsProjectReportProjectReportRequest

Available on WebApiModulesReportsOrderReportsProjectReportProjectReportRequest, provided by the $WebApiModulesReportsOrderReportsProjectReportProjectReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override