WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequest({DateTime? fromDate, DateTime? toDate, String? dateType, bool? filterDates, String? officeLocationId, String? departmentId, String? customerId, String? dealTypeId, String? dealStatusId, String? dealId, String? agentId, List<
FwStandardModelsSelectedCheckBoxListItem> ? orderType, List<FwStandardModelsSelectedCheckBoxListItem> ? quoteStatus, List<FwStandardModelsSelectedCheckBoxListItem> ? orderStatus, List<FwStandardModelsCheckBoxListItem> ? sortBy, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) -
WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agentId → String?
-
final
- customerId → String?
-
final
- customReportLayoutId → String?
-
final
- dateType → String?
-
final
- dealId → String?
-
final
- dealStatusId → String?
-
final
- dealTypeId → String?
-
final
- departmentId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- filterDates → bool?
-
final
- fromDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
- officeLocationId → String?
-
final
-
orderStatus
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
-
orderType
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
-
quoteStatus
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortBy
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- toDate → DateTime?
-
final
Methods
-
copyWith(
{DateTime? fromDate, DateTime? toDate, String? dateType, bool? filterDates, String? officeLocationId, String? departmentId, String? customerId, String? dealTypeId, String? dealStatusId, String? dealId, String? agentId, List< FwStandardModelsSelectedCheckBoxListItem> ? orderType, List<FwStandardModelsSelectedCheckBoxListItem> ? quoteStatus, List<FwStandardModelsSelectedCheckBoxListItem> ? orderStatus, List<FwStandardModelsCheckBoxListItem> ? sortBy, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) → WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequest -
Available on WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequest, provided by the $WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesReportsOrderReportsQuoteOrderMasterReportQuoteOrderMasterReportRequest instance)