WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequest({String? quoteId, WebApiModulesReportsOrderReportsOrderReportReportViewType? reportView, bool? printInventoryType, bool? printCategory, bool? printTotalReplacementCost, bool? printInventoryTypeSubTotal, bool? printCategorySubTotal, bool? printZeroExtended, bool? printLineItemNotes, bool? printGrandTotal, bool? printGrossTotal, bool? printGrandDiscount, bool? printGrandWeekly, bool? printGrandPeriod, bool? printActivityWeekly, bool? printActivityPeriod, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
printActivityPeriod bool?
final
printActivityWeekly bool?
final
printCategory bool?
final
printCategorySubTotal bool?
final
printGrandDiscount bool?
final
printGrandPeriod bool?
final
printGrandTotal bool?
final
printGrandWeekly bool?
final
printGrossTotal bool?
final
printInventoryType bool?
final
printInventoryTypeSubTotal bool?
final
printLineItemNotes bool?
final
printTotalReplacementCost bool?
final
printZeroExtended bool?
final
quoteId String?
final
reportView WebApiModulesReportsOrderReportsOrderReportReportViewType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? quoteId, WebApiModulesReportsOrderReportsOrderReportReportViewType? reportView, bool? printInventoryType, bool? printCategory, bool? printTotalReplacementCost, bool? printInventoryTypeSubTotal, bool? printCategorySubTotal, bool? printZeroExtended, bool? printLineItemNotes, bool? printGrandTotal, bool? printGrossTotal, bool? printGrandDiscount, bool? printGrandWeekly, bool? printGrandPeriod, bool? printActivityWeekly, bool? printActivityPeriod, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequest

Available on WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequest, provided by the $WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequestExtension extension

copyWithWrapped({Wrapped<String?>? quoteId, Wrapped<WebApiModulesReportsOrderReportsOrderReportReportViewType?>? reportView, Wrapped<bool?>? printInventoryType, Wrapped<bool?>? printCategory, Wrapped<bool?>? printTotalReplacementCost, Wrapped<bool?>? printInventoryTypeSubTotal, Wrapped<bool?>? printCategorySubTotal, Wrapped<bool?>? printZeroExtended, Wrapped<bool?>? printLineItemNotes, Wrapped<bool?>? printGrandTotal, Wrapped<bool?>? printGrossTotal, Wrapped<bool?>? printGrandDiscount, Wrapped<bool?>? printGrandWeekly, Wrapped<bool?>? printGrandPeriod, Wrapped<bool?>? printActivityWeekly, Wrapped<bool?>? printActivityPeriod, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields}) WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequest

Available on WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequest, provided by the $WebApiModulesReportsOrderReportsQuoteReportQuoteReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override