WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequest({String? orderId, String? projectId, List<FwStandardModelsCheckBoxListItem>? sortBy, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
orderId String?
final
projectId String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy List<FwStandardModelsCheckBoxListItem>?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final

Methods

copyWith({String? orderId, String? projectId, List<FwStandardModelsCheckBoxListItem>? sortBy, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequest

Available on WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequest, provided by the $WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? projectId, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? sortBy, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequest

Available on WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequest, provided by the $WebApiModulesReportsOrderReportsStandAloneItemReportStandAloneItemReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override