WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequest({String? orderId, String? rentalValue, bool? printZeroExtended, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
orderId String?
final
printZeroExtended bool?
final
rentalValue String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? orderId, String? rentalValue, bool? printZeroExtended, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequest

Available on WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequest, provided by the $WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? rentalValue, Wrapped<bool?>? printZeroExtended, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields}) WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequest

Available on WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequest, provided by the $WebApiModulesReportsOrderValueSheetReportOrderValueSheetReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override