WebApiModulesReportsRepairOrderReportsRepairOrderStatusReportRepairOrderStatusReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsRepairOrderReportsRepairOrderStatusReportRepairOrderStatusReportRequest({List<FwStandardModelsSelectedCheckBoxListItem>? repairOrderStatus, List<FwStandardModelsSelectedCheckBoxListItem>? priority, bool? billable, bool? billed, bool? owned, int? daysInRepair, String? daysInRepairFilterMode, bool? includeOutsideRepairsOnly, bool? includeDamageNotes, String? warehouseId, String? departmentId, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, String? repairItemStatusId, String? vendorId, String? vendorRepairItemStatusId, String? dealId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsRepairOrderReportsRepairOrderStatusReportRepairOrderStatusReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

billable bool?
final
billed bool?
final
categoryId String?
final
customReportLayoutId String?
final
daysInRepair int?
final
daysInRepairFilterMode String?
final
dealId String?
final
departmentId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeDamageNotes bool?
final
includeIdColumns bool?
final
includeOutsideRepairsOnly bool?
final
includeSubHeadingsAndSubTotals bool?
final
inventoryId String?
final
inventoryTypeId String?
final
isSummary bool?
final
locale String?
final
owned bool?
final
priority List<FwStandardModelsSelectedCheckBoxListItem>?
final
repairItemStatusId String?
final
repairOrderStatus List<FwStandardModelsSelectedCheckBoxListItem>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategoryId String?
final
vendorId String?
final
vendorRepairItemStatusId String?
final
warehouseId String?
final

Methods

copyWith({List<FwStandardModelsSelectedCheckBoxListItem>? repairOrderStatus, List<FwStandardModelsSelectedCheckBoxListItem>? priority, bool? billable, bool? billed, bool? owned, int? daysInRepair, String? daysInRepairFilterMode, bool? includeOutsideRepairsOnly, bool? includeDamageNotes, String? warehouseId, String? departmentId, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, String? repairItemStatusId, String? vendorId, String? vendorRepairItemStatusId, String? dealId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsRepairOrderReportsRepairOrderStatusReportRepairOrderStatusReportRequest

Available on WebApiModulesReportsRepairOrderReportsRepairOrderStatusReportRepairOrderStatusReportRequest, provided by the $WebApiModulesReportsRepairOrderReportsRepairOrderStatusReportRepairOrderStatusReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override