WebApiModulesReportsSharedInventoryTransactionReportInventoryTransactionReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
factory
Properties
- categoryId → String?
-
final
- customReportLayoutId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- fromDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- inventoryId → String?
-
final
- inventoryTypeId → String?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subCategoryId → String?
-
final
- toDate → DateTime?
-
final
-
transactionTypes
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{DateTime? fromDate, DateTime? toDate, List< FwStandardModelsSelectedCheckBoxListItem> ? transactionTypes, String? warehouseId, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) → WebApiModulesReportsSharedInventoryTransactionReportInventoryTransactionReportRequest -
Available on WebApiModulesReportsSharedInventoryTransactionReportInventoryTransactionReportRequest, provided by the $WebApiModulesReportsSharedInventoryTransactionReportInventoryTransactionReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
- fromJsonFactory → const WebApiModulesReportsSharedInventoryTransactionReportInventoryTransactionReportRequest Function()
-
toJsonFactory
→ const Map<
String, dynamic> Function()