WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequest({DateTime? fromDate, DateTime? toDate, String? warehouseId, String? inventoryTypeId, String? categoryId, String? inventoryId, String? poTypeId, String? vendorId, String? ranks, bool? oustandingOnly, List<FwStandardModelsSelectedCheckBoxListItem>? statuses, List<FwStandardModelsSelectedCheckBoxListItem>? activities, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

activities List<FwStandardModelsSelectedCheckBoxListItem>?
final
categoryId String?
final
customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
inventoryId String?
final
inventoryTypeId String?
final
isSummary bool?
final
locale String?
final
oustandingOnly bool?
final
poTypeId String?
final
ranks String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statuses List<FwStandardModelsSelectedCheckBoxListItem>?
final
toDate DateTime?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final
vendorId String?
final
warehouseId String?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? warehouseId, String? inventoryTypeId, String? categoryId, String? inventoryId, String? poTypeId, String? vendorId, String? ranks, bool? oustandingOnly, List<FwStandardModelsSelectedCheckBoxListItem>? statuses, List<FwStandardModelsSelectedCheckBoxListItem>? activities, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequest

Available on WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequest, provided by the $WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<String?>? warehouseId, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? categoryId, Wrapped<String?>? inventoryId, Wrapped<String?>? poTypeId, Wrapped<String?>? vendorId, Wrapped<String?>? ranks, Wrapped<bool?>? oustandingOnly, Wrapped<List<FwStandardModelsSelectedCheckBoxListItem>?>? statuses, Wrapped<List<FwStandardModelsSelectedCheckBoxListItem>?>? activities, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequest

Available on WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequest, provided by the $WebApiModulesReportsVendorReportsOutstandingPurchaseReportOutstandingPurchaseReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override