WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequest({String? inventoryTypeId, String? categoryId, String? subCategoryId, String? ranks, List<FwStandardModelsSelectedCheckBoxListItem>? includeFilter, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

categoryId String?
final
customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeFilter List<FwStandardModelsSelectedCheckBoxListItem>?
final
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
inventoryTypeId String?
final
isSummary bool?
final
locale String?
final
ranks String?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategoryId String?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final

Methods

copyWith({String? inventoryTypeId, String? categoryId, String? subCategoryId, String? ranks, List<FwStandardModelsSelectedCheckBoxListItem>? includeFilter, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequest

Available on WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequest, provided by the $WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequestExtension extension

copyWithWrapped({Wrapped<String?>? inventoryTypeId, Wrapped<String?>? categoryId, Wrapped<String?>? subCategoryId, Wrapped<String?>? ranks, Wrapped<List<FwStandardModelsSelectedCheckBoxListItem>?>? includeFilter, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequest

Available on WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequest, provided by the $WebApiModulesReportsWarehouseReportsInactiveEligibleReportInactiveEligibleReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override