WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL({String? rowType, String? description, String? quantity, String? printDate, String? printTime, String? printDateTime, List<String>? dateFields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL.fromJson(Map<String, dynamic> json)
factory

Properties

createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateFields List<String>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
printDate String?
final
printDateTime String?
final
printTime String?
final
quantity String?
final
rowType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final

Methods

copyWith({String? rowType, String? description, String? quantity, String? printDate, String? printTime, String? printDateTime, List<String>? dateFields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL

Available on WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL, provided by the $WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemLExtension extension

copyWithWrapped({Wrapped<String?>? rowType, Wrapped<String?>? description, Wrapped<String?>? quantity, Wrapped<String?>? printDate, Wrapped<String?>? printTime, Wrapped<String?>? printDateTime, Wrapped<List<String>?>? dateFields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL

Available on WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL, provided by the $WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemLExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override