WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportL class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportL({int? sessionNo, String? customer, String? warehouseId, String? estRentFrom, String? estRentTo, String? quikReceiptTermsConditionsId, List<WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL>? items, WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptMetaData? metaData, String? dealId, String? deal, String? dealNumber, String? dealNumberAndDeal, String? orderId, String? orderNumber, String? orderDate, String? orderStatus, String? orderStatusAsOfDate, String? orderPoNumber, String? orderType, String? orderTypeDescription, String? orderDescription, String? orderNumberAndDescription, String? orderBillingStartDate, String? orderBillingEndDate, String? orderLocation, String? deliveryTargetShipDate, String? deliveryRequiredDate, String? deliveryDeliveryType, String? deliveryDeliveryNotes, String? rowType, String? contractId, String? contractNumber, String? contractDate, String? contractTime, String? contractDateAndTime, String? contractType, String? exchangeContractId, bool? hasPendingExchange, bool? hasRental, bool? hasSales, String? inputByUserId, String? billingDate, String? officeLocation, String? officeLocationCompany, String? officeLocationAddress1, String? officeLocationAddress2, String? officeLocationCityStateZipCode, String? officeLocationCityStateZipCodeCountry, String? officeLocationPhone, String? officeLocationFax, String? warehouse, String? warehouseAddress1, String? warehouseAddress2, String? warehouseCityStateZipCode, String? warehouseCityStateZipCodeCountry, String? warehousePhone, String? warehouseFax, String? issuedToCompany, String? issuedToAttentionTo1, String? issuedToAttentionTo2, String? issuedToAddress1, String? issuedToAddress2, String? issuedToCity, String? issuedToState, String? issuedToZipCode, String? issuedToCountry, String? issuedToPhone, String? issuedToFax, String? usageDates, String? billingCycle, String? paymentTerms, String? agent, String? agentEmail, String? agentPhoneAndExtension, String? agentFax, String? agentMobilePhone, String? department, String? deliveryContact, String? deliveryLocation, String? deliveryAttention, String? deliveryAddress1, String? deliveryAddress2, String? deliveryCity, String? deliveryState, String? deliveryZip, String? deliveryCityStateZipCode, String? deliveryCountry, String? deliveryContactPhone, String? deliveryType, String? deliveryCarrier, String? deliveryShipVia, String? termsAndConditionsId, String? termsAndConditionsHtml, bool? termsAndConditionsNewPage, String? personPrintName, String? personSignature, String? note, String? officeLocationId, String? logosrc, String? printDate, String? printTime, String? printDateTime, List<String>? dateFields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportL.fromJson(Map<String, dynamic> json)
factory

Properties

agent String?
final
agentEmail String?
final
agentFax String?
final
agentMobilePhone String?
final
agentPhoneAndExtension String?
final
billingCycle String?
final
billingDate String?
final
contractDate String?
final
contractDateAndTime String?
final
contractId String?
final
contractNumber String?
final
contractTime String?
final
contractType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
customer String?
final
dateFields List<String>?
final
deal String?
final
dealId String?
final
dealNumber String?
final
dealNumberAndDeal String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
deliveryAddress1 String?
final
deliveryAddress2 String?
final
deliveryAttention String?
final
deliveryCarrier String?
final
deliveryCity String?
final
deliveryCityStateZipCode String?
final
deliveryContact String?
final
deliveryContactPhone String?
final
deliveryCountry String?
final
deliveryDeliveryNotes String?
final
deliveryDeliveryType String?
final
deliveryLocation String?
final
deliveryRequiredDate String?
final
deliveryShipVia String?
final
deliveryState String?
final
deliveryTargetShipDate String?
final
deliveryType String?
final
deliveryZip String?
final
department String?
final
estRentFrom String?
final
estRentTo String?
final
exchangeContractId String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hasPendingExchange bool?
final
hasRental bool?
final
hasSales bool?
final
inputByUserId String?
final
issuedToAddress1 String?
final
issuedToAddress2 String?
final
issuedToAttentionTo1 String?
final
issuedToAttentionTo2 String?
final
issuedToCity String?
final
issuedToCompany String?
final
issuedToCountry String?
final
issuedToFax String?
final
issuedToPhone String?
final
issuedToState String?
final
issuedToZipCode String?
final
items List<WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL>?
final
logosrc String?
final
metaData WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptMetaData?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
note String?
final
officeLocation String?
final
officeLocationAddress1 String?
final
officeLocationAddress2 String?
final
officeLocationCityStateZipCode String?
final
officeLocationCityStateZipCodeCountry String?
final
officeLocationCompany String?
final
officeLocationFax String?
final
officeLocationId String?
final
officeLocationPhone String?
final
orderBillingEndDate String?
final
orderBillingStartDate String?
final
orderDate String?
final
orderDescription String?
final
orderId String?
final
orderLocation String?
final
orderNumber String?
final
orderNumberAndDescription String?
final
orderPoNumber String?
final
orderStatus String?
final
orderStatusAsOfDate String?
final
orderType String?
final
orderTypeDescription String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentTerms String?
final
personPrintName String?
final
personSignature String?
final
printDate String?
final
printDateTime String?
final
printTime String?
final
quikReceiptTermsConditionsId String?
final
rowType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionNo int?
final
termsAndConditionsHtml String?
final
termsAndConditionsId String?
final
termsAndConditionsNewPage bool?
final
translation List<FwStandardDataFwTranslatedValue>?
final
usageDates String?
final
warehouse String?
final
warehouseAddress1 String?
final
warehouseAddress2 String?
final
warehouseCityStateZipCode String?
final
warehouseCityStateZipCodeCountry String?
final
warehouseFax String?
final
warehouseId String?
final
warehousePhone String?
final

Methods

copyWith({int? sessionNo, String? customer, String? warehouseId, String? estRentFrom, String? estRentTo, String? quikReceiptTermsConditionsId, List<WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL>? items, WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptMetaData? metaData, String? dealId, String? deal, String? dealNumber, String? dealNumberAndDeal, String? orderId, String? orderNumber, String? orderDate, String? orderStatus, String? orderStatusAsOfDate, String? orderPoNumber, String? orderType, String? orderTypeDescription, String? orderDescription, String? orderNumberAndDescription, String? orderBillingStartDate, String? orderBillingEndDate, String? orderLocation, String? deliveryTargetShipDate, String? deliveryRequiredDate, String? deliveryDeliveryType, String? deliveryDeliveryNotes, String? rowType, String? contractId, String? contractNumber, String? contractDate, String? contractTime, String? contractDateAndTime, String? contractType, String? exchangeContractId, bool? hasPendingExchange, bool? hasRental, bool? hasSales, String? inputByUserId, String? billingDate, String? officeLocation, String? officeLocationCompany, String? officeLocationAddress1, String? officeLocationAddress2, String? officeLocationCityStateZipCode, String? officeLocationCityStateZipCodeCountry, String? officeLocationPhone, String? officeLocationFax, String? warehouse, String? warehouseAddress1, String? warehouseAddress2, String? warehouseCityStateZipCode, String? warehouseCityStateZipCodeCountry, String? warehousePhone, String? warehouseFax, String? issuedToCompany, String? issuedToAttentionTo1, String? issuedToAttentionTo2, String? issuedToAddress1, String? issuedToAddress2, String? issuedToCity, String? issuedToState, String? issuedToZipCode, String? issuedToCountry, String? issuedToPhone, String? issuedToFax, String? usageDates, String? billingCycle, String? paymentTerms, String? agent, String? agentEmail, String? agentPhoneAndExtension, String? agentFax, String? agentMobilePhone, String? department, String? deliveryContact, String? deliveryLocation, String? deliveryAttention, String? deliveryAddress1, String? deliveryAddress2, String? deliveryCity, String? deliveryState, String? deliveryZip, String? deliveryCityStateZipCode, String? deliveryCountry, String? deliveryContactPhone, String? deliveryType, String? deliveryCarrier, String? deliveryShipVia, String? termsAndConditionsId, String? termsAndConditionsHtml, bool? termsAndConditionsNewPage, String? personPrintName, String? personSignature, String? note, String? officeLocationId, String? logosrc, String? printDate, String? printTime, String? printDateTime, List<String>? dateFields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportL

Available on WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportL, provided by the $WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportLExtension extension

copyWithWrapped({Wrapped<int?>? sessionNo, Wrapped<String?>? customer, Wrapped<String?>? warehouseId, Wrapped<String?>? estRentFrom, Wrapped<String?>? estRentTo, Wrapped<String?>? quikReceiptTermsConditionsId, Wrapped<List<WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL>?>? items, Wrapped<WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptMetaData?>? metaData, Wrapped<String?>? dealId, Wrapped<String?>? deal, Wrapped<String?>? dealNumber, Wrapped<String?>? dealNumberAndDeal, Wrapped<String?>? orderId, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDate, Wrapped<String?>? orderStatus, Wrapped<String?>? orderStatusAsOfDate, Wrapped<String?>? orderPoNumber, Wrapped<String?>? orderType, Wrapped<String?>? orderTypeDescription, Wrapped<String?>? orderDescription, Wrapped<String?>? orderNumberAndDescription, Wrapped<String?>? orderBillingStartDate, Wrapped<String?>? orderBillingEndDate, Wrapped<String?>? orderLocation, Wrapped<String?>? deliveryTargetShipDate, Wrapped<String?>? deliveryRequiredDate, Wrapped<String?>? deliveryDeliveryType, Wrapped<String?>? deliveryDeliveryNotes, Wrapped<String?>? rowType, Wrapped<String?>? contractId, Wrapped<String?>? contractNumber, Wrapped<String?>? contractDate, Wrapped<String?>? contractTime, Wrapped<String?>? contractDateAndTime, Wrapped<String?>? contractType, Wrapped<String?>? exchangeContractId, Wrapped<bool?>? hasPendingExchange, Wrapped<bool?>? hasRental, Wrapped<bool?>? hasSales, Wrapped<String?>? inputByUserId, Wrapped<String?>? billingDate, Wrapped<String?>? officeLocation, Wrapped<String?>? officeLocationCompany, Wrapped<String?>? officeLocationAddress1, Wrapped<String?>? officeLocationAddress2, Wrapped<String?>? officeLocationCityStateZipCode, Wrapped<String?>? officeLocationCityStateZipCodeCountry, Wrapped<String?>? officeLocationPhone, Wrapped<String?>? officeLocationFax, Wrapped<String?>? warehouse, Wrapped<String?>? warehouseAddress1, Wrapped<String?>? warehouseAddress2, Wrapped<String?>? warehouseCityStateZipCode, Wrapped<String?>? warehouseCityStateZipCodeCountry, Wrapped<String?>? warehousePhone, Wrapped<String?>? warehouseFax, Wrapped<String?>? issuedToCompany, Wrapped<String?>? issuedToAttentionTo1, Wrapped<String?>? issuedToAttentionTo2, Wrapped<String?>? issuedToAddress1, Wrapped<String?>? issuedToAddress2, Wrapped<String?>? issuedToCity, Wrapped<String?>? issuedToState, Wrapped<String?>? issuedToZipCode, Wrapped<String?>? issuedToCountry, Wrapped<String?>? issuedToPhone, Wrapped<String?>? issuedToFax, Wrapped<String?>? usageDates, Wrapped<String?>? billingCycle, Wrapped<String?>? paymentTerms, Wrapped<String?>? agent, Wrapped<String?>? agentEmail, Wrapped<String?>? agentPhoneAndExtension, Wrapped<String?>? agentFax, Wrapped<String?>? agentMobilePhone, Wrapped<String?>? department, Wrapped<String?>? deliveryContact, Wrapped<String?>? deliveryLocation, Wrapped<String?>? deliveryAttention, Wrapped<String?>? deliveryAddress1, Wrapped<String?>? deliveryAddress2, Wrapped<String?>? deliveryCity, Wrapped<String?>? deliveryState, Wrapped<String?>? deliveryZip, Wrapped<String?>? deliveryCityStateZipCode, Wrapped<String?>? deliveryCountry, Wrapped<String?>? deliveryContactPhone, Wrapped<String?>? deliveryType, Wrapped<String?>? deliveryCarrier, Wrapped<String?>? deliveryShipVia, Wrapped<String?>? termsAndConditionsId, Wrapped<String?>? termsAndConditionsHtml, Wrapped<bool?>? termsAndConditionsNewPage, Wrapped<String?>? personPrintName, Wrapped<String?>? personSignature, Wrapped<String?>? note, Wrapped<String?>? officeLocationId, Wrapped<String?>? logosrc, Wrapped<String?>? printDate, Wrapped<String?>? printTime, Wrapped<String?>? printDateTime, Wrapped<List<String>?>? dateFields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportL

Available on WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportL, provided by the $WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportLExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override