WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequest({String? orderId, String? printedByUsersId, String? storageContainerItemId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
orderId String?
final
printedByUsersId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageContainerItemId String?
final

Methods

copyWith({String? orderId, String? printedByUsersId, String? storageContainerItemId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequest

Available on WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequest, provided by the $WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequestExtension extension

copyWithWrapped({Wrapped<String?>? orderId, Wrapped<String?>? printedByUsersId, Wrapped<String?>? storageContainerItemId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields}) WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequest

Available on WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequest, provided by the $WebApiModulesReportsWarehouseReportsStorageContainerLabelStorageContainerLabelRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override