WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequest({DateTime? fromDate, DateTime? toDate, String? warehouseId, String? departmentId, String? agentId, String? activityTypeId, bool? excludeCompleteOrders, List<FwStandardModelsCheckBoxListItem>? sortBy, List<FwStandardModelsSelectedCheckBoxListItem>? orderTypes, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate})
const
WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

activityTypeId String?
final
agentId String?
final
customReportLayoutId String?
final
departmentId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
excludeCompleteOrders bool?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
orderTypes List<FwStandardModelsSelectedCheckBoxListItem>?
final
reportName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy List<FwStandardModelsCheckBoxListItem>?
final
toDate DateTime?
final
useEmailTemplate bool?
final
userDepartmentId String?
final
userLocationId String?
final
userWarehouseId String?
final
warehouseId String?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? warehouseId, String? departmentId, String? agentId, String? activityTypeId, bool? excludeCompleteOrders, List<FwStandardModelsCheckBoxListItem>? sortBy, List<FwStandardModelsSelectedCheckBoxListItem>? orderTypes, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields, String? reportName, bool? useEmailTemplate}) WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequest

Available on WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequest, provided by the $WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<String?>? warehouseId, Wrapped<String?>? departmentId, Wrapped<String?>? agentId, Wrapped<String?>? activityTypeId, Wrapped<bool?>? excludeCompleteOrders, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? sortBy, Wrapped<List<FwStandardModelsSelectedCheckBoxListItem>?>? orderTypes, Wrapped<String?>? userDepartmentId, Wrapped<String?>? userLocationId, Wrapped<String?>? userWarehouseId, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields, Wrapped<String?>? reportName, Wrapped<bool?>? useEmailTemplate}) WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequest

Available on WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequest, provided by the $WebApiModulesReportsWarehouseReportsWarehouseOutboundReportWarehouseOutboundReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override