FwStandardGridsAppDocumentDocumentImage class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardGridsAppDocumentDocumentImage({String? imageId, String? description, String? imageNumber, String? dataUrl})
const
FwStandardGridsAppDocumentDocumentImage.fromJson(Map<String, dynamic> json)
factory

Properties

dataUrl String?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
imageId String?
final
imageNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? imageId, String? description, String? imageNumber, String? dataUrl}) FwStandardGridsAppDocumentDocumentImage

Available on FwStandardGridsAppDocumentDocumentImage, provided by the $FwStandardGridsAppDocumentDocumentImageExtension extension

copyWithWrapped({Wrapped<String?>? imageId, Wrapped<String?>? description, Wrapped<String?>? imageNumber, Wrapped<String?>? dataUrl}) FwStandardGridsAppDocumentDocumentImage

Available on FwStandardGridsAppDocumentDocumentImage, provided by the $FwStandardGridsAppDocumentDocumentImageExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const FwStandardGridsAppDocumentDocumentImage Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(FwStandardGridsAppDocumentDocumentImage instance)