MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic({MicrosoftAspNetCoreMvcActionResult? result, WebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSound? value})
-
const
-
MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- result → MicrosoftAspNetCoreMvcActionResult?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → WebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSound?
-
final
Methods
-
copyWith(
{MicrosoftAspNetCoreMvcActionResult? result, WebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSound? value}) → MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic -
Available on MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic, provided by the $MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogicExtension extension
-
copyWithWrapped(
{Wrapped< MicrosoftAspNetCoreMvcActionResult?> ? result, Wrapped<WebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSound?> ? value}) → MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic -
Available on MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic, provided by the $MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogicExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(MicrosoftAspNetCoreMvcActionResultWebApiModulesSettingsUserSettingsSoundProfileSoundSoundProfileSoundLogic instance)