WebApiModulesInventoryStorageContainerStorageContainerItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryStorageContainerStorageContainerItem({int? storageContainerItemId, int? storageContainerId, String? storageContainerBarcode, String? aisleShelf, String? orderNumber, String? orderDescription, String? deal, String? pickupLocation, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryStorageContainerStorageContainerItem.fromJson(Map<String, dynamic> json)
factory

Properties

aisleShelf String?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
deal String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderDescription String?
final
orderNumber String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
pickupLocation String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageContainerBarcode String?
final
storageContainerId int?
final
storageContainerItemId int?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? storageContainerItemId, int? storageContainerId, String? storageContainerBarcode, String? aisleShelf, String? orderNumber, String? orderDescription, String? deal, String? pickupLocation, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryStorageContainerStorageContainerItem

Available on WebApiModulesInventoryStorageContainerStorageContainerItem, provided by the $WebApiModulesInventoryStorageContainerStorageContainerItemExtension extension

copyWithWrapped({Wrapped<int?>? storageContainerItemId, Wrapped<int?>? storageContainerId, Wrapped<String?>? storageContainerBarcode, Wrapped<String?>? aisleShelf, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDescription, Wrapped<String?>? deal, Wrapped<String?>? pickupLocation, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryStorageContainerStorageContainerItem

Available on WebApiModulesInventoryStorageContainerStorageContainerItem, provided by the $WebApiModulesInventoryStorageContainerStorageContainerItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override