WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncData class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncData({String? locationId, String? location, bool? connectionEnabled, String? qBOId, String? syncDate})
const
WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncData.fromJson(Map<String, dynamic> json)
factory

Properties

connectionEnabled bool?
final
hashCode int
The hash code for this object.
no setteroverride
location String?
final
locationId String?
final
qBOId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncDate String?
final

Methods

copyWith({String? locationId, String? location, bool? connectionEnabled, String? qBOId, String? syncDate}) WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncData

Available on WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncData, provided by the $WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncDataExtension extension

copyWithWrapped({Wrapped<String?>? locationId, Wrapped<String?>? location, Wrapped<bool?>? connectionEnabled, Wrapped<String?>? qBOId, Wrapped<String?>? syncDate}) WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncData

Available on WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncData, provided by the $WebApiModulesPluginsQuickbooksOnlineRwToQBOLogicLocationSyncDataExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override