WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettings({String? controlId, String? name, bool? usePrefixOnAssetAccounts, bool? usePrefixOnIncomeAccounts, bool? usePrefixOnExpenseAccounts, bool? usePrefixOnLiabilityAccounts, bool? useSuffixOnAssetAccounts, bool? useSuffixOnExpenseAccounts, bool? useSuffixOnIncomeAccounts, bool? useSuffixOnLiabilityAccounts, double? assetUnitCostThreshold, bool? purchaseUseCompleteKitAccounts, bool? enableForeignSubRentalWithholding, String? foreignSubRentalWithholdingCountryId, String? foreignSubRentalWithholdingCountry, double? foreignSubRentalWithholdingPercent, String? assetAccountNumberFormat, String? expenseAccountNumberFormat, String? incomeAccountNumberFormat, String? liabilityAccountNumberFormat, bool? useOrderCost, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettings.fromJson(Map<String, dynamic> json)
factory

Properties

assetAccountNumberFormat String?
final
assetUnitCostThreshold double?
final
auditNote String?
final
controlId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
enableForeignSubRentalWithholding bool?
final
expenseAccountNumberFormat String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
foreignSubRentalWithholdingCountry String?
final
foreignSubRentalWithholdingCountryId String?
final
foreignSubRentalWithholdingPercent double?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
incomeAccountNumberFormat String?
final
liabilityAccountNumberFormat String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
name String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
purchaseUseCompleteKitAccounts bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
useOrderCost bool?
final
usePrefixOnAssetAccounts bool?
final
usePrefixOnExpenseAccounts bool?
final
usePrefixOnIncomeAccounts bool?
final
usePrefixOnLiabilityAccounts bool?
final
useSuffixOnAssetAccounts bool?
final
useSuffixOnExpenseAccounts bool?
final
useSuffixOnIncomeAccounts bool?
final
useSuffixOnLiabilityAccounts bool?
final

Methods

copyWith({String? controlId, String? name, bool? usePrefixOnAssetAccounts, bool? usePrefixOnIncomeAccounts, bool? usePrefixOnExpenseAccounts, bool? usePrefixOnLiabilityAccounts, bool? useSuffixOnAssetAccounts, bool? useSuffixOnExpenseAccounts, bool? useSuffixOnIncomeAccounts, bool? useSuffixOnLiabilityAccounts, double? assetUnitCostThreshold, bool? purchaseUseCompleteKitAccounts, bool? enableForeignSubRentalWithholding, String? foreignSubRentalWithholdingCountryId, String? foreignSubRentalWithholdingCountry, double? foreignSubRentalWithholdingPercent, String? assetAccountNumberFormat, String? expenseAccountNumberFormat, String? incomeAccountNumberFormat, String? liabilityAccountNumberFormat, bool? useOrderCost, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettings

Available on WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettings, provided by the $WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettingsExtension extension

copyWithWrapped({Wrapped<String?>? controlId, Wrapped<String?>? name, Wrapped<bool?>? usePrefixOnAssetAccounts, Wrapped<bool?>? usePrefixOnIncomeAccounts, Wrapped<bool?>? usePrefixOnExpenseAccounts, Wrapped<bool?>? usePrefixOnLiabilityAccounts, Wrapped<bool?>? useSuffixOnAssetAccounts, Wrapped<bool?>? useSuffixOnExpenseAccounts, Wrapped<bool?>? useSuffixOnIncomeAccounts, Wrapped<bool?>? useSuffixOnLiabilityAccounts, Wrapped<double?>? assetUnitCostThreshold, Wrapped<bool?>? purchaseUseCompleteKitAccounts, Wrapped<bool?>? enableForeignSubRentalWithholding, Wrapped<String?>? foreignSubRentalWithholdingCountryId, Wrapped<String?>? foreignSubRentalWithholdingCountry, Wrapped<double?>? foreignSubRentalWithholdingPercent, Wrapped<String?>? assetAccountNumberFormat, Wrapped<String?>? expenseAccountNumberFormat, Wrapped<String?>? incomeAccountNumberFormat, Wrapped<String?>? liabilityAccountNumberFormat, Wrapped<bool?>? useOrderCost, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettings

Available on WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettings, provided by the $WebApiModulesSettingsAccountingSettingsAccountingSettingsAccountingSettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override