WebApiModulesSettingsAccountingSettingsGlAccountGlAccount class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsAccountingSettingsGlAccountGlAccount({String? accountId, String? accountNumber, String? accountNumberSegment2, String? accountNumberSegment3, String? accountNumberSegment4, String? accountNumberSegment5, String? combinedAccountNumber, String? accountDescription, String? accountType, String? exportAccountTypeDebit, String? exportAccountTypeCredit, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsAccountingSettingsGlAccountGlAccount.fromJson(Map<String, dynamic> json)
factory

Properties

accountDescription String?
final
accountId String?
final
accountNumber String?
final
accountNumberSegment2 String?
final
accountNumberSegment3 String?
final
accountNumberSegment4 String?
final
accountNumberSegment5 String?
final
accountType String?
final
auditNote String?
final
combinedAccountNumber String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
exportAccountTypeCredit String?
final
exportAccountTypeDebit String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? accountId, String? accountNumber, String? accountNumberSegment2, String? accountNumberSegment3, String? accountNumberSegment4, String? accountNumberSegment5, String? combinedAccountNumber, String? accountDescription, String? accountType, String? exportAccountTypeDebit, String? exportAccountTypeCredit, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsAccountingSettingsGlAccountGlAccount

Available on WebApiModulesSettingsAccountingSettingsGlAccountGlAccount, provided by the $WebApiModulesSettingsAccountingSettingsGlAccountGlAccountExtension extension

copyWithWrapped({Wrapped<String?>? accountId, Wrapped<String?>? accountNumber, Wrapped<String?>? accountNumberSegment2, Wrapped<String?>? accountNumberSegment3, Wrapped<String?>? accountNumberSegment4, Wrapped<String?>? accountNumberSegment5, Wrapped<String?>? combinedAccountNumber, Wrapped<String?>? accountDescription, Wrapped<String?>? accountType, Wrapped<String?>? exportAccountTypeDebit, Wrapped<String?>? exportAccountTypeCredit, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsAccountingSettingsGlAccountGlAccount

Available on WebApiModulesSettingsAccountingSettingsGlAccountGlAccount, provided by the $WebApiModulesSettingsAccountingSettingsGlAccountGlAccountExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override