WebApiModulesSettingsAddressSettingsCountryCountry class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsAddressSettingsCountryCountry({String? countryId, String? country, String? countryISOName, String? countryCodeISOAlpha2, String? countryCodeISOAlpha3, int? countryCodeISONumeric, int? countryCodePhone, String? flagImage, bool? metric, String? currencyId, String? currency, String? currencyCode, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsAddressSettingsCountryCountry.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
country String?
final
countryCodeISOAlpha2 String?
final
countryCodeISOAlpha3 String?
final
countryCodeISONumeric int?
final
countryCodePhone int?
final
countryId String?
final
countryISOName String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currency String?
final
currencyCode String?
final
currencyId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
flagImage String?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
metric bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? countryId, String? country, String? countryISOName, String? countryCodeISOAlpha2, String? countryCodeISOAlpha3, int? countryCodeISONumeric, int? countryCodePhone, String? flagImage, bool? metric, String? currencyId, String? currency, String? currencyCode, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsAddressSettingsCountryCountry

Available on WebApiModulesSettingsAddressSettingsCountryCountry, provided by the $WebApiModulesSettingsAddressSettingsCountryCountryExtension extension

copyWithWrapped({Wrapped<String?>? countryId, Wrapped<String?>? country, Wrapped<String?>? countryISOName, Wrapped<String?>? countryCodeISOAlpha2, Wrapped<String?>? countryCodeISOAlpha3, Wrapped<int?>? countryCodeISONumeric, Wrapped<int?>? countryCodePhone, Wrapped<String?>? flagImage, Wrapped<bool?>? metric, Wrapped<String?>? currencyId, Wrapped<String?>? currency, Wrapped<String?>? currencyCode, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsAddressSettingsCountryCountry

Available on WebApiModulesSettingsAddressSettingsCountryCountry, provided by the $WebApiModulesSettingsAddressSettingsCountryCountryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override