WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycle class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycle({String? billingCycleId, String? billingCycle, String? billingCycleType, String? nextBillingCycleId, String? nextBillingCycle, bool? prorateMonthly, bool? monthlyWeekdaysOnly, bool? excludeObservedHolidays, String? billOnPeriodStartOrEnd, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycle.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
billingCycle String?
final
billingCycleId String?
final
billingCycleType String?
final
billOnPeriodStartOrEnd String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
excludeObservedHolidays bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
monthlyWeekdaysOnly bool?
final
nextBillingCycle String?
final
nextBillingCycleId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
prorateMonthly bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? billingCycleId, String? billingCycle, String? billingCycleType, String? nextBillingCycleId, String? nextBillingCycle, bool? prorateMonthly, bool? monthlyWeekdaysOnly, bool? excludeObservedHolidays, String? billOnPeriodStartOrEnd, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycle

Available on WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycle, provided by the $WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycleExtension extension

copyWithWrapped({Wrapped<String?>? billingCycleId, Wrapped<String?>? billingCycle, Wrapped<String?>? billingCycleType, Wrapped<String?>? nextBillingCycleId, Wrapped<String?>? nextBillingCycle, Wrapped<bool?>? prorateMonthly, Wrapped<bool?>? monthlyWeekdaysOnly, Wrapped<bool?>? excludeObservedHolidays, Wrapped<String?>? billOnPeriodStartOrEnd, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycle

Available on WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycle, provided by the $WebApiModulesSettingsBillingCycleSettingsBillingCycleBillingCycleExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override