WebApiModulesSettingsCalendarSettingsHolidayHoliday class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsCalendarSettingsHolidayHoliday({String? holidayId, String? holiday, String? countryId, String? country, bool? custom, bool? observed, String? type, int? fixedMonth, int? fixedDay, int? fixedYear, int? dayOfWeek, int? weekOfMonth, int? adjustment, String? offsetHolidayId, String? offsetHoliday, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? $custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsCalendarSettingsHolidayHoliday.fromJson(Map<String, dynamic> json)
factory

Properties

$custom List<FwStandardDataFwCustomValue>?
final
adjustment int?
final
auditNote String?
final
country String?
final
countryId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom bool?
final
dateStamp String?
final
dayOfWeek int?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fixedDay int?
final
fixedMonth int?
final
fixedYear int?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
holiday String?
final
holidayId String?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
observed bool?
final
offsetHoliday String?
final
offsetHolidayId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
type String?
final
urlIdentifier → dynamic
final
weekOfMonth int?
final

Methods

copyWith({String? holidayId, String? holiday, String? countryId, String? country, bool? custom, bool? observed, String? type, int? fixedMonth, int? fixedDay, int? fixedYear, int? dayOfWeek, int? weekOfMonth, int? adjustment, String? offsetHolidayId, String? offsetHoliday, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? $custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsCalendarSettingsHolidayHoliday

Available on WebApiModulesSettingsCalendarSettingsHolidayHoliday, provided by the $WebApiModulesSettingsCalendarSettingsHolidayHolidayExtension extension

copyWithWrapped({Wrapped<String?>? holidayId, Wrapped<String?>? holiday, Wrapped<String?>? countryId, Wrapped<String?>? country, Wrapped<bool?>? custom, Wrapped<bool?>? observed, Wrapped<String?>? type, Wrapped<int?>? fixedMonth, Wrapped<int?>? fixedDay, Wrapped<int?>? fixedYear, Wrapped<int?>? dayOfWeek, Wrapped<int?>? weekOfMonth, Wrapped<int?>? adjustment, Wrapped<String?>? offsetHolidayId, Wrapped<String?>? offsetHoliday, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? $custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsCalendarSettingsHolidayHoliday

Available on WebApiModulesSettingsCalendarSettingsHolidayHoliday, provided by the $WebApiModulesSettingsCalendarSettingsHolidayHolidayExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override