WebApiModulesSettingsCrewPositionCrewPosition class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsCrewPositionCrewPosition({String? crewPositionId, String? crewId, String? rateId, String? laborTypeId, String? laborType, String? description, double? costHourly, double? costDaily, double? costWeekly, double? costMonthly, bool? isPrimary, String? effectiveDate, String? endDate, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsCrewPositionCrewPosition.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
costDaily double?
final
costHourly double?
final
costMonthly double?
final
costWeekly double?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
crewId String?
final
crewPositionId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
effectiveDate String?
final
endDate String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
isPrimary bool?
final
laborType String?
final
laborTypeId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
rateId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? crewPositionId, String? crewId, String? rateId, String? laborTypeId, String? laborType, String? description, double? costHourly, double? costDaily, double? costWeekly, double? costMonthly, bool? isPrimary, String? effectiveDate, String? endDate, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsCrewPositionCrewPosition

Available on WebApiModulesSettingsCrewPositionCrewPosition, provided by the $WebApiModulesSettingsCrewPositionCrewPositionExtension extension

copyWithWrapped({Wrapped<String?>? crewPositionId, Wrapped<String?>? crewId, Wrapped<String?>? rateId, Wrapped<String?>? laborTypeId, Wrapped<String?>? laborType, Wrapped<String?>? description, Wrapped<double?>? costHourly, Wrapped<double?>? costDaily, Wrapped<double?>? costWeekly, Wrapped<double?>? costMonthly, Wrapped<bool?>? isPrimary, Wrapped<String?>? effectiveDate, Wrapped<String?>? endDate, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsCrewPositionCrewPosition

Available on WebApiModulesSettingsCrewPositionCrewPosition, provided by the $WebApiModulesSettingsCrewPositionCrewPositionExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesSettingsCrewPositionCrewPosition Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesSettingsCrewPositionCrewPosition instance)