WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRate class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRate({String? currencyExchangeRateId, String? asOfDate, String? fromCurrencyId, String? importDate, double? exchangeRate, String? toCurrencyId, String? fromCurrencyCode, String? fromCurrency, String? fromCurrencySymbol, String? toCurrencyCode, String? toCurrency, String? toCurrencySymbol, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRate.fromJson(Map<String, dynamic> json)
factory

Properties

asOfDate String?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currencyExchangeRateId String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
exchangeRate double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fromCurrency String?
final
fromCurrencyCode String?
final
fromCurrencyId String?
final
fromCurrencySymbol String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
importDate String?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toCurrency String?
final
toCurrencyCode String?
final
toCurrencyId String?
final
toCurrencySymbol String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? currencyExchangeRateId, String? asOfDate, String? fromCurrencyId, String? importDate, double? exchangeRate, String? toCurrencyId, String? fromCurrencyCode, String? fromCurrency, String? fromCurrencySymbol, String? toCurrencyCode, String? toCurrency, String? toCurrencySymbol, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRate

Available on WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRate, provided by the $WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRateExtension extension

copyWithWrapped({Wrapped<String?>? currencyExchangeRateId, Wrapped<String?>? asOfDate, Wrapped<String?>? fromCurrencyId, Wrapped<String?>? importDate, Wrapped<double?>? exchangeRate, Wrapped<String?>? toCurrencyId, Wrapped<String?>? fromCurrencyCode, Wrapped<String?>? fromCurrency, Wrapped<String?>? fromCurrencySymbol, Wrapped<String?>? toCurrencyCode, Wrapped<String?>? toCurrency, Wrapped<String?>? toCurrencySymbol, Wrapped<bool?>? inactive, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRate

Available on WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRate, provided by the $WebApiModulesSettingsCurrencyExchangeRateCurrencyExchangeRateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override