WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory({String? customerCategoryId, String? customerCategory, String? dateStamp, bool? inactive, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customerCategory → String?
-
final
- customerCategoryId → String?
-
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactive → bool?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? customerCategoryId, String? customerCategory, String? dateStamp, bool? inactive, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory -
Available on WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory, provided by the $WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategoryExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? customerCategoryId, Wrapped<String?> ? customerCategory, Wrapped<String?> ? dateStamp, Wrapped<bool?> ? inactive, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes}) → WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategoryFwStandardDataFwDefaultAttribute> ?> -
Available on WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory, provided by the $WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategoryExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsCustomerSettingsCustomerCategoryCustomerCategory instance)