WebApiModulesSettingsDepartmentLocationDepartmentLocation class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsDepartmentLocationDepartmentLocation({int? id, String? departmentId, String? department, String? locationId, String? location, String? defaultOrderTypeId, String? defaultOrderType, String? projectDefaultOrderTypeId, String? projectDefaultOrderType, String? defaultTransferTypeId, String? defaultTransferType, String? glPrefix, String? glSuffix, bool? allowDecreaseOrderQuantityWhenStaged, bool? allowDecreaseOrderQuantityWhenOut, bool? autoCreditOnSalesReturn, String? depositFeeRateId, String? depositFeeRateICode, String? depositFeeRateDescription, String? flatAmountCreditInvoiceRateId, String? flatAmountCreditInvoiceRateICode, String? flatAmountCreditInvoiceRateDescription, bool? updateEstimatedStartAndStopDatesOnSubPurchaseOrders, bool? promptToUpdateEstimatedStartAndStopDatesOnSubPurchaseOrders, bool? updateBillingStartAndStopDatesOnSubPurchaseOrders, bool? promptToUpdateBillingStartAndStopDatesOnSubPurchaseOrders, String? purchaseOrderApprovalRequiredAsOf, bool? purchaseOrderRequireFirstApproval, bool? purchaseOrderRequireSecondApproval, bool? purchaseOrderAllowSecondApprovalWithoutFirstApproval, double? purchaseOrderUnapproveIncreaseAmount, double? purchaseOrderUnapproveIncreasePercent, bool? purchaseOrderPreventReceiveUnapproved, double? purchaseOrderFirstApprovalThresholdRental, double? purchaseOrderFirstApprovalThresholdSales, double? purchaseOrderFirstApprovalThresholdParts, double? purchaseOrderFirstApprovalThresholdMiscellaneous, double? purchaseOrderFirstApprovalThresholdLabor, double? purchaseOrderFirstApprovalThresholdRepair, double? purchaseOrderFirstApprovalThresholdSubRental, double? purchaseOrderFirstApprovalThresholdSubSales, double? purchaseOrderFirstApprovalThresholdSubMiscellaneous, double? purchaseOrderFirstApprovalThresholdSubLabor, double? purchaseOrderSecondApprovalThresholdRental, double? purchaseOrderSecondApprovalThresholdSales, double? purchaseOrderSecondApprovalThresholdParts, double? purchaseOrderSecondApprovalThresholdMiscellaneous, double? purchaseOrderSecondApprovalThresholdLabor, double? purchaseOrderSecondApprovalThresholdRepair, double? purchaseOrderSecondApprovalThresholdSubRental, double? purchaseOrderSecondApprovalThresholdSubSales, double? purchaseOrderSecondApprovalThresholdSubMiscellaneous, double? purchaseOrderSecondApprovalThresholdSubLabor, bool? completeRentalWithLAndDOrder, bool? disableCrewValidation, bool? storefrontEnableInventoryInquiryEmails, String? storefrontInventoryInquiryEmailToAddress, bool? storefrontEnableQuoteRequestEmails, String? storefrontQuoteRequestEmailToAddress, bool? useResponsiblePerson, bool? requireResponsiblePerson, String? vendorInvoiceModificationsPushToPo, bool? splitRentalLineItemWhenCheckedInEarly, bool? inactive, bool? createInvoiceForItemsAddedAfterPrebill, bool? createCreditForPreBilledItemsReturnedEarly, String? automaticallyCreateCreditForPreBilledItemsReturnedEarly, bool? doNotBillDayWhenItemsAreCheckedInByCertainTime, String? checkInByTimeToAvoidBilling, bool? createInvoiceForItemsCheckedInBeforeEstimatedStopDate, String? automaticallyCreateInvoiceForItemsCheckedInBeforeEstimatedStopDate, bool? automaticallyCompleteRepairOrderWhenAllItemsReleased, String? setInvoiceDate, String? creditInvoiceNumberFrom, bool? orderStaysActiveWithSubsInHolding, bool? assignConsignorBeforeStaging, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsDepartmentLocationDepartmentLocation.fromJson(Map<String, dynamic> json)
factory

Properties

allowDecreaseOrderQuantityWhenOut bool?
final
allowDecreaseOrderQuantityWhenStaged bool?
final
assignConsignorBeforeStaging bool?
final
auditNote String?
final
autoCreditOnSalesReturn bool?
final
automaticallyCompleteRepairOrderWhenAllItemsReleased bool?
final
automaticallyCreateCreditForPreBilledItemsReturnedEarly String?
final
automaticallyCreateInvoiceForItemsCheckedInBeforeEstimatedStopDate String?
final
checkInByTimeToAvoidBilling String?
final
completeRentalWithLAndDOrder bool?
final
createCreditForPreBilledItemsReturnedEarly bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
createInvoiceForItemsAddedAfterPrebill bool?
final
createInvoiceForItemsCheckedInBeforeEstimatedStopDate bool?
final
creditInvoiceNumberFrom String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultOrderType String?
final
defaultOrderTypeId String?
final
defaultTransferType String?
final
defaultTransferTypeId String?
final
department String?
final
departmentId String?
final
depositFeeRateDescription String?
final
depositFeeRateICode String?
final
depositFeeRateId String?
final
disableCrewValidation bool?
final
doNotBillDayWhenItemsAreCheckedInByCertainTime bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
flatAmountCreditInvoiceRateDescription String?
final
flatAmountCreditInvoiceRateICode String?
final
flatAmountCreditInvoiceRateId String?
final
glPrefix String?
final
glSuffix String?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
id int?
final
inactive bool?
final
location String?
final
locationId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderStaysActiveWithSubsInHolding bool?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
projectDefaultOrderType String?
final
projectDefaultOrderTypeId String?
final
promptToUpdateBillingStartAndStopDatesOnSubPurchaseOrders bool?
final
promptToUpdateEstimatedStartAndStopDatesOnSubPurchaseOrders bool?
final
purchaseOrderAllowSecondApprovalWithoutFirstApproval bool?
final
purchaseOrderApprovalRequiredAsOf String?
final
purchaseOrderFirstApprovalThresholdLabor double?
final
purchaseOrderFirstApprovalThresholdMiscellaneous double?
final
purchaseOrderFirstApprovalThresholdParts double?
final
purchaseOrderFirstApprovalThresholdRental double?
final
purchaseOrderFirstApprovalThresholdRepair double?
final
purchaseOrderFirstApprovalThresholdSales double?
final
purchaseOrderFirstApprovalThresholdSubLabor double?
final
purchaseOrderFirstApprovalThresholdSubMiscellaneous double?
final
purchaseOrderFirstApprovalThresholdSubRental double?
final
purchaseOrderFirstApprovalThresholdSubSales double?
final
purchaseOrderPreventReceiveUnapproved bool?
final
purchaseOrderRequireFirstApproval bool?
final
purchaseOrderRequireSecondApproval bool?
final
purchaseOrderSecondApprovalThresholdLabor double?
final
purchaseOrderSecondApprovalThresholdMiscellaneous double?
final
purchaseOrderSecondApprovalThresholdParts double?
final
purchaseOrderSecondApprovalThresholdRental double?
final
purchaseOrderSecondApprovalThresholdRepair double?
final
purchaseOrderSecondApprovalThresholdSales double?
final
purchaseOrderSecondApprovalThresholdSubLabor double?
final
purchaseOrderSecondApprovalThresholdSubMiscellaneous double?
final
purchaseOrderSecondApprovalThresholdSubRental double?
final
purchaseOrderSecondApprovalThresholdSubSales double?
final
purchaseOrderUnapproveIncreaseAmount double?
final
purchaseOrderUnapproveIncreasePercent double?
final
recordTitle String?
final
requireResponsiblePerson bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setInvoiceDate String?
final
splitRentalLineItemWhenCheckedInEarly bool?
final
storefrontEnableInventoryInquiryEmails bool?
final
storefrontEnableQuoteRequestEmails bool?
final
storefrontInventoryInquiryEmailToAddress String?
final
storefrontQuoteRequestEmailToAddress String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
updateBillingStartAndStopDatesOnSubPurchaseOrders bool?
final
updateEstimatedStartAndStopDatesOnSubPurchaseOrders bool?
final
urlIdentifier → dynamic
final
useResponsiblePerson bool?
final
vendorInvoiceModificationsPushToPo String?
final

Methods

copyWith({int? id, String? departmentId, String? department, String? locationId, String? location, String? defaultOrderTypeId, String? defaultOrderType, String? projectDefaultOrderTypeId, String? projectDefaultOrderType, String? defaultTransferTypeId, String? defaultTransferType, String? glPrefix, String? glSuffix, bool? allowDecreaseOrderQuantityWhenStaged, bool? allowDecreaseOrderQuantityWhenOut, bool? autoCreditOnSalesReturn, String? depositFeeRateId, String? depositFeeRateICode, String? depositFeeRateDescription, String? flatAmountCreditInvoiceRateId, String? flatAmountCreditInvoiceRateICode, String? flatAmountCreditInvoiceRateDescription, bool? updateEstimatedStartAndStopDatesOnSubPurchaseOrders, bool? promptToUpdateEstimatedStartAndStopDatesOnSubPurchaseOrders, bool? updateBillingStartAndStopDatesOnSubPurchaseOrders, bool? promptToUpdateBillingStartAndStopDatesOnSubPurchaseOrders, String? purchaseOrderApprovalRequiredAsOf, bool? purchaseOrderRequireFirstApproval, bool? purchaseOrderRequireSecondApproval, bool? purchaseOrderAllowSecondApprovalWithoutFirstApproval, double? purchaseOrderUnapproveIncreaseAmount, double? purchaseOrderUnapproveIncreasePercent, bool? purchaseOrderPreventReceiveUnapproved, double? purchaseOrderFirstApprovalThresholdRental, double? purchaseOrderFirstApprovalThresholdSales, double? purchaseOrderFirstApprovalThresholdParts, double? purchaseOrderFirstApprovalThresholdMiscellaneous, double? purchaseOrderFirstApprovalThresholdLabor, double? purchaseOrderFirstApprovalThresholdRepair, double? purchaseOrderFirstApprovalThresholdSubRental, double? purchaseOrderFirstApprovalThresholdSubSales, double? purchaseOrderFirstApprovalThresholdSubMiscellaneous, double? purchaseOrderFirstApprovalThresholdSubLabor, double? purchaseOrderSecondApprovalThresholdRental, double? purchaseOrderSecondApprovalThresholdSales, double? purchaseOrderSecondApprovalThresholdParts, double? purchaseOrderSecondApprovalThresholdMiscellaneous, double? purchaseOrderSecondApprovalThresholdLabor, double? purchaseOrderSecondApprovalThresholdRepair, double? purchaseOrderSecondApprovalThresholdSubRental, double? purchaseOrderSecondApprovalThresholdSubSales, double? purchaseOrderSecondApprovalThresholdSubMiscellaneous, double? purchaseOrderSecondApprovalThresholdSubLabor, bool? completeRentalWithLAndDOrder, bool? disableCrewValidation, bool? storefrontEnableInventoryInquiryEmails, String? storefrontInventoryInquiryEmailToAddress, bool? storefrontEnableQuoteRequestEmails, String? storefrontQuoteRequestEmailToAddress, bool? useResponsiblePerson, bool? requireResponsiblePerson, String? vendorInvoiceModificationsPushToPo, bool? splitRentalLineItemWhenCheckedInEarly, bool? inactive, bool? createInvoiceForItemsAddedAfterPrebill, bool? createCreditForPreBilledItemsReturnedEarly, String? automaticallyCreateCreditForPreBilledItemsReturnedEarly, bool? doNotBillDayWhenItemsAreCheckedInByCertainTime, String? checkInByTimeToAvoidBilling, bool? createInvoiceForItemsCheckedInBeforeEstimatedStopDate, String? automaticallyCreateInvoiceForItemsCheckedInBeforeEstimatedStopDate, bool? automaticallyCompleteRepairOrderWhenAllItemsReleased, String? setInvoiceDate, String? creditInvoiceNumberFrom, bool? orderStaysActiveWithSubsInHolding, bool? assignConsignorBeforeStaging, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsDepartmentLocationDepartmentLocation

Available on WebApiModulesSettingsDepartmentLocationDepartmentLocation, provided by the $WebApiModulesSettingsDepartmentLocationDepartmentLocationExtension extension

copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? departmentId, Wrapped<String?>? department, Wrapped<String?>? locationId, Wrapped<String?>? location, Wrapped<String?>? defaultOrderTypeId, Wrapped<String?>? defaultOrderType, Wrapped<String?>? projectDefaultOrderTypeId, Wrapped<String?>? projectDefaultOrderType, Wrapped<String?>? defaultTransferTypeId, Wrapped<String?>? defaultTransferType, Wrapped<String?>? glPrefix, Wrapped<String?>? glSuffix, Wrapped<bool?>? allowDecreaseOrderQuantityWhenStaged, Wrapped<bool?>? allowDecreaseOrderQuantityWhenOut, Wrapped<bool?>? autoCreditOnSalesReturn, Wrapped<String?>? depositFeeRateId, Wrapped<String?>? depositFeeRateICode, Wrapped<String?>? depositFeeRateDescription, Wrapped<String?>? flatAmountCreditInvoiceRateId, Wrapped<String?>? flatAmountCreditInvoiceRateICode, Wrapped<String?>? flatAmountCreditInvoiceRateDescription, Wrapped<bool?>? updateEstimatedStartAndStopDatesOnSubPurchaseOrders, Wrapped<bool?>? promptToUpdateEstimatedStartAndStopDatesOnSubPurchaseOrders, Wrapped<bool?>? updateBillingStartAndStopDatesOnSubPurchaseOrders, Wrapped<bool?>? promptToUpdateBillingStartAndStopDatesOnSubPurchaseOrders, Wrapped<String?>? purchaseOrderApprovalRequiredAsOf, Wrapped<bool?>? purchaseOrderRequireFirstApproval, Wrapped<bool?>? purchaseOrderRequireSecondApproval, Wrapped<bool?>? purchaseOrderAllowSecondApprovalWithoutFirstApproval, Wrapped<double?>? purchaseOrderUnapproveIncreaseAmount, Wrapped<double?>? purchaseOrderUnapproveIncreasePercent, Wrapped<bool?>? purchaseOrderPreventReceiveUnapproved, Wrapped<double?>? purchaseOrderFirstApprovalThresholdRental, Wrapped<double?>? purchaseOrderFirstApprovalThresholdSales, Wrapped<double?>? purchaseOrderFirstApprovalThresholdParts, Wrapped<double?>? purchaseOrderFirstApprovalThresholdMiscellaneous, Wrapped<double?>? purchaseOrderFirstApprovalThresholdLabor, Wrapped<double?>? purchaseOrderFirstApprovalThresholdRepair, Wrapped<double?>? purchaseOrderFirstApprovalThresholdSubRental, Wrapped<double?>? purchaseOrderFirstApprovalThresholdSubSales, Wrapped<double?>? purchaseOrderFirstApprovalThresholdSubMiscellaneous, Wrapped<double?>? purchaseOrderFirstApprovalThresholdSubLabor, Wrapped<double?>? purchaseOrderSecondApprovalThresholdRental, Wrapped<double?>? purchaseOrderSecondApprovalThresholdSales, Wrapped<double?>? purchaseOrderSecondApprovalThresholdParts, Wrapped<double?>? purchaseOrderSecondApprovalThresholdMiscellaneous, Wrapped<double?>? purchaseOrderSecondApprovalThresholdLabor, Wrapped<double?>? purchaseOrderSecondApprovalThresholdRepair, Wrapped<double?>? purchaseOrderSecondApprovalThresholdSubRental, Wrapped<double?>? purchaseOrderSecondApprovalThresholdSubSales, Wrapped<double?>? purchaseOrderSecondApprovalThresholdSubMiscellaneous, Wrapped<double?>? purchaseOrderSecondApprovalThresholdSubLabor, Wrapped<bool?>? completeRentalWithLAndDOrder, Wrapped<bool?>? disableCrewValidation, Wrapped<bool?>? storefrontEnableInventoryInquiryEmails, Wrapped<String?>? storefrontInventoryInquiryEmailToAddress, Wrapped<bool?>? storefrontEnableQuoteRequestEmails, Wrapped<String?>? storefrontQuoteRequestEmailToAddress, Wrapped<bool?>? useResponsiblePerson, Wrapped<bool?>? requireResponsiblePerson, Wrapped<String?>? vendorInvoiceModificationsPushToPo, Wrapped<bool?>? splitRentalLineItemWhenCheckedInEarly, Wrapped<bool?>? inactive, Wrapped<bool?>? createInvoiceForItemsAddedAfterPrebill, Wrapped<bool?>? createCreditForPreBilledItemsReturnedEarly, Wrapped<String?>? automaticallyCreateCreditForPreBilledItemsReturnedEarly, Wrapped<bool?>? doNotBillDayWhenItemsAreCheckedInByCertainTime, Wrapped<String?>? checkInByTimeToAvoidBilling, Wrapped<bool?>? createInvoiceForItemsCheckedInBeforeEstimatedStopDate, Wrapped<String?>? automaticallyCreateInvoiceForItemsCheckedInBeforeEstimatedStopDate, Wrapped<bool?>? automaticallyCompleteRepairOrderWhenAllItemsReleased, Wrapped<String?>? setInvoiceDate, Wrapped<String?>? creditInvoiceNumberFrom, Wrapped<bool?>? orderStaysActiveWithSubsInHolding, Wrapped<bool?>? assignConsignorBeforeStaging, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsDepartmentLocationDepartmentLocation

Available on WebApiModulesSettingsDepartmentLocationDepartmentLocation, provided by the $WebApiModulesSettingsDepartmentLocationDepartmentLocationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override