WebApiModulesSettingsEventSettingsEventTypePersonnelTypeEventTypePersonnelType class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsEventSettingsEventTypePersonnelTypeEventTypePersonnelType({String? eventTypePersonnelTypeId, String? eventTypeId, String? personnelTypeId, String? personnelType, String? personnelTypeRename, bool? showOfficePhone, bool? showOfficeExtension, bool? showCellular, double? orderBy, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesSettingsEventSettingsEventTypePersonnelTypeEventTypePersonnelType.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
eventTypeId String?
final
eventTypePersonnelTypeId String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
orderBy double?
final
personnelType String?
final
personnelTypeId String?
final
personnelTypeRename String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCellular bool?
final
showOfficeExtension bool?
final
showOfficePhone bool?
final

Methods

copyWith({String? eventTypePersonnelTypeId, String? eventTypeId, String? personnelTypeId, String? personnelType, String? personnelTypeRename, bool? showOfficePhone, bool? showOfficeExtension, bool? showCellular, double? orderBy, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesSettingsEventSettingsEventTypePersonnelTypeEventTypePersonnelType

Available on WebApiModulesSettingsEventSettingsEventTypePersonnelTypeEventTypePersonnelType, provided by the $WebApiModulesSettingsEventSettingsEventTypePersonnelTypeEventTypePersonnelTypeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override