WebApiModulesSettingsFiscalMonthFiscalMonth class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsFiscalMonthFiscalMonth({String? fiscalMonthId, String? fiscalYearId, String? year, int? month, String? monthDisplay, String? fromDate, String? toDate, String? monthYear, int? workDays, String? fiscalOrder, bool? closed, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsFiscalMonthFiscalMonth.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
closed bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fiscalMonthId String?
final
fiscalOrder String?
final
fiscalYearId String?
final
fromDate String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
month int?
final
monthDisplay String?
final
monthYear String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
workDays int?
final
year String?
final

Methods

copyWith({String? fiscalMonthId, String? fiscalYearId, String? year, int? month, String? monthDisplay, String? fromDate, String? toDate, String? monthYear, int? workDays, String? fiscalOrder, bool? closed, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsFiscalMonthFiscalMonth

Available on WebApiModulesSettingsFiscalMonthFiscalMonth, provided by the $WebApiModulesSettingsFiscalMonthFiscalMonthExtension extension

copyWithWrapped({Wrapped<String?>? fiscalMonthId, Wrapped<String?>? fiscalYearId, Wrapped<String?>? year, Wrapped<int?>? month, Wrapped<String?>? monthDisplay, Wrapped<String?>? fromDate, Wrapped<String?>? toDate, Wrapped<String?>? monthYear, Wrapped<int?>? workDays, Wrapped<String?>? fiscalOrder, Wrapped<bool?>? closed, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsFiscalMonthFiscalMonth

Available on WebApiModulesSettingsFiscalMonthFiscalMonth, provided by the $WebApiModulesSettingsFiscalMonthFiscalMonthExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesSettingsFiscalMonthFiscalMonth Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesSettingsFiscalMonthFiscalMonth instance)