WebApiModulesSettingsInventorySettingsInventoryRankInventoryRank class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsInventorySettingsInventoryRankInventoryRank({String? inventoryRankId, String? inventoryTypeId, String? inventoryType, String? warehouseId, String? warehouseCode, String? warehouse, String? type, String? typeDisplay, double? aFromValue, double? aToValue, double? bFromValue, double? bToValue, double? cFromValue, double? cToValue, double? dFromValue, double? dToValue, double? eFromValue, double? eToValue, double? fFromValue, double? fToValue, double? gFromValue, double? gToValue, String? rankUpdated, String? usersId, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsInventorySettingsInventoryRankInventoryRank.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aFromValue → double?
-
final
- aToValue → double?
-
final
- auditNote → String?
-
final
- bFromValue → double?
-
final
- bToValue → double?
-
final
- cFromValue → double?
-
final
- cToValue → double?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- dFromValue → double?
-
final
- dToValue → double?
-
final
- eFromValue → double?
-
final
- eToValue → double?
-
final
- fFromValue → double?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fToValue → double?
-
final
- gFromValue → double?
-
final
- gToValue → double?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inventoryRankId → String?
-
final
- inventoryType → String?
-
final
- inventoryTypeId → String?
-
final
- rankUpdated → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
- typeDisplay → String?
-
final
- usersId → String?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? inventoryRankId, String? inventoryTypeId, String? inventoryType, String? warehouseId, String? warehouseCode, String? warehouse, String? type, String? typeDisplay, double? aFromValue, double? aToValue, double? bFromValue, double? bToValue, double? cFromValue, double? cToValue, double? dFromValue, double? dToValue, double? eFromValue, double? eToValue, double? fFromValue, double? fToValue, double? gFromValue, double? gToValue, String? rankUpdated, String? usersId, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsInventorySettingsInventoryRankInventoryRank -
Available on WebApiModulesSettingsInventorySettingsInventoryRankInventoryRank, provided by the $WebApiModulesSettingsInventorySettingsInventoryRankInventoryRankExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsInventorySettingsInventoryRankInventoryRank Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsInventorySettingsInventoryRankInventoryRank instance)