WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory({String? category, String? categoryId, bool? availableOnline, List<
WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory> ? subCategories}) -
const
-
WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory.fromJson(Map<
String, dynamic> json) -
factory
Properties
- availableOnline → bool?
-
final
- category → String?
-
final
- categoryId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subCategories
→ List<
WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory> ? -
final
Methods
-
copyWith(
{String? category, String? categoryId, bool? availableOnline, List< WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory> ? subCategories}) → WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory -
Available on WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory, provided by the $WebApiModulesSettingsInventorySettingsStorefrontInventoryCategoryExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? category, Wrapped<String?> ? categoryId, Wrapped<bool?> ? availableOnline, Wrapped<List< ? subCategories}) → WebApiModulesSettingsInventorySettingsStorefrontInventoryCategoryWebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory> ?> -
Available on WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory, provided by the $WebApiModulesSettingsInventorySettingsStorefrontInventoryCategoryExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory instance)