WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment({String? departmentId, String? department, bool? availableOnline, List<
WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory> ? categories}) -
const
-
WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment.fromJson(Map<
String, dynamic> json) -
factory
Properties
- availableOnline → bool?
-
final
-
categories
→ List<
WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? departmentId, String? department, bool? availableOnline, List< WebApiModulesSettingsInventorySettingsStorefrontInventoryCategory> ? categories}) → WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment -
Available on WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment, provided by the $WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartmentExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? departmentId, Wrapped<String?> ? department, Wrapped<bool?> ? availableOnline, Wrapped<List< ? categories}) → WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartmentWebApiModulesSettingsInventorySettingsStorefrontInventoryCategory> ?> -
Available on WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment, provided by the $WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartmentExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsInventorySettingsStorefrontInventoryDepartment instance)