WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

availableOnline bool?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategory String?
final
subCategoryId String?
final

Methods

copyWith({String? subCategoryId, String? subCategory, bool? availableOnline}) WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory

Available on WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory, provided by the $WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategoryExtension extension

copyWithWrapped({Wrapped<String?>? subCategoryId, Wrapped<String?>? subCategory, Wrapped<bool?>? availableOnline}) WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory

Available on WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategory, provided by the $WebApiModulesSettingsInventorySettingsStorefrontInventorySubCategoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override