WebApiModulesSettingsInventorySettingsStorefrontStorefrontViewFieldsDefaultResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

catalogGridFields String?
final
catalogListFields String?
final
hashCode int
The hash code for this object.
no setteroverride
itemDetailFields String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shoppingCartFields String?
final

Methods

copyWith({String? catalogGridFields, String? catalogListFields, String? itemDetailFields, String? shoppingCartFields}) WebApiModulesSettingsInventorySettingsStorefrontStorefrontViewFieldsDefaultResponse

Available on WebApiModulesSettingsInventorySettingsStorefrontStorefrontViewFieldsDefaultResponse, provided by the $WebApiModulesSettingsInventorySettingsStorefrontStorefrontViewFieldsDefaultResponseExtension extension

copyWithWrapped({Wrapped<String?>? catalogGridFields, Wrapped<String?>? catalogListFields, Wrapped<String?>? itemDetailFields, Wrapped<String?>? shoppingCartFields}) WebApiModulesSettingsInventorySettingsStorefrontStorefrontViewFieldsDefaultResponse

Available on WebApiModulesSettingsInventorySettingsStorefrontStorefrontViewFieldsDefaultResponse, provided by the $WebApiModulesSettingsInventorySettingsStorefrontStorefrontViewFieldsDefaultResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override