WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequest({String? recType, String? departmentId, String? categoryId, String? subCategoryId, String? inventoryId, bool? enable})
const
WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

categoryId String?
final
departmentId String?
final
enable bool?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
recType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategoryId String?
final

Methods

copyWith({String? recType, String? departmentId, String? categoryId, String? subCategoryId, String? inventoryId, bool? enable}) WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequest

Available on WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequest, provided by the $WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequestExtension extension

copyWithWrapped({Wrapped<String?>? recType, Wrapped<String?>? departmentId, Wrapped<String?>? categoryId, Wrapped<String?>? subCategoryId, Wrapped<String?>? inventoryId, Wrapped<bool?>? enable}) WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequest

Available on WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequest, provided by the $WebApiModulesSettingsInventorySettingsStorefrontToggleCatalogItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override