WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest({int? onlineCatalogItemId, double? ownedQuantityPercent})
-
const
-
WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- onlineCatalogItemId → int?
-
final
- ownedQuantityPercent → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? onlineCatalogItemId, double? ownedQuantityPercent}) → WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest -
Available on WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest, provided by the $WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequestExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? onlineCatalogItemId, Wrapped<double?> ? ownedQuantityPercent}) → WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest -
Available on WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest, provided by the $WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsInventorySettingsStorefrontUpdateCatalogItemPercentRequest instance)