WebApiModulesSettingsItemLocationHistoryItemLocationHistory class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsItemLocationHistoryItemLocationHistory({String? itemId, String? barCode, String? transferdate, String? transfertime, String? transferdatetime, String? fromlocation, String? tolocation, String? username, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsItemLocationHistoryItemLocationHistory.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- barCode → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fromlocation → String?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- itemId → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tolocation → String?
-
final
- transferdate → String?
-
final
- transferdatetime → String?
-
final
- transfertime → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
- username → String?
-
final
Methods
-
copyWith(
{String? itemId, String? barCode, String? transferdate, String? transfertime, String? transferdatetime, String? fromlocation, String? tolocation, String? username, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsItemLocationHistoryItemLocationHistory -
Available on WebApiModulesSettingsItemLocationHistoryItemLocationHistory, provided by the $WebApiModulesSettingsItemLocationHistoryItemLocationHistoryExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? itemId, Wrapped<String?> ? barCode, Wrapped<String?> ? transferdate, Wrapped<String?> ? transfertime, Wrapped<String?> ? transferdatetime, Wrapped<String?> ? fromlocation, Wrapped<String?> ? tolocation, Wrapped<String?> ? username, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsItemLocationHistoryItemLocationHistory -
Available on WebApiModulesSettingsItemLocationHistoryItemLocationHistory, provided by the $WebApiModulesSettingsItemLocationHistoryItemLocationHistoryExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsItemLocationHistoryItemLocationHistory Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsItemLocationHistoryItemLocationHistory instance)