WebApiModulesSettingsLaborSettingsCrewCrew class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsLaborSettingsCrewCrew({String? crewId, String? userId, bool? isUser, String? salutation, String? nameFirstMiddleLast, String? person, String? lastName, String? firstName, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? zipCode, String? middleInitial, String? location, String? position, String? officePhone, String? officeExtension, String? directPhone, String? directExtension, String? fax, String? faxExtension, String? pager, String? pagerPin, String? mobilePhone, String? homePhone, String? email, String? contactTitleId, String? contactTitle, String? activeDate, String? inactiveDate, bool? contractEmployee, bool? inactive, String? webUserId, bool? webAccess, bool? lockAccount, String? webPassword, bool? expirePassword, int? expireDays, bool? webAdministrator, bool? changePasswordAtNextLogin, String? passwordLastUpdated, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsLaborSettingsCrewCrew.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeDate → String?
-
final
- address1 → String?
-
final
- address2 → String?
-
final
- auditNote → String?
-
final
- changePasswordAtNextLogin → bool?
-
final
- city → String?
-
final
- contactTitle → String?
-
final
- contactTitleId → String?
-
final
- contractEmployee → bool?
-
final
- country → String?
-
final
- countryId → String?
-
final
- crewId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- directExtension → String?
-
final
- directPhone → String?
-
final
- email → String?
-
final
- expireDays → int?
-
final
- expirePassword → bool?
-
final
- fax → String?
-
final
- faxExtension → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- homePhone → String?
-
final
- inactive → bool?
-
final
- inactiveDate → String?
-
final
- isUser → bool?
-
final
- lastName → String?
-
final
- location → String?
-
final
- lockAccount → bool?
-
final
- middleInitial → String?
-
final
- mobilePhone → String?
-
final
- nameFirstMiddleLast → String?
-
final
- officeExtension → String?
-
final
- officePhone → String?
-
final
- pager → String?
-
final
- pagerPin → String?
-
final
- passwordLastUpdated → String?
-
final
- person → String?
-
final
- position → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salutation → String?
-
final
- state → String?
-
final
- userId → String?
-
final
- webAccess → bool?
-
final
- webAdministrator → bool?
-
final
- webPassword → String?
-
final
- webUserId → String?
-
final
- zipCode → String?
-
final
Methods
-
copyWith(
{String? crewId, String? userId, bool? isUser, String? salutation, String? nameFirstMiddleLast, String? person, String? lastName, String? firstName, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? zipCode, String? middleInitial, String? location, String? position, String? officePhone, String? officeExtension, String? directPhone, String? directExtension, String? fax, String? faxExtension, String? pager, String? pagerPin, String? mobilePhone, String? homePhone, String? email, String? contactTitleId, String? contactTitle, String? activeDate, String? inactiveDate, bool? contractEmployee, bool? inactive, String? webUserId, bool? webAccess, bool? lockAccount, String? webPassword, bool? expirePassword, int? expireDays, bool? webAdministrator, bool? changePasswordAtNextLogin, String? passwordLastUpdated, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsLaborSettingsCrewCrew -
Available on WebApiModulesSettingsLaborSettingsCrewCrew, provided by the $WebApiModulesSettingsLaborSettingsCrewCrewExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsLaborSettingsCrewCrew Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsLaborSettingsCrewCrew instance)