WebApiModulesSettingsLaborSettingsCrewStatusCrewStatus class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsLaborSettingsCrewStatusCrewStatus({String? crewStatusId, String? crewStatus, bool? availableToSchedule, String? color, bool? whiteText, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsLaborSettingsCrewStatusCrewStatus.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
availableToSchedule bool?
final
color String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
crewStatus String?
final
crewStatusId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
whiteText bool?
final

Methods

copyWith({String? crewStatusId, String? crewStatus, bool? availableToSchedule, String? color, bool? whiteText, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsLaborSettingsCrewStatusCrewStatus

Available on WebApiModulesSettingsLaborSettingsCrewStatusCrewStatus, provided by the $WebApiModulesSettingsLaborSettingsCrewStatusCrewStatusExtension extension

copyWithWrapped({Wrapped<String?>? crewStatusId, Wrapped<String?>? crewStatus, Wrapped<bool?>? availableToSchedule, Wrapped<String?>? color, Wrapped<bool?>? whiteText, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsLaborSettingsCrewStatusCrewStatus

Available on WebApiModulesSettingsLaborSettingsCrewStatusCrewStatus, provided by the $WebApiModulesSettingsLaborSettingsCrewStatusCrewStatusExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override