WebApiModulesSettingsOrderSettingsOrderTypeOrderType class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsOrderSettingsOrderTypeOrderType({String? orderTypeId, String? orderType, String? ordType, String? defaultPickTime, String? defaultFromTime, String? defaultToTime, String? dailyScheduleDefaultStartTime, String? dailyScheduleDefaultStopTime, bool? isMasterSubOrderType, bool? defaultManualSort, bool? preventManualSort, String? determineQuantitiesToBillBasedOn, bool? useEstimatedDatesForBilling, String? salesInventoryPrice, String? salesInventoryCost, String? rentalFieldsJson, String? salesFieldsJson, String? spaceFieldsJson, String? laborFieldsJson, String? laborScheduleFieldsJson, String? miscFieldsJson, String? repairFieldsJson, String? vehicleFieldsJson, String? rentalSaleFieldsJson, String? lossDamageFieldsJson, String? facilityDescription, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, bool? addInstallationAndStrikeFee, String? installationAndStrikeFeeRateId, String? installationAndStrikeFeeICode, String? installationAndStrikeFeeDescription, String? installationAndStrikeFeeAvailFor, double? installationAndStrikeFeePercent, String? installationAndStrikeFeeBasedOn, bool? addManagementAndServiceFee, String? managementAndServiceFeeRateId, String? managementAndServiceFeeICode, String? managementAndServiceFeeDescription, String? managementAndServiceFeeAvailFor, double? managementAndServiceFeePercent, String? managementAndServiceFeeBasedOn, String? defaultRentalSalePrice, bool? quikPayDiscount, String? quikPayDiscountType, int? quikPayDiscountDays, double? quikPayDiscountPercent, bool? quikPayDiscountExcludeSubs, bool? quikConfirmDiscount, double? quikConfirmDiscountPercent, int? quikConfirmDiscountDays, bool? disableCostGl, bool? excludeFromTopSalesDashboard, bool? separatePackageOnQuoteOrder, double? orderby, bool? subAllShortagesSubMiscellaneous, bool? inactive, bool? isInternal, String? marketTypeId, String? marketType, String? marketSegmentId, String? marketSegment, String? marketSegmentJobId, String? marketSegmentJob, String? crewBilling, double? crewHoursOT, double? crewHoursDT, double? hoursPerDay, bool? crewMonday, bool? crewTuesday, bool? crewWednesday, bool? crewThursday, bool? crewFriday, bool? crewSaturday, bool? crewSunday, String? glPrefix, String? glSuffix, bool? allowRoundTripRentals, String? defaultUseHiatusScheduleFrom, bool? automaticallyBoldPrimaryItem, List<String>? rentalShowFields, List<String>? salesShowFields, List<String>? miscShowFields, List<String>? laborShowFields, List<String>? laborScheduleShowFields, List<String>? rentalSaleShowFields, List<String>? lossAndDamageShowFields, List<String>? facilitiesShowFields, List<String>? repairShowFields, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsOrderSettingsOrderTypeOrderType.fromJson(Map<String, dynamic> json)
factory

Properties

addInstallationAndStrikeFee bool?
final
addManagementAndServiceFee bool?
final
allowRoundTripRentals bool?
final
auditNote String?
final
automaticallyBoldPrimaryItem bool?
final
break1Paid bool?
final
break2Paid bool?
final
break3Paid bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
crewBilling String?
final
crewFriday bool?
final
crewHoursDT double?
final
crewHoursOT double?
final
crewMonday bool?
final
crewSaturday bool?
final
crewSunday bool?
final
crewThursday bool?
final
crewTuesday bool?
final
crewWednesday bool?
final
custom List<FwStandardDataFwCustomValue>?
final
dailyScheduleDefaultStartTime String?
final
dailyScheduleDefaultStopTime String?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultFromTime String?
final
defaultManualSort bool?
final
defaultPickTime String?
final
defaultRentalSalePrice String?
final
defaultToTime String?
final
defaultUseHiatusScheduleFrom String?
final
determineQuantitiesToBillBasedOn String?
final
disableCostGl bool?
final
excludeFromTopSalesDashboard bool?
final
facilitiesShowFields List<String>?
final
facilityDescription String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
glPrefix String?
final
glSuffix String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hideCrewBreaks bool?
final
hoursPerDay double?
final
inactive bool?
final
installationAndStrikeFeeAvailFor String?
final
installationAndStrikeFeeBasedOn String?
final
installationAndStrikeFeeDescription String?
final
installationAndStrikeFeeICode String?
final
installationAndStrikeFeePercent double?
final
installationAndStrikeFeeRateId String?
final
isInternal bool?
final
isMasterSubOrderType bool?
final
laborFieldsJson String?
final
laborScheduleFieldsJson String?
final
laborScheduleShowFields List<String>?
final
laborShowFields List<String>?
final
lossAndDamageShowFields List<String>?
final
lossDamageFieldsJson String?
final
managementAndServiceFeeAvailFor String?
final
managementAndServiceFeeBasedOn String?
final
managementAndServiceFeeDescription String?
final
managementAndServiceFeeICode String?
final
managementAndServiceFeePercent double?
final
managementAndServiceFeeRateId String?
final
marketSegment String?
final
marketSegmentId String?
final
marketSegmentJob String?
final
marketSegmentJobId String?
final
marketType String?
final
marketTypeId String?
final
miscFieldsJson String?
final
miscShowFields List<String>?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderby double?
final
orderType String?
final
orderTypeId String?
final
ordType String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
preventManualSort bool?
final
quikConfirmDiscount bool?
final
quikConfirmDiscountDays int?
final
quikConfirmDiscountPercent double?
final
quikPayDiscount bool?
final
quikPayDiscountDays int?
final
quikPayDiscountExcludeSubs bool?
final
quikPayDiscountPercent double?
final
quikPayDiscountType String?
final
recordTitle String?
final
rentalFieldsJson String?
final
rentalSaleFieldsJson String?
final
rentalSaleShowFields List<String>?
final
rentalShowFields List<String>?
final
repairFieldsJson String?
final
repairShowFields List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesFieldsJson String?
final
salesInventoryCost String?
final
salesInventoryPrice String?
final
salesShowFields List<String>?
final
separatePackageOnQuoteOrder bool?
final
spaceFieldsJson String?
final
subAllShortagesSubMiscellaneous bool?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
useEstimatedDatesForBilling bool?
final
vehicleFieldsJson String?
final

Methods

copyWith({String? orderTypeId, String? orderType, String? ordType, String? defaultPickTime, String? defaultFromTime, String? defaultToTime, String? dailyScheduleDefaultStartTime, String? dailyScheduleDefaultStopTime, bool? isMasterSubOrderType, bool? defaultManualSort, bool? preventManualSort, String? determineQuantitiesToBillBasedOn, bool? useEstimatedDatesForBilling, String? salesInventoryPrice, String? salesInventoryCost, String? rentalFieldsJson, String? salesFieldsJson, String? spaceFieldsJson, String? laborFieldsJson, String? laborScheduleFieldsJson, String? miscFieldsJson, String? repairFieldsJson, String? vehicleFieldsJson, String? rentalSaleFieldsJson, String? lossDamageFieldsJson, String? facilityDescription, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, bool? addInstallationAndStrikeFee, String? installationAndStrikeFeeRateId, String? installationAndStrikeFeeICode, String? installationAndStrikeFeeDescription, String? installationAndStrikeFeeAvailFor, double? installationAndStrikeFeePercent, String? installationAndStrikeFeeBasedOn, bool? addManagementAndServiceFee, String? managementAndServiceFeeRateId, String? managementAndServiceFeeICode, String? managementAndServiceFeeDescription, String? managementAndServiceFeeAvailFor, double? managementAndServiceFeePercent, String? managementAndServiceFeeBasedOn, String? defaultRentalSalePrice, bool? quikPayDiscount, String? quikPayDiscountType, int? quikPayDiscountDays, double? quikPayDiscountPercent, bool? quikPayDiscountExcludeSubs, bool? quikConfirmDiscount, double? quikConfirmDiscountPercent, int? quikConfirmDiscountDays, bool? disableCostGl, bool? excludeFromTopSalesDashboard, bool? separatePackageOnQuoteOrder, double? orderby, bool? subAllShortagesSubMiscellaneous, bool? inactive, bool? isInternal, String? marketTypeId, String? marketType, String? marketSegmentId, String? marketSegment, String? marketSegmentJobId, String? marketSegmentJob, String? crewBilling, double? crewHoursOT, double? crewHoursDT, double? hoursPerDay, bool? crewMonday, bool? crewTuesday, bool? crewWednesday, bool? crewThursday, bool? crewFriday, bool? crewSaturday, bool? crewSunday, String? glPrefix, String? glSuffix, bool? allowRoundTripRentals, String? defaultUseHiatusScheduleFrom, bool? automaticallyBoldPrimaryItem, List<String>? rentalShowFields, List<String>? salesShowFields, List<String>? miscShowFields, List<String>? laborShowFields, List<String>? laborScheduleShowFields, List<String>? rentalSaleShowFields, List<String>? lossAndDamageShowFields, List<String>? facilitiesShowFields, List<String>? repairShowFields, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsOrderSettingsOrderTypeOrderType

Available on WebApiModulesSettingsOrderSettingsOrderTypeOrderType, provided by the $WebApiModulesSettingsOrderSettingsOrderTypeOrderTypeExtension extension

copyWithWrapped({Wrapped<String?>? orderTypeId, Wrapped<String?>? orderType, Wrapped<String?>? ordType, Wrapped<String?>? defaultPickTime, Wrapped<String?>? defaultFromTime, Wrapped<String?>? defaultToTime, Wrapped<String?>? dailyScheduleDefaultStartTime, Wrapped<String?>? dailyScheduleDefaultStopTime, Wrapped<bool?>? isMasterSubOrderType, Wrapped<bool?>? defaultManualSort, Wrapped<bool?>? preventManualSort, Wrapped<String?>? determineQuantitiesToBillBasedOn, Wrapped<bool?>? useEstimatedDatesForBilling, Wrapped<String?>? salesInventoryPrice, Wrapped<String?>? salesInventoryCost, Wrapped<String?>? rentalFieldsJson, Wrapped<String?>? salesFieldsJson, Wrapped<String?>? spaceFieldsJson, Wrapped<String?>? laborFieldsJson, Wrapped<String?>? laborScheduleFieldsJson, Wrapped<String?>? miscFieldsJson, Wrapped<String?>? repairFieldsJson, Wrapped<String?>? vehicleFieldsJson, Wrapped<String?>? rentalSaleFieldsJson, Wrapped<String?>? lossDamageFieldsJson, Wrapped<String?>? facilityDescription, Wrapped<bool?>? hideCrewBreaks, Wrapped<bool?>? break1Paid, Wrapped<bool?>? break2Paid, Wrapped<bool?>? break3Paid, Wrapped<bool?>? addInstallationAndStrikeFee, Wrapped<String?>? installationAndStrikeFeeRateId, Wrapped<String?>? installationAndStrikeFeeICode, Wrapped<String?>? installationAndStrikeFeeDescription, Wrapped<String?>? installationAndStrikeFeeAvailFor, Wrapped<double?>? installationAndStrikeFeePercent, Wrapped<String?>? installationAndStrikeFeeBasedOn, Wrapped<bool?>? addManagementAndServiceFee, Wrapped<String?>? managementAndServiceFeeRateId, Wrapped<String?>? managementAndServiceFeeICode, Wrapped<String?>? managementAndServiceFeeDescription, Wrapped<String?>? managementAndServiceFeeAvailFor, Wrapped<double?>? managementAndServiceFeePercent, Wrapped<String?>? managementAndServiceFeeBasedOn, Wrapped<String?>? defaultRentalSalePrice, Wrapped<bool?>? quikPayDiscount, Wrapped<String?>? quikPayDiscountType, Wrapped<int?>? quikPayDiscountDays, Wrapped<double?>? quikPayDiscountPercent, Wrapped<bool?>? quikPayDiscountExcludeSubs, Wrapped<bool?>? quikConfirmDiscount, Wrapped<double?>? quikConfirmDiscountPercent, Wrapped<int?>? quikConfirmDiscountDays, Wrapped<bool?>? disableCostGl, Wrapped<bool?>? excludeFromTopSalesDashboard, Wrapped<bool?>? separatePackageOnQuoteOrder, Wrapped<double?>? orderby, Wrapped<bool?>? subAllShortagesSubMiscellaneous, Wrapped<bool?>? inactive, Wrapped<bool?>? isInternal, Wrapped<String?>? marketTypeId, Wrapped<String?>? marketType, Wrapped<String?>? marketSegmentId, Wrapped<String?>? marketSegment, Wrapped<String?>? marketSegmentJobId, Wrapped<String?>? marketSegmentJob, Wrapped<String?>? crewBilling, Wrapped<double?>? crewHoursOT, Wrapped<double?>? crewHoursDT, Wrapped<double?>? hoursPerDay, Wrapped<bool?>? crewMonday, Wrapped<bool?>? crewTuesday, Wrapped<bool?>? crewWednesday, Wrapped<bool?>? crewThursday, Wrapped<bool?>? crewFriday, Wrapped<bool?>? crewSaturday, Wrapped<bool?>? crewSunday, Wrapped<String?>? glPrefix, Wrapped<String?>? glSuffix, Wrapped<bool?>? allowRoundTripRentals, Wrapped<String?>? defaultUseHiatusScheduleFrom, Wrapped<bool?>? automaticallyBoldPrimaryItem, Wrapped<List<String>?>? rentalShowFields, Wrapped<List<String>?>? salesShowFields, Wrapped<List<String>?>? miscShowFields, Wrapped<List<String>?>? laborShowFields, Wrapped<List<String>?>? laborScheduleShowFields, Wrapped<List<String>?>? rentalSaleShowFields, Wrapped<List<String>?>? lossAndDamageShowFields, Wrapped<List<String>?>? facilitiesShowFields, Wrapped<List<String>?>? repairShowFields, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsOrderSettingsOrderTypeOrderType

Available on WebApiModulesSettingsOrderSettingsOrderTypeOrderType, provided by the $WebApiModulesSettingsOrderSettingsOrderTypeOrderTypeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override