WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateType class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateType({String? orderTypeDateTypeId, String? orderTypeId, String? orderType, int? activityTypeId, String? activityType, String? description, String? rename, String? descriptionDisplay, bool? enabled, String? color, String? textColor, double? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateType.fromJson(Map<String, dynamic> json)
factory

Properties

activityType String?
final
activityTypeId int?
final
auditNote String?
final
color String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
descriptionDisplay String?
final
enabled bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderBy double?
final
orderType String?
final
orderTypeDateTypeId String?
final
orderTypeId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
rename String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? orderTypeDateTypeId, String? orderTypeId, String? orderType, int? activityTypeId, String? activityType, String? description, String? rename, String? descriptionDisplay, bool? enabled, String? color, String? textColor, double? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateType

Available on WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateType, provided by the $WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateTypeExtension extension

copyWithWrapped({Wrapped<String?>? orderTypeDateTypeId, Wrapped<String?>? orderTypeId, Wrapped<String?>? orderType, Wrapped<int?>? activityTypeId, Wrapped<String?>? activityType, Wrapped<String?>? description, Wrapped<String?>? rename, Wrapped<String?>? descriptionDisplay, Wrapped<bool?>? enabled, Wrapped<String?>? color, Wrapped<String?>? textColor, Wrapped<double?>? orderBy, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateType

Available on WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateType, provided by the $WebApiModulesSettingsOrderTypeDateTypeOrderTypeDateTypeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override