WebApiModulesSettingsOrderTypeLocationOrderTypeLocation class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsOrderTypeLocationOrderTypeLocation({String? orderTypeLocationId, String? orderTypeId, String? locationId, String? location, String? invoiceClass, String? termsConditionsId, String? termsConditions, String? coverLetterId, String? coverLetter, String? presentationLayerId, String? presentationLayer, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsOrderTypeLocationOrderTypeLocation.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
coverLetter String?
final
coverLetterId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
invoiceClass String?
final
location String?
final
locationId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderTypeId String?
final
orderTypeLocationId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
presentationLayer String?
final
presentationLayerId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsConditions String?
final
termsConditionsId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? orderTypeLocationId, String? orderTypeId, String? locationId, String? location, String? invoiceClass, String? termsConditionsId, String? termsConditions, String? coverLetterId, String? coverLetter, String? presentationLayerId, String? presentationLayer, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsOrderTypeLocationOrderTypeLocation

Available on WebApiModulesSettingsOrderTypeLocationOrderTypeLocation, provided by the $WebApiModulesSettingsOrderTypeLocationOrderTypeLocationExtension extension

copyWithWrapped({Wrapped<String?>? orderTypeLocationId, Wrapped<String?>? orderTypeId, Wrapped<String?>? locationId, Wrapped<String?>? location, Wrapped<String?>? invoiceClass, Wrapped<String?>? termsConditionsId, Wrapped<String?>? termsConditions, Wrapped<String?>? coverLetterId, Wrapped<String?>? coverLetter, Wrapped<String?>? presentationLayerId, Wrapped<String?>? presentationLayer, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsOrderTypeLocationOrderTypeLocation

Available on WebApiModulesSettingsOrderTypeLocationOrderTypeLocation, provided by the $WebApiModulesSettingsOrderTypeLocationOrderTypeLocationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override