WebApiModulesSettingsPaymentSettingsPaymentTypePaymentType class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsPaymentSettingsPaymentTypePaymentType({String? paymentTypeId, String? paymentType, String? shortName, String? paymentTypeType, String? glAccountId, String? glAccountNo, String? glAccountDescription, String? exportPaymentMethod, String? exportPaymentType, bool? includeInRentalWorksNet, String? rentalWorksNetCaption, String? color, double? feePercent, String? paymentTypeFeeDescription, String? feeRateId, String? feeRateICode, String? feeRateDescription, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsPaymentSettingsPaymentTypePaymentType.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
color String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
exportPaymentMethod String?
final
exportPaymentType String?
final
feePercent double?
final
feeRateDescription String?
final
feeRateICode String?
final
feeRateId String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
glAccountDescription String?
final
glAccountId String?
final
glAccountNo String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
includeInRentalWorksNet bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
paymentType String?
final
paymentTypeFeeDescription String?
final
paymentTypeId String?
final
paymentTypeType String?
final
recordTitle String?
final
rentalWorksNetCaption String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? paymentTypeId, String? paymentType, String? shortName, String? paymentTypeType, String? glAccountId, String? glAccountNo, String? glAccountDescription, String? exportPaymentMethod, String? exportPaymentType, bool? includeInRentalWorksNet, String? rentalWorksNetCaption, String? color, double? feePercent, String? paymentTypeFeeDescription, String? feeRateId, String? feeRateICode, String? feeRateDescription, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsPaymentSettingsPaymentTypePaymentType

Available on WebApiModulesSettingsPaymentSettingsPaymentTypePaymentType, provided by the $WebApiModulesSettingsPaymentSettingsPaymentTypePaymentTypeExtension extension

copyWithWrapped({Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<String?>? shortName, Wrapped<String?>? paymentTypeType, Wrapped<String?>? glAccountId, Wrapped<String?>? glAccountNo, Wrapped<String?>? glAccountDescription, Wrapped<String?>? exportPaymentMethod, Wrapped<String?>? exportPaymentType, Wrapped<bool?>? includeInRentalWorksNet, Wrapped<String?>? rentalWorksNetCaption, Wrapped<String?>? color, Wrapped<double?>? feePercent, Wrapped<String?>? paymentTypeFeeDescription, Wrapped<String?>? feeRateId, Wrapped<String?>? feeRateICode, Wrapped<String?>? feeRateDescription, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsPaymentSettingsPaymentTypePaymentType

Available on WebApiModulesSettingsPaymentSettingsPaymentTypePaymentType, provided by the $WebApiModulesSettingsPaymentSettingsPaymentTypePaymentTypeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override