WebApiModulesSettingsPoSettingsPoTypePoType class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsPoSettingsPoTypePoType({String? poTypeId, String? poType, bool? approvalNeededByRequired, bool? importanceRequired, bool? payTypeRequired, bool? projectRequired, bool? receiveMiscellaneousLabor, bool? isInternal, String? subRentalFieldsJson, String? subSaleFieldsJson, String? purchaseFieldsJson, String? rentalPurchaseDefaultRate, String? salesPurchaseDefaultRate, String? laborFieldsJson, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, String? miscFieldsJson, String? subLaborFieldsJson, String? subMiscFieldsJson, String? repairFieldsJson, String? consignmentFieldsJson, bool? rwNetDefaultRental, bool? rwNetDefaultMisc, bool? rwNetDefaultLabor, double? orderBy, bool? inactive, bool? separatePackageOnPurchaseOrder, String? dateStamp, List<
String> ? subRentalShowFields, List<String> ? subSaleShowFields, List<String> ? repairShowFields, List<String> ? subMiscShowFields, List<String> ? subLaborShowFields, List<String> ? purchaseShowFields, List<String> ? miscShowFields, List<String> ? laborShowFields, List<String> ? consignmentShowFields, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsPoSettingsPoTypePoType.fromJson(Map<
String, dynamic> json) -
factory
Properties
- approvalNeededByRequired → bool?
-
final
- auditNote → String?
-
final
- break1Paid → bool?
-
final
- break2Paid → bool?
-
final
- break3Paid → bool?
-
final
- consignmentFieldsJson → String?
-
final
-
consignmentShowFields
→ List<
String> ? -
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- hideCrewBreaks → bool?
-
final
- importanceRequired → bool?
-
final
- inactive → bool?
-
final
- isInternal → bool?
-
final
- laborFieldsJson → String?
-
final
-
laborShowFields
→ List<
String> ? -
final
- miscFieldsJson → String?
-
final
-
miscShowFields
→ List<
String> ? -
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- orderBy → double?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- payTypeRequired → bool?
-
final
- poType → String?
-
final
- poTypeId → String?
-
final
- projectRequired → bool?
-
final
- purchaseFieldsJson → String?
-
final
-
purchaseShowFields
→ List<
String> ? -
final
- receiveMiscellaneousLabor → bool?
-
final
- recordTitle → String?
-
final
- rentalPurchaseDefaultRate → String?
-
final
- repairFieldsJson → String?
-
final
-
repairShowFields
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- rwNetDefaultLabor → bool?
-
final
- rwNetDefaultMisc → bool?
-
final
- rwNetDefaultRental → bool?
-
final
- salesPurchaseDefaultRate → String?
-
final
- separatePackageOnPurchaseOrder → bool?
-
final
- subLaborFieldsJson → String?
-
final
-
subLaborShowFields
→ List<
String> ? -
final
- subMiscFieldsJson → String?
-
final
-
subMiscShowFields
→ List<
String> ? -
final
- subRentalFieldsJson → String?
-
final
-
subRentalShowFields
→ List<
String> ? -
final
- subSaleFieldsJson → String?
-
final
-
subSaleShowFields
→ List<
String> ? -
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? poTypeId, String? poType, bool? approvalNeededByRequired, bool? importanceRequired, bool? payTypeRequired, bool? projectRequired, bool? receiveMiscellaneousLabor, bool? isInternal, String? subRentalFieldsJson, String? subSaleFieldsJson, String? purchaseFieldsJson, String? rentalPurchaseDefaultRate, String? salesPurchaseDefaultRate, String? laborFieldsJson, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, String? miscFieldsJson, String? subLaborFieldsJson, String? subMiscFieldsJson, String? repairFieldsJson, String? consignmentFieldsJson, bool? rwNetDefaultRental, bool? rwNetDefaultMisc, bool? rwNetDefaultLabor, double? orderBy, bool? inactive, bool? separatePackageOnPurchaseOrder, String? dateStamp, List< String> ? subRentalShowFields, List<String> ? subSaleShowFields, List<String> ? repairShowFields, List<String> ? subMiscShowFields, List<String> ? subLaborShowFields, List<String> ? purchaseShowFields, List<String> ? miscShowFields, List<String> ? laborShowFields, List<String> ? consignmentShowFields, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsPoSettingsPoTypePoType -
Available on WebApiModulesSettingsPoSettingsPoTypePoType, provided by the $WebApiModulesSettingsPoSettingsPoTypePoTypeExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? poTypeId, Wrapped<String?> ? poType, Wrapped<bool?> ? approvalNeededByRequired, Wrapped<bool?> ? importanceRequired, Wrapped<bool?> ? payTypeRequired, Wrapped<bool?> ? projectRequired, Wrapped<bool?> ? receiveMiscellaneousLabor, Wrapped<bool?> ? isInternal, Wrapped<String?> ? subRentalFieldsJson, Wrapped<String?> ? subSaleFieldsJson, Wrapped<String?> ? purchaseFieldsJson, Wrapped<String?> ? rentalPurchaseDefaultRate, Wrapped<String?> ? salesPurchaseDefaultRate, Wrapped<String?> ? laborFieldsJson, Wrapped<bool?> ? hideCrewBreaks, Wrapped<bool?> ? break1Paid, Wrapped<bool?> ? break2Paid, Wrapped<bool?> ? break3Paid, Wrapped<String?> ? miscFieldsJson, Wrapped<String?> ? subLaborFieldsJson, Wrapped<String?> ? subMiscFieldsJson, Wrapped<String?> ? repairFieldsJson, Wrapped<String?> ? consignmentFieldsJson, Wrapped<bool?> ? rwNetDefaultRental, Wrapped<bool?> ? rwNetDefaultMisc, Wrapped<bool?> ? rwNetDefaultLabor, Wrapped<double?> ? orderBy, Wrapped<bool?> ? inactive, Wrapped<bool?> ? separatePackageOnPurchaseOrder, Wrapped<String?> ? dateStamp, Wrapped<List< ? subRentalShowFields, Wrapped<String> ?>List< ? subSaleShowFields, Wrapped<String> ?>List< ? repairShowFields, Wrapped<String> ?>List< ? subMiscShowFields, Wrapped<String> ?>List< ? subLaborShowFields, Wrapped<String> ?>List< ? purchaseShowFields, Wrapped<String> ?>List< ? miscShowFields, Wrapped<String> ?>List< ? laborShowFields, Wrapped<String> ?>List< ? consignmentShowFields, Wrapped<String> ?>String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsPoSettingsPoTypePoType -
Available on WebApiModulesSettingsPoSettingsPoTypePoType, provided by the $WebApiModulesSettingsPoSettingsPoTypePoTypeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsPoSettingsPoTypePoType Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsPoSettingsPoTypePoType instance)