WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverride class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverride({String? presentationLayerActivityOverrideId, String? presentationLayerId, String? presentationLayerActivityId, String? masterId, String? activity, String? iCode, String? description, String? activityRename, String? recType, String? activityColor, String? exportCode, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverride.fromJson(Map<String, dynamic> json)
factory

Properties

activity String?
final
activityColor String?
final
activityRename String?
final
auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
exportCode String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
masterId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
presentationLayerActivityId String?
final
presentationLayerActivityOverrideId String?
final
presentationLayerId String?
final
recordTitle String?
final
recType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? presentationLayerActivityOverrideId, String? presentationLayerId, String? presentationLayerActivityId, String? masterId, String? activity, String? iCode, String? description, String? activityRename, String? recType, String? activityColor, String? exportCode, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverride

Available on WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverride, provided by the $WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverrideExtension extension

copyWithWrapped({Wrapped<String?>? presentationLayerActivityOverrideId, Wrapped<String?>? presentationLayerId, Wrapped<String?>? presentationLayerActivityId, Wrapped<String?>? masterId, Wrapped<String?>? activity, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? activityRename, Wrapped<String?>? recType, Wrapped<String?>? activityColor, Wrapped<String?>? exportCode, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverride

Available on WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverride, provided by the $WebApiModulesSettingsPresentationLayerActivityOverridePresentationLayerActivityOverrideExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override