WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplate class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplate({int? quikReceiptTemplateId, String? warehouseId, String? description, bool? inactive, int? orderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderBy int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quikReceiptTemplateId int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouseId String?
final

Methods

copyWith({int? quikReceiptTemplateId, String? warehouseId, String? description, bool? inactive, int? orderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplate

Available on WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplate, provided by the $WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplateExtension extension

copyWithWrapped({Wrapped<int?>? quikReceiptTemplateId, Wrapped<String?>? warehouseId, Wrapped<String?>? description, Wrapped<bool?>? inactive, Wrapped<int?>? orderBy, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplate

Available on WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplate, provided by the $WebApiModulesSettingsQuikReceiptTemplateQuikReceiptTemplateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override