WebApiModulesSettingsRateWarehouseRateWarehouse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsRateWarehouseRateWarehouse({String? rateId, double? hourlyRate, double? hourlyCost, double? hourlyMarkupPercent, double? dailyRate, double? dailyCost, double? dailyMarkupPercent, double? weeklyRate, double? weeklyCost, double? weeklyMarkupPercent, double? monthlyRate, double? monthlyCost, double? monthlyMarkupPercent, double? price, double? cost, double? markupPercent, String? defaultStartTime, String? defaultStopTime, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsRateWarehouseRateWarehouse.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
cost double?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dailyCost double?
final
dailyMarkupPercent double?
final
dailyRate double?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultStartTime String?
final
defaultStopTime String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hourlyCost double?
final
hourlyMarkupPercent double?
final
hourlyRate double?
final
itemDescription String?
final
markupPercent double?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
monthlyCost double?
final
monthlyMarkupPercent double?
final
monthlyRate double?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
price double?
final
rateId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final
warehouseOrderBy int?
final
weeklyCost double?
final
weeklyMarkupPercent double?
final
weeklyRate double?
final

Methods

copyWith({String? rateId, double? hourlyRate, double? hourlyCost, double? hourlyMarkupPercent, double? dailyRate, double? dailyCost, double? dailyMarkupPercent, double? weeklyRate, double? weeklyCost, double? weeklyMarkupPercent, double? monthlyRate, double? monthlyCost, double? monthlyMarkupPercent, double? price, double? cost, double? markupPercent, String? defaultStartTime, String? defaultStopTime, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsRateWarehouseRateWarehouse

Available on WebApiModulesSettingsRateWarehouseRateWarehouse, provided by the $WebApiModulesSettingsRateWarehouseRateWarehouseExtension extension

copyWithWrapped({Wrapped<String?>? rateId, Wrapped<double?>? hourlyRate, Wrapped<double?>? hourlyCost, Wrapped<double?>? hourlyMarkupPercent, Wrapped<double?>? dailyRate, Wrapped<double?>? dailyCost, Wrapped<double?>? dailyMarkupPercent, Wrapped<double?>? weeklyRate, Wrapped<double?>? weeklyCost, Wrapped<double?>? weeklyMarkupPercent, Wrapped<double?>? monthlyRate, Wrapped<double?>? monthlyCost, Wrapped<double?>? monthlyMarkupPercent, Wrapped<double?>? price, Wrapped<double?>? cost, Wrapped<double?>? markupPercent, Wrapped<String?>? defaultStartTime, Wrapped<String?>? defaultStopTime, Wrapped<String?>? itemDescription, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouseCode, Wrapped<String?>? warehouse, Wrapped<int?>? warehouseOrderBy, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsRateWarehouseRateWarehouse

Available on WebApiModulesSettingsRateWarehouseRateWarehouse, provided by the $WebApiModulesSettingsRateWarehouseRateWarehouseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override