WebApiModulesSettingsSetSettingsWallDescriptionWallDescription class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsSetSettingsWallDescriptionWallDescription({String? wallDescriptionId, String? wallDescription, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsSetSettingsWallDescriptionWallDescription.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactive → bool?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wallDescription → String?
-
final
- wallDescriptionId → String?
-
final
Methods
-
copyWith(
{String? wallDescriptionId, String? wallDescription, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsSetSettingsWallDescriptionWallDescription -
Available on WebApiModulesSettingsSetSettingsWallDescriptionWallDescription, provided by the $WebApiModulesSettingsSetSettingsWallDescriptionWallDescriptionExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsSetSettingsWallDescriptionWallDescription Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsSetSettingsWallDescriptionWallDescription instance)