WebApiModulesSettingsSetSettingsWallTypeWallType class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsSetSettingsWallTypeWallType({String? wallTypeId, String? wallType, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsSetSettingsWallTypeWallType.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
wallType String?
final
wallTypeId String?
final

Methods

copyWith({String? wallTypeId, String? wallType, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsSetSettingsWallTypeWallType

Available on WebApiModulesSettingsSetSettingsWallTypeWallType, provided by the $WebApiModulesSettingsSetSettingsWallTypeWallTypeExtension extension

copyWithWrapped({Wrapped<String?>? wallTypeId, Wrapped<String?>? wallType, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsSetSettingsWallTypeWallType

Available on WebApiModulesSettingsSetSettingsWallTypeWallType, provided by the $WebApiModulesSettingsSetSettingsWallTypeWallTypeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override