WebApiModulesSettingsSourceSettingsSourceSource class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsSourceSettingsSourceSource({String? sourceId, String? source, String? sourceType, String? description, String? path, String? fileName, String? ftpHost, int? ftpPort, String? ftpUserName, String? ftpPassword, String? ftpPath, String? ftpFileName, bool? ftpArchive, String? ftpArchivePath, bool? ftpSsl, String? temporaryFtpFileName, bool? inactive, bool? systemSource, String? temporarySoapPath, String? webServiceUserName, String? webServicePassword, bool? useProxy, String? proxy, int? proxyPort, String? proxyUserName, String? proxyPassword, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsSourceSettingsSourceSource.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fileName → String?
-
final
- ftpArchive → bool?
-
final
- ftpArchivePath → String?
-
final
- ftpFileName → String?
-
final
- ftpHost → String?
-
final
- ftpPassword → String?
-
final
- ftpPath → String?
-
final
- ftpPort → int?
-
final
- ftpSsl → bool?
-
final
- ftpUserName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactive → bool?
-
final
- path → String?
-
final
- proxy → String?
-
final
- proxyPassword → String?
-
final
- proxyPort → int?
-
final
- proxyUserName → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
final
- sourceId → String?
-
final
- sourceType → String?
-
final
- systemSource → bool?
-
final
- temporaryFtpFileName → String?
-
final
- temporarySoapPath → String?
-
final
- useProxy → bool?
-
final
- webServicePassword → String?
-
final
- webServiceUserName → String?
-
final
Methods
-
copyWith(
{String? sourceId, String? source, String? sourceType, String? description, String? path, String? fileName, String? ftpHost, int? ftpPort, String? ftpUserName, String? ftpPassword, String? ftpPath, String? ftpFileName, bool? ftpArchive, String? ftpArchivePath, bool? ftpSsl, String? temporaryFtpFileName, bool? inactive, bool? systemSource, String? temporarySoapPath, String? webServiceUserName, String? webServicePassword, bool? useProxy, String? proxy, int? proxyPort, String? proxyUserName, String? proxyPassword, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsSourceSettingsSourceSource -
Available on WebApiModulesSettingsSourceSettingsSourceSource, provided by the $WebApiModulesSettingsSourceSettingsSourceSourceExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsSourceSettingsSourceSource Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsSourceSettingsSourceSource instance)