WebApiModulesSettingsSpaceSpace class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsSpaceSpace({String? spaceId, String? buildingId, String? building, String? floorId, String? floor, String? space, int? orderBy, String? buildingSpace, String? buildingFloorSpace, double? squareFeet, String? spaceFromDate, String? spaceToDate, bool? commonSquareFeet, String? primaryDimensionId, int? widthFt, int? heightFt, int? lengthFt, int? occupancy, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsSpaceSpace.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
building String?
final
buildingFloorSpace String?
final
buildingId String?
final
buildingSpace String?
final
commonSquareFeet bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
floor String?
final
floorId String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
heightFt int?
final
inactive bool?
final
lengthFt int?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
occupancy int?
final
orderBy int?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
primaryDimensionId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
space String?
final
spaceFromDate String?
final
spaceId String?
final
spaceToDate String?
final
squareFeet double?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
widthFt int?
final

Methods

copyWith({String? spaceId, String? buildingId, String? building, String? floorId, String? floor, String? space, int? orderBy, String? buildingSpace, String? buildingFloorSpace, double? squareFeet, String? spaceFromDate, String? spaceToDate, bool? commonSquareFeet, String? primaryDimensionId, int? widthFt, int? heightFt, int? lengthFt, int? occupancy, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsSpaceSpace

Available on WebApiModulesSettingsSpaceSpace, provided by the $WebApiModulesSettingsSpaceSpaceExtension extension

copyWithWrapped({Wrapped<String?>? spaceId, Wrapped<String?>? buildingId, Wrapped<String?>? building, Wrapped<String?>? floorId, Wrapped<String?>? floor, Wrapped<String?>? space, Wrapped<int?>? orderBy, Wrapped<String?>? buildingSpace, Wrapped<String?>? buildingFloorSpace, Wrapped<double?>? squareFeet, Wrapped<String?>? spaceFromDate, Wrapped<String?>? spaceToDate, Wrapped<bool?>? commonSquareFeet, Wrapped<String?>? primaryDimensionId, Wrapped<int?>? widthFt, Wrapped<int?>? heightFt, Wrapped<int?>? lengthFt, Wrapped<int?>? occupancy, Wrapped<bool?>? inactive, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsSpaceSpace

Available on WebApiModulesSettingsSpaceSpace, provided by the $WebApiModulesSettingsSpaceSpaceExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesSettingsSpaceSpace Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesSettingsSpaceSpace instance)