WebApiModulesSettingsSubCategorySubCategory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsSubCategorySubCategory({String? subCategoryId, String? subCategory, String? categoryId, String? category, String? typeId, String? type, String? recTypeDescription, String? recType, double? orderBy, int? pickListOrderBy, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsSubCategorySubCategory.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
category String?
final
categoryId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderBy double?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
pickListOrderBy int?
final
recordTitle String?
final
recType String?
final
recTypeDescription String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategory String?
final
subCategoryId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
type String?
final
typeId String?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? subCategoryId, String? subCategory, String? categoryId, String? category, String? typeId, String? type, String? recTypeDescription, String? recType, double? orderBy, int? pickListOrderBy, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsSubCategorySubCategory

Available on WebApiModulesSettingsSubCategorySubCategory, provided by the $WebApiModulesSettingsSubCategorySubCategoryExtension extension

copyWithWrapped({Wrapped<String?>? subCategoryId, Wrapped<String?>? subCategory, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<String?>? typeId, Wrapped<String?>? type, Wrapped<String?>? recTypeDescription, Wrapped<String?>? recType, Wrapped<double?>? orderBy, Wrapped<int?>? pickListOrderBy, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsSubCategorySubCategory

Available on WebApiModulesSettingsSubCategorySubCategory, provided by the $WebApiModulesSettingsSubCategorySubCategoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesSettingsSubCategorySubCategory Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesSettingsSubCategorySubCategory instance)