WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings({String? defaultSettingsId, String? defaultUnitId, String? defaultSettingsName, String? defaultUnit, String? defaultDealStatusId, String? defaultDealStatus, String? defaultCustomerStatusId, String? defaultCustomerStatus, String? defaultDealBillingCycleId, String? defaultDealBillingCycle, bool? defaultDealPoRequired, String? defaultDealPoType, bool? defaultDealStagingExcludeOrderAfterWrap, String? defaultNonRecurringBillingCycleId, String? defaultNonRecurringBillingCycle, String? defaultCustomerPaymentTermsId, String? defaultCustomerPaymentTerms, String? defaultContactGroupId, String? defaultContactGroupName, String? defaultRank, String? defaultCreditStatusId, String? defaultCreditStatus, bool? contactShowAllDeals, String? defaultVendorBillingCycleId, String? defaultVendorBillingCycle, String? defaultVendorPaymentTermsId, String? defaultVendorPaymentTerms, String? defaultVendorOutgoingDeliveryType, String? defaultVendorIncomingDeliveryType, bool? defaultVendorRentalInventory, bool? defaultVendorSalesPartsInventory, bool? defaultVendorRepair, bool? defaultVendorManufacturer, bool? defaultVendorFreight, bool? defaultVendorInsurance, bool? defaultVendorSubRent, bool? defaultVendorSubSales, bool? defaultVendorSubMisc, bool? defaultVendorSubLabor, bool? defaultVendorSubVehicle, bool? defaultVendorConsignment, String? rentalConditionId, String? rentalCondition, String? setConditionId, String? setCondition, String? propsConditionId, String? propsCondition, bool? defaultFulfillStrictPricingMatch, bool? defaultFulfillStrictNestingLvlMatch, bool? defaultQCRequired, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
contactShowAllDeals bool?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultContactGroupId String?
final
defaultContactGroupName String?
final
defaultCreditStatus String?
final
defaultCreditStatusId String?
final
defaultCustomerPaymentTerms String?
final
defaultCustomerPaymentTermsId String?
final
defaultCustomerStatus String?
final
defaultCustomerStatusId String?
final
defaultDealBillingCycle String?
final
defaultDealBillingCycleId String?
final
defaultDealPoRequired bool?
final
defaultDealPoType String?
final
defaultDealStagingExcludeOrderAfterWrap bool?
final
defaultDealStatus String?
final
defaultDealStatusId String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultFulfillStrictNestingLvlMatch bool?
final
defaultFulfillStrictPricingMatch bool?
final
defaultNonRecurringBillingCycle String?
final
defaultNonRecurringBillingCycleId String?
final
defaultQCRequired bool?
final
defaultRank String?
final
defaultSettingsId String?
final
defaultSettingsName String?
final
defaultUnit String?
final
defaultUnitId String?
final
defaultVendorBillingCycle String?
final
defaultVendorBillingCycleId String?
final
defaultVendorConsignment bool?
final
defaultVendorFreight bool?
final
defaultVendorIncomingDeliveryType String?
final
defaultVendorInsurance bool?
final
defaultVendorManufacturer bool?
final
defaultVendorOutgoingDeliveryType String?
final
defaultVendorPaymentTerms String?
final
defaultVendorPaymentTermsId String?
final
defaultVendorRentalInventory bool?
final
defaultVendorRepair bool?
final
defaultVendorSalesPartsInventory bool?
final
defaultVendorSubLabor bool?
final
defaultVendorSubMisc bool?
final
defaultVendorSubRent bool?
final
defaultVendorSubSales bool?
final
defaultVendorSubVehicle bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
propsCondition String?
final
propsConditionId String?
final
recordTitle String?
final
rentalCondition String?
final
rentalConditionId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setCondition String?
final
setConditionId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? defaultSettingsId, String? defaultUnitId, String? defaultSettingsName, String? defaultUnit, String? defaultDealStatusId, String? defaultDealStatus, String? defaultCustomerStatusId, String? defaultCustomerStatus, String? defaultDealBillingCycleId, String? defaultDealBillingCycle, bool? defaultDealPoRequired, String? defaultDealPoType, bool? defaultDealStagingExcludeOrderAfterWrap, String? defaultNonRecurringBillingCycleId, String? defaultNonRecurringBillingCycle, String? defaultCustomerPaymentTermsId, String? defaultCustomerPaymentTerms, String? defaultContactGroupId, String? defaultContactGroupName, String? defaultRank, String? defaultCreditStatusId, String? defaultCreditStatus, bool? contactShowAllDeals, String? defaultVendorBillingCycleId, String? defaultVendorBillingCycle, String? defaultVendorPaymentTermsId, String? defaultVendorPaymentTerms, String? defaultVendorOutgoingDeliveryType, String? defaultVendorIncomingDeliveryType, bool? defaultVendorRentalInventory, bool? defaultVendorSalesPartsInventory, bool? defaultVendorRepair, bool? defaultVendorManufacturer, bool? defaultVendorFreight, bool? defaultVendorInsurance, bool? defaultVendorSubRent, bool? defaultVendorSubSales, bool? defaultVendorSubMisc, bool? defaultVendorSubLabor, bool? defaultVendorSubVehicle, bool? defaultVendorConsignment, String? rentalConditionId, String? rentalCondition, String? setConditionId, String? setCondition, String? propsConditionId, String? propsCondition, bool? defaultFulfillStrictPricingMatch, bool? defaultFulfillStrictNestingLvlMatch, bool? defaultQCRequired, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings

Available on WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings, provided by the $WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettingsExtension extension

copyWithWrapped({Wrapped<String?>? defaultSettingsId, Wrapped<String?>? defaultUnitId, Wrapped<String?>? defaultSettingsName, Wrapped<String?>? defaultUnit, Wrapped<String?>? defaultDealStatusId, Wrapped<String?>? defaultDealStatus, Wrapped<String?>? defaultCustomerStatusId, Wrapped<String?>? defaultCustomerStatus, Wrapped<String?>? defaultDealBillingCycleId, Wrapped<String?>? defaultDealBillingCycle, Wrapped<bool?>? defaultDealPoRequired, Wrapped<String?>? defaultDealPoType, Wrapped<bool?>? defaultDealStagingExcludeOrderAfterWrap, Wrapped<String?>? defaultNonRecurringBillingCycleId, Wrapped<String?>? defaultNonRecurringBillingCycle, Wrapped<String?>? defaultCustomerPaymentTermsId, Wrapped<String?>? defaultCustomerPaymentTerms, Wrapped<String?>? defaultContactGroupId, Wrapped<String?>? defaultContactGroupName, Wrapped<String?>? defaultRank, Wrapped<String?>? defaultCreditStatusId, Wrapped<String?>? defaultCreditStatus, Wrapped<bool?>? contactShowAllDeals, Wrapped<String?>? defaultVendorBillingCycleId, Wrapped<String?>? defaultVendorBillingCycle, Wrapped<String?>? defaultVendorPaymentTermsId, Wrapped<String?>? defaultVendorPaymentTerms, Wrapped<String?>? defaultVendorOutgoingDeliveryType, Wrapped<String?>? defaultVendorIncomingDeliveryType, Wrapped<bool?>? defaultVendorRentalInventory, Wrapped<bool?>? defaultVendorSalesPartsInventory, Wrapped<bool?>? defaultVendorRepair, Wrapped<bool?>? defaultVendorManufacturer, Wrapped<bool?>? defaultVendorFreight, Wrapped<bool?>? defaultVendorInsurance, Wrapped<bool?>? defaultVendorSubRent, Wrapped<bool?>? defaultVendorSubSales, Wrapped<bool?>? defaultVendorSubMisc, Wrapped<bool?>? defaultVendorSubLabor, Wrapped<bool?>? defaultVendorSubVehicle, Wrapped<bool?>? defaultVendorConsignment, Wrapped<String?>? rentalConditionId, Wrapped<String?>? rentalCondition, Wrapped<String?>? setConditionId, Wrapped<String?>? setCondition, Wrapped<String?>? propsConditionId, Wrapped<String?>? propsCondition, Wrapped<bool?>? defaultFulfillStrictPricingMatch, Wrapped<bool?>? defaultFulfillStrictNestingLvlMatch, Wrapped<bool?>? defaultQCRequired, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings

Available on WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings, provided by the $WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override