WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettings({String? emailSettingsId, String? host, int? port, bool? enableSsl, String? accountPassword, String? accountUsername, String? authenticationType, int? deleteDays, String? emailFromAddress, String? emailFromDisplay, bool? enableReplyTo, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettings.fromJson(Map<String, dynamic> json)
factory

Properties

accountPassword String?
final
accountUsername String?
final
auditNote String?
final
authenticationType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
deleteDays int?
final
emailFromAddress String?
final
emailFromDisplay String?
final
emailSettingsId String?
final
enableReplyTo bool?
final
enableSsl bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
host String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
port int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? emailSettingsId, String? host, int? port, bool? enableSsl, String? accountPassword, String? accountUsername, String? authenticationType, int? deleteDays, String? emailFromAddress, String? emailFromDisplay, bool? enableReplyTo, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettings

Available on WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettings, provided by the $WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettingsExtension extension

copyWithWrapped({Wrapped<String?>? emailSettingsId, Wrapped<String?>? host, Wrapped<int?>? port, Wrapped<bool?>? enableSsl, Wrapped<String?>? accountPassword, Wrapped<String?>? accountUsername, Wrapped<String?>? authenticationType, Wrapped<int?>? deleteDays, Wrapped<String?>? emailFromAddress, Wrapped<String?>? emailFromDisplay, Wrapped<bool?>? enableReplyTo, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettings

Available on WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettings, provided by the $WebApiModulesSettingsSystemSettingsEmailSettingsEmailSettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override