WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings({String? inventorySettingsId, String? inventorySettingsName, String? iCodeMask, bool? padICodeWithZeros, bool? userAssignedICodes, int? lastICode, String? iCodePrefix, bool? enable3WeekPricing, bool? enableTieredWeekPricing, String? tier1Name, String? tier2Name, String? tier3Name, String? tier4Name, String? tier5Name, String? salesCheckOutRetiredReasonId, String? salesCheckOutRetiredReason, String? salesCheckInUnretiredReasonId, String? salesCheckInUnretiredReason, String? defaultRentalSaleRetiredReasonId, String? defaultRentalSaleRetiredReason, String? defaultLossAndDamageRetiredReasonId, String? defaultLossAndDamageRetiredReason, bool? startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived, bool? depreciateFixedAssetsWhenRetired, bool? unDepreciateFixedAssetsWhenUnretired, bool? includeTaxInOriginalEquipmentCost, String? defaultRentalQuantityInventoryCostCalculation, String? defaultSalesQuantityInventoryCostCalculation, String? defaultPartsQuantityInventoryCostCalculation, bool? enableLease, bool? autoUpdateInventoryMetricImperialDimensions, bool? convertDimensionsToSmallestUnit, bool? autoSortInventoryByICode, bool? fixedAssetTransferOwnership, String? changeICodeRetiredReasonId, String? changeICodeRetiredReason, bool? changeICodeCreateBrandNewPurchase, String? physicalInventoryRetiredReasonId, String? physicalInventoryRetiredReason, String? physicalInventoryDefaultCost, String? physicalInventoryAdjustmentReasonId, String? physicalInventoryAdjustmentReason, bool? enableInventoryCertification, bool? enablePropsWardrobe, bool? enableSetsWalls, String? returnInventoryRetiredReasonId, String? returnInventoryRetiredReason, String? voidReturnInventoryUnretiredReasonId, String? voidReturnInventoryUnretiredReason, bool? enableOriginalShow, bool? trackItemsInRooms, int? utilizationYears, bool? returnOnAssetUseDaysBilled, String? returnOnAssetRevenueDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- autoSortInventoryByICode → bool?
-
final
- autoUpdateInventoryMetricImperialDimensions → bool?
-
final
- changeICodeCreateBrandNewPurchase → bool?
-
final
- changeICodeRetiredReason → String?
-
final
- changeICodeRetiredReasonId → String?
-
final
- convertDimensionsToSmallestUnit → bool?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultLossAndDamageRetiredReason → String?
-
final
- defaultLossAndDamageRetiredReasonId → String?
-
final
- defaultPartsQuantityInventoryCostCalculation → String?
-
final
- defaultRentalQuantityInventoryCostCalculation → String?
-
final
- defaultRentalSaleRetiredReason → String?
-
final
- defaultRentalSaleRetiredReasonId → String?
-
final
- defaultSalesQuantityInventoryCostCalculation → String?
-
final
- depreciateFixedAssetsWhenRetired → bool?
-
final
- enable3WeekPricing → bool?
-
final
- enableInventoryCertification → bool?
-
final
- enableLease → bool?
-
final
- enableOriginalShow → bool?
-
final
- enablePropsWardrobe → bool?
-
final
- enableSetsWalls → bool?
-
final
- enableTieredWeekPricing → bool?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fixedAssetTransferOwnership → bool?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- iCodeMask → String?
-
final
- iCodePrefix → String?
-
final
- includeTaxInOriginalEquipmentCost → bool?
-
final
- inventorySettingsId → String?
-
final
- inventorySettingsName → String?
-
final
- lastICode → int?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- padICodeWithZeros → bool?
-
final
- physicalInventoryAdjustmentReason → String?
-
final
- physicalInventoryAdjustmentReasonId → String?
-
final
- physicalInventoryDefaultCost → String?
-
final
- physicalInventoryRetiredReason → String?
-
final
- physicalInventoryRetiredReasonId → String?
-
final
- recordTitle → String?
-
final
- returnInventoryRetiredReason → String?
-
final
- returnInventoryRetiredReasonId → String?
-
final
- returnOnAssetRevenueDate → String?
-
final
- returnOnAssetUseDaysBilled → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesCheckInUnretiredReason → String?
-
final
- salesCheckInUnretiredReasonId → String?
-
final
- salesCheckOutRetiredReason → String?
-
final
- salesCheckOutRetiredReasonId → String?
-
final
- startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived → bool?
-
final
- tier1Name → String?
-
final
- tier2Name → String?
-
final
- tier3Name → String?
-
final
- tier4Name → String?
-
final
- tier5Name → String?
-
final
- trackItemsInRooms → bool?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- unDepreciateFixedAssetsWhenUnretired → bool?
-
final
- urlIdentifier → dynamic
-
final
- userAssignedICodes → bool?
-
final
- utilizationYears → int?
-
final
- voidReturnInventoryUnretiredReason → String?
-
final
- voidReturnInventoryUnretiredReasonId → String?
-
final
Methods
-
copyWith(
{String? inventorySettingsId, String? inventorySettingsName, String? iCodeMask, bool? padICodeWithZeros, bool? userAssignedICodes, int? lastICode, String? iCodePrefix, bool? enable3WeekPricing, bool? enableTieredWeekPricing, String? tier1Name, String? tier2Name, String? tier3Name, String? tier4Name, String? tier5Name, String? salesCheckOutRetiredReasonId, String? salesCheckOutRetiredReason, String? salesCheckInUnretiredReasonId, String? salesCheckInUnretiredReason, String? defaultRentalSaleRetiredReasonId, String? defaultRentalSaleRetiredReason, String? defaultLossAndDamageRetiredReasonId, String? defaultLossAndDamageRetiredReason, bool? startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived, bool? depreciateFixedAssetsWhenRetired, bool? unDepreciateFixedAssetsWhenUnretired, bool? includeTaxInOriginalEquipmentCost, String? defaultRentalQuantityInventoryCostCalculation, String? defaultSalesQuantityInventoryCostCalculation, String? defaultPartsQuantityInventoryCostCalculation, bool? enableLease, bool? autoUpdateInventoryMetricImperialDimensions, bool? convertDimensionsToSmallestUnit, bool? autoSortInventoryByICode, bool? fixedAssetTransferOwnership, String? changeICodeRetiredReasonId, String? changeICodeRetiredReason, bool? changeICodeCreateBrandNewPurchase, String? physicalInventoryRetiredReasonId, String? physicalInventoryRetiredReason, String? physicalInventoryDefaultCost, String? physicalInventoryAdjustmentReasonId, String? physicalInventoryAdjustmentReason, bool? enableInventoryCertification, bool? enablePropsWardrobe, bool? enableSetsWalls, String? returnInventoryRetiredReasonId, String? returnInventoryRetiredReason, String? voidReturnInventoryUnretiredReasonId, String? voidReturnInventoryUnretiredReason, bool? enableOriginalShow, bool? trackItemsInRooms, int? utilizationYears, bool? returnOnAssetUseDaysBilled, String? returnOnAssetRevenueDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings -
Available on WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings, provided by the $WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettingsExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? inventorySettingsId, Wrapped<String?> ? inventorySettingsName, Wrapped<String?> ? iCodeMask, Wrapped<bool?> ? padICodeWithZeros, Wrapped<bool?> ? userAssignedICodes, Wrapped<int?> ? lastICode, Wrapped<String?> ? iCodePrefix, Wrapped<bool?> ? enable3WeekPricing, Wrapped<bool?> ? enableTieredWeekPricing, Wrapped<String?> ? tier1Name, Wrapped<String?> ? tier2Name, Wrapped<String?> ? tier3Name, Wrapped<String?> ? tier4Name, Wrapped<String?> ? tier5Name, Wrapped<String?> ? salesCheckOutRetiredReasonId, Wrapped<String?> ? salesCheckOutRetiredReason, Wrapped<String?> ? salesCheckInUnretiredReasonId, Wrapped<String?> ? salesCheckInUnretiredReason, Wrapped<String?> ? defaultRentalSaleRetiredReasonId, Wrapped<String?> ? defaultRentalSaleRetiredReason, Wrapped<String?> ? defaultLossAndDamageRetiredReasonId, Wrapped<String?> ? defaultLossAndDamageRetiredReason, Wrapped<bool?> ? startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived, Wrapped<bool?> ? depreciateFixedAssetsWhenRetired, Wrapped<bool?> ? unDepreciateFixedAssetsWhenUnretired, Wrapped<bool?> ? includeTaxInOriginalEquipmentCost, Wrapped<String?> ? defaultRentalQuantityInventoryCostCalculation, Wrapped<String?> ? defaultSalesQuantityInventoryCostCalculation, Wrapped<String?> ? defaultPartsQuantityInventoryCostCalculation, Wrapped<bool?> ? enableLease, Wrapped<bool?> ? autoUpdateInventoryMetricImperialDimensions, Wrapped<bool?> ? convertDimensionsToSmallestUnit, Wrapped<bool?> ? autoSortInventoryByICode, Wrapped<bool?> ? fixedAssetTransferOwnership, Wrapped<String?> ? changeICodeRetiredReasonId, Wrapped<String?> ? changeICodeRetiredReason, Wrapped<bool?> ? changeICodeCreateBrandNewPurchase, Wrapped<String?> ? physicalInventoryRetiredReasonId, Wrapped<String?> ? physicalInventoryRetiredReason, Wrapped<String?> ? physicalInventoryDefaultCost, Wrapped<String?> ? physicalInventoryAdjustmentReasonId, Wrapped<String?> ? physicalInventoryAdjustmentReason, Wrapped<bool?> ? enableInventoryCertification, Wrapped<bool?> ? enablePropsWardrobe, Wrapped<bool?> ? enableSetsWalls, Wrapped<String?> ? returnInventoryRetiredReasonId, Wrapped<String?> ? returnInventoryRetiredReason, Wrapped<String?> ? voidReturnInventoryUnretiredReasonId, Wrapped<String?> ? voidReturnInventoryUnretiredReason, Wrapped<bool?> ? enableOriginalShow, Wrapped<bool?> ? trackItemsInRooms, Wrapped<int?> ? utilizationYears, Wrapped<bool?> ? returnOnAssetUseDaysBilled, Wrapped<String?> ? returnOnAssetRevenueDate, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings -
Available on WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings, provided by the $WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings instance)