WebApiModulesSettingsTemplateSettingsTemplateTemplate class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsTemplateSettingsTemplateTemplate({String? templateId, String? description, String? departmentId, String? department, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, String? rateType, bool? rental, bool? sales, bool? miscellaneous, bool? labor, bool? facilities, bool? transportation, int? lines, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, String? manualSort, bool? manualSortRental, bool? manualSortSales, bool? manualSortMisc, bool? manualSortLabor, bool? manualSortLossAndDamage, bool? manualSortRentalSale, bool? manualSortParts, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsTemplateSettingsTemplateTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
department String?
final
departmentId String?
final
description String?
final
facilities bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hasFacilitiesItem bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hasLaborItem bool?
final
hasMiscellaneousItem bool?
final
hasRentalItem bool?
final
hasSalesItem bool?
final
labor bool?
final
lines int?
final
manualSort String?
final
manualSortLabor bool?
final
manualSortLossAndDamage bool?
final
manualSortMisc bool?
final
manualSortParts bool?
final
manualSortRental bool?
final
manualSortRentalSale bool?
final
manualSortSales bool?
final
miscellaneous bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officeLocation String?
final
officeLocationId String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
rateType String?
final
recordTitle String?
final
rental bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sales bool?
final
templateId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
transportation bool?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? templateId, String? description, String? departmentId, String? department, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, String? rateType, bool? rental, bool? sales, bool? miscellaneous, bool? labor, bool? facilities, bool? transportation, int? lines, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, String? manualSort, bool? manualSortRental, bool? manualSortSales, bool? manualSortMisc, bool? manualSortLabor, bool? manualSortLossAndDamage, bool? manualSortRentalSale, bool? manualSortParts, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsTemplateSettingsTemplateTemplate

Available on WebApiModulesSettingsTemplateSettingsTemplateTemplate, provided by the $WebApiModulesSettingsTemplateSettingsTemplateTemplateExtension extension

copyWithWrapped({Wrapped<String?>? templateId, Wrapped<String?>? description, Wrapped<String?>? departmentId, Wrapped<String?>? department, Wrapped<String?>? officeLocationId, Wrapped<String?>? officeLocation, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? warehouseCode, Wrapped<String?>? rateType, Wrapped<bool?>? rental, Wrapped<bool?>? sales, Wrapped<bool?>? miscellaneous, Wrapped<bool?>? labor, Wrapped<bool?>? facilities, Wrapped<bool?>? transportation, Wrapped<int?>? lines, Wrapped<bool?>? hasRentalItem, Wrapped<bool?>? hasSalesItem, Wrapped<bool?>? hasMiscellaneousItem, Wrapped<bool?>? hasLaborItem, Wrapped<bool?>? hasFacilitiesItem, Wrapped<String?>? manualSort, Wrapped<bool?>? manualSortRental, Wrapped<bool?>? manualSortSales, Wrapped<bool?>? manualSortMisc, Wrapped<bool?>? manualSortLabor, Wrapped<bool?>? manualSortLossAndDamage, Wrapped<bool?>? manualSortRentalSale, Wrapped<bool?>? manualSortParts, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsTemplateSettingsTemplateTemplate

Available on WebApiModulesSettingsTemplateSettingsTemplateTemplate, provided by the $WebApiModulesSettingsTemplateSettingsTemplateTemplateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override