WebApiModulesSettingsUserSearchSettingsUserSearchSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsUserSearchSettingsUserSearchSettings({String? webUserId, String? mode, String? resultFields, bool? disableAccessoryAutoExpand, bool? hideZeroQuantity, String? defaultSelect, String? defaultSortBy, bool? expandAccessoryOnQuantityIncrease, String? expandAccessoryBehavior, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsUserSearchSettingsUserSearchSettings.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultSelect String?
final
defaultSortBy String?
final
disableAccessoryAutoExpand bool?
final
expandAccessoryBehavior String?
final
expandAccessoryOnQuantityIncrease bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hideZeroQuantity bool?
final
mode String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
resultFields String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
webUserId String?
final

Methods

copyWith({String? webUserId, String? mode, String? resultFields, bool? disableAccessoryAutoExpand, bool? hideZeroQuantity, String? defaultSelect, String? defaultSortBy, bool? expandAccessoryOnQuantityIncrease, String? expandAccessoryBehavior, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsUserSearchSettingsUserSearchSettings

Available on WebApiModulesSettingsUserSearchSettingsUserSearchSettings, provided by the $WebApiModulesSettingsUserSearchSettingsUserSearchSettingsExtension extension

copyWithWrapped({Wrapped<String?>? webUserId, Wrapped<String?>? mode, Wrapped<String?>? resultFields, Wrapped<bool?>? disableAccessoryAutoExpand, Wrapped<bool?>? hideZeroQuantity, Wrapped<String?>? defaultSelect, Wrapped<String?>? defaultSortBy, Wrapped<bool?>? expandAccessoryOnQuantityIncrease, Wrapped<String?>? expandAccessoryBehavior, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsUserSearchSettingsUserSearchSettings

Available on WebApiModulesSettingsUserSearchSettingsUserSearchSettings, provided by the $WebApiModulesSettingsUserSearchSettingsUserSearchSettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override