WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse({String? vehicleTypeId, double? hourlyRate, double? dailyRate, double? weeklyRate, double? monthlyRate, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dailyRate double?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
hourlyRate double?
final
itemDescription String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
monthlyRate double?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
vehicleTypeId String?
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final
warehouseOrderBy int?
final
weeklyRate double?
final

Methods

copyWith({String? vehicleTypeId, double? hourlyRate, double? dailyRate, double? weeklyRate, double? monthlyRate, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse

Available on WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse, provided by the $WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouseExtension extension

copyWithWrapped({Wrapped<String?>? vehicleTypeId, Wrapped<double?>? hourlyRate, Wrapped<double?>? dailyRate, Wrapped<double?>? weeklyRate, Wrapped<double?>? monthlyRate, Wrapped<String?>? itemDescription, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouseCode, Wrapped<String?>? warehouse, Wrapped<int?>? warehouseOrderBy, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse

Available on WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse, provided by the $WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override