WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalog class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalog({String? vendorCatalogId, String? vendorCatalog, String? catalogType, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? vendorId, String? vendor, double? taxRate, double? globalMarkup, String? carrierId, String? carrier, String? shipViaId, String? shipVia, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalog.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
carrier String?
final
carrierId String?
final
catalogType String?
final
category String?
final
categoryId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
globalMarkup double?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
inventoryType String?
final
inventoryTypeId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shipVia String?
final
shipViaId String?
final
taxRate double?
final
vendor String?
final
vendorCatalog String?
final
vendorCatalogId String?
final
vendorId String?
final

Methods

copyWith({String? vendorCatalogId, String? vendorCatalog, String? catalogType, String? inventoryTypeId, String? inventoryType, String? categoryId, String? category, String? vendorId, String? vendor, double? taxRate, double? globalMarkup, String? carrierId, String? carrier, String? shipViaId, String? shipVia, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalog

Available on WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalog, provided by the $WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalogExtension extension

copyWithWrapped({Wrapped<String?>? vendorCatalogId, Wrapped<String?>? vendorCatalog, Wrapped<String?>? catalogType, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? inventoryType, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<String?>? vendorId, Wrapped<String?>? vendor, Wrapped<double?>? taxRate, Wrapped<double?>? globalMarkup, Wrapped<String?>? carrierId, Wrapped<String?>? carrier, Wrapped<String?>? shipViaId, Wrapped<String?>? shipVia, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes}) WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalog

Available on WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalog, provided by the $WebApiModulesSettingsVendorSettingsVendorCatalogVendorCatalogExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override