WebApiModulesSettingsWarehouseDepartmentWarehouseDepartment class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsWarehouseDepartmentWarehouseDepartment({String? warehouseId, String? departmentId, String? department, String? rentalBarCodeRangeId, String? rentalBarCodeRange, String? salesBarCodeRangeId, String? salesBarCodeRange, String? orderBy, String? requestToId, String? requestTo, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsWarehouseDepartmentWarehouseDepartment.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
department String?
final
departmentId String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
orderBy String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
rentalBarCodeRange String?
final
rentalBarCodeRangeId String?
final
requestTo String?
final
requestToId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesBarCodeRange String?
final
salesBarCodeRangeId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouseId String?
final

Methods

copyWith({String? warehouseId, String? departmentId, String? department, String? rentalBarCodeRangeId, String? rentalBarCodeRange, String? salesBarCodeRangeId, String? salesBarCodeRange, String? orderBy, String? requestToId, String? requestTo, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsWarehouseDepartmentWarehouseDepartment

Available on WebApiModulesSettingsWarehouseDepartmentWarehouseDepartment, provided by the $WebApiModulesSettingsWarehouseDepartmentWarehouseDepartmentExtension extension

copyWithWrapped({Wrapped<String?>? warehouseId, Wrapped<String?>? departmentId, Wrapped<String?>? department, Wrapped<String?>? rentalBarCodeRangeId, Wrapped<String?>? rentalBarCodeRange, Wrapped<String?>? salesBarCodeRangeId, Wrapped<String?>? salesBarCodeRange, Wrapped<String?>? orderBy, Wrapped<String?>? requestToId, Wrapped<String?>? requestTo, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsWarehouseDepartmentWarehouseDepartment

Available on WebApiModulesSettingsWarehouseDepartmentWarehouseDepartment, provided by the $WebApiModulesSettingsWarehouseDepartmentWarehouseDepartmentExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override