WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApprover class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApprover({String? warehouseQuikLocateApproverId, String? warehouseId, String? warehouse, String? warehouseCode, String? usersId, String? userName, String? officePhone, String? phoneExtension, String? cellular, String? directPhone, String? email, bool? sendEmail, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApprover.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
cellular String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
directPhone String?
final
email String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
officePhone String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
phoneExtension String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendEmail bool?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userName String?
final
usersId String?
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final
warehouseQuikLocateApproverId String?
final

Methods

copyWith({String? warehouseQuikLocateApproverId, String? warehouseId, String? warehouse, String? warehouseCode, String? usersId, String? userName, String? officePhone, String? phoneExtension, String? cellular, String? directPhone, String? email, bool? sendEmail, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApprover

Available on WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApprover, provided by the $WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApproverExtension extension

copyWithWrapped({Wrapped<String?>? warehouseQuikLocateApproverId, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? warehouseCode, Wrapped<String?>? usersId, Wrapped<String?>? userName, Wrapped<String?>? officePhone, Wrapped<String?>? phoneExtension, Wrapped<String?>? cellular, Wrapped<String?>? directPhone, Wrapped<String?>? email, Wrapped<bool?>? sendEmail, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApprover

Available on WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApprover, provided by the $WebApiModulesSettingsWarehouseQuikLocateApproverWarehouseQuikLocateApproverExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override