Undocumented class abstract
- Annotations
-
- @ChopperApi.new()
Constructors
Properties
- client ↔ ChopperClient
-
getter/setter pairinherited
- definitionType → Type
-
Used internally to retrieve the service from
ChopperClient.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shippingcaseBrowsePost(
{required FwStandardModelsBrowseRequest? body}) → Future< Response< FwStandardSqlServerFwJsonDataTable> > -
shippingcaseIdGet(
{required String? id}) → Future< Response< WebApiModulesWarehouseShippingCaseShippingCase> > - @param id
-
shippingcaseitemBrowsePost(
{required FwStandardModelsBrowseRequest? body}) → Future< Response< FwStandardSqlServerFwJsonDataTable> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{ChopperClient? client, Client? httpClient, Authenticator? authenticator, ErrorConverter? errorConverter, Converter? converter, Uri? baseUrl, List< Interceptor> ? interceptors}) → Undocumented