FwStandardSqlServerFwDataTypes enum

Inheritance
Available extensions

Values

swaggerGeneratedUnknown → const FwStandardSqlServerFwDataTypes
text → const FwStandardSqlServerFwDataTypes
nontrimmabletext → const FwStandardSqlServerFwDataTypes
date → const FwStandardSqlServerFwDataTypes
time → const FwStandardSqlServerFwDataTypes
datetime → const FwStandardSqlServerFwDataTypes
datetimeoffset → const FwStandardSqlServerFwDataTypes
decimal → const FwStandardSqlServerFwDataTypes
decimalstringnotrailingzeros → const FwStandardSqlServerFwDataTypes
decimalstring1digit → const FwStandardSqlServerFwDataTypes
decimalstring2digits → const FwStandardSqlServerFwDataTypes
decimalstring3digits → const FwStandardSqlServerFwDataTypes
decimalstring4digits → const FwStandardSqlServerFwDataTypes
decimalstring8digits → const FwStandardSqlServerFwDataTypes
boolean → const FwStandardSqlServerFwDataTypes
currencystring → const FwStandardSqlServerFwDataTypes
currencystringnodollarsign → const FwStandardSqlServerFwDataTypes
currencystringnodollarsignnodecimalplaces → const FwStandardSqlServerFwDataTypes
phoneus → const FwStandardSqlServerFwDataTypes
zipcodeus → const FwStandardSqlServerFwDataTypes
percentagewholenumber → const FwStandardSqlServerFwDataTypes
percentage2digits → const FwStandardSqlServerFwDataTypes
percentage4digits → const FwStandardSqlServerFwDataTypes
oletohtmlcolor → const FwStandardSqlServerFwDataTypes
integer → const FwStandardSqlServerFwDataTypes
jpgdataurl → const FwStandardSqlServerFwDataTypes
utcdatetime → const FwStandardSqlServerFwDataTypes

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FwStandardSqlServerFwDataTypes>
A constant List of the values in this enum, in order of their declaration.