SwaggerMetaData class

Metadata class containing information from SwaggerRequest

Constructors

SwaggerMetaData({required String summary, required String description, required String operationId, required List<String> consumes, required List<String> produces, required List<String> security, required List<String> tags, required bool deprecated})
const

Properties

consumes List<String>
final
deprecated bool
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
operationId String
final
produces List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security List<String>
final
summary String
final
tags List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited