FwStandardModulesSettingsWidgetSettingsWidgetWidget class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesSettingsWidgetSettingsWidgetWidget({bool? displayNumbers, String? filters, String? filterValues, String? mappedFilterValues, String? dateBehaviorId, String? dateField, DateTime? fromDate, DateTime? toDate, int? timezoneOffset, String? type, FwStandardModulesSettingsWidgetSettingsWidgetWidgetData? data, FwStandardModulesSettingsWidgetSettingsWidgetWidgetOptions? options, int? dataPoints, String? apiName, String? procedureName, String? counterFieldName, String? label1FieldName, String? label2FieldName, String? backgroundColorFieldName, String? borderColorFieldName, double? opacity, bool? stacked})
const
FwStandardModulesSettingsWidgetSettingsWidgetWidget.fromJson(Map<String, dynamic> json)
factory

Properties

apiName String?
final
backgroundColorFieldName String?
final
borderColorFieldName String?
final
counterFieldName String?
final
data FwStandardModulesSettingsWidgetSettingsWidgetWidgetData?
final
dataPoints int?
final
dateBehaviorId String?
final
dateField String?
final
displayNumbers bool?
final
filters String?
final
filterValues String?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
label1FieldName String?
final
label2FieldName String?
final
mappedFilterValues String?
final
opacity double?
final
options FwStandardModulesSettingsWidgetSettingsWidgetWidgetOptions?
final
procedureName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stacked bool?
final
timezoneOffset int?
final
toDate DateTime?
final
type String?
final

Methods

copyWith({bool? displayNumbers, String? filters, String? filterValues, String? mappedFilterValues, String? dateBehaviorId, String? dateField, DateTime? fromDate, DateTime? toDate, int? timezoneOffset, String? type, FwStandardModulesSettingsWidgetSettingsWidgetWidgetData? data, FwStandardModulesSettingsWidgetSettingsWidgetWidgetOptions? options, int? dataPoints, String? apiName, String? procedureName, String? counterFieldName, String? label1FieldName, String? label2FieldName, String? backgroundColorFieldName, String? borderColorFieldName, double? opacity, bool? stacked}) FwStandardModulesSettingsWidgetSettingsWidgetWidget

Available on FwStandardModulesSettingsWidgetSettingsWidgetWidget, provided by the $FwStandardModulesSettingsWidgetSettingsWidgetWidgetExtension extension

copyWithWrapped({Wrapped<bool?>? displayNumbers, Wrapped<String?>? filters, Wrapped<String?>? filterValues, Wrapped<String?>? mappedFilterValues, Wrapped<String?>? dateBehaviorId, Wrapped<String?>? dateField, Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<int?>? timezoneOffset, Wrapped<String?>? type, Wrapped<FwStandardModulesSettingsWidgetSettingsWidgetWidgetData?>? data, Wrapped<FwStandardModulesSettingsWidgetSettingsWidgetWidgetOptions?>? options, Wrapped<int?>? dataPoints, Wrapped<String?>? apiName, Wrapped<String?>? procedureName, Wrapped<String?>? counterFieldName, Wrapped<String?>? label1FieldName, Wrapped<String?>? label2FieldName, Wrapped<String?>? backgroundColorFieldName, Wrapped<String?>? borderColorFieldName, Wrapped<double?>? opacity, Wrapped<bool?>? stacked}) FwStandardModulesSettingsWidgetSettingsWidgetWidget

Available on FwStandardModulesSettingsWidgetSettingsWidgetWidget, provided by the $FwStandardModulesSettingsWidgetSettingsWidgetWidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override