FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSet class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSet({String? label, List<double>? data, List<String>? backgroundColor, List<String>? borderColor, int? borderWidth, List<DateTime>? fromDate, List<DateTime>? toDate})
const
FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSet.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor List<String>?
final
borderColor List<String>?
final
borderWidth int?
final
data List<double>?
final
fromDate List<DateTime>?
final
hashCode int
The hash code for this object.
no setteroverride
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate List<DateTime>?
final

Methods

copyWith({String? label, List<double>? data, List<String>? backgroundColor, List<String>? borderColor, int? borderWidth, List<DateTime>? fromDate, List<DateTime>? toDate}) FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSet

Available on FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSet, provided by the $FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSetExtension extension

copyWithWrapped({Wrapped<String?>? label, Wrapped<List<double>?>? data, Wrapped<List<String>?>? backgroundColor, Wrapped<List<String>?>? borderColor, Wrapped<int?>? borderWidth, Wrapped<List<DateTime>?>? fromDate, Wrapped<List<DateTime>?>? toDate}) FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSet

Available on FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSet, provided by the $FwStandardModulesSettingsWidgetSettingsWidgetWidgetDataSetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override