FwStandardModulesUtilitiesWebImportImportExcelRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesUtilitiesWebImportImportExcelRequest({String? moduleName, String? moduleId, String? importDescription, List<Object>? excelObjects, String? sessionId, int? startIndex, int? totalSteps, bool? isFirstBatch, bool? isLastBatch, String? webImportId, bool? fastMode})
const
FwStandardModulesUtilitiesWebImportImportExcelRequest.fromJson(Map<String, dynamic> json)
factory

Properties

excelObjects List<Object>?
final
fastMode bool?
final
hashCode int
The hash code for this object.
no setteroverride
importDescription String?
final
isFirstBatch bool?
final
isLastBatch bool?
final
moduleId String?
final
moduleName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
startIndex int?
final
totalSteps int?
final
webImportId String?
final

Methods

copyWith({String? moduleName, String? moduleId, String? importDescription, List<Object>? excelObjects, String? sessionId, int? startIndex, int? totalSteps, bool? isFirstBatch, bool? isLastBatch, String? webImportId, bool? fastMode}) FwStandardModulesUtilitiesWebImportImportExcelRequest

Available on FwStandardModulesUtilitiesWebImportImportExcelRequest, provided by the $FwStandardModulesUtilitiesWebImportImportExcelRequestExtension extension

copyWithWrapped({Wrapped<String?>? moduleName, Wrapped<String?>? moduleId, Wrapped<String?>? importDescription, Wrapped<List<Object>?>? excelObjects, Wrapped<String?>? sessionId, Wrapped<int?>? startIndex, Wrapped<int?>? totalSteps, Wrapped<bool?>? isFirstBatch, Wrapped<bool?>? isLastBatch, Wrapped<String?>? webImportId, Wrapped<bool?>? fastMode}) FwStandardModulesUtilitiesWebImportImportExcelRequest

Available on FwStandardModulesUtilitiesWebImportImportExcelRequest, provided by the $FwStandardModulesUtilitiesWebImportImportExcelRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override