WebApiModulesExportsOrderExportOrderExportResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

batchId String?
final
batchNumber String?
final
downloadUrl String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? batchId, String? batchNumber, String? downloadUrl}) WebApiModulesExportsOrderExportOrderExportResponse

Available on WebApiModulesExportsOrderExportOrderExportResponse, provided by the $WebApiModulesExportsOrderExportOrderExportResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override