WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest({String? fromWarehouseId, String? toWarehouseIds})
-
const
-
WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- fromWarehouseId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toWarehouseIds → String?
-
final
Methods
-
copyWith(
{String? fromWarehouseId, String? toWarehouseIds}) → WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest -
Available on WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest, provided by the $WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? fromWarehouseId, Wrapped<String?> ? toWarehouseIds}) → WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest -
Available on WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest, provided by the $WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryInventoryCopyPendingModificationsToOtherWarehousesRequest instance)