WebApiModulesInventoryReservedRentalItemReservedRentalItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryReservedRentalItemReservedRentalItem({int? reservedRentalItemId, String? orderId, String? orderItemId, String? rentalItemId, String? inventoryId, String? iCode, String? description, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? warehouseId, String? returnToWarehouseId, String? usersId, String? barCode, String? serialNumber, String? trackedByCode, String? ownership, String? ownershipSort, String? consignorId, String? consignor, String? orderNumber, String? orderDescription, String? orderType, String? orderStatus, String? dealId, String? deal, String? nameFml, DateTime? fromDateTime, DateTime? toDateTime, String? conflict, String? forceConflict, String? positiveConflict, String? availabilityColor, String? availabilityOrderColor, String? availabilityOrderWhiteText, String? availabilityByHour, String? itemStatus, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesInventoryReservedRentalItemReservedRentalItem.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
availabilityByHour String?
final
availabilityColor String?
final
availabilityOrderColor String?
final
availabilityOrderWhiteText String?
final
barCode String?
final
categoryId String?
final
conflict String?
final
consignor String?
final
consignorId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
deal String?
final
dealId String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
forceConflict String?
final
fromDateTime DateTime?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inventoryId String?
final
inventoryTypeId String?
final
itemStatus String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
nameFml String?
final
orderDescription String?
final
orderId String?
final
orderItemId String?
final
orderNumber String?
final
orderStatus String?
final
orderType String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
ownership String?
final
ownershipSort String?
final
positiveConflict String?
final
recordTitle String?
final
rentalItemId String?
final
reservedRentalItemId int?
final
returnToWarehouseId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
final
subCategoryId String?
final
toDateTime DateTime?
final
trackedByCode String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
usersId String?
final
warehouseId String?
final

Methods

copyWith({int? reservedRentalItemId, String? orderId, String? orderItemId, String? rentalItemId, String? inventoryId, String? iCode, String? description, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? warehouseId, String? returnToWarehouseId, String? usersId, String? barCode, String? serialNumber, String? trackedByCode, String? ownership, String? ownershipSort, String? consignorId, String? consignor, String? orderNumber, String? orderDescription, String? orderType, String? orderStatus, String? dealId, String? deal, String? nameFml, DateTime? fromDateTime, DateTime? toDateTime, String? conflict, String? forceConflict, String? positiveConflict, String? availabilityColor, String? availabilityOrderColor, String? availabilityOrderWhiteText, String? availabilityByHour, String? itemStatus, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesInventoryReservedRentalItemReservedRentalItem

Available on WebApiModulesInventoryReservedRentalItemReservedRentalItem, provided by the $WebApiModulesInventoryReservedRentalItemReservedRentalItemExtension extension

copyWithWrapped({Wrapped<int?>? reservedRentalItemId, Wrapped<String?>? orderId, Wrapped<String?>? orderItemId, Wrapped<String?>? rentalItemId, Wrapped<String?>? inventoryId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? categoryId, Wrapped<String?>? subCategoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? returnToWarehouseId, Wrapped<String?>? usersId, Wrapped<String?>? barCode, Wrapped<String?>? serialNumber, Wrapped<String?>? trackedByCode, Wrapped<String?>? ownership, Wrapped<String?>? ownershipSort, Wrapped<String?>? consignorId, Wrapped<String?>? consignor, Wrapped<String?>? orderNumber, Wrapped<String?>? orderDescription, Wrapped<String?>? orderType, Wrapped<String?>? orderStatus, Wrapped<String?>? dealId, Wrapped<String?>? deal, Wrapped<String?>? nameFml, Wrapped<DateTime?>? fromDateTime, Wrapped<DateTime?>? toDateTime, Wrapped<String?>? conflict, Wrapped<String?>? forceConflict, Wrapped<String?>? positiveConflict, Wrapped<String?>? availabilityColor, Wrapped<String?>? availabilityOrderColor, Wrapped<String?>? availabilityOrderWhiteText, Wrapped<String?>? availabilityByHour, Wrapped<String?>? itemStatus, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesInventoryReservedRentalItemReservedRentalItem

Available on WebApiModulesInventoryReservedRentalItemReservedRentalItem, provided by the $WebApiModulesInventoryReservedRentalItemReservedRentalItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override