WebApiModulesSettingsWidgetSettingsWidgetWidget class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsWidgetSettingsWidgetWidget({String? locationId, String? warehouseId, String? departmentId, String? locationCodes, String? locations, String? dateBehaviorId, String? dateField, DateTime? fromDate, DateTime? toDate, String? type, WebApiModulesSettingsWidgetSettingsWidgetWidgetData? data, WebApiModulesSettingsWidgetSettingsWidgetWidgetOptions? options, int? dataPoints, String? apiName, String? procedureName, String? counterFieldName, String? label1FieldName, String? label2FieldName, String? backgroundColorFieldName, String? borderColorFieldName, double? opacity, bool? stacked})
WebApiModulesSettingsWidgetSettingsWidgetWidget.fromJson(Map<String, dynamic> json)
factory

Properties

apiName String?
final
backgroundColorFieldName String?
final
borderColorFieldName String?
final
counterFieldName String?
final
data WebApiModulesSettingsWidgetSettingsWidgetWidgetData?
final
dataPoints int?
final
dateBehaviorId String?
final
dateField String?
final
departmentId String?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
label1FieldName String?
final
label2FieldName String?
final
locationCodes String?
final
locationId String?
final
locations String?
final
opacity double?
final
options WebApiModulesSettingsWidgetSettingsWidgetWidgetOptions?
final
procedureName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stacked bool?
final
toDate DateTime?
final
type String?
final
warehouseId String?
final

Methods

copyWith({String? locationId, String? warehouseId, String? departmentId, String? locationCodes, String? locations, String? dateBehaviorId, String? dateField, DateTime? fromDate, DateTime? toDate, String? type, WebApiModulesSettingsWidgetSettingsWidgetWidgetData? data, WebApiModulesSettingsWidgetSettingsWidgetWidgetOptions? options, int? dataPoints, String? apiName, String? procedureName, String? counterFieldName, String? label1FieldName, String? label2FieldName, String? backgroundColorFieldName, String? borderColorFieldName, double? opacity, bool? stacked}) WebApiModulesSettingsWidgetSettingsWidgetWidget

Available on WebApiModulesSettingsWidgetSettingsWidgetWidget, provided by the $WebApiModulesSettingsWidgetSettingsWidgetWidgetExtension extension

copyWithWrapped({Wrapped<String?>? locationId, Wrapped<String?>? warehouseId, Wrapped<String?>? departmentId, Wrapped<String?>? locationCodes, Wrapped<String?>? locations, Wrapped<String?>? dateBehaviorId, Wrapped<String?>? dateField, Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<String?>? type, Wrapped<WebApiModulesSettingsWidgetSettingsWidgetWidgetData?>? data, Wrapped<WebApiModulesSettingsWidgetSettingsWidgetWidgetOptions?>? options, Wrapped<int?>? dataPoints, Wrapped<String?>? apiName, Wrapped<String?>? procedureName, Wrapped<String?>? counterFieldName, Wrapped<String?>? label1FieldName, Wrapped<String?>? label2FieldName, Wrapped<String?>? backgroundColorFieldName, Wrapped<String?>? borderColorFieldName, Wrapped<double?>? opacity, Wrapped<bool?>? stacked}) WebApiModulesSettingsWidgetSettingsWidgetWidget

Available on WebApiModulesSettingsWidgetSettingsWidgetWidget, provided by the $WebApiModulesSettingsWidgetSettingsWidgetWidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override