WebApiModulesSettingsWidgetSettingsWidgetWidgetData class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

datasets List<WebApiModulesSettingsWidgetSettingsWidgetWidgetDataSet>?
final
hashCode int
The hash code for this object.
no setteroverride
labels List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? labels, List<WebApiModulesSettingsWidgetSettingsWidgetWidgetDataSet>? datasets}) WebApiModulesSettingsWidgetSettingsWidgetWidgetData

Available on WebApiModulesSettingsWidgetSettingsWidgetWidgetData, provided by the $WebApiModulesSettingsWidgetSettingsWidgetWidgetDataExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override