WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponse({bool? success, String? response, String? message, String? sessionId, int? tokensUsed, DateTime? responseTime, bool? usedSupportArticles, List<String>? relevantArticles})
const
WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
message String?
final
relevantArticles List<String>?
final
response String?
final
responseTime DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
success bool?
final
tokensUsed int?
final
usedSupportArticles bool?
final

Methods

copyWith({bool? success, String? response, String? message, String? sessionId, int? tokensUsed, DateTime? responseTime, bool? usedSupportArticles, List<String>? relevantArticles}) WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponse

Available on WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponse, provided by the $WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponseExtension extension

copyWithWrapped({Wrapped<bool?>? success, Wrapped<String?>? response, Wrapped<String?>? message, Wrapped<String?>? sessionId, Wrapped<int?>? tokensUsed, Wrapped<DateTime?>? responseTime, Wrapped<bool?>? usedSupportArticles, Wrapped<List<String>?>? relevantArticles}) WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponse

Available on WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponse, provided by the $WebApiModulesUtilitiesAIAssistantUtilityAIAssistantResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override