WebApiModulesUtilitiesAIAssistantUtilityChatHistorySaveRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

chatData String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
userId String?
final

Methods

copyWith({String? userId, String? title, String? chatData}) WebApiModulesUtilitiesAIAssistantUtilityChatHistorySaveRequest

Available on WebApiModulesUtilitiesAIAssistantUtilityChatHistorySaveRequest, provided by the $WebApiModulesUtilitiesAIAssistantUtilityChatHistorySaveRequestExtension extension

copyWithWrapped({Wrapped<String?>? userId, Wrapped<String?>? title, Wrapped<String?>? chatData}) WebApiModulesUtilitiesAIAssistantUtilityChatHistorySaveRequest

Available on WebApiModulesUtilitiesAIAssistantUtilityChatHistorySaveRequest, provided by the $WebApiModulesUtilitiesAIAssistantUtilityChatHistorySaveRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override