WebApiModulesUtilitiesAIAssistantUtilityChatMessage class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
message String?
final
role String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String?
final

Methods

copyWith({String? role, String? message, String? timestamp}) WebApiModulesUtilitiesAIAssistantUtilityChatMessage

Available on WebApiModulesUtilitiesAIAssistantUtilityChatMessage, provided by the $WebApiModulesUtilitiesAIAssistantUtilityChatMessageExtension extension

copyWithWrapped({Wrapped<String?>? role, Wrapped<String?>? message, Wrapped<String?>? timestamp}) WebApiModulesUtilitiesAIAssistantUtilityChatMessage

Available on WebApiModulesUtilitiesAIAssistantUtilityChatMessage, provided by the $WebApiModulesUtilitiesAIAssistantUtilityChatMessageExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override