WebApiModulesUtilitiesControlsBrowseActiveViewFieldsBrowseActiveViewFields class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

activeViewFields String?
final
auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
moduleName String?
final
officeLocationId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webUserId String?
final

Methods

copyWith({int? id, String? webUserId, String? officeLocationId, String? moduleName, String? activeViewFields, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesUtilitiesControlsBrowseActiveViewFieldsBrowseActiveViewFields

Available on WebApiModulesUtilitiesControlsBrowseActiveViewFieldsBrowseActiveViewFields, provided by the $WebApiModulesUtilitiesControlsBrowseActiveViewFieldsBrowseActiveViewFieldsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override