WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItem({String? inventoryId, String? warehouseId, String? iCode, String? description, String? availableFor, String? rank, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? inventoryTypeId, String? inventoryType, String? warehouseCode, String? warehouse, double? quantity, String? aisleLocation, String? shelfLocation, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItem.fromJson(Map<String, dynamic> json)
factory

Properties

aisleLocation String?
final
auditNote String?
final
availableFor String?
final
category String?
final
categoryId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
inventoryId String?
final
inventoryType String?
final
inventoryTypeId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quantity double?
final
rank String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelfLocation String?
final
subCategory String?
final
subCategoryId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final

Methods

copyWith({String? inventoryId, String? warehouseId, String? iCode, String? description, String? availableFor, String? rank, String? categoryId, String? category, String? subCategoryId, String? subCategory, String? inventoryTypeId, String? inventoryType, String? warehouseCode, String? warehouse, double? quantity, String? aisleLocation, String? shelfLocation, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItem

Available on WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItem, provided by the $WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItemExtension extension

copyWithWrapped({Wrapped<String?>? inventoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? availableFor, Wrapped<String?>? rank, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<String?>? subCategoryId, Wrapped<String?>? subCategory, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? inventoryType, Wrapped<String?>? warehouseCode, Wrapped<String?>? warehouse, Wrapped<double?>? quantity, Wrapped<String?>? aisleLocation, Wrapped<String?>? shelfLocation, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItem

Available on WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItem, provided by the $WebApiModulesUtilitiesInventoryLocationItemInventoryLocationItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override