WebApiModulesUtilitiesInventoryMergeInventoryMerge class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesInventoryMergeInventoryMerge({int? inventoryMergeId, String? sessionId, String? fromInventoryId, String? fromICode, String? fromDescription, String? toInventoryId, String? toICode, String? toDescription, String? warehouseId, String? warehouse, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesInventoryMergeInventoryMerge.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fromDescription String?
final
fromICode String?
final
fromInventoryId String?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inventoryMergeId int?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
toDescription String?
final
toICode String?
final
toInventoryId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
warehouse String?
final
warehouseId String?
final

Methods

copyWith({int? inventoryMergeId, String? sessionId, String? fromInventoryId, String? fromICode, String? fromDescription, String? toInventoryId, String? toICode, String? toDescription, String? warehouseId, String? warehouse, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesInventoryMergeInventoryMerge

Available on WebApiModulesUtilitiesInventoryMergeInventoryMerge, provided by the $WebApiModulesUtilitiesInventoryMergeInventoryMergeExtension extension

copyWithWrapped({Wrapped<int?>? inventoryMergeId, Wrapped<String?>? sessionId, Wrapped<String?>? fromInventoryId, Wrapped<String?>? fromICode, Wrapped<String?>? fromDescription, Wrapped<String?>? toInventoryId, Wrapped<String?>? toICode, Wrapped<String?>? toDescription, Wrapped<String?>? warehouseId, Wrapped<String?>? warehouse, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesInventoryMergeInventoryMerge

Available on WebApiModulesUtilitiesInventoryMergeInventoryMerge, provided by the $WebApiModulesUtilitiesInventoryMergeInventoryMergeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override