WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest({String? fromWarehouseId, String? toWarehouseId, String? itemId, String? locationId, String? departmentId, String? transferTypeId})
-
const
-
WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- departmentId → String?
-
final
- fromWarehouseId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- itemId → String?
-
final
- locationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toWarehouseId → String?
-
final
- transferTypeId → String?
-
final
Methods
-
copyWith(
{String? fromWarehouseId, String? toWarehouseId, String? itemId, String? locationId, String? departmentId, String? transferTypeId}) → WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest -
Available on WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest, provided by the $WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? fromWarehouseId, Wrapped<String?> ? toWarehouseId, Wrapped<String?> ? itemId, Wrapped<String?> ? locationId, Wrapped<String?> ? departmentId, Wrapped<String?> ? transferTypeId}) → WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest -
Available on WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest, provided by the $WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesUtilitiesInventoryTransferUtilityTransferInventoryRequest instance)