WebApiModulesUtilitiesLabelDesignBarcodeLabel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesLabelDesignBarcodeLabel({String? barcode, String? icode, String? description, String? inventorytype, String? category, String? subcategory, String? trackedby, String? manufacturer, String? manufacturerpartnumber})
const
WebApiModulesUtilitiesLabelDesignBarcodeLabel.fromJson(Map<String, dynamic> json)
factory

Properties

barcode String?
final
category String?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
icode String?
final
inventorytype String?
final
manufacturer String?
final
manufacturerpartnumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subcategory String?
final
trackedby String?
final

Methods

copyWith({String? barcode, String? icode, String? description, String? inventorytype, String? category, String? subcategory, String? trackedby, String? manufacturer, String? manufacturerpartnumber}) WebApiModulesUtilitiesLabelDesignBarcodeLabel

Available on WebApiModulesUtilitiesLabelDesignBarcodeLabel, provided by the $WebApiModulesUtilitiesLabelDesignBarcodeLabelExtension extension

copyWithWrapped({Wrapped<String?>? barcode, Wrapped<String?>? icode, Wrapped<String?>? description, Wrapped<String?>? inventorytype, Wrapped<String?>? category, Wrapped<String?>? subcategory, Wrapped<String?>? trackedby, Wrapped<String?>? manufacturer, Wrapped<String?>? manufacturerpartnumber}) WebApiModulesUtilitiesLabelDesignBarcodeLabel

Available on WebApiModulesUtilitiesLabelDesignBarcodeLabel, provided by the $WebApiModulesUtilitiesLabelDesignBarcodeLabelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesUtilitiesLabelDesignBarcodeLabel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesUtilitiesLabelDesignBarcodeLabel instance)