WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequest({String? sessionId, bool? migrateToNewOrder, String? newOrderOfficeLocationId, String? newOrderWarehouseId, String? newOrderDealId, String? newOrderDepartmentId, String? newOrderOrderTypeId, String? newOrderDescription, String? newOrderRateType, String? newOrderFromDate, String? newOrderFromTime, String? newOrderToDate, String? newOrderToTime, String? newOrderBillingStopDate, bool? newOrderPendingPO, bool? newOrderFlatPO, String? newOrderPurchaseOrderNumber, double? newOrderPurchaseOrderAmount, bool? migrateToExistingOrder, String? existingOrderId, String? inventoryFulfillIncrement, bool? fulfillStrictPricingMatch, bool? copyLineItemNotes, bool? copyOrderNotes, bool? copyRentalRates, bool? updateBillingStopDate, DateTime? billingStopDate, String? officeLocationId, String? warehouseId})
-
WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- billingStopDate → DateTime?
-
final
- copyLineItemNotes → bool?
-
final
- copyOrderNotes → bool?
-
final
- copyRentalRates → bool?
-
final
- existingOrderId → String?
-
final
- fulfillStrictPricingMatch → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inventoryFulfillIncrement → String?
-
final
- migrateToExistingOrder → bool?
-
final
- migrateToNewOrder → bool?
-
final
- newOrderBillingStopDate → String?
-
final
- newOrderDealId → String?
-
final
- newOrderDepartmentId → String?
-
final
- newOrderDescription → String?
-
final
- newOrderFlatPO → bool?
-
final
- newOrderFromDate → String?
-
final
- newOrderFromTime → String?
-
final
- newOrderOfficeLocationId → String?
-
final
- newOrderOrderTypeId → String?
-
final
- newOrderPendingPO → bool?
-
final
- newOrderPurchaseOrderAmount → double?
-
final
- newOrderPurchaseOrderNumber → String?
-
final
- newOrderRateType → String?
-
final
- newOrderToDate → String?
-
final
- newOrderToTime → String?
-
final
- newOrderWarehouseId → String?
-
final
- officeLocationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- updateBillingStopDate → bool?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? sessionId, bool? migrateToNewOrder, String? newOrderOfficeLocationId, String? newOrderWarehouseId, String? newOrderDealId, String? newOrderDepartmentId, String? newOrderOrderTypeId, String? newOrderDescription, String? newOrderRateType, String? newOrderFromDate, String? newOrderFromTime, String? newOrderToDate, String? newOrderToTime, String? newOrderBillingStopDate, bool? newOrderPendingPO, bool? newOrderFlatPO, String? newOrderPurchaseOrderNumber, double? newOrderPurchaseOrderAmount, bool? migrateToExistingOrder, String? existingOrderId, String? inventoryFulfillIncrement, bool? fulfillStrictPricingMatch, bool? copyLineItemNotes, bool? copyOrderNotes, bool? copyRentalRates, bool? updateBillingStopDate, DateTime? billingStopDate, String? officeLocationId, String? warehouseId}) → WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequest -
Available on WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequest, provided by the $WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesUtilitiesMigrateCompleteMigrateSessionRequest instance)