WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequest({required String sessionId, bool? selectAll, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? warehouseId, String? inventoryId, String? vendorId, String? description, String? barCode})
const
WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

barCode String?
final
categoryId String?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
inventoryId String?
final
inventoryTypeId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectAll bool?
final
sessionId String
final
subCategoryId String?
final
vendorId String?
final
warehouseId String?
final

Methods

copyWith({String? sessionId, bool? selectAll, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? warehouseId, String? inventoryId, String? vendorId, String? description, String? barCode}) WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequest

Available on WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequest, provided by the $WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequestExtension extension

copyWithWrapped({Wrapped<String>? sessionId, Wrapped<bool?>? selectAll, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? categoryId, Wrapped<String?>? subCategoryId, Wrapped<String?>? warehouseId, Wrapped<String?>? inventoryId, Wrapped<String?>? vendorId, Wrapped<String?>? description, Wrapped<String?>? barCode}) WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequest

Available on WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequest, provided by the $WebApiModulesUtilitiesMigrateSelectAllNoneMigrateItemRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override