WebApiModulesUtilitiesQuikActivityQuikActivityFuncQuikActivityCalendarEvent class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

activityType String?
final
backColor String?
final
end String?
final
hashCode int
The hash code for this object.
no setteroverride
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start String?
final
text String?
final
textColor String?
final

Methods

copyWith({String? start, String? end, String? text, String? backColor, String? textColor, String? activityType, String? id}) WebApiModulesUtilitiesQuikActivityQuikActivityFuncQuikActivityCalendarEvent

Available on WebApiModulesUtilitiesQuikActivityQuikActivityFuncQuikActivityCalendarEvent, provided by the $WebApiModulesUtilitiesQuikActivityQuikActivityFuncQuikActivityCalendarEventExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override