WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventory({int? id, String? sessionId, String? inventoryId, String? description, String? iCode, String? inventoryType, String? inventoryTypeId, String? category, String? categoryId, String? subCategory, String? subCategoryId, int? quantity, double? unitValue, double? extendedValue, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventory.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
category String?
final
categoryId String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
extendedValue double?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
iCode String?
final
id int?
final
inventoryId String?
final
inventoryType String?
final
inventoryTypeId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quantity int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
subCategory String?
final
subCategoryId String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
unitValue double?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? id, String? sessionId, String? inventoryId, String? description, String? iCode, String? inventoryType, String? inventoryTypeId, String? category, String? categoryId, String? subCategory, String? subCategoryId, int? quantity, double? unitValue, double? extendedValue, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventory

Available on WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventory, provided by the $WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventoryExtension extension

copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? sessionId, Wrapped<String?>? inventoryId, Wrapped<String?>? description, Wrapped<String?>? iCode, Wrapped<String?>? inventoryType, Wrapped<String?>? inventoryTypeId, Wrapped<String?>? category, Wrapped<String?>? categoryId, Wrapped<String?>? subCategory, Wrapped<String?>? subCategoryId, Wrapped<int?>? quantity, Wrapped<double?>? unitValue, Wrapped<double?>? extendedValue, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventory

Available on WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventory, provided by the $WebApiModulesUtilitiesSplitQuantityInventorySplitQuantityInventoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override