WebApiModulesUtilitiesUserProfileUserProfile class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesUserProfileUserProfile({String? webUserId, String? userName, String? userId, String? loginName, int? browseDefaultRows, int? gridDefaultRows, String? applicationTheme, String? homeMenuGuid, String? homeMenuPath, String? languageId, String? language, int? soundProfileId, String? soundProfileName, String? favoritesJson, int? firstDayOfWeek, bool? settingsNavigationMenuVisible, bool? reportsNavigationMenuVisible, bool? showUnreservedQuotes, bool? mainMenuPinned, bool? webAdministrator, String? quikActivitySetting, String? emailSignature, String? newPassword, String? oldPassword, String? locale, String? availabilityPreference, bool? availabilityAllWarehouses, String? emailApp, bool? addRentalWorksUserSignature, String? quikSearchMode, bool? autoPrintContract, bool? showRentalItemsOutOnly, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesUserProfileUserProfile.fromJson(Map<String, dynamic> json)
factory

Properties

addRentalWorksUserSignature bool?
final
applicationTheme String?
final
auditNote String?
final
autoPrintContract bool?
final
availabilityAllWarehouses bool?
final
availabilityPreference String?
final
browseDefaultRows int?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
emailApp String?
final
emailSignature String?
final
favoritesJson String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
firstDayOfWeek int?
final
gridDefaultRows int?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
homeMenuGuid String?
final
homeMenuPath String?
final
language String?
final
languageId String?
final
locale String?
final
loginName String?
final
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
newPassword String?
final
oldPassword String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quikActivitySetting String?
final
quikSearchMode String?
final
recordTitle String?
final
reportsNavigationMenuVisible bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settingsNavigationMenuVisible bool?
final
showRentalItemsOutOnly bool?
final
showUnreservedQuotes bool?
final
soundProfileId int?
final
soundProfileName String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userId String?
final
userName String?
final
webAdministrator bool?
final
webUserId String?
final

Methods

copyWith({String? webUserId, String? userName, String? userId, String? loginName, int? browseDefaultRows, int? gridDefaultRows, String? applicationTheme, String? homeMenuGuid, String? homeMenuPath, String? languageId, String? language, int? soundProfileId, String? soundProfileName, String? favoritesJson, int? firstDayOfWeek, bool? settingsNavigationMenuVisible, bool? reportsNavigationMenuVisible, bool? showUnreservedQuotes, bool? mainMenuPinned, bool? webAdministrator, String? quikActivitySetting, String? emailSignature, String? newPassword, String? oldPassword, String? locale, String? availabilityPreference, bool? availabilityAllWarehouses, String? emailApp, bool? addRentalWorksUserSignature, String? quikSearchMode, bool? autoPrintContract, bool? showRentalItemsOutOnly, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesUserProfileUserProfile

Available on WebApiModulesUtilitiesUserProfileUserProfile, provided by the $WebApiModulesUtilitiesUserProfileUserProfileExtension extension

copyWithWrapped({Wrapped<String?>? webUserId, Wrapped<String?>? userName, Wrapped<String?>? userId, Wrapped<String?>? loginName, Wrapped<int?>? browseDefaultRows, Wrapped<int?>? gridDefaultRows, Wrapped<String?>? applicationTheme, Wrapped<String?>? homeMenuGuid, Wrapped<String?>? homeMenuPath, Wrapped<String?>? languageId, Wrapped<String?>? language, Wrapped<int?>? soundProfileId, Wrapped<String?>? soundProfileName, Wrapped<String?>? favoritesJson, Wrapped<int?>? firstDayOfWeek, Wrapped<bool?>? settingsNavigationMenuVisible, Wrapped<bool?>? reportsNavigationMenuVisible, Wrapped<bool?>? showUnreservedQuotes, Wrapped<bool?>? mainMenuPinned, Wrapped<bool?>? webAdministrator, Wrapped<String?>? quikActivitySetting, Wrapped<String?>? emailSignature, Wrapped<String?>? newPassword, Wrapped<String?>? oldPassword, Wrapped<String?>? locale, Wrapped<String?>? availabilityPreference, Wrapped<bool?>? availabilityAllWarehouses, Wrapped<String?>? emailApp, Wrapped<bool?>? addRentalWorksUserSignature, Wrapped<String?>? quikSearchMode, Wrapped<bool?>? autoPrintContract, Wrapped<bool?>? showRentalItemsOutOnly, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesUserProfileUserProfile

Available on WebApiModulesUtilitiesUserProfileUserProfile, provided by the $WebApiModulesUtilitiesUserProfileUserProfileExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesUtilitiesUserProfileUserProfile Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesUtilitiesUserProfileUserProfile instance)