WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatch class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatch({String? batchId, String? locationId, String? batchType, String? divisionCode, String? batchNumber, String? batchDate, String? batchTime, String? batchDateTime, String? exportDate, bool? exported, int? recordCount, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatch.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
batchDate String?
final
batchDateTime String?
final
batchId String?
final
batchNumber String?
final
batchTime String?
final
batchType String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
divisionCode String?
final
exportDate String?
final
exported bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
locationId String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordCount int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({String? batchId, String? locationId, String? batchType, String? divisionCode, String? batchNumber, String? batchDate, String? batchTime, String? batchDateTime, String? exportDate, bool? exported, int? recordCount, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatch

Available on WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatch, provided by the $WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatchExtension extension

copyWithWrapped({Wrapped<String?>? batchId, Wrapped<String?>? locationId, Wrapped<String?>? batchType, Wrapped<String?>? divisionCode, Wrapped<String?>? batchNumber, Wrapped<String?>? batchDate, Wrapped<String?>? batchTime, Wrapped<String?>? batchDateTime, Wrapped<String?>? exportDate, Wrapped<bool?>? exported, Wrapped<int?>? recordCount, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatch

Available on WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatch, provided by the $WebApiModulesUtilitiesVendorInvoiceProcessBatchVendorInvoiceProcessBatchExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override