WebApiModulesUtilitiesWebImportRecordWebImportRecord class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesWebImportRecordWebImportRecord({int? webImportRecordId, String? webImportId, String? moduleName, String? uniqueId01, String? uniqueId02, String? uniqueId03, String? originalJson, String? preImportJson, String? postImportJson, String? errorMessage, String? importDateTime, bool? isReverted, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesWebImportRecordWebImportRecord.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
errorMessage String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
importDateTime String?
final
isReverted bool?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
moduleName String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
originalJson String?
final
postImportJson String?
final
preImportJson String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final
uniqueId01 String?
final
uniqueId02 String?
final
uniqueId03 String?
final
urlIdentifier → dynamic
final
webImportId String?
final
webImportRecordId int?
final

Methods

copyWith({int? webImportRecordId, String? webImportId, String? moduleName, String? uniqueId01, String? uniqueId02, String? uniqueId03, String? originalJson, String? preImportJson, String? postImportJson, String? errorMessage, String? importDateTime, bool? isReverted, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesWebImportRecordWebImportRecord

Available on WebApiModulesUtilitiesWebImportRecordWebImportRecord, provided by the $WebApiModulesUtilitiesWebImportRecordWebImportRecordExtension extension

copyWithWrapped({Wrapped<int?>? webImportRecordId, Wrapped<String?>? webImportId, Wrapped<String?>? moduleName, Wrapped<String?>? uniqueId01, Wrapped<String?>? uniqueId02, Wrapped<String?>? uniqueId03, Wrapped<String?>? originalJson, Wrapped<String?>? preImportJson, Wrapped<String?>? postImportJson, Wrapped<String?>? errorMessage, Wrapped<String?>? importDateTime, Wrapped<bool?>? isReverted, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesWebImportRecordWebImportRecord

Available on WebApiModulesUtilitiesWebImportRecordWebImportRecord, provided by the $WebApiModulesUtilitiesWebImportRecordWebImportRecordExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override