WebApiModulesUtilitiesWebImportWebImport class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesWebImportWebImport({int? webImportId, String? userId, String? userName, String? moduleName, String? description, String? importDateTime, int? totalRecords, int? totalImported, int? totalFailed, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesUtilitiesWebImportWebImport.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
importDateTime String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
moduleName String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalFailed int?
final
totalImported int?
final
totalRecords int?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final
userId String?
final
userName String?
final
webImportId int?
final

Methods

copyWith({int? webImportId, String? userId, String? userName, String? moduleName, String? description, String? importDateTime, int? totalRecords, int? totalImported, int? totalFailed, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesUtilitiesWebImportWebImport

Available on WebApiModulesUtilitiesWebImportWebImport, provided by the $WebApiModulesUtilitiesWebImportWebImportExtension extension

copyWithWrapped({Wrapped<int?>? webImportId, Wrapped<String?>? userId, Wrapped<String?>? userName, Wrapped<String?>? moduleName, Wrapped<String?>? description, Wrapped<String?>? importDateTime, Wrapped<int?>? totalRecords, Wrapped<int?>? totalImported, Wrapped<int?>? totalFailed, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesUtilitiesWebImportWebImport

Available on WebApiModulesUtilitiesWebImportWebImport, provided by the $WebApiModulesUtilitiesWebImportWebImportExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesUtilitiesWebImportWebImport Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesUtilitiesWebImportWebImport instance)