WebApiModulesWarehouseActivityActivity class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesWarehouseActivityActivity({int? activityId, int? activityTypeId, String? activityType, String? activityTypeDescription, String? activityTypeColor, String? activityTypeTextColor, int? activityStatusId, String? activityStatus, String? activityStatusDescription, String? activityStatusColor, String? activityStatusTextColor, String? officeLocationId, String? warehouseId, String? warehouse, String? orderId, String? orderNumber, String? orderDescription, String? orderType, String? orderStatus, String? orderTypeId, String? departmentId, String? dealId, String? orderTypeDescription, String? vendorId, String? assignedToUserId, String? assignedToUserName, DateTime? activityDateTime, String? activityDate, String? activityTime, int? totalQuantity, int? completeQuantity, int? remainingQuantity, double? completePercent, bool? forcedComplete, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesWarehouseActivityActivity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activityDate → String?
-
final
- activityDateTime → DateTime?
-
final
- activityId → int?
-
final
- activityStatus → String?
-
final
- activityStatusColor → String?
-
final
- activityStatusDescription → String?
-
final
- activityStatusId → int?
-
final
- activityStatusTextColor → String?
-
final
- activityTime → String?
-
final
- activityType → String?
-
final
- activityTypeColor → String?
-
final
- activityTypeDescription → String?
-
final
- activityTypeId → int?
-
final
- activityTypeTextColor → String?
-
final
- assignedToUserId → String?
-
final
- assignedToUserName → String?
-
final
- auditNote → String?
-
final
- completePercent → double?
-
final
- completeQuantity → int?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- departmentId → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- forcedComplete → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- officeLocationId → String?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- orderNumber → String?
-
final
- orderStatus → String?
-
final
- orderType → String?
-
final
- orderTypeDescription → String?
-
final
- orderTypeId → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- remainingQuantity → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalQuantity → int?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
- vendorId → String?
-
final
- warehouse → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{int? activityId, int? activityTypeId, String? activityType, String? activityTypeDescription, String? activityTypeColor, String? activityTypeTextColor, int? activityStatusId, String? activityStatus, String? activityStatusDescription, String? activityStatusColor, String? activityStatusTextColor, String? officeLocationId, String? warehouseId, String? warehouse, String? orderId, String? orderNumber, String? orderDescription, String? orderType, String? orderStatus, String? orderTypeId, String? departmentId, String? dealId, String? orderTypeDescription, String? vendorId, String? assignedToUserId, String? assignedToUserName, DateTime? activityDateTime, String? activityDate, String? activityTime, int? totalQuantity, int? completeQuantity, int? remainingQuantity, double? completePercent, bool? forcedComplete, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesWarehouseActivityActivity -
Available on WebApiModulesWarehouseActivityActivity, provided by the $WebApiModulesWarehouseActivityActivityExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? activityId, Wrapped<int?> ? activityTypeId, Wrapped<String?> ? activityType, Wrapped<String?> ? activityTypeDescription, Wrapped<String?> ? activityTypeColor, Wrapped<String?> ? activityTypeTextColor, Wrapped<int?> ? activityStatusId, Wrapped<String?> ? activityStatus, Wrapped<String?> ? activityStatusDescription, Wrapped<String?> ? activityStatusColor, Wrapped<String?> ? activityStatusTextColor, Wrapped<String?> ? officeLocationId, Wrapped<String?> ? warehouseId, Wrapped<String?> ? warehouse, Wrapped<String?> ? orderId, Wrapped<String?> ? orderNumber, Wrapped<String?> ? orderDescription, Wrapped<String?> ? orderType, Wrapped<String?> ? orderStatus, Wrapped<String?> ? orderTypeId, Wrapped<String?> ? departmentId, Wrapped<String?> ? dealId, Wrapped<String?> ? orderTypeDescription, Wrapped<String?> ? vendorId, Wrapped<String?> ? assignedToUserId, Wrapped<String?> ? assignedToUserName, Wrapped<DateTime?> ? activityDateTime, Wrapped<String?> ? activityDate, Wrapped<String?> ? activityTime, Wrapped<int?> ? totalQuantity, Wrapped<int?> ? completeQuantity, Wrapped<int?> ? remainingQuantity, Wrapped<double?> ? completePercent, Wrapped<bool?> ? forcedComplete, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesWarehouseActivityActivity -
Available on WebApiModulesWarehouseActivityActivity, provided by the $WebApiModulesWarehouseActivityActivityExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseActivityActivity Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseActivityActivity instance)