AccountServices class abstract
- Annotations
-
- @ChopperApi.new()
Constructors
Properties
- client ↔ ChopperClient
-
getter/setter pairinherited
- definitionType → Type
-
Used internally to retrieve the service from
ChopperClient.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accountGetsettingsPost(
{required WebApiModulesAccountServicesAccountGetSettingsRequest? body}) → Future< Response< WebApiLogicAppFuncGetSettingsResponse> > -
accountOfficelocationGet(
{String? locationid, String? warehouseid, String? departmentid}) → Future< Response< WebApiModulesAccountServicesAccountAccountControllerGetOfficeLocationResponse> > - @param locationid @param warehouseid @param departmentid
-
accountResetpasswordPost(
{required WebApiModulesAccountServicesAccountResetPasswordRequest? body}) → Future< Response< WebApiModulesAccountServicesAccountResetPasswordResponse> > -
accountSessionGet(
{String? applicationId}) → Future< Response< WebApiModulesAccountServicesAccountAccountControllerGetSessionResponse> > - @param applicationId
-
jwtOktaPost(
{required WebApiModulesAccountServicesJwtOktaRequest? body}) → Future< Response< FwCoreControllersFwJwtControllerJwtResponseModel> > -
jwtOktaverifyPost(
{required WebApiModulesAccountServicesJwtOktaSessionRequest? body}) → Future< Response< WebApiModulesAccountServicesJwtOktaSessionResponseModel> > -
jwtPost(
{required FwStandardModelsFwApplicationUser? body}) → Future< Response< FwCoreControllersFwJwtControllerJwtResponseModel> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{ChopperClient? client, String? baseUrl, Iterable? interceptors}) → AccountServices