WebApiLogicAppFuncSessionLocation class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiLogicAppFuncSessionLocation({String? locationid, String? location, String? locationcode, String? companyname, String? locationcolor, String? ratetype, String? ratetypedisplay, String? defaultcurrency, String? defaultcurrencyid, String? defaultcurrencycode, String? defaultcurrencysymbol, String? defaulttaxoptionid, String? defaulttaxoption, String? countryid, String? country, String? phone, bool? useorderlocationbydefault})
-
WebApiLogicAppFuncSessionLocation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- companyname → String?
-
final
- country → String?
-
final
- countryid → String?
-
final
- defaultcurrency → String?
-
final
- defaultcurrencycode → String?
-
final
- defaultcurrencyid → String?
-
final
- defaultcurrencysymbol → String?
-
final
- defaulttaxoption → String?
-
final
- defaulttaxoptionid → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → String?
-
final
- locationcode → String?
-
final
- locationcolor → String?
-
final
- locationid → String?
-
final
- phone → String?
-
final
- ratetype → String?
-
final
- ratetypedisplay → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useorderlocationbydefault → bool?
-
final
Methods
-
copyWith(
{String? locationid, String? location, String? locationcode, String? companyname, String? locationcolor, String? ratetype, String? ratetypedisplay, String? defaultcurrency, String? defaultcurrencyid, String? defaultcurrencycode, String? defaultcurrencysymbol, String? defaulttaxoptionid, String? defaulttaxoption, String? countryid, String? country, String? phone, bool? useorderlocationbydefault}) → WebApiLogicAppFuncSessionLocation -
Available on WebApiLogicAppFuncSessionLocation, provided by the $WebApiLogicAppFuncSessionLocationExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? locationid, Wrapped<String?> ? location, Wrapped<String?> ? locationcode, Wrapped<String?> ? companyname, Wrapped<String?> ? locationcolor, Wrapped<String?> ? ratetype, Wrapped<String?> ? ratetypedisplay, Wrapped<String?> ? defaultcurrency, Wrapped<String?> ? defaultcurrencyid, Wrapped<String?> ? defaultcurrencycode, Wrapped<String?> ? defaultcurrencysymbol, Wrapped<String?> ? defaulttaxoptionid, Wrapped<String?> ? defaulttaxoption, Wrapped<String?> ? countryid, Wrapped<String?> ? country, Wrapped<String?> ? phone, Wrapped<bool?> ? useorderlocationbydefault}) → WebApiLogicAppFuncSessionLocation -
Available on WebApiLogicAppFuncSessionLocation, provided by the $WebApiLogicAppFuncSessionLocationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiLogicAppFuncSessionLocation Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiLogicAppFuncSessionLocation instance)