WebApiLogicAppFuncSystemSettingsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiLogicAppFuncSystemSettingsResponse({bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? enableReceipts, bool? enablePayments, bool? shareDealsAcrossOfficeLocations, String? systemName, String? companyName, bool? isVendorNumberAssignedByUser})
WebApiLogicAppFuncSystemSettingsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

allowDeleteInvoices bool?
final
allowInvoiceDateChange bool?
final
companyName String?
final
enablePayments bool?
final
enableReceipts bool?
final
hashCode int
The hash code for this object.
no setteroverride
isVendorNumberAssignedByUser bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareDealsAcrossOfficeLocations bool?
final
systemName String?
final

Methods

copyWith({bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? enableReceipts, bool? enablePayments, bool? shareDealsAcrossOfficeLocations, String? systemName, String? companyName, bool? isVendorNumberAssignedByUser}) WebApiLogicAppFuncSystemSettingsResponse

Available on WebApiLogicAppFuncSystemSettingsResponse, provided by the $WebApiLogicAppFuncSystemSettingsResponseExtension extension

copyWithWrapped({Wrapped<bool?>? allowDeleteInvoices, Wrapped<bool?>? allowInvoiceDateChange, Wrapped<bool?>? enableReceipts, Wrapped<bool?>? enablePayments, Wrapped<bool?>? shareDealsAcrossOfficeLocations, Wrapped<String?>? systemName, Wrapped<String?>? companyName, Wrapped<bool?>? isVendorNumberAssignedByUser}) WebApiLogicAppFuncSystemSettingsResponse

Available on WebApiLogicAppFuncSystemSettingsResponse, provided by the $WebApiLogicAppFuncSystemSettingsResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiLogicAppFuncSystemSettingsResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiLogicAppFuncSystemSettingsResponse instance)