WebApiModulesAccountServicesAccountSystemSettingsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAccountServicesAccountSystemSettingsResponse({String? defaultUnitId, String? defaultRank, bool? requireOriginalShow, bool? userAssignedICodes, bool? quikScanStageBySession, FwStandardSqlServerFwJsonDataTable? barcodeSkipPrefixes})
-
WebApiModulesAccountServicesAccountSystemSettingsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- barcodeSkipPrefixes → FwStandardSqlServerFwJsonDataTable?
-
final
- defaultRank → String?
-
final
- defaultUnitId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- quikScanStageBySession → bool?
-
final
- requireOriginalShow → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAssignedICodes → bool?
-
final
Methods
-
copyWith(
{String? defaultUnitId, String? defaultRank, bool? requireOriginalShow, bool? userAssignedICodes, bool? quikScanStageBySession, FwStandardSqlServerFwJsonDataTable? barcodeSkipPrefixes}) → WebApiModulesAccountServicesAccountSystemSettingsResponse -
Available on WebApiModulesAccountServicesAccountSystemSettingsResponse, provided by the $WebApiModulesAccountServicesAccountSystemSettingsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAccountServicesAccountSystemSettingsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAccountServicesAccountSystemSettingsResponse instance)