FwStandardModulesAdministratorAlertConditionAlertConditionLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorAlertConditionAlertConditionLogic({String? alertId, String? alertConditionId, String? fieldName1, String? condition, String? fieldName2, String? value, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
FwStandardModulesAdministratorAlertConditionAlertConditionLogic.fromJson(Map<String, dynamic> json)
factory

Properties

alertConditionId String?
final
alertId String?
final
auditNote String?
final
condition String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fieldName1 String?
final
fieldName2 String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

copyWith({String? alertId, String? alertConditionId, String? fieldName1, String? condition, String? fieldName2, String? value, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) FwStandardModulesAdministratorAlertConditionAlertConditionLogic

Available on FwStandardModulesAdministratorAlertConditionAlertConditionLogic, provided by the $FwStandardModulesAdministratorAlertConditionAlertConditionLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override