FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic({String? appEmailId, String? description, String? filterId, String? subject, String? emailText, String? category, String? bodyFormat, String? emailType, bool? inactive, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic.fromJson(Map<String, dynamic> json)
factory

Properties

appEmailId String?
final
auditNote String?
final
bodyFormat String?
final
category String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
emailText String?
final
emailType String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
filterId String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
final

Methods

copyWith({String? appEmailId, String? description, String? filterId, String? subject, String? emailText, String? category, String? bodyFormat, String? emailType, bool? inactive, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic

Available on FwStandardModulesAdministratorEmailTemplateEmailTemplateLogic, provided by the $FwStandardModulesAdministratorEmailTemplateEmailTemplateLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override