FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic({int? webAuditId, String? moduleName, String? title, String? uniqueId1, String? uniqueId2, String? uniqueId3, String? webUserId, String? userName, String? json, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
json String?
final
moduleName String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
uniqueId1 String?
final
uniqueId2 String?
final
uniqueId3 String?
final
userName String?
final
webAuditId int?
final
webUserId String?
final

Methods

copyWith({int? webAuditId, String? moduleName, String? title, String? uniqueId1, String? uniqueId2, String? uniqueId3, String? webUserId, String? userName, String? json, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic

Available on FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogic, provided by the $FwStandardModulesAdministratorWebAuditJsonWebAuditJsonLogicExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override