FwStandardModulesAdministratorWebEventLogWebEventLogLogic class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardModulesAdministratorWebEventLogWebEventLogLogic({int? id, String? serverName, String? webUsersId, String? userId, String? userName, String? logType, String? message, String? data, int? totalMemoryUsageBytes, String? totalMemoryUsageKiloBytes, String? totalMemoryUsageMegaBytes, String? totalMemoryUsageGigaBytes, String? hourStr, String? dateStr, String? activityDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
FwStandardModulesAdministratorWebEventLogWebEventLogLogic.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activityDate → String?
-
final
- auditNote → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- data → String?
-
final
- dateStamp → String?
-
final
- dateStr → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- hourStr → String?
-
final
- id → int?
-
final
- logType → String?
-
final
- message → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverName → String?
-
final
- totalMemoryUsageBytes → int?
-
final
- totalMemoryUsageGigaBytes → String?
-
final
- totalMemoryUsageKiloBytes → String?
-
final
- totalMemoryUsageMegaBytes → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
- userId → String?
-
final
- userName → String?
-
final
- webUsersId → String?
-
final
Methods
-
copyWith(
{int? id, String? serverName, String? webUsersId, String? userId, String? userName, String? logType, String? message, String? data, int? totalMemoryUsageBytes, String? totalMemoryUsageKiloBytes, String? totalMemoryUsageMegaBytes, String? totalMemoryUsageGigaBytes, String? hourStr, String? dateStr, String? activityDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → FwStandardModulesAdministratorWebEventLogWebEventLogLogic -
Available on FwStandardModulesAdministratorWebEventLogWebEventLogLogic, provided by the $FwStandardModulesAdministratorWebEventLogWebEventLogLogicExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? id, Wrapped<String?> ? serverName, Wrapped<String?> ? webUsersId, Wrapped<String?> ? userId, Wrapped<String?> ? userName, Wrapped<String?> ? logType, Wrapped<String?> ? message, Wrapped<String?> ? data, Wrapped<int?> ? totalMemoryUsageBytes, Wrapped<String?> ? totalMemoryUsageKiloBytes, Wrapped<String?> ? totalMemoryUsageMegaBytes, Wrapped<String?> ? totalMemoryUsageGigaBytes, Wrapped<String?> ? hourStr, Wrapped<String?> ? dateStr, Wrapped<String?> ? activityDate, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → FwStandardModulesAdministratorWebEventLogWebEventLogLogic -
Available on FwStandardModulesAdministratorWebEventLogWebEventLogLogic, provided by the $FwStandardModulesAdministratorWebEventLogWebEventLogLogicExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardModulesAdministratorWebEventLogWebEventLogLogic Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardModulesAdministratorWebEventLogWebEventLogLogic instance)