WebApiModulesAdministratorDataHealthDataHealth class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorDataHealthDataHealth({int? dataHealthId, String? dataHealthType, String? captureDateTime, String? captureDate, String? json, String? severity, String? severityColor, String? notes, bool? resolved, int? quantity, String? knowledgeBaseArticleId, String? knowledgeBaseArticleUrl, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesAdministratorDataHealthDataHealth.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
captureDate String?
final
captureDateTime String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
custom List<FwStandardDataFwCustomValue>?
final
dataHealthId int?
final
dataHealthType String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
inactive bool?
final
json String?
final
knowledgeBaseArticleId String?
final
knowledgeBaseArticleUrl String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
notes String?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
quantity int?
final
recordTitle String?
final
resolved bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String?
final
severityColor String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
urlIdentifier → dynamic
final

Methods

copyWith({int? dataHealthId, String? dataHealthType, String? captureDateTime, String? captureDate, String? json, String? severity, String? severityColor, String? notes, bool? resolved, int? quantity, String? knowledgeBaseArticleId, String? knowledgeBaseArticleUrl, bool? inactive, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesAdministratorDataHealthDataHealth

Available on WebApiModulesAdministratorDataHealthDataHealth, provided by the $WebApiModulesAdministratorDataHealthDataHealthExtension extension

copyWithWrapped({Wrapped<int?>? dataHealthId, Wrapped<String?>? dataHealthType, Wrapped<String?>? captureDateTime, Wrapped<String?>? captureDate, Wrapped<String?>? json, Wrapped<String?>? severity, Wrapped<String?>? severityColor, Wrapped<String?>? notes, Wrapped<bool?>? resolved, Wrapped<int?>? quantity, Wrapped<String?>? knowledgeBaseArticleId, Wrapped<String?>? knowledgeBaseArticleUrl, Wrapped<bool?>? inactive, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped? urlIdentifier, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesAdministratorDataHealthDataHealth

Available on WebApiModulesAdministratorDataHealthDataHealth, provided by the $WebApiModulesAdministratorDataHealthDataHealthExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAdministratorDataHealthDataHealth Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAdministratorDataHealthDataHealth instance)