WebApiModulesAdministratorEmailHistoryEmailHistory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorEmailHistoryEmailHistory({String? emailHistoryId, String? reportId, String? fromUserId, String? fromWebUserId, String? fromUser, String? emailDate, String? status, String? emailText, String? emailTo, String? emailSubject, String? emailCC, String? title, String? relatedToId, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesAdministratorEmailHistoryEmailHistory.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
emailCC String?
final
emailDate String?
final
emailHistoryId String?
final
emailSubject String?
final
emailText String?
final
emailTo String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fromUser String?
final
fromUserId String?
final
fromWebUserId String?
final
hashCode int
The hash code for this object.
no setteroverride
recordTitle String?
final
relatedToId String?
final
reportId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
title String?
final

Methods

copyWith({String? emailHistoryId, String? reportId, String? fromUserId, String? fromWebUserId, String? fromUser, String? emailDate, String? status, String? emailText, String? emailTo, String? emailSubject, String? emailCC, String? title, String? relatedToId, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesAdministratorEmailHistoryEmailHistory

Available on WebApiModulesAdministratorEmailHistoryEmailHistory, provided by the $WebApiModulesAdministratorEmailHistoryEmailHistoryExtension extension

copyWithWrapped({Wrapped<String?>? emailHistoryId, Wrapped<String?>? reportId, Wrapped<String?>? fromUserId, Wrapped<String?>? fromWebUserId, Wrapped<String?>? fromUser, Wrapped<String?>? emailDate, Wrapped<String?>? status, Wrapped<String?>? emailText, Wrapped<String?>? emailTo, Wrapped<String?>? emailSubject, Wrapped<String?>? emailCC, Wrapped<String?>? title, Wrapped<String?>? relatedToId, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes}) WebApiModulesAdministratorEmailHistoryEmailHistory

Available on WebApiModulesAdministratorEmailHistoryEmailHistory, provided by the $WebApiModulesAdministratorEmailHistoryEmailHistoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override