WebApiModulesAdministratorHotfixHotfix class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAdministratorHotfixHotfix({String? hotfixId, String? fileName, String? description, String? hotfixBegin, String? hotfixEnd, double? hotfixSeconds, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesAdministratorHotfixHotfix.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fileName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hotfixBegin → String?
-
final
- hotfixEnd → String?
-
final
- hotfixId → String?
-
final
- hotfixSeconds → double?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? hotfixId, String? fileName, String? description, String? hotfixBegin, String? hotfixEnd, double? hotfixSeconds, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesAdministratorHotfixHotfix -
Available on WebApiModulesAdministratorHotfixHotfix, provided by the $WebApiModulesAdministratorHotfixHotfixExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? hotfixId, Wrapped<String?> ? fileName, Wrapped<String?> ? description, Wrapped<String?> ? hotfixBegin, Wrapped<String?> ? hotfixEnd, Wrapped<double?> ? hotfixSeconds, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes}) → WebApiModulesAdministratorHotfixHotfixFwStandardDataFwDefaultAttribute> ?> -
Available on WebApiModulesAdministratorHotfixHotfix, provided by the $WebApiModulesAdministratorHotfixHotfixExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAdministratorHotfixHotfix Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAdministratorHotfixHotfix instance)