WebApiModulesAdministratorPluginPlugin class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorPluginPlugin({int? pluginId, String? category, String? description, String? settings, bool? inactive, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesAdministratorPluginPlugin.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
category String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
pluginId int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings String?
final

Methods

copyWith({int? pluginId, String? category, String? description, String? settings, bool? inactive, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesAdministratorPluginPlugin

Available on WebApiModulesAdministratorPluginPlugin, provided by the $WebApiModulesAdministratorPluginPluginExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesAdministratorPluginPlugin Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesAdministratorPluginPlugin instance)