WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory({int? systemUpdateHistoryId, String? usersId, String? userName, DateTime? updateDateTime, String? fromVersion, String? toVersion, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
errorMessage String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fromVersion String?
final
hashCode int
The hash code for this object.
no setteroverride
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemUpdateHistoryId int?
final
toVersion String?
final
updateDateTime DateTime?
final
userName String?
final
usersId String?
final

Methods

copyWith({int? systemUpdateHistoryId, String? usersId, String? userName, DateTime? updateDateTime, String? fromVersion, String? toVersion, String? errorMessage, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory

Available on WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistory, provided by the $WebApiModulesAdministratorSystemUpdateHistorySystemUpdateHistoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override