customerLookupOfficelocationsGet method
Future<Response<FwStandardModelsGetResponseWebApiModulesSettingsOfficeLocationSettingsOfficeLocationGetManyOfficeLocationModel> >
customerLookupOfficelocationsGet({})
@param LocationId Filter Expression @param Location Filter Expression @param PageNo The page number in the result set starting from 1. PageNo is required when the PageSize is specified. @param PageSize Limit result set to the specified amount. @param Sort A sort expression to use of the form: Field1:asc,Field2:desc
Implementation
Future<
chopper.Response<
FwStandardModelsGetResponseWebApiModulesSettingsOfficeLocationSettingsOfficeLocationGetManyOfficeLocationModel
>
>
customerLookupOfficelocationsGet({
String? locationId,
String? location,
int? pageNo,
int? pageSize,
String? sort,
}) {
generatedMapping.putIfAbsent(
FwStandardModelsGetResponseWebApiModulesSettingsOfficeLocationSettingsOfficeLocationGetManyOfficeLocationModel,
() =>
FwStandardModelsGetResponseWebApiModulesSettingsOfficeLocationSettingsOfficeLocationGetManyOfficeLocationModel
.fromJsonFactory,
);
return _customerLookupOfficelocationsGet(
locationId: locationId,
location: location,
pageNo: pageNo,
pageSize: pageSize,
sort: sort,
);
}