WebApiModulesAgentOrderApplyTemplateRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentOrderApplyTemplateRequest({List<
String> ? templateIds, String? orderId, String? recType, String? moduleName}) -
const
-
WebApiModulesAgentOrderApplyTemplateRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- moduleName → String?
-
final
- orderId → String?
-
final
- recType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
templateIds
→ List<
String> ? -
final
Methods
-
copyWith(
{List< String> ? templateIds, String? orderId, String? recType, String? moduleName}) → WebApiModulesAgentOrderApplyTemplateRequest -
Available on WebApiModulesAgentOrderApplyTemplateRequest, provided by the $WebApiModulesAgentOrderApplyTemplateRequestExtension extension
-
copyWithWrapped(
{Wrapped< List< ? templateIds, Wrapped<String> ?>String?> ? orderId, Wrapped<String?> ? recType, Wrapped<String?> ? moduleName}) → WebApiModulesAgentOrderApplyTemplateRequest -
Available on WebApiModulesAgentOrderApplyTemplateRequest, provided by the $WebApiModulesAgentOrderApplyTemplateRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderApplyTemplateRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderApplyTemplateRequest instance)