WebApiModulesAgentOrderContactOrderContact class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentOrderContactOrderContact({int? orderContactId, String? orderId, String? contactId, String? nameFml, String? nameLfm, String? person, String? personColor, String? firstName, String? middleInitial, String? lastName, String? contactTitle, String? officePhone, String? officeExtension, String? mobilePhone, String? email, String? pager, String? pagerPin, String? jobTitle, String? contactTitleId, String? companyContactId, String? companyId, bool? isPrimary, String? countryId, bool? isOrderedBy, bool? isAccountsPayable, bool? isAccountsReceivable, bool? isProductionContact, bool? isPrintable, bool? contactOnOrder, int? orderBy, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesAgentOrderContactOrderContact.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- companyContactId → String?
-
final
- companyId → String?
-
final
- contactId → String?
-
final
- contactOnOrder → bool?
-
final
- contactTitle → String?
-
final
- contactTitleId → String?
-
final
- countryId → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- email → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- firstName → String?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- inactive → bool?
-
final
- isAccountsPayable → bool?
-
final
- isAccountsReceivable → bool?
-
final
- isOrderedBy → bool?
-
final
- isPrimary → bool?
-
final
- isPrintable → bool?
-
final
- isProductionContact → bool?
-
final
- jobTitle → String?
-
final
- lastName → String?
-
final
- middleInitial → String?
-
final
- mobilePhone → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- nameFml → String?
-
final
- nameLfm → String?
-
final
- officeExtension → String?
-
final
- officePhone → String?
-
final
- orderBy → int?
-
final
- orderContactId → int?
-
final
- orderId → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- pager → String?
-
final
- pagerPin → String?
-
final
- person → String?
-
final
- personColor → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{int? orderContactId, String? orderId, String? contactId, String? nameFml, String? nameLfm, String? person, String? personColor, String? firstName, String? middleInitial, String? lastName, String? contactTitle, String? officePhone, String? officeExtension, String? mobilePhone, String? email, String? pager, String? pagerPin, String? jobTitle, String? contactTitleId, String? companyContactId, String? companyId, bool? isPrimary, String? countryId, bool? isOrderedBy, bool? isAccountsPayable, bool? isAccountsReceivable, bool? isProductionContact, bool? isPrintable, bool? contactOnOrder, int? orderBy, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesAgentOrderContactOrderContact -
Available on WebApiModulesAgentOrderContactOrderContact, provided by the $WebApiModulesAgentOrderContactOrderContactExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? orderContactId, Wrapped<String?> ? orderId, Wrapped<String?> ? contactId, Wrapped<String?> ? nameFml, Wrapped<String?> ? nameLfm, Wrapped<String?> ? person, Wrapped<String?> ? personColor, Wrapped<String?> ? firstName, Wrapped<String?> ? middleInitial, Wrapped<String?> ? lastName, Wrapped<String?> ? contactTitle, Wrapped<String?> ? officePhone, Wrapped<String?> ? officeExtension, Wrapped<String?> ? mobilePhone, Wrapped<String?> ? email, Wrapped<String?> ? pager, Wrapped<String?> ? pagerPin, Wrapped<String?> ? jobTitle, Wrapped<String?> ? contactTitleId, Wrapped<String?> ? companyContactId, Wrapped<String?> ? companyId, Wrapped<bool?> ? isPrimary, Wrapped<String?> ? countryId, Wrapped<bool?> ? isOrderedBy, Wrapped<bool?> ? isAccountsPayable, Wrapped<bool?> ? isAccountsReceivable, Wrapped<bool?> ? isProductionContact, Wrapped<bool?> ? isPrintable, Wrapped<bool?> ? contactOnOrder, Wrapped<int?> ? orderBy, Wrapped<bool?> ? inactive, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesAgentOrderContactOrderContact -
Available on WebApiModulesAgentOrderContactOrderContact, provided by the $WebApiModulesAgentOrderContactOrderContactExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderContactOrderContact Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderContactOrderContact instance)