WebApiModulesAgentOrderCopyQuoteOrderRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentOrderCopyQuoteOrderRequest({String? copyToType, String? locationId, String? warehouseId, String? newDescription, bool? copyLineItemNotes, bool? copyOrderNotes, bool? combineSubs, bool? copyDocuments, bool? copyCarrierShipVia})
-
WebApiModulesAgentOrderCopyQuoteOrderRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- combineSubs → bool?
-
final
- copyCarrierShipVia → bool?
-
final
- copyDocuments → bool?
-
final
- copyLineItemNotes → bool?
-
final
- copyOrderNotes → bool?
-
final
- copyToType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- locationId → String?
-
final
- newDescription → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? copyToType, String? locationId, String? warehouseId, String? newDescription, bool? copyLineItemNotes, bool? copyOrderNotes, bool? combineSubs, bool? copyDocuments, bool? copyCarrierShipVia}) → WebApiModulesAgentOrderCopyQuoteOrderRequest -
Available on WebApiModulesAgentOrderCopyQuoteOrderRequest, provided by the $WebApiModulesAgentOrderCopyQuoteOrderRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderCopyQuoteOrderRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderCopyQuoteOrderRequest instance)