WebApiModulesAgentOrderCrewHoursPerDaysRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentOrderCrewHoursPerDaysRequest({String? orderItemId, String? orderId, List<
WebApiModulesAgentOrderCrewHoursPerDay> ? crewHoursPerDay}) -
const
-
WebApiModulesAgentOrderCrewHoursPerDaysRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
crewHoursPerDay
→ List<
WebApiModulesAgentOrderCrewHoursPerDay> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- orderId → String?
-
final
- orderItemId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? orderItemId, String? orderId, List< WebApiModulesAgentOrderCrewHoursPerDay> ? crewHoursPerDay}) → WebApiModulesAgentOrderCrewHoursPerDaysRequest -
Available on WebApiModulesAgentOrderCrewHoursPerDaysRequest, provided by the $WebApiModulesAgentOrderCrewHoursPerDaysRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? orderItemId, Wrapped<String?> ? orderId, Wrapped<List< ? crewHoursPerDay}) → WebApiModulesAgentOrderCrewHoursPerDaysRequestWebApiModulesAgentOrderCrewHoursPerDay> ?> -
Available on WebApiModulesAgentOrderCrewHoursPerDaysRequest, provided by the $WebApiModulesAgentOrderCrewHoursPerDaysRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderCrewHoursPerDaysRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderCrewHoursPerDaysRequest instance)