WebApiModulesAgentOrderDuplicateOrderItemsRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesAgentOrderDuplicateOrderItemsRequest({String? orderId, List<
String> ? orderItemIds}) -
const
-
WebApiModulesAgentOrderDuplicateOrderItemsRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- orderId → String?
-
final
-
orderItemIds
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? orderId, List< String> ? orderItemIds}) → WebApiModulesAgentOrderDuplicateOrderItemsRequest -
Available on WebApiModulesAgentOrderDuplicateOrderItemsRequest, provided by the $WebApiModulesAgentOrderDuplicateOrderItemsRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? orderId, Wrapped<List< ? orderItemIds}) → WebApiModulesAgentOrderDuplicateOrderItemsRequestString> ?> -
Available on WebApiModulesAgentOrderDuplicateOrderItemsRequest, provided by the $WebApiModulesAgentOrderDuplicateOrderItemsRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderDuplicateOrderItemsRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderDuplicateOrderItemsRequest instance)