WebApiModulesAgentOrderLaborTotalsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentOrderLaborTotalsResponse({WebApiModulesAgentOrderTotals? weeklyTotals, WebApiModulesAgentOrderTotals? averageWeeklyTotals, WebApiModulesAgentOrderTotals? monthlyTotals, WebApiModulesAgentOrderTotals? periodTotals, String? operatingRevenue, String? costExtended, String? grossProfit, String? marginPercent, String? operatingRevenuePercent})
-
const
-
WebApiModulesAgentOrderLaborTotalsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- averageWeeklyTotals → WebApiModulesAgentOrderTotals?
-
final
- costExtended → String?
-
final
- grossProfit → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- marginPercent → String?
-
final
- monthlyTotals → WebApiModulesAgentOrderTotals?
-
final
- operatingRevenue → String?
-
final
- operatingRevenuePercent → String?
-
final
- periodTotals → WebApiModulesAgentOrderTotals?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weeklyTotals → WebApiModulesAgentOrderTotals?
-
final
Methods
-
copyWith(
{WebApiModulesAgentOrderTotals? weeklyTotals, WebApiModulesAgentOrderTotals? averageWeeklyTotals, WebApiModulesAgentOrderTotals? monthlyTotals, WebApiModulesAgentOrderTotals? periodTotals, String? operatingRevenue, String? costExtended, String? grossProfit, String? marginPercent, String? operatingRevenuePercent}) → WebApiModulesAgentOrderLaborTotalsResponse -
Available on WebApiModulesAgentOrderLaborTotalsResponse, provided by the $WebApiModulesAgentOrderLaborTotalsResponseExtension extension
-
copyWithWrapped(
{Wrapped< WebApiModulesAgentOrderTotals?> ? weeklyTotals, Wrapped<WebApiModulesAgentOrderTotals?> ? averageWeeklyTotals, Wrapped<WebApiModulesAgentOrderTotals?> ? monthlyTotals, Wrapped<WebApiModulesAgentOrderTotals?> ? periodTotals, Wrapped<String?> ? operatingRevenue, Wrapped<String?> ? costExtended, Wrapped<String?> ? grossProfit, Wrapped<String?> ? marginPercent, Wrapped<String?> ? operatingRevenuePercent}) → WebApiModulesAgentOrderLaborTotalsResponse -
Available on WebApiModulesAgentOrderLaborTotalsResponse, provided by the $WebApiModulesAgentOrderLaborTotalsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderLaborTotalsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderLaborTotalsResponse instance)