WebApiModulesAgentOrderSortingCorruptionItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentOrderSortingCorruptionItem({String? recType, String? itemOrder, String? description})
-
const
-
WebApiModulesAgentOrderSortingCorruptionItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- itemOrder → String?
-
final
- recType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? recType, String? itemOrder, String? description}) → WebApiModulesAgentOrderSortingCorruptionItem -
Available on WebApiModulesAgentOrderSortingCorruptionItem, provided by the $WebApiModulesAgentOrderSortingCorruptionItemExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? recType, Wrapped<String?> ? itemOrder, Wrapped<String?> ? description}) → WebApiModulesAgentOrderSortingCorruptionItem -
Available on WebApiModulesAgentOrderSortingCorruptionItem, provided by the $WebApiModulesAgentOrderSortingCorruptionItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentOrderSortingCorruptionItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentOrderSortingCorruptionItem instance)