WebApiModulesAgentPurchaseOrderPOMessage class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentPurchaseOrderPOMessage({String? tag, String? message, String? textColor, String? backgroundColor, bool? preventReceive})
-
const
-
WebApiModulesAgentPurchaseOrderPOMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backgroundColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String?
-
final
- preventReceive → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
- textColor → String?
-
final
Methods
-
copyWith(
{String? tag, String? message, String? textColor, String? backgroundColor, bool? preventReceive}) → WebApiModulesAgentPurchaseOrderPOMessage -
Available on WebApiModulesAgentPurchaseOrderPOMessage, provided by the $WebApiModulesAgentPurchaseOrderPOMessageExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? tag, Wrapped<String?> ? message, Wrapped<String?> ? textColor, Wrapped<String?> ? backgroundColor, Wrapped<bool?> ? preventReceive}) → WebApiModulesAgentPurchaseOrderPOMessage -
Available on WebApiModulesAgentPurchaseOrderPOMessage, provided by the $WebApiModulesAgentPurchaseOrderPOMessageExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentPurchaseOrderPOMessage Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentPurchaseOrderPOMessage instance)