WebApiModulesAgentPurchaseOrderReceiveItemResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesAgentPurchaseOrderReceiveItemResponse({String? contractId, String? purchaseOrderId, String? purchaseOrderItemId, int? quantity, double? quantityOrdered, double? quantityReceived, double? quantityNeedBarCode, String? quantityColor, int? status, bool? success, String? msg})
-
WebApiModulesAgentPurchaseOrderReceiveItemResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- contractId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- msg → String?
-
final
- purchaseOrderId → String?
-
final
- purchaseOrderItemId → String?
-
final
- quantity → int?
-
final
- quantityColor → String?
-
final
- quantityNeedBarCode → double?
-
final
- quantityOrdered → double?
-
final
- quantityReceived → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- success → bool?
-
final
Methods
-
copyWith(
{String? contractId, String? purchaseOrderId, String? purchaseOrderItemId, int? quantity, double? quantityOrdered, double? quantityReceived, double? quantityNeedBarCode, String? quantityColor, int? status, bool? success, String? msg}) → WebApiModulesAgentPurchaseOrderReceiveItemResponse -
Available on WebApiModulesAgentPurchaseOrderReceiveItemResponse, provided by the $WebApiModulesAgentPurchaseOrderReceiveItemResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesAgentPurchaseOrderReceiveItemResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesAgentPurchaseOrderReceiveItemResponse instance)