WebApiModulesBillingDealCreditDealCredit class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesBillingDealCreditDealCredit({String? receiptId, String? customerId, String? customer, String? dealId, String? deal, String? officeLocationId, String? paymentBy, String? recType, String? recTypeDisplay, String? recTypeColor, String? receiptDate, String? receiptTime, String? paymentTypeId, String? paymentType, String? invoiceId, String? invoiceNumer, String? checkNumber, double? amount, double? applied, double? refunded, double? remaining, String? currencySymbol, String? orderId, String? creditCardName, String? creditCardNumber, String? creditCardExpirationDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesBillingDealCreditDealCredit.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → double?
-
final
- applied → double?
-
final
- auditNote → String?
-
final
- checkNumber → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
- creditCardExpirationDate → String?
-
final
- creditCardName → String?
-
final
- creditCardNumber → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerId → String?
-
final
- dateStamp → String?
-
final
- deal → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- invoiceId → String?
-
final
- invoiceNumer → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- officeLocationId → String?
-
final
- orderId → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- paymentBy → String?
-
final
- paymentType → String?
-
final
- paymentTypeId → String?
-
final
- receiptDate → String?
-
final
- receiptId → String?
-
final
- receiptTime → String?
-
final
- recordTitle → String?
-
final
- recType → String?
-
final
- recTypeColor → String?
-
final
- recTypeDisplay → String?
-
final
- refunded → double?
-
final
- remaining → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? receiptId, String? customerId, String? customer, String? dealId, String? deal, String? officeLocationId, String? paymentBy, String? recType, String? recTypeDisplay, String? recTypeColor, String? receiptDate, String? receiptTime, String? paymentTypeId, String? paymentType, String? invoiceId, String? invoiceNumer, String? checkNumber, double? amount, double? applied, double? refunded, double? remaining, String? currencySymbol, String? orderId, String? creditCardName, String? creditCardNumber, String? creditCardExpirationDate, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesBillingDealCreditDealCredit -
Available on WebApiModulesBillingDealCreditDealCredit, provided by the $WebApiModulesBillingDealCreditDealCreditExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? receiptId, Wrapped<String?> ? customerId, Wrapped<String?> ? customer, Wrapped<String?> ? dealId, Wrapped<String?> ? deal, Wrapped<String?> ? officeLocationId, Wrapped<String?> ? paymentBy, Wrapped<String?> ? recType, Wrapped<String?> ? recTypeDisplay, Wrapped<String?> ? recTypeColor, Wrapped<String?> ? receiptDate, Wrapped<String?> ? receiptTime, Wrapped<String?> ? paymentTypeId, Wrapped<String?> ? paymentType, Wrapped<String?> ? invoiceId, Wrapped<String?> ? invoiceNumer, Wrapped<String?> ? checkNumber, Wrapped<double?> ? amount, Wrapped<double?> ? applied, Wrapped<double?> ? refunded, Wrapped<double?> ? remaining, Wrapped<String?> ? currencySymbol, Wrapped<String?> ? orderId, Wrapped<String?> ? creditCardName, Wrapped<String?> ? creditCardNumber, Wrapped<String?> ? creditCardExpirationDate, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesBillingDealCreditDealCredit -
Available on WebApiModulesBillingDealCreditDealCredit, provided by the $WebApiModulesBillingDealCreditDealCreditExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesBillingDealCreditDealCredit Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesBillingDealCreditDealCredit instance)