WebApiModulesContainersContainerContainer class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesContainersContainerContainer({String? containerId, String? description, bool? rental, String? iCode, String? scannableInventoryId, String? scannableICode, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesContainersContainerContainer.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
containerId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
iCode String?
final
recordTitle String?
final
rental bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scannableICode String?
final
scannableInventoryId String?
final

Methods

copyWith({String? containerId, String? description, bool? rental, String? iCode, String? scannableInventoryId, String? scannableICode, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesContainersContainerContainer

Available on WebApiModulesContainersContainerContainer, provided by the $WebApiModulesContainersContainerContainerExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesContainersContainerContainer Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesContainersContainerContainer instance)