WebApiModulesHomeAddressAddress class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeAddressAddress({String? addressId, String? name, String? attention, String? attention2, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? zipCode, String? phone, String? fax, String? phoneTollFree, String? phoneOther, String? uniqueId1, String? uniqueId2, String? uniqueId3, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesHomeAddressAddress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address1 → String?
-
final
- address2 → String?
-
final
- addressId → String?
-
final
- attention → String?
-
final
- attention2 → String?
-
final
- auditNote → String?
-
final
- city → String?
-
final
- country → String?
-
final
- countryId → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- fax → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- name → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- phone → String?
-
final
- phoneOther → String?
-
final
- phoneTollFree → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- uniqueId1 → String?
-
final
- uniqueId2 → String?
-
final
- uniqueId3 → String?
-
final
- urlIdentifier → dynamic
-
final
- zipCode → String?
-
final
Methods
-
copyWith(
{String? addressId, String? name, String? attention, String? attention2, String? address1, String? address2, String? city, String? state, String? countryId, String? country, String? zipCode, String? phone, String? fax, String? phoneTollFree, String? phoneOther, String? uniqueId1, String? uniqueId2, String? uniqueId3, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesHomeAddressAddress -
Available on WebApiModulesHomeAddressAddress, provided by the $WebApiModulesHomeAddressAddressExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? addressId, Wrapped<String?> ? name, Wrapped<String?> ? attention, Wrapped<String?> ? attention2, Wrapped<String?> ? address1, Wrapped<String?> ? address2, Wrapped<String?> ? city, Wrapped<String?> ? state, Wrapped<String?> ? countryId, Wrapped<String?> ? country, Wrapped<String?> ? zipCode, Wrapped<String?> ? phone, Wrapped<String?> ? fax, Wrapped<String?> ? phoneTollFree, Wrapped<String?> ? phoneOther, Wrapped<String?> ? uniqueId1, Wrapped<String?> ? uniqueId2, Wrapped<String?> ? uniqueId3, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesHomeAddressAddress -
Available on WebApiModulesHomeAddressAddress, provided by the $WebApiModulesHomeAddressAddressExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeAddressAddress Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeAddressAddress instance)