WebApiModulesHomeControlsInventoryConsignorInventoryConsignor class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsInventoryConsignorInventoryConsignor({String? consignorId, String? consignorAgreementId, String? consignor, String? agreementNumber, String? agreementDescription, String? inventoryId, String? iCode, String? description, String? trackedBy, bool? treatConsignedQtyAsOwned, int? qtyConsigned, int? consignorPercent, int? housePercent, bool? flatRate, double? flatRateAmount, String? itemId, String? barCode, String? serialNumber, String? inventoryStatusId, String? inventoryStatus, String? inventoryStatusType, String? warehouseId, String? warehouse, String? warehouseCode, String? textColor, String? color, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsInventoryConsignorInventoryConsignor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agreementDescription → String?
-
final
- agreementNumber → String?
-
final
- auditNote → String?
-
final
- barCode → String?
-
final
- color → String?
-
final
- consignor → String?
-
final
- consignorAgreementId → String?
-
final
- consignorId → String?
-
final
- consignorPercent → int?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- flatRate → bool?
-
final
- flatRateAmount → double?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- housePercent → int?
-
final
- iCode → String?
-
final
- inventoryId → String?
-
final
- inventoryStatus → String?
-
final
- inventoryStatusId → String?
-
final
- inventoryStatusType → String?
-
final
- itemId → String?
-
final
- qtyConsigned → int?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber → String?
-
final
- textColor → String?
-
final
- trackedBy → String?
-
final
- treatConsignedQtyAsOwned → bool?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? consignorId, String? consignorAgreementId, String? consignor, String? agreementNumber, String? agreementDescription, String? inventoryId, String? iCode, String? description, String? trackedBy, bool? treatConsignedQtyAsOwned, int? qtyConsigned, int? consignorPercent, int? housePercent, bool? flatRate, double? flatRateAmount, String? itemId, String? barCode, String? serialNumber, String? inventoryStatusId, String? inventoryStatus, String? inventoryStatusType, String? warehouseId, String? warehouse, String? warehouseCode, String? textColor, String? color, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsInventoryConsignorInventoryConsignor -
Available on WebApiModulesHomeControlsInventoryConsignorInventoryConsignor, provided by the $WebApiModulesHomeControlsInventoryConsignorInventoryConsignorExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsInventoryConsignorInventoryConsignor Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsInventoryConsignorInventoryConsignor instance)