WebApiModulesHomeControlsOrderNoteOrderNote class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsOrderNoteOrderNote({String? orderNoteId, String? orderId, String? noteDate, String? userId, String? notesDescription, bool? billing, bool? printOnOrder, bool? copyToInvoice, bool? scheduleNote, String? scheduleNoteDate, bool? pickList, String? userName, String? notes, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesHomeControlsOrderNoteOrderNote.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- billing → bool?
-
final
- copyToInvoice → bool?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- noteDate → String?
-
final
- notes → String?
-
final
- notesDescription → String?
-
final
- orderId → String?
-
final
- orderNoteId → String?
-
final
- pickList → bool?
-
final
- printOnOrder → bool?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleNote → bool?
-
final
- scheduleNoteDate → String?
-
final
- userId → String?
-
final
- userName → String?
-
final
Methods
-
copyWith(
{String? orderNoteId, String? orderId, String? noteDate, String? userId, String? notesDescription, bool? billing, bool? printOnOrder, bool? copyToInvoice, bool? scheduleNote, String? scheduleNoteDate, bool? pickList, String? userName, String? notes, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesHomeControlsOrderNoteOrderNote -
Available on WebApiModulesHomeControlsOrderNoteOrderNote, provided by the $WebApiModulesHomeControlsOrderNoteOrderNoteExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsOrderNoteOrderNote Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsOrderNoteOrderNote instance)