WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory({int? id, String? physicalInventoryId, String? inventoryId, String? consignorId, String? iCode, String? description, String? availableFor, String? availableForDisplay, String? trackedBy, String? rank, String? aisleLocation, String? shelfLocation, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory.fromJson(Map<String, dynamic> json)
factory

Properties

aisleLocation String?
final
auditNote String?
final
availableFor String?
final
availableForDisplay String?
final
consignorId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
iCode String?
final
id int?
final
inventoryId String?
final
physicalInventoryId String?
final
rank String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelfLocation String?
final
trackedBy String?
final

Methods

copyWith({int? id, String? physicalInventoryId, String? inventoryId, String? consignorId, String? iCode, String? description, String? availableFor, String? availableForDisplay, String? trackedBy, String? rank, String? aisleLocation, String? shelfLocation, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory

Available on WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory, provided by the $WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventoryExtension extension

copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? physicalInventoryId, Wrapped<String?>? inventoryId, Wrapped<String?>? consignorId, Wrapped<String?>? iCode, Wrapped<String?>? description, Wrapped<String?>? availableFor, Wrapped<String?>? availableForDisplay, Wrapped<String?>? trackedBy, Wrapped<String?>? rank, Wrapped<String?>? aisleLocation, Wrapped<String?>? shelfLocation, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes}) WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory

Available on WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventory, provided by the $WebApiModulesHomeControlsPhysicalInventoryCycleInventoryPhysicalInventoryCycleInventoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override