WebApiModulesHomeControlsReceiptCreditReceiptCredit class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeControlsReceiptCreditReceiptCredit({int? creditReceiptId, String? creditingInvoiceId, String? receiptId, String? customerId, String? customer, String? dealId, String? deal, String? officeLocationId, String? paymentBy, String? recType, String? recTypeDisplay, String? recTypeColor, String? receiptDate, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? checkNumber, double? origAmount, double? applied, double? refunded, double? remaining, double? amount, String? currencyId, String? currencyCode, String? currencySymbol, String? creditCardName, String? creditCardExpirationDate, DateTime? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesHomeControlsReceiptCreditReceiptCredit.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → double?
-
final
- applied → double?
-
final
- auditNote → String?
-
final
- checkNumber → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
- creditCardExpirationDate → String?
-
final
- creditCardName → String?
-
final
- creditingInvoiceId → String?
-
final
- creditReceiptId → int?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
- currencySymbol → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- customer → String?
-
final
- customerId → String?
-
final
- dateStamp → DateTime?
-
final
- deal → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- officeLocationId → String?
-
final
- origAmount → double?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- paymentBy → String?
-
final
- paymentType → String?
-
final
- paymentTypeId → String?
-
final
- paymentTypeType → String?
-
final
- receiptDate → String?
-
final
- receiptId → String?
-
final
- recordTitle → String?
-
final
- recType → String?
-
final
- recTypeColor → String?
-
final
- recTypeDisplay → String?
-
final
- refunded → double?
-
final
- remaining → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{int? creditReceiptId, String? creditingInvoiceId, String? receiptId, String? customerId, String? customer, String? dealId, String? deal, String? officeLocationId, String? paymentBy, String? recType, String? recTypeDisplay, String? recTypeColor, String? receiptDate, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? checkNumber, double? origAmount, double? applied, double? refunded, double? remaining, double? amount, String? currencyId, String? currencyCode, String? currencySymbol, String? creditCardName, String? creditCardExpirationDate, DateTime? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesHomeControlsReceiptCreditReceiptCredit -
Available on WebApiModulesHomeControlsReceiptCreditReceiptCredit, provided by the $WebApiModulesHomeControlsReceiptCreditReceiptCreditExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? creditReceiptId, Wrapped<String?> ? creditingInvoiceId, Wrapped<String?> ? receiptId, Wrapped<String?> ? customerId, Wrapped<String?> ? customer, Wrapped<String?> ? dealId, Wrapped<String?> ? deal, Wrapped<String?> ? officeLocationId, Wrapped<String?> ? paymentBy, Wrapped<String?> ? recType, Wrapped<String?> ? recTypeDisplay, Wrapped<String?> ? recTypeColor, Wrapped<String?> ? receiptDate, Wrapped<String?> ? paymentTypeId, Wrapped<String?> ? paymentType, Wrapped<String?> ? paymentTypeType, Wrapped<String?> ? checkNumber, Wrapped<double?> ? origAmount, Wrapped<double?> ? applied, Wrapped<double?> ? refunded, Wrapped<double?> ? remaining, Wrapped<double?> ? amount, Wrapped<String?> ? currencyId, Wrapped<String?> ? currencyCode, Wrapped<String?> ? currencySymbol, Wrapped<String?> ? creditCardName, Wrapped<String?> ? creditCardExpirationDate, Wrapped<DateTime?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesHomeControlsReceiptCreditReceiptCredit -
Available on WebApiModulesHomeControlsReceiptCreditReceiptCredit, provided by the $WebApiModulesHomeControlsReceiptCreditReceiptCreditExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeControlsReceiptCreditReceiptCredit Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeControlsReceiptCreditReceiptCredit instance)