WebApiModulesHomeControlsReceiptCreditReceiptCredit class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesHomeControlsReceiptCreditReceiptCredit({String? creditReceiptId, String? creditingInvoiceId, String? receiptId, String? customerId, String? customer, String? dealId, String? deal, String? officeLocationId, String? paymentBy, String? recType, String? recTypeDisplay, String? recTypeColor, String? receiptDate, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? checkNumber, double? origAmount, double? applied, double? refunded, double? remaining, double? amount, String? currencyId, String? currencyCode, String? currencySymbol, String? creditCardName, String? creditCardExpirationDate, DateTime? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation})
WebApiModulesHomeControlsReceiptCreditReceiptCredit.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
final
applied double?
final
auditNote String?
final
checkNumber String?
final
creditCardExpirationDate String?
final
creditCardName String?
final
creditingInvoiceId String?
final
creditReceiptId String?
final
currencyCode String?
final
currencyId String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
customer String?
final
customerId String?
final
dateStamp DateTime?
final
deal String?
final
dealId String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
officeLocationId String?
final
origAmount double?
final
paymentBy String?
final
paymentType String?
final
paymentTypeId String?
final
paymentTypeType String?
final
receiptDate String?
final
receiptId String?
final
recordTitle String?
final
recType String?
final
recTypeColor String?
final
recTypeDisplay String?
final
refunded double?
final
remaining double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation List<FwStandardDataFwTranslatedValue>?
final

Methods

copyWith({String? creditReceiptId, String? creditingInvoiceId, String? receiptId, String? customerId, String? customer, String? dealId, String? deal, String? officeLocationId, String? paymentBy, String? recType, String? recTypeDisplay, String? recTypeColor, String? receiptDate, String? paymentTypeId, String? paymentType, String? paymentTypeType, String? checkNumber, double? origAmount, double? applied, double? refunded, double? remaining, double? amount, String? currencyId, String? currencyCode, String? currencySymbol, String? creditCardName, String? creditCardExpirationDate, DateTime? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation}) WebApiModulesHomeControlsReceiptCreditReceiptCredit

Available on WebApiModulesHomeControlsReceiptCreditReceiptCredit, provided by the $WebApiModulesHomeControlsReceiptCreditReceiptCreditExtension extension

copyWithWrapped({Wrapped<String?>? creditReceiptId, Wrapped<String?>? creditingInvoiceId, Wrapped<String?>? receiptId, Wrapped<String?>? customerId, Wrapped<String?>? customer, Wrapped<String?>? dealId, Wrapped<String?>? deal, Wrapped<String?>? officeLocationId, Wrapped<String?>? paymentBy, Wrapped<String?>? recType, Wrapped<String?>? recTypeDisplay, Wrapped<String?>? recTypeColor, Wrapped<String?>? receiptDate, Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<String?>? paymentTypeType, Wrapped<String?>? checkNumber, Wrapped<double?>? origAmount, Wrapped<double?>? applied, Wrapped<double?>? refunded, Wrapped<double?>? remaining, Wrapped<double?>? amount, Wrapped<String?>? currencyId, Wrapped<String?>? currencyCode, Wrapped<String?>? currencySymbol, Wrapped<String?>? creditCardName, Wrapped<String?>? creditCardExpirationDate, Wrapped<DateTime?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation}) WebApiModulesHomeControlsReceiptCreditReceiptCredit

Available on WebApiModulesHomeControlsReceiptCreditReceiptCredit, provided by the $WebApiModulesHomeControlsReceiptCreditReceiptCreditExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override