WebApiModulesHomeEmailRecipientEmailRecipient class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesHomeEmailRecipientEmailRecipient({String? companyContactId, String? companyId, String? company, String? companyType, String? companyTypeColor, String? contactId, String? salutation, String? nameFirstMiddleLast, String? person, String? lastName, String? firstName, String? middleInitial, String? jobTitle, String? contactTitleId, String? contactTitle, bool? isPrimary, String? activeDate, String? inactiveDate, bool? authorized, bool? orderNotify, String? officePhone, String? officeExtension, String? fax, String? faxExtension, String? email, String? directPhone, String? directExtension, String? pager, String? pagerPin, bool? printable, String? mobilePhone, bool? isAccountsReceivable, bool? isAccountsPayable, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesHomeEmailRecipientEmailRecipient.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeDate → String?
-
final
- auditNote → String?
-
final
-
final
- company → String?
-
final
- companyContactId → String?
-
final
- companyId → String?
-
final
- companyType → String?
-
final
- companyTypeColor → String?
-
final
- contactId → String?
-
final
- contactTitle → String?
-
final
- contactTitleId → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- directExtension → String?
-
final
- directPhone → String?
-
final
- email → String?
-
final
- fax → String?
-
final
- faxExtension → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- firstName → String?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- inactive → bool?
-
final
- inactiveDate → String?
-
final
- isAccountsPayable → bool?
-
final
- isAccountsReceivable → bool?
-
final
- isPrimary → bool?
-
final
- jobTitle → String?
-
final
- lastName → String?
-
final
- middleInitial → String?
-
final
- mobilePhone → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- nameFirstMiddleLast → String?
-
final
- officeExtension → String?
-
final
- officePhone → String?
-
final
- orderNotify → bool?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- pager → String?
-
final
- pagerPin → String?
-
final
- person → String?
-
final
- printable → bool?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salutation → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? companyContactId, String? companyId, String? company, String? companyType, String? companyTypeColor, String? contactId, String? salutation, String? nameFirstMiddleLast, String? person, String? lastName, String? firstName, String? middleInitial, String? jobTitle, String? contactTitleId, String? contactTitle, bool? isPrimary, String? activeDate, String? inactiveDate, bool? authorized, bool? orderNotify, String? officePhone, String? officeExtension, String? fax, String? faxExtension, String? email, String? directPhone, String? directExtension, String? pager, String? pagerPin, bool? printable, String? mobilePhone, bool? isAccountsReceivable, bool? isAccountsPayable, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesHomeEmailRecipientEmailRecipient -
Available on WebApiModulesHomeEmailRecipientEmailRecipient, provided by the $WebApiModulesHomeEmailRecipientEmailRecipientExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? companyContactId, Wrapped<String?> ? companyId, Wrapped<String?> ? company, Wrapped<String?> ? companyType, Wrapped<String?> ? companyTypeColor, Wrapped<String?> ? contactId, Wrapped<String?> ? salutation, Wrapped<String?> ? nameFirstMiddleLast, Wrapped<String?> ? person, Wrapped<String?> ? lastName, Wrapped<String?> ? firstName, Wrapped<String?> ? middleInitial, Wrapped<String?> ? jobTitle, Wrapped<String?> ? contactTitleId, Wrapped<String?> ? contactTitle, Wrapped<bool?> ? isPrimary, Wrapped<String?> ? activeDate, Wrapped<String?> ? inactiveDate, Wrapped<bool?> ? authorized, Wrapped<bool?> ? orderNotify, Wrapped<String?> ? officePhone, Wrapped<String?> ? officeExtension, Wrapped<String?> ? fax, Wrapped<String?> ? faxExtension, Wrapped<String?> ? email, Wrapped<String?> ? directPhone, Wrapped<String?> ? directExtension, Wrapped<String?> ? pager, Wrapped<String?> ? pagerPin, Wrapped<bool?> ? printable, Wrapped<String?> ? mobilePhone, Wrapped<bool?> ? isAccountsReceivable, Wrapped<bool?> ? isAccountsPayable, Wrapped<bool?> ? inactive, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesHomeEmailRecipientEmailRecipient -
Available on WebApiModulesHomeEmailRecipientEmailRecipient, provided by the $WebApiModulesHomeEmailRecipientEmailRecipientExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesHomeEmailRecipientEmailRecipient Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesHomeEmailRecipientEmailRecipient instance)