WebApiModulesInventoryInventoryPrepInventoryPrep class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesInventoryInventoryPrepInventoryPrep({String? inventoryPrepId, String? inventoryId, String? iCode, String? description, String? prepRateId, String? prepICode, String? prepDescription, String? prepUnit, String? prepUnitType, bool? isDefault, double? prepRate, String? prepTime, double? prepExtended, double? qtyOrdered, double? price, bool? orderId, bool? masteritemId, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesInventoryInventoryPrepInventoryPrep.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- iCode → String?
-
final
- inventoryId → String?
-
final
- inventoryPrepId → String?
-
final
- isDefault → bool?
-
final
- masteritemId → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- orderId → bool?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- prepDescription → String?
-
final
- prepExtended → double?
-
final
- prepICode → String?
-
final
- prepRate → double?
-
final
- prepRateId → String?
-
final
- prepTime → String?
-
final
- prepUnit → String?
-
final
- prepUnitType → String?
-
final
- price → double?
-
final
- qtyOrdered → double?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? inventoryPrepId, String? inventoryId, String? iCode, String? description, String? prepRateId, String? prepICode, String? prepDescription, String? prepUnit, String? prepUnitType, bool? isDefault, double? prepRate, String? prepTime, double? prepExtended, double? qtyOrdered, double? price, bool? orderId, bool? masteritemId, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesInventoryInventoryPrepInventoryPrep -
Available on WebApiModulesInventoryInventoryPrepInventoryPrep, provided by the $WebApiModulesInventoryInventoryPrepInventoryPrepExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? inventoryPrepId, Wrapped<String?> ? inventoryId, Wrapped<String?> ? iCode, Wrapped<String?> ? description, Wrapped<String?> ? prepRateId, Wrapped<String?> ? prepICode, Wrapped<String?> ? prepDescription, Wrapped<String?> ? prepUnit, Wrapped<String?> ? prepUnitType, Wrapped<bool?> ? isDefault, Wrapped<double?> ? prepRate, Wrapped<String?> ? prepTime, Wrapped<double?> ? prepExtended, Wrapped<double?> ? qtyOrdered, Wrapped<double?> ? price, Wrapped<bool?> ? orderId, Wrapped<bool?> ? masteritemId, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesInventoryInventoryPrepInventoryPrep -
Available on WebApiModulesInventoryInventoryPrepInventoryPrep, provided by the $WebApiModulesInventoryInventoryPrepInventoryPrepExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryInventoryPrepInventoryPrep Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryInventoryPrepInventoryPrep instance)