WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest({String? sessionId, String? orderId, String? lineage, String? warehouseId, String? languageId, bool? showAvailability, DateTime? fromDate, String? fromTime, DateTime? toDate, String? toTime, bool? showImages})
-
const
-
WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- fromDate → DateTime?
-
final
- fromTime → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageId → String?
-
final
- lineage → String?
-
final
- orderId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- showAvailability → bool?
-
final
- showImages → bool?
-
final
- toDate → DateTime?
-
final
- toTime → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? sessionId, String? orderId, String? lineage, String? warehouseId, String? languageId, bool? showAvailability, DateTime? fromDate, String? fromTime, DateTime? toDate, String? toTime, bool? showImages}) → WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest -
Available on WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest, provided by the $WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? sessionId, Wrapped<String?> ? orderId, Wrapped<String?> ? lineage, Wrapped<String?> ? warehouseId, Wrapped<String?> ? languageId, Wrapped<bool?> ? showAvailability, Wrapped<DateTime?> ? fromDate, Wrapped<String?> ? fromTime, Wrapped<DateTime?> ? toDate, Wrapped<String?> ? toTime, Wrapped<bool?> ? showImages}) → WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest -
Available on WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest, provided by the $WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryInventorySearchInventorySearchAccessoriesRequest instance)