WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial({String? physicalInventoryId, String? inventoryId, String? inventoryType, String? category, String? iCode, String? description, String? aisleLocation, String? shelfLocation, String? categoryId, double? categoryOrderBy, int? inventoryTypeOrderBy, String? inventoryTypeId, String? unitId, String? unit, String? currentSpaceId, String? currentSpace, String? consignorId, String? consignor, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aisleLocation → String?
-
final
- auditNote → String?
-
final
- category → String?
-
final
- categoryId → String?
-
final
- categoryOrderBy → double?
-
final
- consignor → String?
-
final
- consignorId → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
- currentSpace → String?
-
final
- currentSpaceId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- iCode → String?
-
final
- inventoryId → String?
-
final
- inventoryType → String?
-
final
- inventoryTypeId → String?
-
final
- inventoryTypeOrderBy → int?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- physicalInventoryId → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shelfLocation → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- unit → String?
-
final
- unitId → String?
-
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? physicalInventoryId, String? inventoryId, String? inventoryType, String? category, String? iCode, String? description, String? aisleLocation, String? shelfLocation, String? categoryId, double? categoryOrderBy, int? inventoryTypeOrderBy, String? inventoryTypeId, String? unitId, String? unit, String? currentSpaceId, String? currentSpace, String? consignorId, String? consignor, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial -
Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerialExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? physicalInventoryId, Wrapped<String?> ? inventoryId, Wrapped<String?> ? inventoryType, Wrapped<String?> ? category, Wrapped<String?> ? iCode, Wrapped<String?> ? description, Wrapped<String?> ? aisleLocation, Wrapped<String?> ? shelfLocation, Wrapped<String?> ? categoryId, Wrapped<double?> ? categoryOrderBy, Wrapped<int?> ? inventoryTypeOrderBy, Wrapped<String?> ? inventoryTypeId, Wrapped<String?> ? unitId, Wrapped<String?> ? unit, Wrapped<String?> ? currentSpaceId, Wrapped<String?> ? currentSpace, Wrapped<String?> ? consignorId, Wrapped<String?> ? consignor, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial -
Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerialExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial instance)