WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial({String? physicalInventoryId, String? inventoryId, String? inventoryType, String? category, String? iCode, String? description, String? aisleLocation, String? shelfLocation, String? categoryId, double? categoryOrderBy, int? inventoryTypeOrderBy, String? inventoryTypeId, String? unitId, String? unit, String? currentSpaceId, String? currentSpace, String? consignorId, String? consignor, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aisleLocation → String?
-
final
- auditNote → String?
-
final
- category → String?
-
final
- categoryId → String?
-
final
- categoryOrderBy → double?
-
final
- consignor → String?
-
final
- consignorId → String?
-
final
- currentSpace → String?
-
final
- currentSpaceId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- inventoryId → String?
-
final
- inventoryType → String?
-
final
- inventoryTypeId → String?
-
final
- inventoryTypeOrderBy → int?
-
final
- physicalInventoryId → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shelfLocation → String?
-
final
- unit → String?
-
final
- unitId → String?
-
final
Methods
-
copyWith(
{String? physicalInventoryId, String? inventoryId, String? inventoryType, String? category, String? iCode, String? description, String? aisleLocation, String? shelfLocation, String? categoryId, double? categoryOrderBy, int? inventoryTypeOrderBy, String? inventoryTypeId, String? unitId, String? unit, String? currentSpaceId, String? currentSpace, String? consignorId, String? consignor, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial -
Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerialExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventoryPhysicalInventoryPhysicalInventoryCountSerial instance)