WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExceptions class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExceptions({String? physicalInventoryId, String? scannedCode, String? iCode, String? description, String? exception, String? inventoryId, String? userName, String? date, String? time, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExceptions.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
date String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
exception String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
iCode String?
final
inventoryId String?
final
physicalInventoryId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scannedCode String?
final
time String?
final
userName String?
final

Methods

copyWith({String? physicalInventoryId, String? scannedCode, String? iCode, String? description, String? exception, String? inventoryId, String? userName, String? date, String? time, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExceptions

Available on WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExceptions, provided by the $WebApiModulesInventoryPhysicalInventoryPhysicalInventoryExceptionsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override