WebApiModulesInventorySetBrochureSetBrochure class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesInventorySetBrochureSetBrochure({String? brochureId, String? setId, String? iCode, String? setDescription, String? orderId, String? orderNumber, String? orderDescription, String? dealId, String? deal, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesInventorySetBrochureSetBrochure.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- brochureId → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- deal → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- iCode → String?
-
final
- inactive → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- orderNumber → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setDescription → String?
-
final
- setId → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? brochureId, String? setId, String? iCode, String? setDescription, String? orderId, String? orderNumber, String? orderDescription, String? dealId, String? deal, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesInventorySetBrochureSetBrochure -
Available on WebApiModulesInventorySetBrochureSetBrochure, provided by the $WebApiModulesInventorySetBrochureSetBrochureExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? brochureId, Wrapped<String?> ? setId, Wrapped<String?> ? iCode, Wrapped<String?> ? setDescription, Wrapped<String?> ? orderId, Wrapped<String?> ? orderNumber, Wrapped<String?> ? orderDescription, Wrapped<String?> ? dealId, Wrapped<String?> ? deal, Wrapped<bool?> ? inactive, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesInventorySetBrochureSetBrochure -
Available on WebApiModulesInventorySetBrochureSetBrochure, provided by the $WebApiModulesInventorySetBrochureSetBrochureExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventorySetBrochureSetBrochure Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventorySetBrochureSetBrochure instance)