WebApiModulesInventorySetBrochureSetBrochure class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesInventorySetBrochureSetBrochure({String? brochureId, String? setId, String? iCode, String? setDescription, String? orderId, String? orderNumber, String? orderDescription, String? dealId, String? deal, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue> ? translation}) -
WebApiModulesInventorySetBrochureSetBrochure.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- brochureId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- deal → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- inactive → bool?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- orderNumber → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setDescription → String?
-
final
- setId → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
Methods
-
copyWith(
{String? brochureId, String? setId, String? iCode, String? setDescription, String? orderId, String? orderNumber, String? orderDescription, String? dealId, String? deal, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue> ? translation}) → WebApiModulesInventorySetBrochureSetBrochure -
Available on WebApiModulesInventorySetBrochureSetBrochure, provided by the $WebApiModulesInventorySetBrochureSetBrochureExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? brochureId, Wrapped<String?> ? setId, Wrapped<String?> ? iCode, Wrapped<String?> ? setDescription, Wrapped<String?> ? orderId, Wrapped<String?> ? orderNumber, Wrapped<String?> ? orderDescription, Wrapped<String?> ? dealId, Wrapped<String?> ? deal, Wrapped<bool?> ? inactive, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>List< ? translation}) → WebApiModulesInventorySetBrochureSetBrochureFwStandardDataFwTranslatedValue> ?> -
Available on WebApiModulesInventorySetBrochureSetBrochure, provided by the $WebApiModulesInventorySetBrochureSetBrochureExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesInventorySetBrochureSetBrochure Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesInventorySetBrochureSetBrochure instance)