WebApiModulesWarehouseCheckInReconcileCheckInReconcile class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesWarehouseCheckInReconcileCheckInReconcile({String? contractId, String? contractDate, String? contractNumber, String? contractType, String? contractTime, String? locationId, String? locationCode, String? location, String? warehouseId, String? warehouseCode, String? warehouse, String? dealId, String? deal, String? departmentId, String? department, String? quikInOneOrderPerContract, bool? hasAssigned, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesWarehouseCheckInReconcileCheckInReconcile.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- contractDate → String?
-
final
- contractId → String?
-
final
- contractNumber → String?
-
final
- contractTime → String?
-
final
- contractType → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- deal → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasAssigned → bool?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- location → String?
-
final
- locationCode → String?
-
final
- locationId → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- quikInOneOrderPerContract → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? contractId, String? contractDate, String? contractNumber, String? contractType, String? contractTime, String? locationId, String? locationCode, String? location, String? warehouseId, String? warehouseCode, String? warehouse, String? dealId, String? deal, String? departmentId, String? department, String? quikInOneOrderPerContract, bool? hasAssigned, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesWarehouseCheckInReconcileCheckInReconcile -
Available on WebApiModulesWarehouseCheckInReconcileCheckInReconcile, provided by the $WebApiModulesWarehouseCheckInReconcileCheckInReconcileExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? contractId, Wrapped<String?> ? contractDate, Wrapped<String?> ? contractNumber, Wrapped<String?> ? contractType, Wrapped<String?> ? contractTime, Wrapped<String?> ? locationId, Wrapped<String?> ? locationCode, Wrapped<String?> ? location, Wrapped<String?> ? warehouseId, Wrapped<String?> ? warehouseCode, Wrapped<String?> ? warehouse, Wrapped<String?> ? dealId, Wrapped<String?> ? deal, Wrapped<String?> ? departmentId, Wrapped<String?> ? department, Wrapped<String?> ? quikInOneOrderPerContract, Wrapped<bool?> ? hasAssigned, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesWarehouseCheckInReconcileCheckInReconcile -
Available on WebApiModulesWarehouseCheckInReconcileCheckInReconcile, provided by the $WebApiModulesWarehouseCheckInReconcileCheckInReconcileExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseCheckInReconcileCheckInReconcile Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseCheckInReconcileCheckInReconcile instance)