WebApiModulesWarehouseCheckInReconcileReconcileICode class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesWarehouseCheckInReconcileReconcileICode({String? iCode, String? inventoryDescription, String? orderId, String? orderDescription, String? dueDate, String? contractId, String? dealId, String? departmentId, String? crossVendor, String? vendor, double? unassigned, String? inventoryId, String? vendorId, String? itemClass, String? nestedMasterItemId, String? packageId, String? packageItemId, String? trackedBy, String? scannedBy, String? orderNumber, String? barcode, String? exception, String? inContractId, String? orderItemId, bool? returnToReceipt, double? orderTranId, String? internalChar, double? quikInItemId, String? quikInInternalChar, String? inContractNumber, double? sessionNumber, double? ordered, double? stillOut, double? counted, double? quantity, double? sessionIn, double? remaining, double? status, String? message})
-
const
-
WebApiModulesWarehouseCheckInReconcileReconcileICode.fromJson(Map<
String, dynamic> json) -
factory
Properties
- barcode → String?
-
final
- contractId → String?
-
final
- counted → double?
-
final
- crossVendor → String?
-
final
- dealId → String?
-
final
- departmentId → String?
-
final
- dueDate → String?
-
final
- exception → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- inContractId → String?
-
final
- inContractNumber → String?
-
final
- internalChar → String?
-
final
- inventoryDescription → String?
-
final
- inventoryId → String?
-
final
- itemClass → String?
-
final
- message → String?
-
final
- nestedMasterItemId → String?
-
final
- orderDescription → String?
-
final
- ordered → double?
-
final
- orderId → String?
-
final
- orderItemId → String?
-
final
- orderNumber → String?
-
final
- orderTranId → double?
-
final
- packageId → String?
-
final
- packageItemId → String?
-
final
- quantity → double?
-
final
- quikInInternalChar → String?
-
final
- quikInItemId → double?
-
final
- remaining → double?
-
final
- returnToReceipt → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannedBy → String?
-
final
- sessionIn → double?
-
final
- sessionNumber → double?
-
final
- status → double?
-
final
- stillOut → double?
-
final
- trackedBy → String?
-
final
- unassigned → double?
-
final
- vendor → String?
-
final
- vendorId → String?
-
final
Methods
-
copyWith(
{String? iCode, String? inventoryDescription, String? orderId, String? orderDescription, String? dueDate, String? contractId, String? dealId, String? departmentId, String? crossVendor, String? vendor, double? unassigned, String? inventoryId, String? vendorId, String? itemClass, String? nestedMasterItemId, String? packageId, String? packageItemId, String? trackedBy, String? scannedBy, String? orderNumber, String? barcode, String? exception, String? inContractId, String? orderItemId, bool? returnToReceipt, double? orderTranId, String? internalChar, double? quikInItemId, String? quikInInternalChar, String? inContractNumber, double? sessionNumber, double? ordered, double? stillOut, double? counted, double? quantity, double? sessionIn, double? remaining, double? status, String? message}) → WebApiModulesWarehouseCheckInReconcileReconcileICode -
Available on WebApiModulesWarehouseCheckInReconcileReconcileICode, provided by the $WebApiModulesWarehouseCheckInReconcileReconcileICodeExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? iCode, Wrapped<String?> ? inventoryDescription, Wrapped<String?> ? orderId, Wrapped<String?> ? orderDescription, Wrapped<String?> ? dueDate, Wrapped<String?> ? contractId, Wrapped<String?> ? dealId, Wrapped<String?> ? departmentId, Wrapped<String?> ? crossVendor, Wrapped<String?> ? vendor, Wrapped<double?> ? unassigned, Wrapped<String?> ? inventoryId, Wrapped<String?> ? vendorId, Wrapped<String?> ? itemClass, Wrapped<String?> ? nestedMasterItemId, Wrapped<String?> ? packageId, Wrapped<String?> ? packageItemId, Wrapped<String?> ? trackedBy, Wrapped<String?> ? scannedBy, Wrapped<String?> ? orderNumber, Wrapped<String?> ? barcode, Wrapped<String?> ? exception, Wrapped<String?> ? inContractId, Wrapped<String?> ? orderItemId, Wrapped<bool?> ? returnToReceipt, Wrapped<double?> ? orderTranId, Wrapped<String?> ? internalChar, Wrapped<double?> ? quikInItemId, Wrapped<String?> ? quikInInternalChar, Wrapped<String?> ? inContractNumber, Wrapped<double?> ? sessionNumber, Wrapped<double?> ? ordered, Wrapped<double?> ? stillOut, Wrapped<double?> ? counted, Wrapped<double?> ? quantity, Wrapped<double?> ? sessionIn, Wrapped<double?> ? remaining, Wrapped<double?> ? status, Wrapped<String?> ? message}) → WebApiModulesWarehouseCheckInReconcileReconcileICode -
Available on WebApiModulesWarehouseCheckInReconcileReconcileICode, provided by the $WebApiModulesWarehouseCheckInReconcileReconcileICodeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseCheckInReconcileReconcileICode Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseCheckInReconcileReconcileICode instance)