WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse({String? shippingCaseItemId, String? iCode, String? description, String? shippingCaseDescription, String? shippingCaseNumber, int? shippingCaseId, int? status, String? message})
-
const
-
WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingCaseDescription → String?
-
final
- shippingCaseId → int?
-
final
- shippingCaseItemId → String?
-
final
- shippingCaseNumber → String?
-
final
- status → int?
-
final
Methods
-
copyWith(
{String? shippingCaseItemId, String? iCode, String? description, String? shippingCaseDescription, String? shippingCaseNumber, int? shippingCaseId, int? status, String? message}) → WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse -
Available on WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse, provided by the $WebApiModulesWarehouseCheckOutIsValidShippingCaseResponseExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? shippingCaseItemId, Wrapped<String?> ? iCode, Wrapped<String?> ? description, Wrapped<String?> ? shippingCaseDescription, Wrapped<String?> ? shippingCaseNumber, Wrapped<int?> ? shippingCaseId, Wrapped<int?> ? status, Wrapped<String?> ? message}) → WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse -
Available on WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse, provided by the $WebApiModulesWarehouseCheckOutIsValidShippingCaseResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseCheckOutIsValidShippingCaseResponse instance)