WebApiModulesWarehouseExchangeExchangeNonBcItemRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesWarehouseExchangeExchangeNonBcItemRequest({String? contractId, String? orderId, String? dealId, String? departmentId, String? warehouseId, String? masterId, String? orderItemId, int? quantity, bool? pendingExchange, bool? completingPending})
-
const
-
WebApiModulesWarehouseExchangeExchangeNonBcItemRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- completingPending → bool?
-
final
- contractId → String?
-
final
- dealId → String?
-
final
- departmentId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- masterId → String?
-
final
- orderId → String?
-
final
- orderItemId → String?
-
final
- pendingExchange → bool?
-
final
- quantity → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? contractId, String? orderId, String? dealId, String? departmentId, String? warehouseId, String? masterId, String? orderItemId, int? quantity, bool? pendingExchange, bool? completingPending}) → WebApiModulesWarehouseExchangeExchangeNonBcItemRequest -
Available on WebApiModulesWarehouseExchangeExchangeNonBcItemRequest, provided by the $WebApiModulesWarehouseExchangeExchangeNonBcItemRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? contractId, Wrapped<String?> ? orderId, Wrapped<String?> ? dealId, Wrapped<String?> ? departmentId, Wrapped<String?> ? warehouseId, Wrapped<String?> ? masterId, Wrapped<String?> ? orderItemId, Wrapped<int?> ? quantity, Wrapped<bool?> ? pendingExchange, Wrapped<bool?> ? completingPending}) → WebApiModulesWarehouseExchangeExchangeNonBcItemRequest -
Available on WebApiModulesWarehouseExchangeExchangeNonBcItemRequest, provided by the $WebApiModulesWarehouseExchangeExchangeNonBcItemRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseExchangeExchangeNonBcItemRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseExchangeExchangeNonBcItemRequest instance)