WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest({String? inventoryId, List<
String> ? warehouseId, String? regionId, DateTime? fromDate, DateTime? toDate, bool? includeHours, bool? yearView, String? sortReservationsBy, bool? excludeConsigned, bool? consignedOnly, List<String> ? filterReservationsBy}) -
const
-
WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- consignedOnly → bool?
-
final
- excludeConsigned → bool?
-
final
-
filterReservationsBy
→ List<
String> ? -
final
- fromDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeHours → bool?
-
final
- inventoryId → String?
-
final
- regionId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortReservationsBy → String?
-
final
- toDate → DateTime?
-
final
-
warehouseId
→ List<
String> ? -
final
- yearView → bool?
-
final
Methods
-
copyWith(
{String? inventoryId, List< String> ? warehouseId, String? regionId, DateTime? fromDate, DateTime? toDate, bool? includeHours, bool? yearView, String? sortReservationsBy, bool? excludeConsigned, bool? consignedOnly, List<String> ? filterReservationsBy}) → WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest -
Available on WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest, provided by the $WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? inventoryId, Wrapped<List< ? warehouseId, Wrapped<String> ?>String?> ? regionId, Wrapped<DateTime?> ? fromDate, Wrapped<DateTime?> ? toDate, Wrapped<bool?> ? includeHours, Wrapped<bool?> ? yearView, Wrapped<String?> ? sortReservationsBy, Wrapped<bool?> ? excludeConsigned, Wrapped<bool?> ? consignedOnly, Wrapped<List< ? filterReservationsBy}) → WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequestString> ?> -
Available on WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest, provided by the $WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiServicesAvailabilityServiceAvailabilityCalendarAndScheduleRequest instance)