WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment({String? consignorId, String? consignor, String? consignorAgreementId, String? agreementNumber, double? quantity, DateTime? expirationDate, String? inventoryId, String? warehouseId})
-
const
-
WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agreementNumber → String?
-
final
- consignor → String?
-
final
- consignorAgreementId → String?
-
final
- consignorId → String?
-
final
- expirationDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inventoryId → String?
-
final
- quantity → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? consignorId, String? consignor, String? consignorAgreementId, String? agreementNumber, double? quantity, DateTime? expirationDate, String? inventoryId, String? warehouseId}) → WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment -
Available on WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment, provided by the $WebApiServicesAvailabilityServiceTInventoryWarehouseConsignmentExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? consignorId, Wrapped<String?> ? consignor, Wrapped<String?> ? consignorAgreementId, Wrapped<String?> ? agreementNumber, Wrapped<double?> ? quantity, Wrapped<DateTime?> ? expirationDate, Wrapped<String?> ? inventoryId, Wrapped<String?> ? warehouseId}) → WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment -
Available on WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment, provided by the $WebApiServicesAvailabilityServiceTInventoryWarehouseConsignmentExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiServicesAvailabilityServiceTInventoryWarehouseConsignment instance)