ShopifySharpAddress class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpAddress({String? address1, String? address2, String? city, String? company, String? country, String? countryCode, String? countryName, bool? $default, String? firstName, String? lastName, double? latitude, double? longitude, String? name, String? phone, String? province, String? provinceCode, String? zip, int? id, String? adminGraphqlApiId})
-
const
-
ShopifySharpAddress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $default → bool?
-
final
- address1 → String?
-
final
- address2 → String?
-
final
- adminGraphqlApiId → String?
-
final
- city → String?
-
final
- company → String?
-
final
- country → String?
-
final
- countryCode → String?
-
final
- countryName → String?
-
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- lastName → String?
-
final
- latitude → double?
-
final
- longitude → double?
-
final
- name → String?
-
final
- phone → String?
-
final
- province → String?
-
final
- provinceCode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zip → String?
-
final
Methods
-
copyWith(
{String? address1, String? address2, String? city, String? company, String? country, String? countryCode, String? countryName, bool? $default, String? firstName, String? lastName, double? latitude, double? longitude, String? name, String? phone, String? province, String? provinceCode, String? zip, int? id, String? adminGraphqlApiId}) → ShopifySharpAddress -
Available on ShopifySharpAddress, provided by the $ShopifySharpAddressExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? address1, Wrapped<String?> ? address2, Wrapped<String?> ? city, Wrapped<String?> ? company, Wrapped<String?> ? country, Wrapped<String?> ? countryCode, Wrapped<String?> ? countryName, Wrapped<bool?> ? $default, Wrapped<String?> ? firstName, Wrapped<String?> ? lastName, Wrapped<double?> ? latitude, Wrapped<double?> ? longitude, Wrapped<String?> ? name, Wrapped<String?> ? phone, Wrapped<String?> ? province, Wrapped<String?> ? provinceCode, Wrapped<String?> ? zip, Wrapped<int?> ? id, Wrapped<String?> ? adminGraphqlApiId}) → ShopifySharpAddress -
Available on ShopifySharpAddress, provided by the $ShopifySharpAddressExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpAddress Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpAddress instance)