ShopifySharpCurrencyExchangeAdjustment class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpCurrencyExchangeAdjustment({double? adjustment, double? originalAmount, double? finalAmount, String? currency, int? id, String? adminGraphqlApiId})
-
const
-
ShopifySharpCurrencyExchangeAdjustment.fromJson(Map<
String, dynamic> json) -
factory
Properties
- adjustment → double?
-
final
- adminGraphqlApiId → String?
-
final
- currency → String?
-
final
- finalAmount → double?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- originalAmount → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? adjustment, double? originalAmount, double? finalAmount, String? currency, int? id, String? adminGraphqlApiId}) → ShopifySharpCurrencyExchangeAdjustment -
Available on ShopifySharpCurrencyExchangeAdjustment, provided by the $ShopifySharpCurrencyExchangeAdjustmentExtension extension
-
copyWithWrapped(
{Wrapped< double?> ? adjustment, Wrapped<double?> ? originalAmount, Wrapped<double?> ? finalAmount, Wrapped<String?> ? currency, Wrapped<int?> ? id, Wrapped<String?> ? adminGraphqlApiId}) → ShopifySharpCurrencyExchangeAdjustment -
Available on ShopifySharpCurrencyExchangeAdjustment, provided by the $ShopifySharpCurrencyExchangeAdjustmentExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpCurrencyExchangeAdjustment Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpCurrencyExchangeAdjustment instance)