ShopifySharpDiscountAllocation class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ShopifySharpDiscountAllocation({String? amount, int? discountApplicationIndex, ShopifySharpPriceSet? amountSet})
-
const
-
ShopifySharpDiscountAllocation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → String?
-
final
- amountSet → ShopifySharpPriceSet?
-
final
- discountApplicationIndex → int?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? amount, int? discountApplicationIndex, ShopifySharpPriceSet? amountSet}) → ShopifySharpDiscountAllocation -
Available on ShopifySharpDiscountAllocation, provided by the $ShopifySharpDiscountAllocationExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? amount, Wrapped<int?> ? discountApplicationIndex, Wrapped<ShopifySharpPriceSet?> ? amountSet}) → ShopifySharpDiscountAllocation -
Available on ShopifySharpDiscountAllocation, provided by the $ShopifySharpDiscountAllocationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpDiscountAllocation Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpDiscountAllocation instance)