ShopifySharpRefundLineItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ShopifySharpRefundLineItem({ShopifySharpLineItem? lineItem, int? lineItemId, int? quantity, double? totalTax, double? subtotal, ShopifySharpPriceSet? subtotalSet, ShopifySharpPriceSet? totalTaxSet, String? restockType, int? locationId, int? id, String? adminGraphqlApiId})
const
ShopifySharpRefundLineItem.fromJson(Map<String, dynamic> json)
factory

Properties

adminGraphqlApiId String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
lineItem ShopifySharpLineItem?
final
lineItemId int?
final
locationId int?
final
quantity int?
final
restockType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtotal double?
final
subtotalSet ShopifySharpPriceSet?
final
totalTax double?
final
totalTaxSet ShopifySharpPriceSet?
final

Methods

copyWith({ShopifySharpLineItem? lineItem, int? lineItemId, int? quantity, double? totalTax, double? subtotal, ShopifySharpPriceSet? subtotalSet, ShopifySharpPriceSet? totalTaxSet, String? restockType, int? locationId, int? id, String? adminGraphqlApiId}) ShopifySharpRefundLineItem

Available on ShopifySharpRefundLineItem, provided by the $ShopifySharpRefundLineItemExtension extension

copyWithWrapped({Wrapped<ShopifySharpLineItem?>? lineItem, Wrapped<int?>? lineItemId, Wrapped<int?>? quantity, Wrapped<double?>? totalTax, Wrapped<double?>? subtotal, Wrapped<ShopifySharpPriceSet?>? subtotalSet, Wrapped<ShopifySharpPriceSet?>? totalTaxSet, Wrapped<String?>? restockType, Wrapped<int?>? locationId, Wrapped<int?>? id, Wrapped<String?>? adminGraphqlApiId}) ShopifySharpRefundLineItem

Available on ShopifySharpRefundLineItem, provided by the $ShopifySharpRefundLineItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ShopifySharpRefundLineItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ShopifySharpRefundLineItem instance)