ShopifySharpShippingLine class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ShopifySharpShippingLine({String? carrierIdentifier, String? code, bool? isRemoved, String? phone, double? price, double? discountedPrice, List<
ShopifySharpDiscountAllocation> ? discountAllocations, String? source, String? title, List<ShopifySharpTaxLine> ? taxLines, ShopifySharpPriceSet? priceSet, ShopifySharpPriceSet? discountedPriceSet, int? id, String? adminGraphqlApiId}) -
const
-
ShopifySharpShippingLine.fromJson(Map<
String, dynamic> json) -
factory
Properties
- adminGraphqlApiId → String?
-
final
- carrierIdentifier → String?
-
final
- code → String?
-
final
-
discountAllocations
→ List<
ShopifySharpDiscountAllocation> ? -
final
- discountedPrice → double?
-
final
- discountedPriceSet → ShopifySharpPriceSet?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int?
-
final
- isRemoved → bool?
-
final
- phone → String?
-
final
- price → double?
-
final
- priceSet → ShopifySharpPriceSet?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
final
-
taxLines
→ List<
ShopifySharpTaxLine> ? -
final
- title → String?
-
final
Methods
-
copyWith(
{String? carrierIdentifier, String? code, bool? isRemoved, String? phone, double? price, double? discountedPrice, List< ShopifySharpDiscountAllocation> ? discountAllocations, String? source, String? title, List<ShopifySharpTaxLine> ? taxLines, ShopifySharpPriceSet? priceSet, ShopifySharpPriceSet? discountedPriceSet, int? id, String? adminGraphqlApiId}) → ShopifySharpShippingLine -
Available on ShopifySharpShippingLine, provided by the $ShopifySharpShippingLineExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? carrierIdentifier, Wrapped<String?> ? code, Wrapped<bool?> ? isRemoved, Wrapped<String?> ? phone, Wrapped<double?> ? price, Wrapped<double?> ? discountedPrice, Wrapped<List< ? discountAllocations, Wrapped<ShopifySharpDiscountAllocation> ?>String?> ? source, Wrapped<String?> ? title, Wrapped<List< ? taxLines, Wrapped<ShopifySharpTaxLine> ?>ShopifySharpPriceSet?> ? priceSet, Wrapped<ShopifySharpPriceSet?> ? discountedPriceSet, Wrapped<int?> ? id, Wrapped<String?> ? adminGraphqlApiId}) → ShopifySharpShippingLine -
Available on ShopifySharpShippingLine, provided by the $ShopifySharpShippingLineExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ShopifySharpShippingLine Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ShopifySharpShippingLine instance)