WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse({WebApiModulesIntegrationsStorefrontProductAvailability? availability, double? dailyRate, double? weeklyRate, double? monthlyRate, String? currencySymbol, String? currencyCode})
-
const
-
WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- availability → WebApiModulesIntegrationsStorefrontProductAvailability?
-
final
- currencyCode → String?
-
final
- currencySymbol → String?
-
final
- dailyRate → double?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- monthlyRate → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weeklyRate → double?
-
final
Methods
-
copyWith(
{WebApiModulesIntegrationsStorefrontProductAvailability? availability, double? dailyRate, double? weeklyRate, double? monthlyRate, String? currencySymbol, String? currencyCode}) → WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse -
Available on WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse, provided by the $WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponseExtension extension
-
copyWithWrapped(
{Wrapped< WebApiModulesIntegrationsStorefrontProductAvailability?> ? availability, Wrapped<double?> ? dailyRate, Wrapped<double?> ? weeklyRate, Wrapped<double?> ? monthlyRate, Wrapped<String?> ? currencySymbol, Wrapped<String?> ? currencyCode}) → WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse -
Available on WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse, provided by the $WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontGetProductWarehouseDetailsResponse instance)