WebApiModulesIntegrationsStorefrontQuoteRequestItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesIntegrationsStorefrontQuoteRequestItem({required String inventoryId, required String webCatalogId, required double qty, List<
WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem> ? packageItems}) -
const
-
WebApiModulesIntegrationsStorefrontQuoteRequestItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inventoryId → String
-
final
-
packageItems
→ List<
WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem> ? -
final
- qty → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webCatalogId → String
-
final
Methods
-
copyWith(
{String? inventoryId, String? webCatalogId, double? qty, List< WebApiModulesIntegrationsStorefrontQuoteRequestPackageItem> ? packageItems}) → WebApiModulesIntegrationsStorefrontQuoteRequestItem -
Available on WebApiModulesIntegrationsStorefrontQuoteRequestItem, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestItemExtension extension
-
copyWithWrapped(
{Wrapped< String> ? inventoryId, Wrapped<String> ? webCatalogId, Wrapped<double> ? qty, Wrapped<List< ? packageItems}) → WebApiModulesIntegrationsStorefrontQuoteRequestItemWebApiModulesIntegrationsStorefrontQuoteRequestPackageItem> ?> -
Available on WebApiModulesIntegrationsStorefrontQuoteRequestItem, provided by the $WebApiModulesIntegrationsStorefrontQuoteRequestItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontQuoteRequestItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontQuoteRequestItem instance)