WebApiModulesIntegrationsStorefrontStorefrontProductL class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontStorefrontProductL({List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, int? id, String? warehouseId, String? inventoryId, String? inventoryNo, String? itemName, String? keywords, String? tags, String? barcodes, String? itemUrlName, String? detailedDescription, String? technicalNotes, String? classification, String? availableFor, double? owned, String? inventoryTypeOrderBy, String? categoryOrderBy, String? subCategoryOrderBy, String? masterOrderBy, WebApiModulesIntegrationsStorefrontProductAvailability? availability, bool? warehouseSpecific, String? packagePrice, double? dailyRate, double? weeklyRate, double? monthlyRate, double? salesPrice, String? currencySymbol, String? currencyCode, List<StorefrontPackageItem>? packageItems, String? manufacturer, String? manufacturerPartNumber, String? manufacturerUrl, double? unitValue, double? replacementCost, double? shipWeightLbs, double? shipWeightOz, List<WebApiModulesIntegrationsStorefrontProductImage>? images, String? webCatalogId, String? webCatalog, String? webCatalogUrlName, String? inventoryDepartmentId, String? inventoryDepartment, String? inventoryDepartmentUrlName, String? categoryId, String? category, String? categoryUrlName, String? subCategoryId, String? subCategory, String? subCategoryUrlName, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime})
const
WebApiModulesIntegrationsStorefrontStorefrontProductL.fromJson(Map<String, dynamic> json)
factory

Properties

availability WebApiModulesIntegrationsStorefrontProductAvailability?
final
availableFor String?
final
barcodes String?
final
category String?
final
categoryId String?
final
categoryOrderBy String?
final
categoryUrlName String?
final
classification String?
final
createdByUserId String?
final
createdByUserName String?
final
createdDateTime String?
final
currencyCode String?
final
currencySymbol String?
final
custom List<FwStandardDataFwCustomValue>?
final
dailyRate double?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
detailedDescription String?
final
hasDocuments bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasImport bool?
final
id int?
final
images List<WebApiModulesIntegrationsStorefrontProductImage>?
final
inventoryDepartment String?
final
inventoryDepartmentId String?
final
inventoryDepartmentUrlName String?
final
inventoryId String?
final
inventoryNo String?
final
inventoryTypeOrderBy String?
final
itemName String?
final
itemUrlName String?
final
keywords String?
final
manufacturer String?
final
manufacturerPartNumber String?
final
manufacturerUrl String?
final
masterOrderBy String?
final
modifiedByUserId String?
final
modifiedByUserName String?
final
modifiedDateTime String?
final
monthlyRate double?
final
original FwStandardBusinessLogicFwBusinessLogic?
final
owned double?
final
packageItems List<StorefrontPackageItem>?
final
packagePrice String?
final
replacementCost double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesPrice double?
final
shipWeightLbs double?
final
shipWeightOz double?
final
subCategory String?
final
subCategoryId String?
final
subCategoryOrderBy String?
final
subCategoryUrlName String?
final
tags String?
final
technicalNotes String?
final
translation List<FwStandardDataFwTranslatedValue>?
final
unitValue double?
final
warehouseId String?
final
warehouseSpecific bool?
final
webCatalog String?
final
webCatalogId String?
final
webCatalogUrlName String?
final
weeklyRate double?
final

Methods

copyWith({List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue>? translation, bool? hasImport, bool? hasDocuments, int? id, String? warehouseId, String? inventoryId, String? inventoryNo, String? itemName, String? keywords, String? tags, String? barcodes, String? itemUrlName, String? detailedDescription, String? technicalNotes, String? classification, String? availableFor, double? owned, String? inventoryTypeOrderBy, String? categoryOrderBy, String? subCategoryOrderBy, String? masterOrderBy, WebApiModulesIntegrationsStorefrontProductAvailability? availability, bool? warehouseSpecific, String? packagePrice, double? dailyRate, double? weeklyRate, double? monthlyRate, double? salesPrice, String? currencySymbol, String? currencyCode, List<StorefrontPackageItem>? packageItems, String? manufacturer, String? manufacturerPartNumber, String? manufacturerUrl, double? unitValue, double? replacementCost, double? shipWeightLbs, double? shipWeightOz, List<WebApiModulesIntegrationsStorefrontProductImage>? images, String? webCatalogId, String? webCatalog, String? webCatalogUrlName, String? inventoryDepartmentId, String? inventoryDepartment, String? inventoryDepartmentUrlName, String? categoryId, String? category, String? categoryUrlName, String? subCategoryId, String? subCategory, String? subCategoryUrlName, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) WebApiModulesIntegrationsStorefrontStorefrontProductL

Available on WebApiModulesIntegrationsStorefrontStorefrontProductL, provided by the $WebApiModulesIntegrationsStorefrontStorefrontProductLExtension extension

copyWithWrapped({Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes, Wrapped<List<FwStandardDataFwTranslatedValue>?>? translation, Wrapped<bool?>? hasImport, Wrapped<bool?>? hasDocuments, Wrapped<int?>? id, Wrapped<String?>? warehouseId, Wrapped<String?>? inventoryId, Wrapped<String?>? inventoryNo, Wrapped<String?>? itemName, Wrapped<String?>? keywords, Wrapped<String?>? tags, Wrapped<String?>? barcodes, Wrapped<String?>? itemUrlName, Wrapped<String?>? detailedDescription, Wrapped<String?>? technicalNotes, Wrapped<String?>? classification, Wrapped<String?>? availableFor, Wrapped<double?>? owned, Wrapped<String?>? inventoryTypeOrderBy, Wrapped<String?>? categoryOrderBy, Wrapped<String?>? subCategoryOrderBy, Wrapped<String?>? masterOrderBy, Wrapped<WebApiModulesIntegrationsStorefrontProductAvailability?>? availability, Wrapped<bool?>? warehouseSpecific, Wrapped<String?>? packagePrice, Wrapped<double?>? dailyRate, Wrapped<double?>? weeklyRate, Wrapped<double?>? monthlyRate, Wrapped<double?>? salesPrice, Wrapped<String?>? currencySymbol, Wrapped<String?>? currencyCode, Wrapped<List<StorefrontPackageItem>?>? packageItems, Wrapped<String?>? manufacturer, Wrapped<String?>? manufacturerPartNumber, Wrapped<String?>? manufacturerUrl, Wrapped<double?>? unitValue, Wrapped<double?>? replacementCost, Wrapped<double?>? shipWeightLbs, Wrapped<double?>? shipWeightOz, Wrapped<List<WebApiModulesIntegrationsStorefrontProductImage>?>? images, Wrapped<String?>? webCatalogId, Wrapped<String?>? webCatalog, Wrapped<String?>? webCatalogUrlName, Wrapped<String?>? inventoryDepartmentId, Wrapped<String?>? inventoryDepartment, Wrapped<String?>? inventoryDepartmentUrlName, Wrapped<String?>? categoryId, Wrapped<String?>? category, Wrapped<String?>? categoryUrlName, Wrapped<String?>? subCategoryId, Wrapped<String?>? subCategory, Wrapped<String?>? subCategoryUrlName, Wrapped<FwStandardBusinessLogicFwBusinessLogic?>? original, Wrapped<String?>? createdByUserId, Wrapped<String?>? createdByUserName, Wrapped<String?>? createdDateTime, Wrapped<String?>? modifiedByUserId, Wrapped<String?>? modifiedByUserName, Wrapped<String?>? modifiedDateTime}) WebApiModulesIntegrationsStorefrontStorefrontProductL

Available on WebApiModulesIntegrationsStorefrontStorefrontProductL, provided by the $WebApiModulesIntegrationsStorefrontStorefrontProductLExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override