WebApiModulesIntegrationsStorefrontStorefrontProgress class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesIntegrationsStorefrontStorefrontProgress({DateTime? lastUpdated, bool? failed, String? failureMessage, String? failureStackTrace, String? sessionId, String? caption, int? currentStep, int? totalSteps, int? percentComplete})
-
const
-
WebApiModulesIntegrationsStorefrontStorefrontProgress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- caption → String?
-
final
- currentStep → int?
-
final
- failed → bool?
-
final
- failureMessage → String?
-
final
- failureStackTrace → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastUpdated → DateTime?
-
final
- percentComplete → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- totalSteps → int?
-
final
Methods
-
copyWith(
{DateTime? lastUpdated, bool? failed, String? failureMessage, String? failureStackTrace, String? sessionId, String? caption, int? currentStep, int? totalSteps, int? percentComplete}) → WebApiModulesIntegrationsStorefrontStorefrontProgress -
Available on WebApiModulesIntegrationsStorefrontStorefrontProgress, provided by the $WebApiModulesIntegrationsStorefrontStorefrontProgressExtension extension
-
copyWithWrapped(
{Wrapped< DateTime?> ? lastUpdated, Wrapped<bool?> ? failed, Wrapped<String?> ? failureMessage, Wrapped<String?> ? failureStackTrace, Wrapped<String?> ? sessionId, Wrapped<String?> ? caption, Wrapped<int?> ? currentStep, Wrapped<int?> ? totalSteps, Wrapped<int?> ? percentComplete}) → WebApiModulesIntegrationsStorefrontStorefrontProgress -
Available on WebApiModulesIntegrationsStorefrontStorefrontProgress, provided by the $WebApiModulesIntegrationsStorefrontStorefrontProgressExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesIntegrationsStorefrontStorefrontProgress Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesIntegrationsStorefrontStorefrontProgress instance)