WebApiModulesIntegrationsStorefrontStorefrontSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesIntegrationsStorefrontStorefrontSettings({bool? isStorefrontEnabled, bool? isUniversity, bool? isAnonymousAccessEnabled, bool? separateQuoteRequestsByCatalog, bool? makeQuoteRequestIntoOrderOnSubmission, bool? filterCatalogsByLocation, double? autoplaySpeed, bool? autoplayImagesOnLandingPage, bool? autoplayImagesOnProductBrowser, bool? autoplayImagesOnProductDetails})
const
WebApiModulesIntegrationsStorefrontStorefrontSettings.fromJson(Map<String, dynamic> json)
factory

Properties

autoplayImagesOnLandingPage bool?
final
autoplayImagesOnProductBrowser bool?
final
autoplayImagesOnProductDetails bool?
final
autoplaySpeed double?
final
filterCatalogsByLocation bool?
final
hashCode int
The hash code for this object.
no setteroverride
isAnonymousAccessEnabled bool?
final
isStorefrontEnabled bool?
final
isUniversity bool?
final
makeQuoteRequestIntoOrderOnSubmission bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separateQuoteRequestsByCatalog bool?
final

Methods

copyWith({bool? isStorefrontEnabled, bool? isUniversity, bool? isAnonymousAccessEnabled, bool? separateQuoteRequestsByCatalog, bool? makeQuoteRequestIntoOrderOnSubmission, bool? filterCatalogsByLocation, double? autoplaySpeed, bool? autoplayImagesOnLandingPage, bool? autoplayImagesOnProductBrowser, bool? autoplayImagesOnProductDetails}) WebApiModulesIntegrationsStorefrontStorefrontSettings

Available on WebApiModulesIntegrationsStorefrontStorefrontSettings, provided by the $WebApiModulesIntegrationsStorefrontStorefrontSettingsExtension extension

copyWithWrapped({Wrapped<bool?>? isStorefrontEnabled, Wrapped<bool?>? isUniversity, Wrapped<bool?>? isAnonymousAccessEnabled, Wrapped<bool?>? separateQuoteRequestsByCatalog, Wrapped<bool?>? makeQuoteRequestIntoOrderOnSubmission, Wrapped<bool?>? filterCatalogsByLocation, Wrapped<double?>? autoplaySpeed, Wrapped<bool?>? autoplayImagesOnLandingPage, Wrapped<bool?>? autoplayImagesOnProductBrowser, Wrapped<bool?>? autoplayImagesOnProductDetails}) WebApiModulesIntegrationsStorefrontStorefrontSettings

Available on WebApiModulesIntegrationsStorefrontStorefrontSettings, provided by the $WebApiModulesIntegrationsStorefrontStorefrontSettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override