Pages class abstract

Annotations
  • @ChopperApi.new()

Constructors

Pages()

Properties

client ↔ ChopperClient
getter/setter pairinherited
definitionType Type
Used internally to retrieve the service from ChopperClient.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cardpointepaymentactivelinkEmptybrowseobjectGet() Future<Response>
Get an empty browse object
cardpointepaymentactivelinkEmptyobjectGet() Future<Response>
Get an empty object
cardpointepaymentactivelinkGet({required String? activeLinkToken}) Future<Response<WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkGetActiveLinkDetailsResponse>>
@param ActiveLinkToken
cardpointepaymentactivelinkKeyfieldnamesGet() Future<Response>
Get an array of primary key field names
cardpointepaymentactivelinkMakepaymentPost({required WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkAuthorizeRequest? body}) Future<Response<WebApiModulesPagesActiveLinkCardPointePaymentPaymentActiveLinkMakePaymentAsyncResponse>>
cardpointetokenizerEmptybrowseobjectGet() Future<Response>
Get an empty browse object
cardpointetokenizerEmptyobjectGet() Future<Response>
Get an empty object
cardpointetokenizerGet() Future<Response<WebApiModulesPagesPluginsCardPointeTokenizerGetCardPointeTokenizerResponse>>
cardpointetokenizerKeyfieldnamesGet() Future<Response>
Get an array of primary key field names
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({ChopperClient? client, String? baseUrl, Iterable? interceptors}) Pages