FwStandardBusinessLogicFwBusinessLogicFieldDefinition class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- FwStandardBusinessLogicFwBusinessLogicFieldDefinition({String? name, FwStandardSqlServerFwDataTypes? dataType, FwStandardSqlServerAttributesFwExcelOptions? excelOptions, int? maxLength, bool? isRequired, bool? isPrimaryKey, bool? isReadOnly, String? displayFieldName, String? allowedValues, int? templateSequence, bool? isEmail})
-
const
-
FwStandardBusinessLogicFwBusinessLogicFieldDefinition.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allowedValues → String?
-
final
- dataType → FwStandardSqlServerFwDataTypes?
-
final
- displayFieldName → String?
-
final
- excelOptions → FwStandardSqlServerAttributesFwExcelOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isEmail → bool?
-
final
- isPrimaryKey → bool?
-
final
- isReadOnly → bool?
-
final
- isRequired → bool?
-
final
- maxLength → int?
-
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateSequence → int?
-
final
Methods
-
copyWith(
{String? name, FwStandardSqlServerFwDataTypes? dataType, FwStandardSqlServerAttributesFwExcelOptions? excelOptions, int? maxLength, bool? isRequired, bool? isPrimaryKey, bool? isReadOnly, String? displayFieldName, String? allowedValues, int? templateSequence, bool? isEmail}) → FwStandardBusinessLogicFwBusinessLogicFieldDefinition -
Available on FwStandardBusinessLogicFwBusinessLogicFieldDefinition, provided by the $FwStandardBusinessLogicFwBusinessLogicFieldDefinitionExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? name, Wrapped<FwStandardSqlServerFwDataTypes?> ? dataType, Wrapped<FwStandardSqlServerAttributesFwExcelOptions?> ? excelOptions, Wrapped<int?> ? maxLength, Wrapped<bool?> ? isRequired, Wrapped<bool?> ? isPrimaryKey, Wrapped<bool?> ? isReadOnly, Wrapped<String?> ? displayFieldName, Wrapped<String?> ? allowedValues, Wrapped<int?> ? templateSequence, Wrapped<bool?> ? isEmail}) → FwStandardBusinessLogicFwBusinessLogicFieldDefinition -
Available on FwStandardBusinessLogicFwBusinessLogicFieldDefinition, provided by the $FwStandardBusinessLogicFwBusinessLogicFieldDefinitionExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardBusinessLogicFwBusinessLogicFieldDefinition Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardBusinessLogicFwBusinessLogicFieldDefinition instance)