WebApiModulesPluginsCreditCardOrderDeposit class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

amount double?
final
auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
orderId String?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionDate DateTime?
final

Methods

copyWith({String? orderId, DateTime? transactionDate, double? amount, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesPluginsCreditCardOrderDeposit

Available on WebApiModulesPluginsCreditCardOrderDeposit, provided by the $WebApiModulesPluginsCreditCardOrderDepositExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesPluginsCreditCardOrderDeposit Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesPluginsCreditCardOrderDeposit instance)