WebApiModulesPluginsCreditCardProcessCreditCardPaymentType class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesPluginsCreditCardProcessCreditCardPaymentType({String? paymentTypeId, String? paymentType, String? paymentTypeType, double? feePercent})
const
WebApiModulesPluginsCreditCardProcessCreditCardPaymentType.fromJson(Map<String, dynamic> json)
factory

Properties

feePercent double?
final
hashCode int
The hash code for this object.
no setteroverride
paymentType String?
final
paymentTypeId String?
final
paymentTypeType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? paymentTypeId, String? paymentType, String? paymentTypeType, double? feePercent}) WebApiModulesPluginsCreditCardProcessCreditCardPaymentType

Available on WebApiModulesPluginsCreditCardProcessCreditCardPaymentType, provided by the $WebApiModulesPluginsCreditCardProcessCreditCardPaymentTypeExtension extension

copyWithWrapped({Wrapped<String?>? paymentTypeId, Wrapped<String?>? paymentType, Wrapped<String?>? paymentTypeType, Wrapped<double?>? feePercent}) WebApiModulesPluginsCreditCardProcessCreditCardPaymentType

Available on WebApiModulesPluginsCreditCardProcessCreditCardPaymentType, provided by the $WebApiModulesPluginsCreditCardProcessCreditCardPaymentTypeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override