WebApiModulesPluginsKissFlowProjectResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsKissFlowProjectResponse({int? status, bool? success, String? msg, WebApiModulesAgentProjectProject? project, String? projectUrl, String? agentEmail, String? projectManagerEmail, String? outsideSalesRepresentativeEmail})
-
const
-
WebApiModulesPluginsKissFlowProjectResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agentEmail → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- msg → String?
-
final
- outsideSalesRepresentativeEmail → String?
-
final
- project → WebApiModulesAgentProjectProject?
-
final
- projectManagerEmail → String?
-
final
- projectUrl → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- success → bool?
-
final
Methods
-
copyWith(
{int? status, bool? success, String? msg, WebApiModulesAgentProjectProject? project, String? projectUrl, String? agentEmail, String? projectManagerEmail, String? outsideSalesRepresentativeEmail}) → WebApiModulesPluginsKissFlowProjectResponse -
Available on WebApiModulesPluginsKissFlowProjectResponse, provided by the $WebApiModulesPluginsKissFlowProjectResponseExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? status, Wrapped<bool?> ? success, Wrapped<String?> ? msg, Wrapped<WebApiModulesAgentProjectProject?> ? project, Wrapped<String?> ? projectUrl, Wrapped<String?> ? agentEmail, Wrapped<String?> ? projectManagerEmail, Wrapped<String?> ? outsideSalesRepresentativeEmail}) → WebApiModulesPluginsKissFlowProjectResponse -
Available on WebApiModulesPluginsKissFlowProjectResponse, provided by the $WebApiModulesPluginsKissFlowProjectResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsKissFlowProjectResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsKissFlowProjectResponse instance)