WebApiModulesPluginsOpenAIOpenAISettingsTestResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsOpenAIOpenAISettingsTestResponse({bool? success, String? message, bool? openAISuccess, String? openAIMessage, bool? zendeskSuccess, String? zendeskMessage})
-
const
-
WebApiModulesPluginsOpenAIOpenAISettingsTestResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String?
-
final
- openAIMessage → String?
-
final
- openAISuccess → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool?
-
final
- zendeskMessage → String?
-
final
- zendeskSuccess → bool?
-
final
Methods
-
copyWith(
{bool? success, String? message, bool? openAISuccess, String? openAIMessage, bool? zendeskSuccess, String? zendeskMessage}) → WebApiModulesPluginsOpenAIOpenAISettingsTestResponse -
Available on WebApiModulesPluginsOpenAIOpenAISettingsTestResponse, provided by the $WebApiModulesPluginsOpenAIOpenAISettingsTestResponseExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? success, Wrapped<String?> ? message, Wrapped<bool?> ? openAISuccess, Wrapped<String?> ? openAIMessage, Wrapped<bool?> ? zendeskSuccess, Wrapped<String?> ? zendeskMessage}) → WebApiModulesPluginsOpenAIOpenAISettingsTestResponse -
Available on WebApiModulesPluginsOpenAIOpenAISettingsTestResponse, provided by the $WebApiModulesPluginsOpenAIOpenAISettingsTestResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsOpenAIOpenAISettingsTestResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsOpenAIOpenAISettingsTestResponse instance)