WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation({String? locationId, String? locationName, String? lastConnected, String? expiresIn, bool? expired})
-
const
-
WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- expired → bool?
-
final
- expiresIn → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastConnected → String?
-
final
- locationId → String?
-
final
- locationName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? locationId, String? locationName, String? lastConnected, String? expiresIn, bool? expired}) → WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation -
Available on WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation, provided by the $WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocationExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? locationId, Wrapped<String?> ? locationName, Wrapped<String?> ? lastConnected, Wrapped<String?> ? expiresIn, Wrapped<bool?> ? expired}) → WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation -
Available on WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation, provided by the $WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsQuickbooksOnlineQuickBooksOnlinePluginLogicLocation instance)