WebApiModulesPluginsTeamupTeamupSettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesPluginsTeamupTeamupSettings({List<
WebApiModulesPluginsTeamupTeamupPluginLocationSettings> ? locations, int? status, bool? success, String? msg, String? teamupApiKey}) -
const
-
WebApiModulesPluginsTeamupTeamupSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
locations
→ List<
WebApiModulesPluginsTeamupTeamupPluginLocationSettings> ? -
final
- msg → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- success → bool?
-
final
- teamupApiKey → String?
-
final
Methods
-
copyWith(
{List< WebApiModulesPluginsTeamupTeamupPluginLocationSettings> ? locations, int? status, bool? success, String? msg, String? teamupApiKey}) → WebApiModulesPluginsTeamupTeamupSettings -
Available on WebApiModulesPluginsTeamupTeamupSettings, provided by the $WebApiModulesPluginsTeamupTeamupSettingsExtension extension
-
copyWithWrapped(
{Wrapped< List< ? locations, Wrapped<WebApiModulesPluginsTeamupTeamupPluginLocationSettings> ?>int?> ? status, Wrapped<bool?> ? success, Wrapped<String?> ? msg, Wrapped<String?> ? teamupApiKey}) → WebApiModulesPluginsTeamupTeamupSettings -
Available on WebApiModulesPluginsTeamupTeamupSettings, provided by the $WebApiModulesPluginsTeamupTeamupSettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesPluginsTeamupTeamupSettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesPluginsTeamupTeamupSettings instance)