FwStandardDataFwReportLoader class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
FwStandardDataFwReportLoader({String? printDate, String? printTime, String? printDateTime, List<
String> ? dateFields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
FwStandardDataFwReportLoader.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
-
dateFields
→ List<
String> ? -
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- printDate → String?
-
final
- printDateTime → String?
-
final
- printTime → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
Methods
-
copyWith(
{String? printDate, String? printTime, String? printDateTime, List< String> ? dateFields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, FwStandardBusinessLogicFwBusinessLogic? original, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → FwStandardDataFwReportLoader -
Available on FwStandardDataFwReportLoader, provided by the $FwStandardDataFwReportLoaderExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? printDate, Wrapped<String?> ? printTime, Wrapped<String?> ? printDateTime, Wrapped<List< ? dateFields, Wrapped<String> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → FwStandardDataFwReportLoader -
Available on FwStandardDataFwReportLoader, provided by the $FwStandardDataFwReportLoaderExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FwStandardDataFwReportLoader Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FwStandardDataFwReportLoader instance)