WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest({DateTime? fromDate, DateTime? toDate, String? moduleName, String? webUsersId, String? keyword, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customReportLayoutId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
keyword String?
final
locale String?
final
moduleName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate DateTime?
final
webUsersId String?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? moduleName, String? webUsersId, String? keyword, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest

Available on WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest, provided by the $WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequestExtension extension

copyWithWrapped({Wrapped<DateTime?>? fromDate, Wrapped<DateTime?>? toDate, Wrapped<String?>? moduleName, Wrapped<String?>? webUsersId, Wrapped<String?>? keyword, Wrapped<String?>? customReportLayoutId, Wrapped<bool?>? isSummary, Wrapped<bool?>? includeSubHeadingsAndSubTotals, Wrapped<bool?>? includeIdColumns, Wrapped<String?>? locale, Wrapped<List<FwStandardModelsCheckBoxListItem>?>? excelfields}) WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest

Available on WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequest, provided by the $WebApiModulesReportsChangeAuditReportsChangeAuditReportChangeAuditReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override