WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest({String? batchId, String? batchNumber, DateTime? batchDate, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<
FwStandardModelsCheckBoxListItem> ? excelfields}) -
WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- batchDate → DateTime?
-
final
- batchId → String?
-
final
- batchNumber → String?
-
final
- customReportLayoutId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? batchId, String? batchNumber, DateTime? batchDate, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List< FwStandardModelsCheckBoxListItem> ? excelfields}) → WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest -
Available on WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest, provided by the $WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesReportsChargeProcessingReportsReceiptBatchReportReceiptBatchReportRequest instance)