WebApiModulesReportsOrderChangeReportOrderChangeReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesReportsOrderChangeReportOrderChangeReportRequest({String? orderType, String? orderId, String? quoteId, String? fromDate, String? fromTime, String? toDate, String? toTime, String? filterBy, int? hoursOffsetFromUTC, bool? excludeZeroVariance, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<
FwStandardModelsCheckBoxListItem> ? excelfields, String? reportName, bool? useEmailTemplate}) -
const
-
WebApiModulesReportsOrderChangeReportOrderChangeReportRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- customReportLayoutId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- excludeZeroVariance → bool?
-
final
- filterBy → String?
-
final
- fromDate → String?
-
final
- fromTime → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hoursOffsetFromUTC → int?
-
final
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
- orderId → String?
-
final
- orderType → String?
-
final
- quoteId → String?
-
final
- reportName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toDate → String?
-
final
- toTime → String?
-
final
- useEmailTemplate → bool?
-
final
- userDepartmentId → String?
-
final
- userLocationId → String?
-
final
- userWarehouseId → String?
-
final
Methods
-
copyWith(
{String? orderType, String? orderId, String? quoteId, String? fromDate, String? fromTime, String? toDate, String? toTime, String? filterBy, int? hoursOffsetFromUTC, bool? excludeZeroVariance, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List< FwStandardModelsCheckBoxListItem> ? excelfields, String? reportName, bool? useEmailTemplate}) → WebApiModulesReportsOrderChangeReportOrderChangeReportRequest -
Available on WebApiModulesReportsOrderChangeReportOrderChangeReportRequest, provided by the $WebApiModulesReportsOrderChangeReportOrderChangeReportRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? orderType, Wrapped<String?> ? orderId, Wrapped<String?> ? quoteId, Wrapped<String?> ? fromDate, Wrapped<String?> ? fromTime, Wrapped<String?> ? toDate, Wrapped<String?> ? toTime, Wrapped<String?> ? filterBy, Wrapped<int?> ? hoursOffsetFromUTC, Wrapped<bool?> ? excludeZeroVariance, Wrapped<String?> ? userDepartmentId, Wrapped<String?> ? userLocationId, Wrapped<String?> ? userWarehouseId, Wrapped<String?> ? customReportLayoutId, Wrapped<bool?> ? isSummary, Wrapped<bool?> ? includeSubHeadingsAndSubTotals, Wrapped<bool?> ? includeIdColumns, Wrapped<String?> ? locale, Wrapped<List< ? excelfields, Wrapped<FwStandardModelsCheckBoxListItem> ?>String?> ? reportName, Wrapped<bool?> ? useEmailTemplate}) → WebApiModulesReportsOrderChangeReportOrderChangeReportRequest -
Available on WebApiModulesReportsOrderChangeReportOrderChangeReportRequest, provided by the $WebApiModulesReportsOrderChangeReportOrderChangeReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesReportsOrderChangeReportOrderChangeReportRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesReportsOrderChangeReportOrderChangeReportRequest instance)