WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest({String? warehouseId, String? departmentId, String? officeLocationId, String? userId, String? orderTypeId, List<
FwStandardModelsSelectedCheckBoxListItem> ? orderStatus, List<FwStandardModelsSelectedCheckBoxListItem> ? outgoingDeliveryType, List<FwStandardModelsSelectedCheckBoxListItem> ? incomingDeliveryType, bool? printAlertBannerMessage, DateTime? fromDate, DateTime? toDate, bool? filterByPickDate, bool? filterByEstimatedStartDate, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields, String? reportName, bool? useEmailTemplate}) -
const
-
WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- customReportLayoutId → String?
-
final
- departmentId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- filterByEstimatedStartDate → bool?
-
final
- filterByPickDate → bool?
-
final
- fromDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
-
incomingDeliveryType
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- isSummary → bool?
-
final
- locale → String?
-
final
- officeLocationId → String?
-
final
-
orderStatus
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- orderTypeId → String?
-
final
-
outgoingDeliveryType
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- printAlertBannerMessage → bool?
-
final
- reportName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toDate → DateTime?
-
final
- useEmailTemplate → bool?
-
final
- userDepartmentId → String?
-
final
- userId → String?
-
final
- userLocationId → String?
-
final
- userWarehouseId → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? warehouseId, String? departmentId, String? officeLocationId, String? userId, String? orderTypeId, List< FwStandardModelsSelectedCheckBoxListItem> ? orderStatus, List<FwStandardModelsSelectedCheckBoxListItem> ? outgoingDeliveryType, List<FwStandardModelsSelectedCheckBoxListItem> ? incomingDeliveryType, bool? printAlertBannerMessage, DateTime? fromDate, DateTime? toDate, bool? filterByPickDate, bool? filterByEstimatedStartDate, String? userDepartmentId, String? userLocationId, String? userWarehouseId, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields, String? reportName, bool? useEmailTemplate}) → WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest -
Available on WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest, provided by the $WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? warehouseId, Wrapped<String?> ? departmentId, Wrapped<String?> ? officeLocationId, Wrapped<String?> ? userId, Wrapped<String?> ? orderTypeId, Wrapped<List< ? orderStatus, Wrapped<FwStandardModelsSelectedCheckBoxListItem> ?>List< ? outgoingDeliveryType, Wrapped<FwStandardModelsSelectedCheckBoxListItem> ?>List< ? incomingDeliveryType, Wrapped<FwStandardModelsSelectedCheckBoxListItem> ?>bool?> ? printAlertBannerMessage, Wrapped<DateTime?> ? fromDate, Wrapped<DateTime?> ? toDate, Wrapped<bool?> ? filterByPickDate, Wrapped<bool?> ? filterByEstimatedStartDate, Wrapped<String?> ? userDepartmentId, Wrapped<String?> ? userLocationId, Wrapped<String?> ? userWarehouseId, Wrapped<String?> ? customReportLayoutId, Wrapped<bool?> ? isSummary, Wrapped<bool?> ? includeSubHeadingsAndSubTotals, Wrapped<bool?> ? includeIdColumns, Wrapped<String?> ? locale, Wrapped<List< ? excelfields, Wrapped<FwStandardModelsCheckBoxListItem> ?>String?> ? reportName, Wrapped<bool?> ? useEmailTemplate}) → WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest -
Available on WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest, provided by the $WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesReportsOrderReportsOrderDatesAndBannersReportOrderDatesAndBannersReportRequest instance)