WebApiModulesReportsSharedInventoryAttributesReportInventoryAttributesReportRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
factory
Properties
- attributeId → String?
-
final
- categoryId → String?
-
final
- customReportLayoutId → String?
-
final
-
excelfields
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- fixedAsset → WebApiIncludeExcludeAll?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeIdColumns → bool?
-
final
- includeSubHeadingsAndSubTotals → bool?
-
final
- inventoryId → String?
-
final
- inventoryTypeId → String?
-
final
- isSummary → bool?
-
final
- locale → String?
-
final
-
ranks
→ List<
FwStandardModelsSelectedCheckBoxListItem> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortBy
→ List<
FwStandardModelsCheckBoxListItem> ? -
final
- subCategoryId → String?
-
final
Methods
-
copyWith(
{List< FwStandardModelsCheckBoxListItem> ? sortBy, String? inventoryTypeId, String? categoryId, String? subCategoryId, String? inventoryId, String? attributeId, WebApiIncludeExcludeAll? fixedAsset, List<FwStandardModelsSelectedCheckBoxListItem> ? ranks, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem> ? excelfields}) → WebApiModulesReportsSharedInventoryAttributesReportInventoryAttributesReportRequest -
Available on WebApiModulesReportsSharedInventoryAttributesReportInventoryAttributesReportRequest, provided by the $WebApiModulesReportsSharedInventoryAttributesReportInventoryAttributesReportRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
- fromJsonFactory → const WebApiModulesReportsSharedInventoryAttributesReportInventoryAttributesReportRequest Function()
-
toJsonFactory
→ const Map<
String, dynamic> Function()