WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

custom List<FwStandardDataFwCustomValue>?
final
dateFields List<String>?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
printDate String?
final
printDateTime String?
final
printTime String?
final
quantity String?
final
rowType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? rowType, String? description, String? quantity, String? printDate, String? printTime, String? printDateTime, List<String>? dateFields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL

Available on WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL, provided by the $WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemLExtension extension

copyWithWrapped({Wrapped<String?>? rowType, Wrapped<String?>? description, Wrapped<String?>? quantity, Wrapped<String?>? printDate, Wrapped<String?>? printTime, Wrapped<String?>? printDateTime, Wrapped<List<String>?>? dateFields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes}) WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL

Available on WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemL, provided by the $WebApiModulesReportsWarehouseReportsQuikReceiptReportQuikReceiptReportItemLExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override