WebApiModulesReportsWarehouseReportsWarehouseInboundReportWarehouseInboundReportRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesReportsWarehouseReportsWarehouseInboundReportWarehouseInboundReportRequest({DateTime? fromDate, DateTime? toDate, String? warehouseId, String? departmentId, String? agentId, String? activityTypeId, List<FwStandardModelsCheckBoxListItem>? sortBy, List<FwStandardModelsSelectedCheckBoxListItem>? orderTypes, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields})
WebApiModulesReportsWarehouseReportsWarehouseInboundReportWarehouseInboundReportRequest.fromJson(Map<String, dynamic> json)
factory

Properties

activityTypeId String?
final
agentId String?
final
customReportLayoutId String?
final
departmentId String?
final
excelfields List<FwStandardModelsCheckBoxListItem>?
final
fromDate DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
includeIdColumns bool?
final
includeSubHeadingsAndSubTotals bool?
final
isSummary bool?
final
locale String?
final
orderTypes List<FwStandardModelsSelectedCheckBoxListItem>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy List<FwStandardModelsCheckBoxListItem>?
final
toDate DateTime?
final
warehouseId String?
final

Methods

copyWith({DateTime? fromDate, DateTime? toDate, String? warehouseId, String? departmentId, String? agentId, String? activityTypeId, List<FwStandardModelsCheckBoxListItem>? sortBy, List<FwStandardModelsSelectedCheckBoxListItem>? orderTypes, String? customReportLayoutId, bool? isSummary, bool? includeSubHeadingsAndSubTotals, bool? includeIdColumns, String? locale, List<FwStandardModelsCheckBoxListItem>? excelfields}) WebApiModulesReportsWarehouseReportsWarehouseInboundReportWarehouseInboundReportRequest

Available on WebApiModulesReportsWarehouseReportsWarehouseInboundReportWarehouseInboundReportRequest, provided by the $WebApiModulesReportsWarehouseReportsWarehouseInboundReportWarehouseInboundReportRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override