WebApiModulesSettingsAccountingSettingsGlAccountGlAccount class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsAccountingSettingsGlAccountGlAccount({String? glAccountId, String? glAccountNo, String? glAccountDescription, String? glAccountType, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesSettingsAccountingSettingsGlAccountGlAccount.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
glAccountDescription String?
final
glAccountId String?
final
glAccountNo String?
final
glAccountType String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? glAccountId, String? glAccountNo, String? glAccountDescription, String? glAccountType, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesSettingsAccountingSettingsGlAccountGlAccount

Available on WebApiModulesSettingsAccountingSettingsGlAccountGlAccount, provided by the $WebApiModulesSettingsAccountingSettingsGlAccountGlAccountExtension extension

copyWithWrapped({Wrapped<String?>? glAccountId, Wrapped<String?>? glAccountNo, Wrapped<String?>? glAccountDescription, Wrapped<String?>? glAccountType, Wrapped<bool?>? inactive, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes}) WebApiModulesSettingsAccountingSettingsGlAccountGlAccount

Available on WebApiModulesSettingsAccountingSettingsGlAccountGlAccount, provided by the $WebApiModulesSettingsAccountingSettingsGlAccountGlAccountExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override