WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType({int? creditCardPaymentTypeId, String? description, String? chargePaymentTypeId, String? chargePaymentType, String? chargePaymentTypeType, String? refundPaymentTypeId, String? refundPaymentType, String? refundPaymentTypeType, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- chargePaymentType → String?
-
final
- chargePaymentTypeId → String?
-
final
- chargePaymentTypeType → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
- creditCardPaymentTypeId → int?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- refundPaymentType → String?
-
final
- refundPaymentTypeId → String?
-
final
- refundPaymentTypeType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{int? creditCardPaymentTypeId, String? description, String? chargePaymentTypeId, String? chargePaymentType, String? chargePaymentTypeType, String? refundPaymentTypeId, String? refundPaymentType, String? refundPaymentTypeType, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType -
Available on WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType, provided by the $WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentTypeExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? creditCardPaymentTypeId, Wrapped<String?> ? description, Wrapped<String?> ? chargePaymentTypeId, Wrapped<String?> ? chargePaymentType, Wrapped<String?> ? chargePaymentTypeType, Wrapped<String?> ? refundPaymentTypeId, Wrapped<String?> ? refundPaymentType, Wrapped<String?> ? refundPaymentTypeType, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType -
Available on WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType, provided by the $WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentTypeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsCreditCardSettingsCreditCardPaymentTypeCreditCardPaymentType instance)