WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat({int? dataExportFormatId, String? exportType, String? description, bool? active, String? exportString, bool? inactive, bool? defaultFormat, String? fileName, String? encoding, bool? crLf, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat.fromJson(Map<
String, dynamic> json) -
factory
Properties
- active → bool?
-
final
- auditNote → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
- crLf → bool?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dataExportFormatId → int?
-
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultFormat → bool?
-
final
- description → String?
-
final
- encoding → String?
-
final
- exportString → String?
-
final
- exportType → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fileName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- inactive → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{int? dataExportFormatId, String? exportType, String? description, bool? active, String? exportString, bool? inactive, bool? defaultFormat, String? fileName, String? encoding, bool? crLf, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat -
Available on WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat, provided by the $WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormatExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? dataExportFormatId, Wrapped<String?> ? exportType, Wrapped<String?> ? description, Wrapped<bool?> ? active, Wrapped<String?> ? exportString, Wrapped<bool?> ? inactive, Wrapped<bool?> ? defaultFormat, Wrapped<String?> ? fileName, Wrapped<String?> ? encoding, Wrapped<bool?> ? crLf, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat -
Available on WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat, provided by the $WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormatExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat instance)