WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat({int? dataExportFormatId, String? exportType, String? description, bool? active, String? exportString, bool? inactive, bool? defaultFormat, String? fileName, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat.fromJson(Map<String, dynamic> json)
factory

Properties

active bool?
final
auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dataExportFormatId int?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
defaultFormat bool?
final
description String?
final
exportString String?
final
exportType String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
fileName String?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? dataExportFormatId, String? exportType, String? description, bool? active, String? exportString, bool? inactive, bool? defaultFormat, String? fileName, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat

Available on WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormat, provided by the $WebApiModulesSettingsExportSettingsDataExportFormatDataExportFormatExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override