WebApiModulesSettingsFiscalMonthFiscalMonth class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsFiscalMonthFiscalMonth({String? fiscalMonthId, String? fiscalYearId, String? year, int? month, String? monthDisplay, String? fromDate, String? toDate, String? monthYear, int? workDays, String? fiscalOrder, bool? closed, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsFiscalMonthFiscalMonth.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- closed → bool?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fiscalMonthId → String?
-
final
- fiscalOrder → String?
-
final
- fiscalYearId → String?
-
final
- fromDate → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- month → int?
-
final
- monthDisplay → String?
-
final
- monthYear → String?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toDate → String?
-
final
- workDays → int?
-
final
- year → String?
-
final
Methods
-
copyWith(
{String? fiscalMonthId, String? fiscalYearId, String? year, int? month, String? monthDisplay, String? fromDate, String? toDate, String? monthYear, int? workDays, String? fiscalOrder, bool? closed, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsFiscalMonthFiscalMonth -
Available on WebApiModulesSettingsFiscalMonthFiscalMonth, provided by the $WebApiModulesSettingsFiscalMonthFiscalMonthExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsFiscalMonthFiscalMonth Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsFiscalMonthFiscalMonth instance)