WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem({int? onlineCatalogItemId, String? inventoryId, String? iCode, String? description, bool? availableOnline, String? thumbnail, String? originalShow, double? ownedQuantityPercent, double? ownedQuantity, double? owned})
-
const
-
WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- availableOnline → bool?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCode → String?
-
final
- inventoryId → String?
-
final
- onlineCatalogItemId → int?
-
final
- originalShow → String?
-
final
- owned → double?
-
final
- ownedQuantity → double?
-
final
- ownedQuantityPercent → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail → String?
-
final
Methods
-
copyWith(
{int? onlineCatalogItemId, String? inventoryId, String? iCode, String? description, bool? availableOnline, String? thumbnail, String? originalShow, double? ownedQuantityPercent, double? ownedQuantity, double? owned}) → WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem -
Available on WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem, provided by the $WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItemExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? onlineCatalogItemId, Wrapped<String?> ? inventoryId, Wrapped<String?> ? iCode, Wrapped<String?> ? description, Wrapped<bool?> ? availableOnline, Wrapped<String?> ? thumbnail, Wrapped<String?> ? originalShow, Wrapped<double?> ? ownedQuantityPercent, Wrapped<double?> ? ownedQuantity, Wrapped<double?> ? owned}) → WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem -
Available on WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem, provided by the $WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsInventorySettingsStorefrontOnlineCatalogItem instance)