WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog({String? storefrontCatalogId, String? description, bool? rental, bool? sales, String? integration, double? ownedQuantityPercent, String? locationId, String? location, String? warehouseId, String? warehouse, String? departmentId, String? department, bool? inactive, String? storefrontCatalogGridFields, String? storefrontCatalogListFields, String? storefrontItemDetailFields, String? storefrontShoppingCartFields, bool? includeZeroOwned, bool? syncRunning, String? orderTypeId, String? orderType, String? dealId, String? landingPageHtml, String? deal, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
final
- auditNote → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- deal → String?
-
final
- dealId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
- description → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- inactive → bool?
-
final
- includeZeroOwned → bool?
-
final
- integration → String?
-
final
- landingPageHtml → String?
-
final
- location → String?
-
final
- locationId → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- orderType → String?
-
final
- orderTypeId → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- ownedQuantityPercent → double?
-
final
- recordTitle → String?
-
final
- rental → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sales → bool?
-
final
- storefrontCatalogGridFields → String?
-
final
- storefrontCatalogId → String?
-
final
- storefrontCatalogListFields → String?
-
final
- storefrontItemDetailFields → String?
-
final
- storefrontShoppingCartFields → String?
-
final
- syncRunning → bool?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
- warehouse → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? storefrontCatalogId, String? description, bool? rental, bool? sales, String? integration, double? ownedQuantityPercent, String? locationId, String? location, String? warehouseId, String? warehouse, String? departmentId, String? department, bool? inactive, String? storefrontCatalogGridFields, String? storefrontCatalogListFields, String? storefrontItemDetailFields, String? storefrontShoppingCartFields, bool? includeZeroOwned, bool? syncRunning, String? orderTypeId, String? orderType, String? dealId, String? landingPageHtml, String? deal, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog -
Available on WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog, provided by the $WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalogExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? storefrontCatalogId, Wrapped<String?> ? description, Wrapped<bool?> ? rental, Wrapped<bool?> ? sales, Wrapped<String?> ? integration, Wrapped<double?> ? ownedQuantityPercent, Wrapped<String?> ? locationId, Wrapped<String?> ? location, Wrapped<String?> ? warehouseId, Wrapped<String?> ? warehouse, Wrapped<String?> ? departmentId, Wrapped<String?> ? department, Wrapped<bool?> ? inactive, Wrapped<String?> ? storefrontCatalogGridFields, Wrapped<String?> ? storefrontCatalogListFields, Wrapped<String?> ? storefrontItemDetailFields, Wrapped<String?> ? storefrontShoppingCartFields, Wrapped<bool?> ? includeZeroOwned, Wrapped<bool?> ? syncRunning, Wrapped<String?> ? orderTypeId, Wrapped<String?> ? orderType, Wrapped<String?> ? dealId, Wrapped<String?> ? landingPageHtml, Wrapped<String?> ? deal, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog -
Available on WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog, provided by the $WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalogExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsInventorySettingsStorefrontStorefrontCatalog instance)