WebApiModulesSettingsOrderSettingsOrderTypeOrderType class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsOrderSettingsOrderTypeOrderType({String? orderTypeId, String? orderType, String? ordType, String? defaultPickTime, String? defaultFromTime, String? defaultToTime, String? dailyScheduleDefaultStartTime, String? dailyScheduleDefaultStopTime, bool? isMasterSubOrderType, bool? combineActivityTabs, bool? defaultManualSort, String? determineQuantitiesToBillBasedOn, bool? useEstimatedDatesForBilling, bool? allowNesting, bool? rentalShowICode, int? rentalICodeWidth, bool? rentalShowDescription, int? rentalDescriptionWidth, bool? rentalShowPickDate, bool? rentalShowPickTime, bool? rentalShowFromDate, bool? rentalShowFromTime, bool? rentalShowToDate, bool? rentalShowToTime, bool? rentalShowBillablePeriods, bool? rentalShowEpisodes, bool? rentalShowSubQuantity, bool? rentalShowAvailableQuantity, bool? rentalShowConflictDate, bool? rentalShowAvailableQuantityRegion, bool? rentalShowConflictDateRegion, bool? rentalShowAvailableQuantityAllWarehouses, bool? rentalShowConflictDateAllWarehouses, bool? rentalShowReservedItems, bool? rentalShowConsignmentQuantity, bool? rentalShowConsignmentAvailableQuantity, bool? rentalShowConsignmentConflictDate, bool? rentalShowRate, bool? rentalShowDaysPerWeek, bool? rentalShowPremiumPercent, bool? rentalShowUnit, bool? rentalShowCost, bool? rentalShowPeriodCostExtended, bool? rentalShowDiscountPercent, bool? rentalShowMarkupPercent, bool? rentalShowMarginPercent, bool? rentalShowUnitDiscountAmount, bool? rentalShowUnitExtended, bool? rentalShowWeeklyDiscountAmount, bool? rentalShowWeeklyExtended, bool? rentalShowEpisodeExtended, bool? rentalShowEpisodeDiscountAmount, bool? rentalShowMonthlyDiscountAmount, bool? rentalShowMonthlyExtended, bool? rentalShowPeriodDiscountAmount, bool? rentalShowPeriodExtended, bool? rentalShowWarehouse, bool? rentalShowTaxable, bool? rentalShowNotes, bool? rentalShowReturnToWarehouse, bool? rentalShowConsignor, String? rentalDateStamp, bool? allowRoundTripRentals, bool? salesShowICode, int? salesICodeWidth, bool? salesShowDescription, int? salesDescriptionWidth, bool? salesShowManufacturerPartNumber, int? salesManufacturerPartNumberWidth, bool? salesShowPickDate, bool? salesShowPickTime, bool? salesShowFromDate, bool? salesShowFromTime, bool? salesShowSubQuantity, bool? salesShowCost, bool? salesShowRate, bool? salesShowAvailableQuantity, bool? salesShowConflictDate, bool? salesShowAvailableQuantityRegion, bool? salesShowConflictDateRegion, bool? salesShowAvailableQuantityAllWarehouses, bool? salesShowConflictDateAllWarehouses, bool? salesShowMarkupPercent, bool? salesShowMarginPercent, bool? salesShowUnit, bool? salesShowPeriodCostExtended, bool? salesShowDiscountPercent, bool? salesShowUnitDiscountAmount, bool? salesShowUnitExtended, bool? salesShowPeriodDiscountAmount, bool? salesShowPeriodExtended, bool? salesShowVariancePercent, bool? salesShowVarianceExtended, bool? salesShowWarehouse, bool? salesShowTaxable, bool? salesShowNotes, bool? salesShowConsignor, String? salesDateStamp, String? salesInventoryPrice, String? salesInventoryCost, bool? facilityShowDescription, int? facilityDescriptionWidth, bool? facilityShowFromDate, bool? facilityShowFromTime, bool? facilityShowToDate, bool? facilityShowToTime, bool? facilityShowWeeksAndDays, bool? facilityShowMonthsAndDays, bool? facilityShowBillablePeriods, bool? facilityShowRate, bool? facilityShowDaysPerWeek, bool? facilityShowDiscountPercent, bool? facilityShowSplit, bool? facilityShowUnit, bool? facilityShowUnitDiscountAmount, bool? facilityShowUnitExtended, bool? facilityShowWeeklyDiscountAmount, bool? facilityShowWeeklyExtended, bool? facilityShowMonthlyDiscountAmount, bool? facilityShowMonthlyExtended, bool? facilityShowPeriodDiscountAmount, bool? facilityShowPeriodExtended, bool? facilityShowTaxable, bool? facilityShowNotes, String? facilityDateStamp, String? facilityDescription, bool? vehicleShowDescription, int? vehicleDescriptionWidth, bool? vehicleShowVehicleNumber, bool? vehicleShowPickDate, bool? vehicleShowPickTime, bool? vehicleShowFromDate, bool? vehicleShowFromTime, bool? vehicleShowToDate, bool? vehicleShowToTime, bool? vehicleShowBillablePeriods, bool? vehicleShowSubQuantity, bool? vehicleShowAvailableQuantity, bool? vehicleShowConflictDate, bool? vehicleShowUnit, bool? vehicleShowRate, bool? vehicleShowDaysPerWeek, bool? vehicleShowCost, bool? vehicleShowWeeklyCostExtended, bool? vehicleShowMonthlyCostExtended, bool? vehicleShowPeriodCostExtended, bool? vehicleShowDiscountPercent, bool? vehicleShowUnitDiscountAmount, bool? vehicleShowUnitExtended, bool? vehicleShowWeeklyDiscountAmount, bool? vehicleShowWeeklyExtended, bool? vehicleShowMonthlyDiscountAmount, bool? vehicleShowMonthlyExtended, bool? vehicleShowPeriodDiscountAmount, bool? vehicleShowPeriodExtended, bool? vehicleShowWarehouse, bool? vehicleShowReturnToWarehouse, bool? vehicleShowTaxable, bool? vehicleShowNotes, String? vehicleDateStamp, bool? laborShowICode, int? laborICodeWidth, bool? laborShowDescription, int? laborDescriptionWidth, bool? laborShowOrderActivity, bool? laborShowCrewName, bool? laborShowFromDate, bool? laborShowFromTime, bool? laborShowToDate, bool? laborShowToTime, bool? laborShowBillablePeriods, bool? laborShowHours, bool? laborShowSubQuantity, bool? laborShowCost, bool? laborShowRate, bool? laborShowPeriodCostExtended, bool? laborShowDiscountPercent, bool? laborShowUnit, bool? laborShowUnitDiscountAmount, bool? laborShowUnitExtended, bool? laborShowWeeklyDiscountAmount, bool? laborShowWeeklyExtended, bool? laborShowMonthlyDiscountAmount, bool? laborShowMonthlyExtended, bool? laborShowPeriodDiscountAmount, bool? laborShowPeriodExtended, bool? laborShowWarehouse, bool? laborShowTaxable, bool? laborShowNotes, String? laborDateStamp, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, bool? miscShowICode, int? miscICodeWidth, bool? miscShowDescription, int? miscDescriptionWidth, bool? miscShowFromDate, bool? miscShowFromTime, bool? miscShowToDate, bool? miscShowToTime, bool? miscShowBillablePeriods, bool? miscShowSubQuantity, bool? miscShowWeeksAndDays, bool? miscShowMonthsAndDays, bool? miscShowUnit, bool? miscShowRate, bool? miscShowCost, bool? miscShowPeriodCostExtended, bool? miscShowDiscountPercent, bool? miscShowUnitDiscountAmount, bool? miscShowUnitExtended, bool? miscShowWeeklyDiscountAmount, bool? miscShowWeeklyExtended, bool? miscShowMonthlyDiscountAmount, bool? miscShowMonthlyExtended, bool? miscShowPeriodDiscountAmount, bool? miscShowPeriodExtended, bool? miscShowWarehouse, bool? miscShowTaxable, bool? miscShowNotes, String? miscDateStamp, bool? rentalSaleShowBarCode, bool? rentalSaleShowSerialNumber, bool? rentalSaleShowICode, int? rentalSaleICodeWidth, bool? rentalSaleShowDescription, int? rentalSaleDescriptionWidth, bool? rentalSaleShowPickDate, bool? rentalSaleShowPickTime, bool? rentalSaleShowAvailableQuantity, bool? rentalSaleShowConflictDate, bool? rentalSaleShowUnit, bool? rentalSaleShowRate, bool? rentalSaleShowCost, bool? rentalSaleShowPeriodCostExtended, bool? rentalSaleShowDiscountPercent, bool? rentalSaleShowUnitDiscountAmount, bool? rentalSaleShowUnitExtended, bool? rentalSaleShowPeriodDiscountAmount, bool? rentalSaleShowPeriodExtended, bool? rentalSaleShowWarehouse, bool? rentalSaleShowTaxable, bool? rentalSaleShowNotes, String? rentalSaleDateStamp, bool? lossAndDamageShowOrderNumber, bool? lossAndDamageShowRepairOrderNumber, bool? lossAndDamageShowBarCode, bool? lossAndDamageShowSerialNumber, bool? lossAndDamageShowICode, int? lossAndDamageICodeWidth, bool? lossAndDamageShowDescription, int? lossAndDamageDescriptionWidth, bool? lossAndDamageShowUnit, bool? lossAndDamageShowRate, bool? lossAndDamageShowCost, bool? lossAndDamageShowDiscountPercent, bool? lossAndDamageShowUnitDiscountAmount, bool? lossAndDamageShowUnitExtended, bool? lossAndDamageShowPeriodDiscountAmount, bool? lossAndDamageShowPeriodExtended, bool? lossAndDamageShowWarehouse, bool? lossAndDamageShowTaxable, bool? lossAndDamageShowNotes, String? lossAndDamageDateStamp, bool? addInstallationAndStrikeFee, String? installationAndStrikeFeeRateId, String? installationAndStrikeFeeICode, String? installationAndStrikeFeeDescription, double? installationAndStrikeFeePercent, String? installationAndStrikeFeeBasedOn, bool? addManagementAndServiceFee, String? managementAndServiceFeeRateId, String? managementAndServiceFeeICode, String? managementAndServiceFeeDescription, double? managementAndServiceFeePercent, String? managementAndServiceFeeBasedOn, String? defaultRentalSalePrice, bool? quikPayDiscount, String? quikPayDiscountType, int? quikPayDiscountDays, double? quikPayDiscountPercent, bool? quikPayDiscountExcludeSubs, bool? quikConfirmDiscount, double? quikConfirmDiscountPercent, int? quikConfirmDiscountDays, bool? disableCostGl, bool? excludeFromTopSalesDashboard, bool? separatePackageOnQuoteOrder, double? orderby, bool? subAllShortagesSubMiscellaneous, bool? inactive, List<
String> ? combinedShowFields, List<String> ? rentalShowFields, List<String> ? salesShowFields, List<String> ? miscShowFields, List<String> ? laborShowFields, List<String> ? rentalSaleShowFields, List<String> ? lossAndDamageShowFields, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsOrderSettingsOrderTypeOrderType.fromJson(Map<
String, dynamic> json) -
factory
Properties
- addInstallationAndStrikeFee → bool?
-
final
- addManagementAndServiceFee → bool?
-
final
- allowNesting → bool?
-
final
- allowRoundTripRentals → bool?
-
final
- auditNote → String?
-
final
- break1Paid → bool?
-
final
- break2Paid → bool?
-
final
- break3Paid → bool?
-
final
- combineActivityTabs → bool?
-
final
-
combinedShowFields
→ List<
String> ? -
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dailyScheduleDefaultStartTime → String?
-
final
- dailyScheduleDefaultStopTime → String?
-
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultFromTime → String?
-
final
- defaultManualSort → bool?
-
final
- defaultPickTime → String?
-
final
- defaultRentalSalePrice → String?
-
final
- defaultToTime → String?
-
final
- determineQuantitiesToBillBasedOn → String?
-
final
- disableCostGl → bool?
-
final
- excludeFromTopSalesDashboard → bool?
-
final
- facilityDateStamp → String?
-
final
- facilityDescription → String?
-
final
- facilityDescriptionWidth → int?
-
final
- facilityShowBillablePeriods → bool?
-
final
- facilityShowDaysPerWeek → bool?
-
final
- facilityShowDescription → bool?
-
final
- facilityShowDiscountPercent → bool?
-
final
- facilityShowFromDate → bool?
-
final
- facilityShowFromTime → bool?
-
final
- facilityShowMonthlyDiscountAmount → bool?
-
final
- facilityShowMonthlyExtended → bool?
-
final
- facilityShowMonthsAndDays → bool?
-
final
- facilityShowNotes → bool?
-
final
- facilityShowPeriodDiscountAmount → bool?
-
final
- facilityShowPeriodExtended → bool?
-
final
- facilityShowRate → bool?
-
final
- facilityShowSplit → bool?
-
final
- facilityShowTaxable → bool?
-
final
- facilityShowToDate → bool?
-
final
- facilityShowToTime → bool?
-
final
- facilityShowUnit → bool?
-
final
- facilityShowUnitDiscountAmount → bool?
-
final
- facilityShowUnitExtended → bool?
-
final
- facilityShowWeeklyDiscountAmount → bool?
-
final
- facilityShowWeeklyExtended → bool?
-
final
- facilityShowWeeksAndDays → bool?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hideCrewBreaks → bool?
-
final
- inactive → bool?
-
final
- installationAndStrikeFeeBasedOn → String?
-
final
- installationAndStrikeFeeDescription → String?
-
final
- installationAndStrikeFeeICode → String?
-
final
- installationAndStrikeFeePercent → double?
-
final
- installationAndStrikeFeeRateId → String?
-
final
- isMasterSubOrderType → bool?
-
final
- laborDateStamp → String?
-
final
- laborDescriptionWidth → int?
-
final
- laborICodeWidth → int?
-
final
- laborShowBillablePeriods → bool?
-
final
- laborShowCost → bool?
-
final
- laborShowCrewName → bool?
-
final
- laborShowDescription → bool?
-
final
- laborShowDiscountPercent → bool?
-
final
-
laborShowFields
→ List<
String> ? -
final
- laborShowFromDate → bool?
-
final
- laborShowFromTime → bool?
-
final
- laborShowHours → bool?
-
final
- laborShowICode → bool?
-
final
- laborShowMonthlyDiscountAmount → bool?
-
final
- laborShowMonthlyExtended → bool?
-
final
- laborShowNotes → bool?
-
final
- laborShowOrderActivity → bool?
-
final
- laborShowPeriodCostExtended → bool?
-
final
- laborShowPeriodDiscountAmount → bool?
-
final
- laborShowPeriodExtended → bool?
-
final
- laborShowRate → bool?
-
final
- laborShowSubQuantity → bool?
-
final
- laborShowTaxable → bool?
-
final
- laborShowToDate → bool?
-
final
- laborShowToTime → bool?
-
final
- laborShowUnit → bool?
-
final
- laborShowUnitDiscountAmount → bool?
-
final
- laborShowUnitExtended → bool?
-
final
- laborShowWarehouse → bool?
-
final
- laborShowWeeklyDiscountAmount → bool?
-
final
- laborShowWeeklyExtended → bool?
-
final
- lossAndDamageDateStamp → String?
-
final
- lossAndDamageDescriptionWidth → int?
-
final
- lossAndDamageICodeWidth → int?
-
final
- lossAndDamageShowBarCode → bool?
-
final
- lossAndDamageShowCost → bool?
-
final
- lossAndDamageShowDescription → bool?
-
final
- lossAndDamageShowDiscountPercent → bool?
-
final
-
lossAndDamageShowFields
→ List<
String> ? -
final
- lossAndDamageShowICode → bool?
-
final
- lossAndDamageShowNotes → bool?
-
final
- lossAndDamageShowOrderNumber → bool?
-
final
- lossAndDamageShowPeriodDiscountAmount → bool?
-
final
- lossAndDamageShowPeriodExtended → bool?
-
final
- lossAndDamageShowRate → bool?
-
final
- lossAndDamageShowRepairOrderNumber → bool?
-
final
- lossAndDamageShowSerialNumber → bool?
-
final
- lossAndDamageShowTaxable → bool?
-
final
- lossAndDamageShowUnit → bool?
-
final
- lossAndDamageShowUnitDiscountAmount → bool?
-
final
- lossAndDamageShowUnitExtended → bool?
-
final
- lossAndDamageShowWarehouse → bool?
-
final
- managementAndServiceFeeBasedOn → String?
-
final
- managementAndServiceFeeDescription → String?
-
final
- managementAndServiceFeeICode → String?
-
final
- managementAndServiceFeePercent → double?
-
final
- managementAndServiceFeeRateId → String?
-
final
- miscDateStamp → String?
-
final
- miscDescriptionWidth → int?
-
final
- miscICodeWidth → int?
-
final
- miscShowBillablePeriods → bool?
-
final
- miscShowCost → bool?
-
final
- miscShowDescription → bool?
-
final
- miscShowDiscountPercent → bool?
-
final
-
miscShowFields
→ List<
String> ? -
final
- miscShowFromDate → bool?
-
final
- miscShowFromTime → bool?
-
final
- miscShowICode → bool?
-
final
- miscShowMonthlyDiscountAmount → bool?
-
final
- miscShowMonthlyExtended → bool?
-
final
- miscShowMonthsAndDays → bool?
-
final
- miscShowNotes → bool?
-
final
- miscShowPeriodCostExtended → bool?
-
final
- miscShowPeriodDiscountAmount → bool?
-
final
- miscShowPeriodExtended → bool?
-
final
- miscShowRate → bool?
-
final
- miscShowSubQuantity → bool?
-
final
- miscShowTaxable → bool?
-
final
- miscShowToDate → bool?
-
final
- miscShowToTime → bool?
-
final
- miscShowUnit → bool?
-
final
- miscShowUnitDiscountAmount → bool?
-
final
- miscShowUnitExtended → bool?
-
final
- miscShowWarehouse → bool?
-
final
- miscShowWeeklyDiscountAmount → bool?
-
final
- miscShowWeeklyExtended → bool?
-
final
- miscShowWeeksAndDays → bool?
-
final
- orderby → double?
-
final
- orderType → String?
-
final
- orderTypeId → String?
-
final
- ordType → String?
-
final
- quikConfirmDiscount → bool?
-
final
- quikConfirmDiscountDays → int?
-
final
- quikConfirmDiscountPercent → double?
-
final
- quikPayDiscount → bool?
-
final
- quikPayDiscountDays → int?
-
final
- quikPayDiscountExcludeSubs → bool?
-
final
- quikPayDiscountPercent → double?
-
final
- quikPayDiscountType → String?
-
final
- recordTitle → String?
-
final
- rentalDateStamp → String?
-
final
- rentalDescriptionWidth → int?
-
final
- rentalICodeWidth → int?
-
final
- rentalSaleDateStamp → String?
-
final
- rentalSaleDescriptionWidth → int?
-
final
- rentalSaleICodeWidth → int?
-
final
- rentalSaleShowAvailableQuantity → bool?
-
final
- rentalSaleShowBarCode → bool?
-
final
- rentalSaleShowConflictDate → bool?
-
final
- rentalSaleShowCost → bool?
-
final
- rentalSaleShowDescription → bool?
-
final
- rentalSaleShowDiscountPercent → bool?
-
final
-
rentalSaleShowFields
→ List<
String> ? -
final
- rentalSaleShowICode → bool?
-
final
- rentalSaleShowNotes → bool?
-
final
- rentalSaleShowPeriodCostExtended → bool?
-
final
- rentalSaleShowPeriodDiscountAmount → bool?
-
final
- rentalSaleShowPeriodExtended → bool?
-
final
- rentalSaleShowPickDate → bool?
-
final
- rentalSaleShowPickTime → bool?
-
final
- rentalSaleShowRate → bool?
-
final
- rentalSaleShowSerialNumber → bool?
-
final
- rentalSaleShowTaxable → bool?
-
final
- rentalSaleShowUnit → bool?
-
final
- rentalSaleShowUnitDiscountAmount → bool?
-
final
- rentalSaleShowUnitExtended → bool?
-
final
- rentalSaleShowWarehouse → bool?
-
final
- rentalShowAvailableQuantity → bool?
-
final
- rentalShowAvailableQuantityAllWarehouses → bool?
-
final
- rentalShowAvailableQuantityRegion → bool?
-
final
- rentalShowBillablePeriods → bool?
-
final
- rentalShowConflictDate → bool?
-
final
- rentalShowConflictDateAllWarehouses → bool?
-
final
- rentalShowConflictDateRegion → bool?
-
final
- rentalShowConsignmentAvailableQuantity → bool?
-
final
- rentalShowConsignmentConflictDate → bool?
-
final
- rentalShowConsignmentQuantity → bool?
-
final
- rentalShowConsignor → bool?
-
final
- rentalShowCost → bool?
-
final
- rentalShowDaysPerWeek → bool?
-
final
- rentalShowDescription → bool?
-
final
- rentalShowDiscountPercent → bool?
-
final
- rentalShowEpisodeDiscountAmount → bool?
-
final
- rentalShowEpisodeExtended → bool?
-
final
- rentalShowEpisodes → bool?
-
final
-
rentalShowFields
→ List<
String> ? -
final
- rentalShowFromDate → bool?
-
final
- rentalShowFromTime → bool?
-
final
- rentalShowICode → bool?
-
final
- rentalShowMarginPercent → bool?
-
final
- rentalShowMarkupPercent → bool?
-
final
- rentalShowMonthlyDiscountAmount → bool?
-
final
- rentalShowMonthlyExtended → bool?
-
final
- rentalShowNotes → bool?
-
final
- rentalShowPeriodCostExtended → bool?
-
final
- rentalShowPeriodDiscountAmount → bool?
-
final
- rentalShowPeriodExtended → bool?
-
final
- rentalShowPickDate → bool?
-
final
- rentalShowPickTime → bool?
-
final
- rentalShowPremiumPercent → bool?
-
final
- rentalShowRate → bool?
-
final
- rentalShowReservedItems → bool?
-
final
- rentalShowReturnToWarehouse → bool?
-
final
- rentalShowSubQuantity → bool?
-
final
- rentalShowTaxable → bool?
-
final
- rentalShowToDate → bool?
-
final
- rentalShowToTime → bool?
-
final
- rentalShowUnit → bool?
-
final
- rentalShowUnitDiscountAmount → bool?
-
final
- rentalShowUnitExtended → bool?
-
final
- rentalShowWarehouse → bool?
-
final
- rentalShowWeeklyDiscountAmount → bool?
-
final
- rentalShowWeeklyExtended → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesDateStamp → String?
-
final
- salesDescriptionWidth → int?
-
final
- salesICodeWidth → int?
-
final
- salesInventoryCost → String?
-
final
- salesInventoryPrice → String?
-
final
- salesManufacturerPartNumberWidth → int?
-
final
- salesShowAvailableQuantity → bool?
-
final
- salesShowAvailableQuantityAllWarehouses → bool?
-
final
- salesShowAvailableQuantityRegion → bool?
-
final
- salesShowConflictDate → bool?
-
final
- salesShowConflictDateAllWarehouses → bool?
-
final
- salesShowConflictDateRegion → bool?
-
final
- salesShowConsignor → bool?
-
final
- salesShowCost → bool?
-
final
- salesShowDescription → bool?
-
final
- salesShowDiscountPercent → bool?
-
final
-
salesShowFields
→ List<
String> ? -
final
- salesShowFromDate → bool?
-
final
- salesShowFromTime → bool?
-
final
- salesShowICode → bool?
-
final
- salesShowManufacturerPartNumber → bool?
-
final
- salesShowMarginPercent → bool?
-
final
- salesShowMarkupPercent → bool?
-
final
- salesShowNotes → bool?
-
final
- salesShowPeriodCostExtended → bool?
-
final
- salesShowPeriodDiscountAmount → bool?
-
final
- salesShowPeriodExtended → bool?
-
final
- salesShowPickDate → bool?
-
final
- salesShowPickTime → bool?
-
final
- salesShowRate → bool?
-
final
- salesShowSubQuantity → bool?
-
final
- salesShowTaxable → bool?
-
final
- salesShowUnit → bool?
-
final
- salesShowUnitDiscountAmount → bool?
-
final
- salesShowUnitExtended → bool?
-
final
- salesShowVarianceExtended → bool?
-
final
- salesShowVariancePercent → bool?
-
final
- salesShowWarehouse → bool?
-
final
- separatePackageOnQuoteOrder → bool?
-
final
- subAllShortagesSubMiscellaneous → bool?
-
final
- useEstimatedDatesForBilling → bool?
-
final
- vehicleDateStamp → String?
-
final
- vehicleDescriptionWidth → int?
-
final
- vehicleShowAvailableQuantity → bool?
-
final
- vehicleShowBillablePeriods → bool?
-
final
- vehicleShowConflictDate → bool?
-
final
- vehicleShowCost → bool?
-
final
- vehicleShowDaysPerWeek → bool?
-
final
- vehicleShowDescription → bool?
-
final
- vehicleShowDiscountPercent → bool?
-
final
- vehicleShowFromDate → bool?
-
final
- vehicleShowFromTime → bool?
-
final
- vehicleShowMonthlyCostExtended → bool?
-
final
- vehicleShowMonthlyDiscountAmount → bool?
-
final
- vehicleShowMonthlyExtended → bool?
-
final
- vehicleShowNotes → bool?
-
final
- vehicleShowPeriodCostExtended → bool?
-
final
- vehicleShowPeriodDiscountAmount → bool?
-
final
- vehicleShowPeriodExtended → bool?
-
final
- vehicleShowPickDate → bool?
-
final
- vehicleShowPickTime → bool?
-
final
- vehicleShowRate → bool?
-
final
- vehicleShowReturnToWarehouse → bool?
-
final
- vehicleShowSubQuantity → bool?
-
final
- vehicleShowTaxable → bool?
-
final
- vehicleShowToDate → bool?
-
final
- vehicleShowToTime → bool?
-
final
- vehicleShowUnit → bool?
-
final
- vehicleShowUnitDiscountAmount → bool?
-
final
- vehicleShowUnitExtended → bool?
-
final
- vehicleShowVehicleNumber → bool?
-
final
- vehicleShowWarehouse → bool?
-
final
- vehicleShowWeeklyCostExtended → bool?
-
final
- vehicleShowWeeklyDiscountAmount → bool?
-
final
- vehicleShowWeeklyExtended → bool?
-
final
Methods
-
copyWith(
{String? orderTypeId, String? orderType, String? ordType, String? defaultPickTime, String? defaultFromTime, String? defaultToTime, String? dailyScheduleDefaultStartTime, String? dailyScheduleDefaultStopTime, bool? isMasterSubOrderType, bool? combineActivityTabs, bool? defaultManualSort, String? determineQuantitiesToBillBasedOn, bool? useEstimatedDatesForBilling, bool? allowNesting, bool? rentalShowICode, int? rentalICodeWidth, bool? rentalShowDescription, int? rentalDescriptionWidth, bool? rentalShowPickDate, bool? rentalShowPickTime, bool? rentalShowFromDate, bool? rentalShowFromTime, bool? rentalShowToDate, bool? rentalShowToTime, bool? rentalShowBillablePeriods, bool? rentalShowEpisodes, bool? rentalShowSubQuantity, bool? rentalShowAvailableQuantity, bool? rentalShowConflictDate, bool? rentalShowAvailableQuantityRegion, bool? rentalShowConflictDateRegion, bool? rentalShowAvailableQuantityAllWarehouses, bool? rentalShowConflictDateAllWarehouses, bool? rentalShowReservedItems, bool? rentalShowConsignmentQuantity, bool? rentalShowConsignmentAvailableQuantity, bool? rentalShowConsignmentConflictDate, bool? rentalShowRate, bool? rentalShowDaysPerWeek, bool? rentalShowPremiumPercent, bool? rentalShowUnit, bool? rentalShowCost, bool? rentalShowPeriodCostExtended, bool? rentalShowDiscountPercent, bool? rentalShowMarkupPercent, bool? rentalShowMarginPercent, bool? rentalShowUnitDiscountAmount, bool? rentalShowUnitExtended, bool? rentalShowWeeklyDiscountAmount, bool? rentalShowWeeklyExtended, bool? rentalShowEpisodeExtended, bool? rentalShowEpisodeDiscountAmount, bool? rentalShowMonthlyDiscountAmount, bool? rentalShowMonthlyExtended, bool? rentalShowPeriodDiscountAmount, bool? rentalShowPeriodExtended, bool? rentalShowWarehouse, bool? rentalShowTaxable, bool? rentalShowNotes, bool? rentalShowReturnToWarehouse, bool? rentalShowConsignor, String? rentalDateStamp, bool? allowRoundTripRentals, bool? salesShowICode, int? salesICodeWidth, bool? salesShowDescription, int? salesDescriptionWidth, bool? salesShowManufacturerPartNumber, int? salesManufacturerPartNumberWidth, bool? salesShowPickDate, bool? salesShowPickTime, bool? salesShowFromDate, bool? salesShowFromTime, bool? salesShowSubQuantity, bool? salesShowCost, bool? salesShowRate, bool? salesShowAvailableQuantity, bool? salesShowConflictDate, bool? salesShowAvailableQuantityRegion, bool? salesShowConflictDateRegion, bool? salesShowAvailableQuantityAllWarehouses, bool? salesShowConflictDateAllWarehouses, bool? salesShowMarkupPercent, bool? salesShowMarginPercent, bool? salesShowUnit, bool? salesShowPeriodCostExtended, bool? salesShowDiscountPercent, bool? salesShowUnitDiscountAmount, bool? salesShowUnitExtended, bool? salesShowPeriodDiscountAmount, bool? salesShowPeriodExtended, bool? salesShowVariancePercent, bool? salesShowVarianceExtended, bool? salesShowWarehouse, bool? salesShowTaxable, bool? salesShowNotes, bool? salesShowConsignor, String? salesDateStamp, String? salesInventoryPrice, String? salesInventoryCost, bool? facilityShowDescription, int? facilityDescriptionWidth, bool? facilityShowFromDate, bool? facilityShowFromTime, bool? facilityShowToDate, bool? facilityShowToTime, bool? facilityShowWeeksAndDays, bool? facilityShowMonthsAndDays, bool? facilityShowBillablePeriods, bool? facilityShowRate, bool? facilityShowDaysPerWeek, bool? facilityShowDiscountPercent, bool? facilityShowSplit, bool? facilityShowUnit, bool? facilityShowUnitDiscountAmount, bool? facilityShowUnitExtended, bool? facilityShowWeeklyDiscountAmount, bool? facilityShowWeeklyExtended, bool? facilityShowMonthlyDiscountAmount, bool? facilityShowMonthlyExtended, bool? facilityShowPeriodDiscountAmount, bool? facilityShowPeriodExtended, bool? facilityShowTaxable, bool? facilityShowNotes, String? facilityDateStamp, String? facilityDescription, bool? vehicleShowDescription, int? vehicleDescriptionWidth, bool? vehicleShowVehicleNumber, bool? vehicleShowPickDate, bool? vehicleShowPickTime, bool? vehicleShowFromDate, bool? vehicleShowFromTime, bool? vehicleShowToDate, bool? vehicleShowToTime, bool? vehicleShowBillablePeriods, bool? vehicleShowSubQuantity, bool? vehicleShowAvailableQuantity, bool? vehicleShowConflictDate, bool? vehicleShowUnit, bool? vehicleShowRate, bool? vehicleShowDaysPerWeek, bool? vehicleShowCost, bool? vehicleShowWeeklyCostExtended, bool? vehicleShowMonthlyCostExtended, bool? vehicleShowPeriodCostExtended, bool? vehicleShowDiscountPercent, bool? vehicleShowUnitDiscountAmount, bool? vehicleShowUnitExtended, bool? vehicleShowWeeklyDiscountAmount, bool? vehicleShowWeeklyExtended, bool? vehicleShowMonthlyDiscountAmount, bool? vehicleShowMonthlyExtended, bool? vehicleShowPeriodDiscountAmount, bool? vehicleShowPeriodExtended, bool? vehicleShowWarehouse, bool? vehicleShowReturnToWarehouse, bool? vehicleShowTaxable, bool? vehicleShowNotes, String? vehicleDateStamp, bool? laborShowICode, int? laborICodeWidth, bool? laborShowDescription, int? laborDescriptionWidth, bool? laborShowOrderActivity, bool? laborShowCrewName, bool? laborShowFromDate, bool? laborShowFromTime, bool? laborShowToDate, bool? laborShowToTime, bool? laborShowBillablePeriods, bool? laborShowHours, bool? laborShowSubQuantity, bool? laborShowCost, bool? laborShowRate, bool? laborShowPeriodCostExtended, bool? laborShowDiscountPercent, bool? laborShowUnit, bool? laborShowUnitDiscountAmount, bool? laborShowUnitExtended, bool? laborShowWeeklyDiscountAmount, bool? laborShowWeeklyExtended, bool? laborShowMonthlyDiscountAmount, bool? laborShowMonthlyExtended, bool? laborShowPeriodDiscountAmount, bool? laborShowPeriodExtended, bool? laborShowWarehouse, bool? laborShowTaxable, bool? laborShowNotes, String? laborDateStamp, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, bool? miscShowICode, int? miscICodeWidth, bool? miscShowDescription, int? miscDescriptionWidth, bool? miscShowFromDate, bool? miscShowFromTime, bool? miscShowToDate, bool? miscShowToTime, bool? miscShowBillablePeriods, bool? miscShowSubQuantity, bool? miscShowWeeksAndDays, bool? miscShowMonthsAndDays, bool? miscShowUnit, bool? miscShowRate, bool? miscShowCost, bool? miscShowPeriodCostExtended, bool? miscShowDiscountPercent, bool? miscShowUnitDiscountAmount, bool? miscShowUnitExtended, bool? miscShowWeeklyDiscountAmount, bool? miscShowWeeklyExtended, bool? miscShowMonthlyDiscountAmount, bool? miscShowMonthlyExtended, bool? miscShowPeriodDiscountAmount, bool? miscShowPeriodExtended, bool? miscShowWarehouse, bool? miscShowTaxable, bool? miscShowNotes, String? miscDateStamp, bool? rentalSaleShowBarCode, bool? rentalSaleShowSerialNumber, bool? rentalSaleShowICode, int? rentalSaleICodeWidth, bool? rentalSaleShowDescription, int? rentalSaleDescriptionWidth, bool? rentalSaleShowPickDate, bool? rentalSaleShowPickTime, bool? rentalSaleShowAvailableQuantity, bool? rentalSaleShowConflictDate, bool? rentalSaleShowUnit, bool? rentalSaleShowRate, bool? rentalSaleShowCost, bool? rentalSaleShowPeriodCostExtended, bool? rentalSaleShowDiscountPercent, bool? rentalSaleShowUnitDiscountAmount, bool? rentalSaleShowUnitExtended, bool? rentalSaleShowPeriodDiscountAmount, bool? rentalSaleShowPeriodExtended, bool? rentalSaleShowWarehouse, bool? rentalSaleShowTaxable, bool? rentalSaleShowNotes, String? rentalSaleDateStamp, bool? lossAndDamageShowOrderNumber, bool? lossAndDamageShowRepairOrderNumber, bool? lossAndDamageShowBarCode, bool? lossAndDamageShowSerialNumber, bool? lossAndDamageShowICode, int? lossAndDamageICodeWidth, bool? lossAndDamageShowDescription, int? lossAndDamageDescriptionWidth, bool? lossAndDamageShowUnit, bool? lossAndDamageShowRate, bool? lossAndDamageShowCost, bool? lossAndDamageShowDiscountPercent, bool? lossAndDamageShowUnitDiscountAmount, bool? lossAndDamageShowUnitExtended, bool? lossAndDamageShowPeriodDiscountAmount, bool? lossAndDamageShowPeriodExtended, bool? lossAndDamageShowWarehouse, bool? lossAndDamageShowTaxable, bool? lossAndDamageShowNotes, String? lossAndDamageDateStamp, bool? addInstallationAndStrikeFee, String? installationAndStrikeFeeRateId, String? installationAndStrikeFeeICode, String? installationAndStrikeFeeDescription, double? installationAndStrikeFeePercent, String? installationAndStrikeFeeBasedOn, bool? addManagementAndServiceFee, String? managementAndServiceFeeRateId, String? managementAndServiceFeeICode, String? managementAndServiceFeeDescription, double? managementAndServiceFeePercent, String? managementAndServiceFeeBasedOn, String? defaultRentalSalePrice, bool? quikPayDiscount, String? quikPayDiscountType, int? quikPayDiscountDays, double? quikPayDiscountPercent, bool? quikPayDiscountExcludeSubs, bool? quikConfirmDiscount, double? quikConfirmDiscountPercent, int? quikConfirmDiscountDays, bool? disableCostGl, bool? excludeFromTopSalesDashboard, bool? separatePackageOnQuoteOrder, double? orderby, bool? subAllShortagesSubMiscellaneous, bool? inactive, List< String> ? combinedShowFields, List<String> ? rentalShowFields, List<String> ? salesShowFields, List<String> ? miscShowFields, List<String> ? laborShowFields, List<String> ? rentalSaleShowFields, List<String> ? lossAndDamageShowFields, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsOrderSettingsOrderTypeOrderType -
Available on WebApiModulesSettingsOrderSettingsOrderTypeOrderType, provided by the $WebApiModulesSettingsOrderSettingsOrderTypeOrderTypeExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? orderTypeId, Wrapped<String?> ? orderType, Wrapped<String?> ? ordType, Wrapped<String?> ? defaultPickTime, Wrapped<String?> ? defaultFromTime, Wrapped<String?> ? defaultToTime, Wrapped<String?> ? dailyScheduleDefaultStartTime, Wrapped<String?> ? dailyScheduleDefaultStopTime, Wrapped<bool?> ? isMasterSubOrderType, Wrapped<bool?> ? combineActivityTabs, Wrapped<bool?> ? defaultManualSort, Wrapped<String?> ? determineQuantitiesToBillBasedOn, Wrapped<bool?> ? useEstimatedDatesForBilling, Wrapped<bool?> ? allowNesting, Wrapped<bool?> ? rentalShowICode, Wrapped<int?> ? rentalICodeWidth, Wrapped<bool?> ? rentalShowDescription, Wrapped<int?> ? rentalDescriptionWidth, Wrapped<bool?> ? rentalShowPickDate, Wrapped<bool?> ? rentalShowPickTime, Wrapped<bool?> ? rentalShowFromDate, Wrapped<bool?> ? rentalShowFromTime, Wrapped<bool?> ? rentalShowToDate, Wrapped<bool?> ? rentalShowToTime, Wrapped<bool?> ? rentalShowBillablePeriods, Wrapped<bool?> ? rentalShowEpisodes, Wrapped<bool?> ? rentalShowSubQuantity, Wrapped<bool?> ? rentalShowAvailableQuantity, Wrapped<bool?> ? rentalShowConflictDate, Wrapped<bool?> ? rentalShowAvailableQuantityRegion, Wrapped<bool?> ? rentalShowConflictDateRegion, Wrapped<bool?> ? rentalShowAvailableQuantityAllWarehouses, Wrapped<bool?> ? rentalShowConflictDateAllWarehouses, Wrapped<bool?> ? rentalShowReservedItems, Wrapped<bool?> ? rentalShowConsignmentQuantity, Wrapped<bool?> ? rentalShowConsignmentAvailableQuantity, Wrapped<bool?> ? rentalShowConsignmentConflictDate, Wrapped<bool?> ? rentalShowRate, Wrapped<bool?> ? rentalShowDaysPerWeek, Wrapped<bool?> ? rentalShowPremiumPercent, Wrapped<bool?> ? rentalShowUnit, Wrapped<bool?> ? rentalShowCost, Wrapped<bool?> ? rentalShowPeriodCostExtended, Wrapped<bool?> ? rentalShowDiscountPercent, Wrapped<bool?> ? rentalShowMarkupPercent, Wrapped<bool?> ? rentalShowMarginPercent, Wrapped<bool?> ? rentalShowUnitDiscountAmount, Wrapped<bool?> ? rentalShowUnitExtended, Wrapped<bool?> ? rentalShowWeeklyDiscountAmount, Wrapped<bool?> ? rentalShowWeeklyExtended, Wrapped<bool?> ? rentalShowEpisodeExtended, Wrapped<bool?> ? rentalShowEpisodeDiscountAmount, Wrapped<bool?> ? rentalShowMonthlyDiscountAmount, Wrapped<bool?> ? rentalShowMonthlyExtended, Wrapped<bool?> ? rentalShowPeriodDiscountAmount, Wrapped<bool?> ? rentalShowPeriodExtended, Wrapped<bool?> ? rentalShowWarehouse, Wrapped<bool?> ? rentalShowTaxable, Wrapped<bool?> ? rentalShowNotes, Wrapped<bool?> ? rentalShowReturnToWarehouse, Wrapped<bool?> ? rentalShowConsignor, Wrapped<String?> ? rentalDateStamp, Wrapped<bool?> ? allowRoundTripRentals, Wrapped<bool?> ? salesShowICode, Wrapped<int?> ? salesICodeWidth, Wrapped<bool?> ? salesShowDescription, Wrapped<int?> ? salesDescriptionWidth, Wrapped<bool?> ? salesShowManufacturerPartNumber, Wrapped<int?> ? salesManufacturerPartNumberWidth, Wrapped<bool?> ? salesShowPickDate, Wrapped<bool?> ? salesShowPickTime, Wrapped<bool?> ? salesShowFromDate, Wrapped<bool?> ? salesShowFromTime, Wrapped<bool?> ? salesShowSubQuantity, Wrapped<bool?> ? salesShowCost, Wrapped<bool?> ? salesShowRate, Wrapped<bool?> ? salesShowAvailableQuantity, Wrapped<bool?> ? salesShowConflictDate, Wrapped<bool?> ? salesShowAvailableQuantityRegion, Wrapped<bool?> ? salesShowConflictDateRegion, Wrapped<bool?> ? salesShowAvailableQuantityAllWarehouses, Wrapped<bool?> ? salesShowConflictDateAllWarehouses, Wrapped<bool?> ? salesShowMarkupPercent, Wrapped<bool?> ? salesShowMarginPercent, Wrapped<bool?> ? salesShowUnit, Wrapped<bool?> ? salesShowPeriodCostExtended, Wrapped<bool?> ? salesShowDiscountPercent, Wrapped<bool?> ? salesShowUnitDiscountAmount, Wrapped<bool?> ? salesShowUnitExtended, Wrapped<bool?> ? salesShowPeriodDiscountAmount, Wrapped<bool?> ? salesShowPeriodExtended, Wrapped<bool?> ? salesShowVariancePercent, Wrapped<bool?> ? salesShowVarianceExtended, Wrapped<bool?> ? salesShowWarehouse, Wrapped<bool?> ? salesShowTaxable, Wrapped<bool?> ? salesShowNotes, Wrapped<bool?> ? salesShowConsignor, Wrapped<String?> ? salesDateStamp, Wrapped<String?> ? salesInventoryPrice, Wrapped<String?> ? salesInventoryCost, Wrapped<bool?> ? facilityShowDescription, Wrapped<int?> ? facilityDescriptionWidth, Wrapped<bool?> ? facilityShowFromDate, Wrapped<bool?> ? facilityShowFromTime, Wrapped<bool?> ? facilityShowToDate, Wrapped<bool?> ? facilityShowToTime, Wrapped<bool?> ? facilityShowWeeksAndDays, Wrapped<bool?> ? facilityShowMonthsAndDays, Wrapped<bool?> ? facilityShowBillablePeriods, Wrapped<bool?> ? facilityShowRate, Wrapped<bool?> ? facilityShowDaysPerWeek, Wrapped<bool?> ? facilityShowDiscountPercent, Wrapped<bool?> ? facilityShowSplit, Wrapped<bool?> ? facilityShowUnit, Wrapped<bool?> ? facilityShowUnitDiscountAmount, Wrapped<bool?> ? facilityShowUnitExtended, Wrapped<bool?> ? facilityShowWeeklyDiscountAmount, Wrapped<bool?> ? facilityShowWeeklyExtended, Wrapped<bool?> ? facilityShowMonthlyDiscountAmount, Wrapped<bool?> ? facilityShowMonthlyExtended, Wrapped<bool?> ? facilityShowPeriodDiscountAmount, Wrapped<bool?> ? facilityShowPeriodExtended, Wrapped<bool?> ? facilityShowTaxable, Wrapped<bool?> ? facilityShowNotes, Wrapped<String?> ? facilityDateStamp, Wrapped<String?> ? facilityDescription, Wrapped<bool?> ? vehicleShowDescription, Wrapped<int?> ? vehicleDescriptionWidth, Wrapped<bool?> ? vehicleShowVehicleNumber, Wrapped<bool?> ? vehicleShowPickDate, Wrapped<bool?> ? vehicleShowPickTime, Wrapped<bool?> ? vehicleShowFromDate, Wrapped<bool?> ? vehicleShowFromTime, Wrapped<bool?> ? vehicleShowToDate, Wrapped<bool?> ? vehicleShowToTime, Wrapped<bool?> ? vehicleShowBillablePeriods, Wrapped<bool?> ? vehicleShowSubQuantity, Wrapped<bool?> ? vehicleShowAvailableQuantity, Wrapped<bool?> ? vehicleShowConflictDate, Wrapped<bool?> ? vehicleShowUnit, Wrapped<bool?> ? vehicleShowRate, Wrapped<bool?> ? vehicleShowDaysPerWeek, Wrapped<bool?> ? vehicleShowCost, Wrapped<bool?> ? vehicleShowWeeklyCostExtended, Wrapped<bool?> ? vehicleShowMonthlyCostExtended, Wrapped<bool?> ? vehicleShowPeriodCostExtended, Wrapped<bool?> ? vehicleShowDiscountPercent, Wrapped<bool?> ? vehicleShowUnitDiscountAmount, Wrapped<bool?> ? vehicleShowUnitExtended, Wrapped<bool?> ? vehicleShowWeeklyDiscountAmount, Wrapped<bool?> ? vehicleShowWeeklyExtended, Wrapped<bool?> ? vehicleShowMonthlyDiscountAmount, Wrapped<bool?> ? vehicleShowMonthlyExtended, Wrapped<bool?> ? vehicleShowPeriodDiscountAmount, Wrapped<bool?> ? vehicleShowPeriodExtended, Wrapped<bool?> ? vehicleShowWarehouse, Wrapped<bool?> ? vehicleShowReturnToWarehouse, Wrapped<bool?> ? vehicleShowTaxable, Wrapped<bool?> ? vehicleShowNotes, Wrapped<String?> ? vehicleDateStamp, Wrapped<bool?> ? laborShowICode, Wrapped<int?> ? laborICodeWidth, Wrapped<bool?> ? laborShowDescription, Wrapped<int?> ? laborDescriptionWidth, Wrapped<bool?> ? laborShowOrderActivity, Wrapped<bool?> ? laborShowCrewName, Wrapped<bool?> ? laborShowFromDate, Wrapped<bool?> ? laborShowFromTime, Wrapped<bool?> ? laborShowToDate, Wrapped<bool?> ? laborShowToTime, Wrapped<bool?> ? laborShowBillablePeriods, Wrapped<bool?> ? laborShowHours, Wrapped<bool?> ? laborShowSubQuantity, Wrapped<bool?> ? laborShowCost, Wrapped<bool?> ? laborShowRate, Wrapped<bool?> ? laborShowPeriodCostExtended, Wrapped<bool?> ? laborShowDiscountPercent, Wrapped<bool?> ? laborShowUnit, Wrapped<bool?> ? laborShowUnitDiscountAmount, Wrapped<bool?> ? laborShowUnitExtended, Wrapped<bool?> ? laborShowWeeklyDiscountAmount, Wrapped<bool?> ? laborShowWeeklyExtended, Wrapped<bool?> ? laborShowMonthlyDiscountAmount, Wrapped<bool?> ? laborShowMonthlyExtended, Wrapped<bool?> ? laborShowPeriodDiscountAmount, Wrapped<bool?> ? laborShowPeriodExtended, Wrapped<bool?> ? laborShowWarehouse, Wrapped<bool?> ? laborShowTaxable, Wrapped<bool?> ? laborShowNotes, Wrapped<String?> ? laborDateStamp, Wrapped<bool?> ? hideCrewBreaks, Wrapped<bool?> ? break1Paid, Wrapped<bool?> ? break2Paid, Wrapped<bool?> ? break3Paid, Wrapped<bool?> ? miscShowICode, Wrapped<int?> ? miscICodeWidth, Wrapped<bool?> ? miscShowDescription, Wrapped<int?> ? miscDescriptionWidth, Wrapped<bool?> ? miscShowFromDate, Wrapped<bool?> ? miscShowFromTime, Wrapped<bool?> ? miscShowToDate, Wrapped<bool?> ? miscShowToTime, Wrapped<bool?> ? miscShowBillablePeriods, Wrapped<bool?> ? miscShowSubQuantity, Wrapped<bool?> ? miscShowWeeksAndDays, Wrapped<bool?> ? miscShowMonthsAndDays, Wrapped<bool?> ? miscShowUnit, Wrapped<bool?> ? miscShowRate, Wrapped<bool?> ? miscShowCost, Wrapped<bool?> ? miscShowPeriodCostExtended, Wrapped<bool?> ? miscShowDiscountPercent, Wrapped<bool?> ? miscShowUnitDiscountAmount, Wrapped<bool?> ? miscShowUnitExtended, Wrapped<bool?> ? miscShowWeeklyDiscountAmount, Wrapped<bool?> ? miscShowWeeklyExtended, Wrapped<bool?> ? miscShowMonthlyDiscountAmount, Wrapped<bool?> ? miscShowMonthlyExtended, Wrapped<bool?> ? miscShowPeriodDiscountAmount, Wrapped<bool?> ? miscShowPeriodExtended, Wrapped<bool?> ? miscShowWarehouse, Wrapped<bool?> ? miscShowTaxable, Wrapped<bool?> ? miscShowNotes, Wrapped<String?> ? miscDateStamp, Wrapped<bool?> ? rentalSaleShowBarCode, Wrapped<bool?> ? rentalSaleShowSerialNumber, Wrapped<bool?> ? rentalSaleShowICode, Wrapped<int?> ? rentalSaleICodeWidth, Wrapped<bool?> ? rentalSaleShowDescription, Wrapped<int?> ? rentalSaleDescriptionWidth, Wrapped<bool?> ? rentalSaleShowPickDate, Wrapped<bool?> ? rentalSaleShowPickTime, Wrapped<bool?> ? rentalSaleShowAvailableQuantity, Wrapped<bool?> ? rentalSaleShowConflictDate, Wrapped<bool?> ? rentalSaleShowUnit, Wrapped<bool?> ? rentalSaleShowRate, Wrapped<bool?> ? rentalSaleShowCost, Wrapped<bool?> ? rentalSaleShowPeriodCostExtended, Wrapped<bool?> ? rentalSaleShowDiscountPercent, Wrapped<bool?> ? rentalSaleShowUnitDiscountAmount, Wrapped<bool?> ? rentalSaleShowUnitExtended, Wrapped<bool?> ? rentalSaleShowPeriodDiscountAmount, Wrapped<bool?> ? rentalSaleShowPeriodExtended, Wrapped<bool?> ? rentalSaleShowWarehouse, Wrapped<bool?> ? rentalSaleShowTaxable, Wrapped<bool?> ? rentalSaleShowNotes, Wrapped<String?> ? rentalSaleDateStamp, Wrapped<bool?> ? lossAndDamageShowOrderNumber, Wrapped<bool?> ? lossAndDamageShowRepairOrderNumber, Wrapped<bool?> ? lossAndDamageShowBarCode, Wrapped<bool?> ? lossAndDamageShowSerialNumber, Wrapped<bool?> ? lossAndDamageShowICode, Wrapped<int?> ? lossAndDamageICodeWidth, Wrapped<bool?> ? lossAndDamageShowDescription, Wrapped<int?> ? lossAndDamageDescriptionWidth, Wrapped<bool?> ? lossAndDamageShowUnit, Wrapped<bool?> ? lossAndDamageShowRate, Wrapped<bool?> ? lossAndDamageShowCost, Wrapped<bool?> ? lossAndDamageShowDiscountPercent, Wrapped<bool?> ? lossAndDamageShowUnitDiscountAmount, Wrapped<bool?> ? lossAndDamageShowUnitExtended, Wrapped<bool?> ? lossAndDamageShowPeriodDiscountAmount, Wrapped<bool?> ? lossAndDamageShowPeriodExtended, Wrapped<bool?> ? lossAndDamageShowWarehouse, Wrapped<bool?> ? lossAndDamageShowTaxable, Wrapped<bool?> ? lossAndDamageShowNotes, Wrapped<String?> ? lossAndDamageDateStamp, Wrapped<bool?> ? addInstallationAndStrikeFee, Wrapped<String?> ? installationAndStrikeFeeRateId, Wrapped<String?> ? installationAndStrikeFeeICode, Wrapped<String?> ? installationAndStrikeFeeDescription, Wrapped<double?> ? installationAndStrikeFeePercent, Wrapped<String?> ? installationAndStrikeFeeBasedOn, Wrapped<bool?> ? addManagementAndServiceFee, Wrapped<String?> ? managementAndServiceFeeRateId, Wrapped<String?> ? managementAndServiceFeeICode, Wrapped<String?> ? managementAndServiceFeeDescription, Wrapped<double?> ? managementAndServiceFeePercent, Wrapped<String?> ? managementAndServiceFeeBasedOn, Wrapped<String?> ? defaultRentalSalePrice, Wrapped<bool?> ? quikPayDiscount, Wrapped<String?> ? quikPayDiscountType, Wrapped<int?> ? quikPayDiscountDays, Wrapped<double?> ? quikPayDiscountPercent, Wrapped<bool?> ? quikPayDiscountExcludeSubs, Wrapped<bool?> ? quikConfirmDiscount, Wrapped<double?> ? quikConfirmDiscountPercent, Wrapped<int?> ? quikConfirmDiscountDays, Wrapped<bool?> ? disableCostGl, Wrapped<bool?> ? excludeFromTopSalesDashboard, Wrapped<bool?> ? separatePackageOnQuoteOrder, Wrapped<double?> ? orderby, Wrapped<bool?> ? subAllShortagesSubMiscellaneous, Wrapped<bool?> ? inactive, Wrapped<List< ? combinedShowFields, Wrapped<String> ?>List< ? rentalShowFields, Wrapped<String> ?>List< ? salesShowFields, Wrapped<String> ?>List< ? miscShowFields, Wrapped<String> ?>List< ? laborShowFields, Wrapped<String> ?>List< ? rentalSaleShowFields, Wrapped<String> ?>List< ? lossAndDamageShowFields, Wrapped<String> ?>String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes}) → WebApiModulesSettingsOrderSettingsOrderTypeOrderTypeFwStandardDataFwDefaultAttribute> ?> -
Available on WebApiModulesSettingsOrderSettingsOrderTypeOrderType, provided by the $WebApiModulesSettingsOrderSettingsOrderTypeOrderTypeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsOrderSettingsOrderTypeOrderType Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsOrderSettingsOrderTypeOrderType instance)