WebApiModulesSettingsPoSettingsPoTypePoType class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsPoSettingsPoTypePoType({String? poTypeId, String? poType, bool? approvalNeededByRequired, bool? importanceRequired, bool? payTypeRequired, bool? projectRequired, bool? subRentalShowOrderNumber, bool? subRentalShowRepairOrderNumber, bool? subRentalShowICode, int? subRentalICodeWidth, bool? subRentalShowDescription, int? subRentalDescriptionWidth, bool? subRentalShowFromDate, bool? subRentalShowFromTime, bool? subRentalShowToDate, bool? subRentalShowToTime, bool? subRentalShowBillablePeriods, bool? subRentalShowRate, bool? subRentalShowDaysPerWeek, bool? subRentalShowDiscountPercent, bool? subRentalShowUnit, bool? subRentalShowUnitDiscountAmount, bool? subRentalShowUnitExtended, bool? subRentalShowWeeklyDiscountAmount, bool? subRentalShowWeeklyExtended, bool? subRentalShowMonthlyDiscountAmount, bool? subRentalShowMonthlyExtended, bool? subRentalShowPeriodDiscountAmount, bool? subRentalShowPeriodExtended, bool? subRentalShowWarehouse, bool? subRentalShowTaxable, bool? subRentalShowNotes, String? subRentalDateStamp, bool? subSaleShowOrderNumber, bool? subSaleShowICode, int? subSaleICodeWidth, bool? subSaleShowDescription, int? subSaleDescriptionWidth, bool? subSaleShowManufacturerPartNumber, bool? subSaleShowRate, bool? subSaleShowDiscountPercent, bool? subSaleShowUnit, bool? subSaleShowUnitDiscountAmount, bool? subSaleShowUnitExtended, bool? subSaleShowPeriodDiscountAmount, bool? subSaleShowPeriodExtended, bool? subSaleShowWarehouse, bool? subSaleShowTaxable, bool? subSaleShowNotes, String? subSaleDateStamp, bool? purchaseShowICode, int? purchaseICodeWidth, bool? purchaseShowDescription, int? purchaseDescriptionWidth, bool? purchaseShowRate, bool? purchaseShowDiscountPercent, bool? purchaseShowUnit, bool? purchaseShowUnitDiscountAmount, bool? purchaseShowUnitExtended, bool? purchaseShowPeriodDiscountAmount, bool? purchaseShowPeriodExtended, bool? purchaseShowCountryOfOrigin, bool? purchaseShowManufacturer, bool? purchaseShowManufacturerPartNumber, int? purchaseManufacturerPartNumberWidth, bool? purchaseShowModelNumber, bool? purchaseShowVendorPartNumber, bool? purchaseShowWarehouse, bool? purchaseShowTaxable, bool? purchaseShowNotes, bool? purchaseShowCostOrder, String? purchaseDateStamp, String? rentalPurchaseDefaultRate, String? salesPurchaseDefaultRate, bool? laborShowICode, int? laborICodeWidth, bool? laborShowDescription, int? laborDescriptionWidth, bool? laborShowOrderActivity, bool? laborShowCrewName, bool? laborShowFromDate, bool? laborShowFromTime, bool? laborShowToDate, bool? laborShowToTime, bool? laborShowHours, bool? laborShowBillablePeriods, bool? laborShowRate, bool? laborShowDiscountPercent, bool? laborShowUnit, bool? laborShowUnitDiscountAmount, bool? laborShowUnitExtended, bool? laborShowWeeklyDiscountAmount, bool? laborShowWeeklyExtended, bool? laborShowMonthlyDiscountAmount, bool? laborShowMonthlyExtended, bool? laborShowPeriodDiscountAmount, bool? laborShowPeriodExtended, bool? laborShowWarehouse, bool? laborShowTaxable, bool? laborShowNotes, bool? laborShowCostOrder, String? laborDateStamp, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, bool? miscShowICode, int? miscICodeWidth, bool? miscShowDescription, int? miscDescriptionWidth, bool? miscShowFromDate, bool? miscShowToDate, bool? miscShowBillablePeriods, bool? miscShowRate, bool? miscShowDiscountPercent, bool? miscShowUnit, bool? miscShowUnitDiscountAmount, bool? miscShowUnitExtended, bool? miscShowWeeklyDiscountAmount, bool? miscShowWeeklyExtended, bool? miscShowMonthlyDiscountAmount, bool? miscShowMonthlyExtended, bool? miscShowPeriodDiscountAmount, bool? miscShowPeriodExtended, bool? miscShowWarehouse, bool? miscShowTaxable, bool? miscShowNotes, bool? miscShowCostOrder, bool? miscShowWeeksAndDays, bool? miscShowMonthsAndDays, String? miscDateStamp, bool? subLaborShowOrderNumber, bool? subLaborShowICode, int? subLaborICodeWidth, bool? subLaborShowDescription, int? subLaborDescriptionWidth, bool? subLaborShowFromDate, bool? subLaborShowFromTime, bool? subLaborShowToDate, bool? subLaborShowToTime, bool? subLaborShowHours, bool? subLaborShowBillablePeriods, bool? subLaborShowRate, bool? subLaborShowDiscountPercent, bool? subLaborShowUnit, bool? subLaborShowUnitDiscountAmount, bool? subLaborShowUnitExtended, bool? subLaborShowWeeklyDiscountAmount, bool? subLaborShowWeeklyExtended, bool? subLaborShowMonthlyDiscountAmount, bool? subLaborShowMonthlyExtended, bool? subLaborShowPeriodDiscountAmount, bool? subLaborShowPeriodExtended, bool? subLaborShowWarehouse, bool? subLaborShowTaxable, bool? subLaborShowNotes, String? subLaborDateStamp, bool? subMiscShowOrderNumber, bool? subMiscShowICode, int? subMiscICodeWidth, bool? subMiscShowDescription, int? subMiscDescriptionWidth, bool? subMiscShowFromDate, bool? subMiscShowToDate, bool? subMiscShowBillablePeriods, bool? subMiscShowRate, bool? subMiscShowDiscountPercent, bool? subMiscShowUnit, bool? subMiscShowUnitDiscountAmount, bool? subMiscShowUnitExtended, bool? subMiscShowWeeklyDiscountAmount, bool? subMiscShowWeeklyExtended, bool? subMiscShowMonthlyDiscountAmount, bool? subMiscShowMonthlyExtended, bool? subMiscShowPeriodDiscountAmount, bool? subMiscShowPeriodExtended, bool? subMiscShowWarehouse, bool? subMiscShowTaxable, bool? subMiscShowNotes, String? subMiscDateStamp, bool? repairShowRepairOrderNumber, bool? repairShowICode, int? repairICodeWidth, bool? repairShowDescription, int? repairDescriptionWidth, bool? repairShowPickDate, bool? repairShowRate, bool? repairShowUnit, bool? repairShowUnitDiscountAmount, bool? repairShowUnitExtended, bool? repairShowPeriodDiscountAmount, bool? repairShowPeriodExtended, bool? repairShowWarehouse, bool? repairShowTaxable, bool? repairShowNotes, String? repairDateStamp, bool? rwNetDefaultRental, bool? rwNetDefaultMisc, bool? rwNetDefaultLabor, double? orderBy, bool? inactive, String? dateStamp, List<
String> ? subRentalShowFields, List<String> ? subSaleShowFields, List<String> ? subMiscShowFields, List<String> ? subLaborShowFields, List<String> ? purchaseShowFields, List<String> ? miscShowFields, List<String> ? laborShowFields, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsPoSettingsPoTypePoType.fromJson(Map<
String, dynamic> json) -
factory
Properties
- approvalNeededByRequired → bool?
-
final
- auditNote → String?
-
final
- break1Paid → bool?
-
final
- break2Paid → bool?
-
final
- break3Paid → bool?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hideCrewBreaks → bool?
-
final
- importanceRequired → bool?
-
final
- inactive → bool?
-
final
- laborDateStamp → String?
-
final
- laborDescriptionWidth → int?
-
final
- laborICodeWidth → int?
-
final
- laborShowBillablePeriods → bool?
-
final
- laborShowCostOrder → bool?
-
final
- laborShowCrewName → bool?
-
final
- laborShowDescription → bool?
-
final
- laborShowDiscountPercent → bool?
-
final
-
laborShowFields
→ List<
String> ? -
final
- laborShowFromDate → bool?
-
final
- laborShowFromTime → bool?
-
final
- laborShowHours → bool?
-
final
- laborShowICode → bool?
-
final
- laborShowMonthlyDiscountAmount → bool?
-
final
- laborShowMonthlyExtended → bool?
-
final
- laborShowNotes → bool?
-
final
- laborShowOrderActivity → bool?
-
final
- laborShowPeriodDiscountAmount → bool?
-
final
- laborShowPeriodExtended → bool?
-
final
- laborShowRate → bool?
-
final
- laborShowTaxable → bool?
-
final
- laborShowToDate → bool?
-
final
- laborShowToTime → bool?
-
final
- laborShowUnit → bool?
-
final
- laborShowUnitDiscountAmount → bool?
-
final
- laborShowUnitExtended → bool?
-
final
- laborShowWarehouse → bool?
-
final
- laborShowWeeklyDiscountAmount → bool?
-
final
- laborShowWeeklyExtended → bool?
-
final
- miscDateStamp → String?
-
final
- miscDescriptionWidth → int?
-
final
- miscICodeWidth → int?
-
final
- miscShowBillablePeriods → bool?
-
final
- miscShowCostOrder → bool?
-
final
- miscShowDescription → bool?
-
final
- miscShowDiscountPercent → bool?
-
final
-
miscShowFields
→ List<
String> ? -
final
- miscShowFromDate → bool?
-
final
- miscShowICode → bool?
-
final
- miscShowMonthlyDiscountAmount → bool?
-
final
- miscShowMonthlyExtended → bool?
-
final
- miscShowMonthsAndDays → bool?
-
final
- miscShowNotes → bool?
-
final
- miscShowPeriodDiscountAmount → bool?
-
final
- miscShowPeriodExtended → bool?
-
final
- miscShowRate → bool?
-
final
- miscShowTaxable → bool?
-
final
- miscShowToDate → bool?
-
final
- miscShowUnit → bool?
-
final
- miscShowUnitDiscountAmount → bool?
-
final
- miscShowUnitExtended → bool?
-
final
- miscShowWarehouse → bool?
-
final
- miscShowWeeklyDiscountAmount → bool?
-
final
- miscShowWeeklyExtended → bool?
-
final
- miscShowWeeksAndDays → bool?
-
final
- orderBy → double?
-
final
- payTypeRequired → bool?
-
final
- poType → String?
-
final
- poTypeId → String?
-
final
- projectRequired → bool?
-
final
- purchaseDateStamp → String?
-
final
- purchaseDescriptionWidth → int?
-
final
- purchaseICodeWidth → int?
-
final
- purchaseManufacturerPartNumberWidth → int?
-
final
- purchaseShowCostOrder → bool?
-
final
- purchaseShowCountryOfOrigin → bool?
-
final
- purchaseShowDescription → bool?
-
final
- purchaseShowDiscountPercent → bool?
-
final
-
purchaseShowFields
→ List<
String> ? -
final
- purchaseShowICode → bool?
-
final
- purchaseShowManufacturer → bool?
-
final
- purchaseShowManufacturerPartNumber → bool?
-
final
- purchaseShowModelNumber → bool?
-
final
- purchaseShowNotes → bool?
-
final
- purchaseShowPeriodDiscountAmount → bool?
-
final
- purchaseShowPeriodExtended → bool?
-
final
- purchaseShowRate → bool?
-
final
- purchaseShowTaxable → bool?
-
final
- purchaseShowUnit → bool?
-
final
- purchaseShowUnitDiscountAmount → bool?
-
final
- purchaseShowUnitExtended → bool?
-
final
- purchaseShowVendorPartNumber → bool?
-
final
- purchaseShowWarehouse → bool?
-
final
- recordTitle → String?
-
final
- rentalPurchaseDefaultRate → String?
-
final
- repairDateStamp → String?
-
final
- repairDescriptionWidth → int?
-
final
- repairICodeWidth → int?
-
final
- repairShowDescription → bool?
-
final
- repairShowICode → bool?
-
final
- repairShowNotes → bool?
-
final
- repairShowPeriodDiscountAmount → bool?
-
final
- repairShowPeriodExtended → bool?
-
final
- repairShowPickDate → bool?
-
final
- repairShowRate → bool?
-
final
- repairShowRepairOrderNumber → bool?
-
final
- repairShowTaxable → bool?
-
final
- repairShowUnit → bool?
-
final
- repairShowUnitDiscountAmount → bool?
-
final
- repairShowUnitExtended → bool?
-
final
- repairShowWarehouse → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- rwNetDefaultLabor → bool?
-
final
- rwNetDefaultMisc → bool?
-
final
- rwNetDefaultRental → bool?
-
final
- salesPurchaseDefaultRate → String?
-
final
- subLaborDateStamp → String?
-
final
- subLaborDescriptionWidth → int?
-
final
- subLaborICodeWidth → int?
-
final
- subLaborShowBillablePeriods → bool?
-
final
- subLaborShowDescription → bool?
-
final
- subLaborShowDiscountPercent → bool?
-
final
-
subLaborShowFields
→ List<
String> ? -
final
- subLaborShowFromDate → bool?
-
final
- subLaborShowFromTime → bool?
-
final
- subLaborShowHours → bool?
-
final
- subLaborShowICode → bool?
-
final
- subLaborShowMonthlyDiscountAmount → bool?
-
final
- subLaborShowMonthlyExtended → bool?
-
final
- subLaborShowNotes → bool?
-
final
- subLaborShowOrderNumber → bool?
-
final
- subLaborShowPeriodDiscountAmount → bool?
-
final
- subLaborShowPeriodExtended → bool?
-
final
- subLaborShowRate → bool?
-
final
- subLaborShowTaxable → bool?
-
final
- subLaborShowToDate → bool?
-
final
- subLaborShowToTime → bool?
-
final
- subLaborShowUnit → bool?
-
final
- subLaborShowUnitDiscountAmount → bool?
-
final
- subLaborShowUnitExtended → bool?
-
final
- subLaborShowWarehouse → bool?
-
final
- subLaborShowWeeklyDiscountAmount → bool?
-
final
- subLaborShowWeeklyExtended → bool?
-
final
- subMiscDateStamp → String?
-
final
- subMiscDescriptionWidth → int?
-
final
- subMiscICodeWidth → int?
-
final
- subMiscShowBillablePeriods → bool?
-
final
- subMiscShowDescription → bool?
-
final
- subMiscShowDiscountPercent → bool?
-
final
-
subMiscShowFields
→ List<
String> ? -
final
- subMiscShowFromDate → bool?
-
final
- subMiscShowICode → bool?
-
final
- subMiscShowMonthlyDiscountAmount → bool?
-
final
- subMiscShowMonthlyExtended → bool?
-
final
- subMiscShowNotes → bool?
-
final
- subMiscShowOrderNumber → bool?
-
final
- subMiscShowPeriodDiscountAmount → bool?
-
final
- subMiscShowPeriodExtended → bool?
-
final
- subMiscShowRate → bool?
-
final
- subMiscShowTaxable → bool?
-
final
- subMiscShowToDate → bool?
-
final
- subMiscShowUnit → bool?
-
final
- subMiscShowUnitDiscountAmount → bool?
-
final
- subMiscShowUnitExtended → bool?
-
final
- subMiscShowWarehouse → bool?
-
final
- subMiscShowWeeklyDiscountAmount → bool?
-
final
- subMiscShowWeeklyExtended → bool?
-
final
- subRentalDateStamp → String?
-
final
- subRentalDescriptionWidth → int?
-
final
- subRentalICodeWidth → int?
-
final
- subRentalShowBillablePeriods → bool?
-
final
- subRentalShowDaysPerWeek → bool?
-
final
- subRentalShowDescription → bool?
-
final
- subRentalShowDiscountPercent → bool?
-
final
-
subRentalShowFields
→ List<
String> ? -
final
- subRentalShowFromDate → bool?
-
final
- subRentalShowFromTime → bool?
-
final
- subRentalShowICode → bool?
-
final
- subRentalShowMonthlyDiscountAmount → bool?
-
final
- subRentalShowMonthlyExtended → bool?
-
final
- subRentalShowNotes → bool?
-
final
- subRentalShowOrderNumber → bool?
-
final
- subRentalShowPeriodDiscountAmount → bool?
-
final
- subRentalShowPeriodExtended → bool?
-
final
- subRentalShowRate → bool?
-
final
- subRentalShowRepairOrderNumber → bool?
-
final
- subRentalShowTaxable → bool?
-
final
- subRentalShowToDate → bool?
-
final
- subRentalShowToTime → bool?
-
final
- subRentalShowUnit → bool?
-
final
- subRentalShowUnitDiscountAmount → bool?
-
final
- subRentalShowUnitExtended → bool?
-
final
- subRentalShowWarehouse → bool?
-
final
- subRentalShowWeeklyDiscountAmount → bool?
-
final
- subRentalShowWeeklyExtended → bool?
-
final
- subSaleDateStamp → String?
-
final
- subSaleDescriptionWidth → int?
-
final
- subSaleICodeWidth → int?
-
final
- subSaleShowDescription → bool?
-
final
- subSaleShowDiscountPercent → bool?
-
final
-
subSaleShowFields
→ List<
String> ? -
final
- subSaleShowICode → bool?
-
final
- subSaleShowManufacturerPartNumber → bool?
-
final
- subSaleShowNotes → bool?
-
final
- subSaleShowOrderNumber → bool?
-
final
- subSaleShowPeriodDiscountAmount → bool?
-
final
- subSaleShowPeriodExtended → bool?
-
final
- subSaleShowRate → bool?
-
final
- subSaleShowTaxable → bool?
-
final
- subSaleShowUnit → bool?
-
final
- subSaleShowUnitDiscountAmount → bool?
-
final
- subSaleShowUnitExtended → bool?
-
final
- subSaleShowWarehouse → bool?
-
final
Methods
-
copyWith(
{String? poTypeId, String? poType, bool? approvalNeededByRequired, bool? importanceRequired, bool? payTypeRequired, bool? projectRequired, bool? subRentalShowOrderNumber, bool? subRentalShowRepairOrderNumber, bool? subRentalShowICode, int? subRentalICodeWidth, bool? subRentalShowDescription, int? subRentalDescriptionWidth, bool? subRentalShowFromDate, bool? subRentalShowFromTime, bool? subRentalShowToDate, bool? subRentalShowToTime, bool? subRentalShowBillablePeriods, bool? subRentalShowRate, bool? subRentalShowDaysPerWeek, bool? subRentalShowDiscountPercent, bool? subRentalShowUnit, bool? subRentalShowUnitDiscountAmount, bool? subRentalShowUnitExtended, bool? subRentalShowWeeklyDiscountAmount, bool? subRentalShowWeeklyExtended, bool? subRentalShowMonthlyDiscountAmount, bool? subRentalShowMonthlyExtended, bool? subRentalShowPeriodDiscountAmount, bool? subRentalShowPeriodExtended, bool? subRentalShowWarehouse, bool? subRentalShowTaxable, bool? subRentalShowNotes, String? subRentalDateStamp, bool? subSaleShowOrderNumber, bool? subSaleShowICode, int? subSaleICodeWidth, bool? subSaleShowDescription, int? subSaleDescriptionWidth, bool? subSaleShowManufacturerPartNumber, bool? subSaleShowRate, bool? subSaleShowDiscountPercent, bool? subSaleShowUnit, bool? subSaleShowUnitDiscountAmount, bool? subSaleShowUnitExtended, bool? subSaleShowPeriodDiscountAmount, bool? subSaleShowPeriodExtended, bool? subSaleShowWarehouse, bool? subSaleShowTaxable, bool? subSaleShowNotes, String? subSaleDateStamp, bool? purchaseShowICode, int? purchaseICodeWidth, bool? purchaseShowDescription, int? purchaseDescriptionWidth, bool? purchaseShowRate, bool? purchaseShowDiscountPercent, bool? purchaseShowUnit, bool? purchaseShowUnitDiscountAmount, bool? purchaseShowUnitExtended, bool? purchaseShowPeriodDiscountAmount, bool? purchaseShowPeriodExtended, bool? purchaseShowCountryOfOrigin, bool? purchaseShowManufacturer, bool? purchaseShowManufacturerPartNumber, int? purchaseManufacturerPartNumberWidth, bool? purchaseShowModelNumber, bool? purchaseShowVendorPartNumber, bool? purchaseShowWarehouse, bool? purchaseShowTaxable, bool? purchaseShowNotes, bool? purchaseShowCostOrder, String? purchaseDateStamp, String? rentalPurchaseDefaultRate, String? salesPurchaseDefaultRate, bool? laborShowICode, int? laborICodeWidth, bool? laborShowDescription, int? laborDescriptionWidth, bool? laborShowOrderActivity, bool? laborShowCrewName, bool? laborShowFromDate, bool? laborShowFromTime, bool? laborShowToDate, bool? laborShowToTime, bool? laborShowHours, bool? laborShowBillablePeriods, bool? laborShowRate, bool? laborShowDiscountPercent, bool? laborShowUnit, bool? laborShowUnitDiscountAmount, bool? laborShowUnitExtended, bool? laborShowWeeklyDiscountAmount, bool? laborShowWeeklyExtended, bool? laborShowMonthlyDiscountAmount, bool? laborShowMonthlyExtended, bool? laborShowPeriodDiscountAmount, bool? laborShowPeriodExtended, bool? laborShowWarehouse, bool? laborShowTaxable, bool? laborShowNotes, bool? laborShowCostOrder, String? laborDateStamp, bool? hideCrewBreaks, bool? break1Paid, bool? break2Paid, bool? break3Paid, bool? miscShowICode, int? miscICodeWidth, bool? miscShowDescription, int? miscDescriptionWidth, bool? miscShowFromDate, bool? miscShowToDate, bool? miscShowBillablePeriods, bool? miscShowRate, bool? miscShowDiscountPercent, bool? miscShowUnit, bool? miscShowUnitDiscountAmount, bool? miscShowUnitExtended, bool? miscShowWeeklyDiscountAmount, bool? miscShowWeeklyExtended, bool? miscShowMonthlyDiscountAmount, bool? miscShowMonthlyExtended, bool? miscShowPeriodDiscountAmount, bool? miscShowPeriodExtended, bool? miscShowWarehouse, bool? miscShowTaxable, bool? miscShowNotes, bool? miscShowCostOrder, bool? miscShowWeeksAndDays, bool? miscShowMonthsAndDays, String? miscDateStamp, bool? subLaborShowOrderNumber, bool? subLaborShowICode, int? subLaborICodeWidth, bool? subLaborShowDescription, int? subLaborDescriptionWidth, bool? subLaborShowFromDate, bool? subLaborShowFromTime, bool? subLaborShowToDate, bool? subLaborShowToTime, bool? subLaborShowHours, bool? subLaborShowBillablePeriods, bool? subLaborShowRate, bool? subLaborShowDiscountPercent, bool? subLaborShowUnit, bool? subLaborShowUnitDiscountAmount, bool? subLaborShowUnitExtended, bool? subLaborShowWeeklyDiscountAmount, bool? subLaborShowWeeklyExtended, bool? subLaborShowMonthlyDiscountAmount, bool? subLaborShowMonthlyExtended, bool? subLaborShowPeriodDiscountAmount, bool? subLaborShowPeriodExtended, bool? subLaborShowWarehouse, bool? subLaborShowTaxable, bool? subLaborShowNotes, String? subLaborDateStamp, bool? subMiscShowOrderNumber, bool? subMiscShowICode, int? subMiscICodeWidth, bool? subMiscShowDescription, int? subMiscDescriptionWidth, bool? subMiscShowFromDate, bool? subMiscShowToDate, bool? subMiscShowBillablePeriods, bool? subMiscShowRate, bool? subMiscShowDiscountPercent, bool? subMiscShowUnit, bool? subMiscShowUnitDiscountAmount, bool? subMiscShowUnitExtended, bool? subMiscShowWeeklyDiscountAmount, bool? subMiscShowWeeklyExtended, bool? subMiscShowMonthlyDiscountAmount, bool? subMiscShowMonthlyExtended, bool? subMiscShowPeriodDiscountAmount, bool? subMiscShowPeriodExtended, bool? subMiscShowWarehouse, bool? subMiscShowTaxable, bool? subMiscShowNotes, String? subMiscDateStamp, bool? repairShowRepairOrderNumber, bool? repairShowICode, int? repairICodeWidth, bool? repairShowDescription, int? repairDescriptionWidth, bool? repairShowPickDate, bool? repairShowRate, bool? repairShowUnit, bool? repairShowUnitDiscountAmount, bool? repairShowUnitExtended, bool? repairShowPeriodDiscountAmount, bool? repairShowPeriodExtended, bool? repairShowWarehouse, bool? repairShowTaxable, bool? repairShowNotes, String? repairDateStamp, bool? rwNetDefaultRental, bool? rwNetDefaultMisc, bool? rwNetDefaultLabor, double? orderBy, bool? inactive, String? dateStamp, List< String> ? subRentalShowFields, List<String> ? subSaleShowFields, List<String> ? subMiscShowFields, List<String> ? subLaborShowFields, List<String> ? purchaseShowFields, List<String> ? miscShowFields, List<String> ? laborShowFields, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsPoSettingsPoTypePoType -
Available on WebApiModulesSettingsPoSettingsPoTypePoType, provided by the $WebApiModulesSettingsPoSettingsPoTypePoTypeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsPoSettingsPoTypePoType Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsPoSettingsPoTypePoType instance)