WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover({String? vendorInvoiceApproverId, String? locationId, String? location, String? departmentId, String? department, String? usersId, String? username, bool? rental, bool? sales, bool? parts, bool? misc, bool? labor, bool? vehicle, bool? subRent, bool? subSale, bool? repair, bool? subMisc, bool? subLabor, bool? subVehicle, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- labor → bool?
-
final
- location → String?
-
final
- locationId → String?
-
final
- misc → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- parts → bool?
-
final
- recordTitle → String?
-
final
- rental → bool?
-
final
- repair → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sales → bool?
-
final
- subLabor → bool?
-
final
- subMisc → bool?
-
final
- subRent → bool?
-
final
- subSale → bool?
-
final
- subVehicle → bool?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
- username → String?
-
final
- usersId → String?
-
final
- vehicle → bool?
-
final
- vendorInvoiceApproverId → String?
-
final
Methods
-
copyWith(
{String? vendorInvoiceApproverId, String? locationId, String? location, String? departmentId, String? department, String? usersId, String? username, bool? rental, bool? sales, bool? parts, bool? misc, bool? labor, bool? vehicle, bool? subRent, bool? subSale, bool? repair, bool? subMisc, bool? subLabor, bool? subVehicle, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover -
Available on WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover, provided by the $WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApproverExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? vendorInvoiceApproverId, Wrapped<String?> ? locationId, Wrapped<String?> ? location, Wrapped<String?> ? departmentId, Wrapped<String?> ? department, Wrapped<String?> ? usersId, Wrapped<String?> ? username, Wrapped<bool?> ? rental, Wrapped<bool?> ? sales, Wrapped<bool?> ? parts, Wrapped<bool?> ? misc, Wrapped<bool?> ? labor, Wrapped<bool?> ? vehicle, Wrapped<bool?> ? subRent, Wrapped<bool?> ? subSale, Wrapped<bool?> ? repair, Wrapped<bool?> ? subMisc, Wrapped<bool?> ? subLabor, Wrapped<bool?> ? subVehicle, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover -
Available on WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover, provided by the $WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApproverExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover instance)