WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover({String? vendorInvoiceApproverId, String? locationId, String? location, String? departmentId, String? department, String? usersId, String? username, bool? rental, bool? sales, bool? parts, bool? misc, bool? labor, bool? vehicle, bool? subRent, bool? subSale, bool? repair, bool? subMisc, bool? subLabor, bool? subVehicle, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue> ? translation}) -
WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- labor → bool?
-
final
- location → String?
-
final
- locationId → String?
-
final
- misc → bool?
-
final
- parts → bool?
-
final
- recordTitle → String?
-
final
- rental → bool?
-
final
- repair → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sales → bool?
-
final
- subLabor → bool?
-
final
- subMisc → bool?
-
final
- subRent → bool?
-
final
- subSale → bool?
-
final
- subVehicle → bool?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- username → String?
-
final
- usersId → String?
-
final
- vehicle → bool?
-
final
- vendorInvoiceApproverId → String?
-
final
Methods
-
copyWith(
{String? vendorInvoiceApproverId, String? locationId, String? location, String? departmentId, String? department, String? usersId, String? username, bool? rental, bool? sales, bool? parts, bool? misc, bool? labor, bool? vehicle, bool? subRent, bool? subSale, bool? repair, bool? subMisc, bool? subLabor, bool? subVehicle, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, List<FwStandardDataFwTranslatedValue> ? translation}) → WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover -
Available on WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover, provided by the $WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApproverExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? vendorInvoiceApproverId, Wrapped<String?> ? locationId, Wrapped<String?> ? location, Wrapped<String?> ? departmentId, Wrapped<String?> ? department, Wrapped<String?> ? usersId, Wrapped<String?> ? username, Wrapped<bool?> ? rental, Wrapped<bool?> ? sales, Wrapped<bool?> ? parts, Wrapped<bool?> ? misc, Wrapped<bool?> ? labor, Wrapped<bool?> ? vehicle, Wrapped<bool?> ? subRent, Wrapped<bool?> ? subSale, Wrapped<bool?> ? repair, Wrapped<bool?> ? subMisc, Wrapped<bool?> ? subLabor, Wrapped<bool?> ? subVehicle, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>List< ? translation}) → WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApproverFwStandardDataFwTranslatedValue> ?> -
Available on WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover, provided by the $WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApproverExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsPoSettingsVendorInvoiceApproverVendorInvoiceApprover instance)