WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity({String? presentationLayerActivityId, String? presentationLayerId, String? activity, String? activityRename, String? groupNo, String? recType, String? exportCode, double? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activity → String?
-
final
- activityRename → String?
-
final
- auditNote → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- exportCode → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- groupNo → String?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- orderBy → double?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- presentationLayerActivityId → String?
-
final
- presentationLayerId → String?
-
final
- recordTitle → String?
-
final
- recType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? presentationLayerActivityId, String? presentationLayerId, String? activity, String? activityRename, String? groupNo, String? recType, String? exportCode, double? orderBy, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity -
Available on WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity, provided by the $WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivityExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? presentationLayerActivityId, Wrapped<String?> ? presentationLayerId, Wrapped<String?> ? activity, Wrapped<String?> ? activityRename, Wrapped<String?> ? groupNo, Wrapped<String?> ? recType, Wrapped<String?> ? exportCode, Wrapped<double?> ? orderBy, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity -
Available on WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity, provided by the $WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivityExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsPresentationLayerActivityPresentationLayerActivity instance)