WebApiModulesSettingsSubCategorySubCategory class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsSubCategorySubCategory({String? subCategoryId, String? subCategory, String? categoryId, String? category, String? typeId, String? type, double? orderBy, int? pickListOrderBy, String? dateStamp, bool? inactive, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesSettingsSubCategorySubCategory.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
category String?
final
categoryId String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
inactive bool?
final
orderBy double?
final
pickListOrderBy int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategory String?
final
subCategoryId String?
final
type String?
final
typeId String?
final

Methods

copyWith({String? subCategoryId, String? subCategory, String? categoryId, String? category, String? typeId, String? type, double? orderBy, int? pickListOrderBy, String? dateStamp, bool? inactive, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesSettingsSubCategorySubCategory

Available on WebApiModulesSettingsSubCategorySubCategory, provided by the $WebApiModulesSettingsSubCategorySubCategoryExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const WebApiModulesSettingsSubCategorySubCategory Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WebApiModulesSettingsSubCategorySubCategory instance)