WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings({String? consignmentSettingsId, String? consignmentSettingsName, bool? enableConsignment, String? consignmentColor, String? consignorFeePoRateId, String? consignorFeePoRateICode, String? consignorFeePoRateDescription, String? consignorFeePoTypeId, String? consignorFeePoDescription, String? consignorFeePoType, String? defaultConsignorFeeBasedOn, int? defaultConsignorPercent, int? defaultHousePercent, String? reReceiveConsignedItemUnretiredReasonId, String? reReceiveConsignedItemUnretiredReason, bool? hideConsignmentTransactionsOnSubRentalTab, bool? awardConsignorFeesForStaged, bool? awardFullConsignorFeeEvenWhenItemsAreOverfulfilled, bool? defaultTreatConsignedQtyAsOwned, String? dateStamp, bool? defaultProcessConsignmentSelectAllInvoices, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- awardConsignorFeesForStaged → bool?
-
final
- awardFullConsignorFeeEvenWhenItemsAreOverfulfilled → bool?
-
final
- consignmentColor → String?
-
final
- consignmentSettingsId → String?
-
final
- consignmentSettingsName → String?
-
final
- consignorFeePoDescription → String?
-
final
- consignorFeePoRateDescription → String?
-
final
- consignorFeePoRateICode → String?
-
final
- consignorFeePoRateId → String?
-
final
- consignorFeePoType → String?
-
final
- consignorFeePoTypeId → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- defaultConsignorFeeBasedOn → String?
-
final
- defaultConsignorPercent → int?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultHousePercent → int?
-
final
- defaultProcessConsignmentSelectAllInvoices → bool?
-
final
- defaultTreatConsignedQtyAsOwned → bool?
-
final
- enableConsignment → bool?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- hideConsignmentTransactionsOnSubRentalTab → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- reReceiveConsignedItemUnretiredReason → String?
-
final
- reReceiveConsignedItemUnretiredReasonId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? consignmentSettingsId, String? consignmentSettingsName, bool? enableConsignment, String? consignmentColor, String? consignorFeePoRateId, String? consignorFeePoRateICode, String? consignorFeePoRateDescription, String? consignorFeePoTypeId, String? consignorFeePoDescription, String? consignorFeePoType, String? defaultConsignorFeeBasedOn, int? defaultConsignorPercent, int? defaultHousePercent, String? reReceiveConsignedItemUnretiredReasonId, String? reReceiveConsignedItemUnretiredReason, bool? hideConsignmentTransactionsOnSubRentalTab, bool? awardConsignorFeesForStaged, bool? awardFullConsignorFeeEvenWhenItemsAreOverfulfilled, bool? defaultTreatConsignedQtyAsOwned, String? dateStamp, bool? defaultProcessConsignmentSelectAllInvoices, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings -
Available on WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings, provided by the $WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettingsExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? consignmentSettingsId, Wrapped<String?> ? consignmentSettingsName, Wrapped<bool?> ? enableConsignment, Wrapped<String?> ? consignmentColor, Wrapped<String?> ? consignorFeePoRateId, Wrapped<String?> ? consignorFeePoRateICode, Wrapped<String?> ? consignorFeePoRateDescription, Wrapped<String?> ? consignorFeePoTypeId, Wrapped<String?> ? consignorFeePoDescription, Wrapped<String?> ? consignorFeePoType, Wrapped<String?> ? defaultConsignorFeeBasedOn, Wrapped<int?> ? defaultConsignorPercent, Wrapped<int?> ? defaultHousePercent, Wrapped<String?> ? reReceiveConsignedItemUnretiredReasonId, Wrapped<String?> ? reReceiveConsignedItemUnretiredReason, Wrapped<bool?> ? hideConsignmentTransactionsOnSubRentalTab, Wrapped<bool?> ? awardConsignorFeesForStaged, Wrapped<bool?> ? awardFullConsignorFeeEvenWhenItemsAreOverfulfilled, Wrapped<bool?> ? defaultTreatConsignedQtyAsOwned, Wrapped<String?> ? dateStamp, Wrapped<bool?> ? defaultProcessConsignmentSelectAllInvoices, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings -
Available on WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings, provided by the $WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsSystemSettingsConsignmentSettingsConsignmentSettings instance)