WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings({String? defaultSettingsId, String? defaultUnitId, String? defaultSettingsName, String? defaultUnit, String? defaultDealStatusId, String? defaultDealStatus, String? defaultCustomerStatusId, String? defaultCustomerStatus, String? defaultDealBillingCycleId, String? defaultDealBillingCycle, bool? defaultDealPoRequired, String? defaultDealPoType, String? defaultNonRecurringBillingCycleId, String? defaultNonRecurringBillingCycle, String? defaultCustomerPaymentTermsId, String? defaultCustomerPaymentTerms, String? defaultContactGroupId, String? defaultContactGroupName, String? defaultRank, String? defaultCreditStatusId, String? defaultCreditStatus, bool? contactShowAllDeals, String? defaultVendorBillingCycleId, String? defaultVendorBillingCycle, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- contactShowAllDeals → bool?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
- defaultContactGroupId → String?
-
final
- defaultContactGroupName → String?
-
final
- defaultCreditStatus → String?
-
final
- defaultCreditStatusId → String?
-
final
- defaultCustomerPaymentTerms → String?
-
final
- defaultCustomerPaymentTermsId → String?
-
final
- defaultCustomerStatus → String?
-
final
- defaultCustomerStatusId → String?
-
final
- defaultDealBillingCycle → String?
-
final
- defaultDealBillingCycleId → String?
-
final
- defaultDealPoRequired → bool?
-
final
- defaultDealPoType → String?
-
final
- defaultDealStatus → String?
-
final
- defaultDealStatusId → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultNonRecurringBillingCycle → String?
-
final
- defaultNonRecurringBillingCycleId → String?
-
final
- defaultRank → String?
-
final
- defaultSettingsId → String?
-
final
- defaultSettingsName → String?
-
final
- defaultUnit → String?
-
final
- defaultUnitId → String?
-
final
- defaultVendorBillingCycle → String?
-
final
- defaultVendorBillingCycleId → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? defaultSettingsId, String? defaultUnitId, String? defaultSettingsName, String? defaultUnit, String? defaultDealStatusId, String? defaultDealStatus, String? defaultCustomerStatusId, String? defaultCustomerStatus, String? defaultDealBillingCycleId, String? defaultDealBillingCycle, bool? defaultDealPoRequired, String? defaultDealPoType, String? defaultNonRecurringBillingCycleId, String? defaultNonRecurringBillingCycle, String? defaultCustomerPaymentTermsId, String? defaultCustomerPaymentTerms, String? defaultContactGroupId, String? defaultContactGroupName, String? defaultRank, String? defaultCreditStatusId, String? defaultCreditStatus, bool? contactShowAllDeals, String? defaultVendorBillingCycleId, String? defaultVendorBillingCycle, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings -
Available on WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings, provided by the $WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsSystemSettingsDefaultSettingsDefaultSettings instance)