WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings({String? inventorySettingsId, String? inventorySettingsName, String? iCodeMask, bool? userAssignedICodes, int? lastICode, String? iCodePrefix, bool? enable3WeekPricing, bool? enableTieredWeekPricing, String? salesCheckOutRetiredReasonId, String? salesCheckOutRetiredReason, String? salesCheckInUnretiredReasonId, String? salesCheckInUnretiredReason, String? defaultRentalSaleRetiredReasonId, String? defaultRentalSaleRetiredReason, String? defaultLossAndDamageRetiredReasonId, String? defaultLossAndDamageRetiredReason, bool? startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived, bool? depreciateFixedAssetsWhenRetired, bool? includeTaxInOriginalEquipmentCost, String? defaultRentalQuantityInventoryCostCalculation, String? defaultSalesQuantityInventoryCostCalculation, String? defaultPartsQuantityInventoryCostCalculation, bool? enableLease, bool? autoUpdateInventoryMetricImperialDimensions, bool? fixedAssetTransferFutureDepreciation, String? changeICodeRetiredReasonId, String? changeICodeRetiredReason, bool? changeICodeCreateBrandNewPurchase, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- autoUpdateInventoryMetricImperialDimensions → bool?
-
final
- changeICodeCreateBrandNewPurchase → bool?
-
final
- changeICodeRetiredReason → String?
-
final
- changeICodeRetiredReasonId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultLossAndDamageRetiredReason → String?
-
final
- defaultLossAndDamageRetiredReasonId → String?
-
final
- defaultPartsQuantityInventoryCostCalculation → String?
-
final
- defaultRentalQuantityInventoryCostCalculation → String?
-
final
- defaultRentalSaleRetiredReason → String?
-
final
- defaultRentalSaleRetiredReasonId → String?
-
final
- defaultSalesQuantityInventoryCostCalculation → String?
-
final
- depreciateFixedAssetsWhenRetired → bool?
-
final
- enable3WeekPricing → bool?
-
final
- enableLease → bool?
-
final
- enableTieredWeekPricing → bool?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- fixedAssetTransferFutureDepreciation → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iCodeMask → String?
-
final
- iCodePrefix → String?
-
final
- includeTaxInOriginalEquipmentCost → bool?
-
final
- inventorySettingsId → String?
-
final
- inventorySettingsName → String?
-
final
- lastICode → int?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesCheckInUnretiredReason → String?
-
final
- salesCheckInUnretiredReasonId → String?
-
final
- salesCheckOutRetiredReason → String?
-
final
- salesCheckOutRetiredReasonId → String?
-
final
- startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived → bool?
-
final
- userAssignedICodes → bool?
-
final
Methods
-
copyWith(
{String? inventorySettingsId, String? inventorySettingsName, String? iCodeMask, bool? userAssignedICodes, int? lastICode, String? iCodePrefix, bool? enable3WeekPricing, bool? enableTieredWeekPricing, String? salesCheckOutRetiredReasonId, String? salesCheckOutRetiredReason, String? salesCheckInUnretiredReasonId, String? salesCheckInUnretiredReason, String? defaultRentalSaleRetiredReasonId, String? defaultRentalSaleRetiredReason, String? defaultLossAndDamageRetiredReasonId, String? defaultLossAndDamageRetiredReason, bool? startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived, bool? depreciateFixedAssetsWhenRetired, bool? includeTaxInOriginalEquipmentCost, String? defaultRentalQuantityInventoryCostCalculation, String? defaultSalesQuantityInventoryCostCalculation, String? defaultPartsQuantityInventoryCostCalculation, bool? enableLease, bool? autoUpdateInventoryMetricImperialDimensions, bool? fixedAssetTransferFutureDepreciation, String? changeICodeRetiredReasonId, String? changeICodeRetiredReason, bool? changeICodeCreateBrandNewPurchase, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings -
Available on WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings, provided by the $WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettingsExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? inventorySettingsId, Wrapped<String?> ? inventorySettingsName, Wrapped<String?> ? iCodeMask, Wrapped<bool?> ? userAssignedICodes, Wrapped<int?> ? lastICode, Wrapped<String?> ? iCodePrefix, Wrapped<bool?> ? enable3WeekPricing, Wrapped<bool?> ? enableTieredWeekPricing, Wrapped<String?> ? salesCheckOutRetiredReasonId, Wrapped<String?> ? salesCheckOutRetiredReason, Wrapped<String?> ? salesCheckInUnretiredReasonId, Wrapped<String?> ? salesCheckInUnretiredReason, Wrapped<String?> ? defaultRentalSaleRetiredReasonId, Wrapped<String?> ? defaultRentalSaleRetiredReason, Wrapped<String?> ? defaultLossAndDamageRetiredReasonId, Wrapped<String?> ? defaultLossAndDamageRetiredReason, Wrapped<bool?> ? startDepreciatingFixedAssetsTheMonthAfterTheyAreReceived, Wrapped<bool?> ? depreciateFixedAssetsWhenRetired, Wrapped<bool?> ? includeTaxInOriginalEquipmentCost, Wrapped<String?> ? defaultRentalQuantityInventoryCostCalculation, Wrapped<String?> ? defaultSalesQuantityInventoryCostCalculation, Wrapped<String?> ? defaultPartsQuantityInventoryCostCalculation, Wrapped<bool?> ? enableLease, Wrapped<bool?> ? autoUpdateInventoryMetricImperialDimensions, Wrapped<bool?> ? fixedAssetTransferFutureDepreciation, Wrapped<String?> ? changeICodeRetiredReasonId, Wrapped<String?> ? changeICodeRetiredReason, Wrapped<bool?> ? changeICodeCreateBrandNewPurchase, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes}) → WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettingsFwStandardDataFwDefaultAttribute> ?> -
Available on WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings, provided by the $WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsSystemSettingsInventorySettingsInventorySettings instance)