WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings({String? systemSettingsId, bool? isVendorNumberAssignedByUser, int? lastVendorNumber, bool? allowDeleteExportedReceipts, bool? enableReceipts, bool? enableVendorInvoice, double? closePoReminingInvoiceAmount, bool? enableBetaUpdates, bool? enableQaUpdates, bool? enablePayments, bool? allowDeleteExportedPayments, bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? ordersCompleteWithItemsNotYetStaged, int? billingScheduleAutoRecalculateThreshold, bool? defaultBillingSelectAllOrders, bool? defaultProcessConsignmentSelectAllInvoices, bool? synchronizeCustomerStatusAndCreditStatus, bool? synchronizeDealStatusAndCreditStatus, bool? changeCustomerStatusIfNoInvoices, String? changeToCustomerStatusIdIfNoInvoices, String? changeToCustomerStatusIfNoInvoices, bool? changeDealStatusIfNoInvoices, String? changeToDealStatusIdIfNoInvoices, String? changeToDealStatusIfNoInvoices, int? changeCustomerStatusIfNoInvoicesDays, int? changeDealStatusIfNoInvoicesDays, String? quoteOrderMessageFormat, bool? enableOriginalShow, bool? enablePropsWardrobe, bool? enableSetsWalls, int? deleteDataHealthDays, bool? allCaps, bool? enableQuikLocate, bool? quikSearchDontUpdateBottomLine, bool? hasInternalVendors, bool? disableCrossWarehouseCheckIn, bool? enableCrew, bool? disableHelpIcon, bool? consolidateOwnedAndSubbedLineItems, bool? setSubQuantityToZero, bool? promptUserOnPasteLineItems, String? overrideHelpURL, bool? delayRevenueAndGlUntilMidnight, bool? purgeOrderAuditHistory, int? returnOnAssetYears, bool? returnOnAssetUseDaysBilled, String? returnOnAssetRevenueDate, String? systemSettingsName, String? companyName, String? systemName, String? databaseVersion, String? dataLanguageId, String? dataLanguage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allCaps → bool?
-
final
- allowDeleteExportedPayments → bool?
-
final
- allowDeleteExportedReceipts → bool?
-
final
- allowDeleteInvoices → bool?
-
final
- allowInvoiceDateChange → bool?
-
final
- auditNote → String?
-
final
- billingScheduleAutoRecalculateThreshold → int?
-
final
- changeCustomerStatusIfNoInvoices → bool?
-
final
- changeCustomerStatusIfNoInvoicesDays → int?
-
final
- changeDealStatusIfNoInvoices → bool?
-
final
- changeDealStatusIfNoInvoicesDays → int?
-
final
- changeToCustomerStatusIdIfNoInvoices → String?
-
final
- changeToCustomerStatusIfNoInvoices → String?
-
final
- changeToDealStatusIdIfNoInvoices → String?
-
final
- changeToDealStatusIfNoInvoices → String?
-
final
- closePoReminingInvoiceAmount → double?
-
final
- companyName → String?
-
final
- consolidateOwnedAndSubbedLineItems → bool?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- databaseVersion → String?
-
final
- dataLanguage → String?
-
final
- dataLanguageId → String?
-
final
- dateStamp → String?
-
final
- defaultBillingSelectAllOrders → bool?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultProcessConsignmentSelectAllInvoices → bool?
-
final
- delayRevenueAndGlUntilMidnight → bool?
-
final
- deleteDataHealthDays → int?
-
final
- disableCrossWarehouseCheckIn → bool?
-
final
- disableHelpIcon → bool?
-
final
- enableBetaUpdates → bool?
-
final
- enableCrew → bool?
-
final
- enableOriginalShow → bool?
-
final
- enablePayments → bool?
-
final
- enablePropsWardrobe → bool?
-
final
- enableQaUpdates → bool?
-
final
- enableQuikLocate → bool?
-
final
- enableReceipts → bool?
-
final
- enableSetsWalls → bool?
-
final
- enableVendorInvoice → bool?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- hasInternalVendors → bool?
-
final
- isVendorNumberAssignedByUser → bool?
-
final
- lastVendorNumber → int?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- ordersCompleteWithItemsNotYetStaged → bool?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- overrideHelpURL → String?
-
final
- promptUserOnPasteLineItems → bool?
-
final
- purgeOrderAuditHistory → bool?
-
final
- quikSearchDontUpdateBottomLine → bool?
-
final
- quoteOrderMessageFormat → String?
-
final
- recordTitle → String?
-
final
- returnOnAssetRevenueDate → String?
-
final
- returnOnAssetUseDaysBilled → bool?
-
final
- returnOnAssetYears → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setSubQuantityToZero → bool?
-
final
-
final
- synchronizeCustomerStatusAndCreditStatus → bool?
-
final
- synchronizeDealStatusAndCreditStatus → bool?
-
final
- systemName → String?
-
final
- systemSettingsId → String?
-
final
- systemSettingsName → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? systemSettingsId, bool? isVendorNumberAssignedByUser, int? lastVendorNumber, bool? allowDeleteExportedReceipts, bool? enableReceipts, bool? enableVendorInvoice, double? closePoReminingInvoiceAmount, bool? enableBetaUpdates, bool? enableQaUpdates, bool? enablePayments, bool? allowDeleteExportedPayments, bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? ordersCompleteWithItemsNotYetStaged, int? billingScheduleAutoRecalculateThreshold, bool? defaultBillingSelectAllOrders, bool? defaultProcessConsignmentSelectAllInvoices, bool? synchronizeCustomerStatusAndCreditStatus, bool? synchronizeDealStatusAndCreditStatus, bool? changeCustomerStatusIfNoInvoices, String? changeToCustomerStatusIdIfNoInvoices, String? changeToCustomerStatusIfNoInvoices, bool? changeDealStatusIfNoInvoices, String? changeToDealStatusIdIfNoInvoices, String? changeToDealStatusIfNoInvoices, int? changeCustomerStatusIfNoInvoicesDays, int? changeDealStatusIfNoInvoicesDays, String? quoteOrderMessageFormat, bool? enableOriginalShow, bool? enablePropsWardrobe, bool? enableSetsWalls, int? deleteDataHealthDays, bool? allCaps, bool? enableQuikLocate, bool? quikSearchDontUpdateBottomLine, bool? hasInternalVendors, bool? disableCrossWarehouseCheckIn, bool? enableCrew, bool? disableHelpIcon, bool? consolidateOwnedAndSubbedLineItems, bool? setSubQuantityToZero, bool? promptUserOnPasteLineItems, String? overrideHelpURL, bool? delayRevenueAndGlUntilMidnight, bool? purgeOrderAuditHistory, int? returnOnAssetYears, bool? returnOnAssetUseDaysBilled, String? returnOnAssetRevenueDate, String? systemSettingsName, String? companyName, String? systemName, String? databaseVersion, String? dataLanguageId, String? dataLanguage, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings -
Available on WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings, provided by the $WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettingsExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? systemSettingsId, Wrapped<bool?> ? isVendorNumberAssignedByUser, Wrapped<int?> ? lastVendorNumber, Wrapped<bool?> ? allowDeleteExportedReceipts, Wrapped<bool?> ? enableReceipts, Wrapped<bool?> ? enableVendorInvoice, Wrapped<double?> ? closePoReminingInvoiceAmount, Wrapped<bool?> ? enableBetaUpdates, Wrapped<bool?> ? enableQaUpdates, Wrapped<bool?> ? enablePayments, Wrapped<bool?> ? allowDeleteExportedPayments, Wrapped<bool?> ? allowDeleteInvoices, Wrapped<bool?> ? allowInvoiceDateChange, Wrapped<bool?> ? ordersCompleteWithItemsNotYetStaged, Wrapped<int?> ? billingScheduleAutoRecalculateThreshold, Wrapped<bool?> ? defaultBillingSelectAllOrders, Wrapped<bool?> ? defaultProcessConsignmentSelectAllInvoices, Wrapped<bool?> ? synchronizeCustomerStatusAndCreditStatus, Wrapped<bool?> ? synchronizeDealStatusAndCreditStatus, Wrapped<bool?> ? changeCustomerStatusIfNoInvoices, Wrapped<String?> ? changeToCustomerStatusIdIfNoInvoices, Wrapped<String?> ? changeToCustomerStatusIfNoInvoices, Wrapped<bool?> ? changeDealStatusIfNoInvoices, Wrapped<String?> ? changeToDealStatusIdIfNoInvoices, Wrapped<String?> ? changeToDealStatusIfNoInvoices, Wrapped<int?> ? changeCustomerStatusIfNoInvoicesDays, Wrapped<int?> ? changeDealStatusIfNoInvoicesDays, Wrapped<String?> ? quoteOrderMessageFormat, Wrapped<bool?> ? enableOriginalShow, Wrapped<bool?> ? enablePropsWardrobe, Wrapped<bool?> ? enableSetsWalls, Wrapped<int?> ? deleteDataHealthDays, Wrapped<bool?> ? allCaps, Wrapped<bool?> ? enableQuikLocate, Wrapped<bool?> ? quikSearchDontUpdateBottomLine, Wrapped<bool?> ? hasInternalVendors, Wrapped<bool?> ? disableCrossWarehouseCheckIn, Wrapped<bool?> ? enableCrew, Wrapped<bool?> ? disableHelpIcon, Wrapped<bool?> ? consolidateOwnedAndSubbedLineItems, Wrapped<bool?> ? setSubQuantityToZero, Wrapped<bool?> ? promptUserOnPasteLineItems, Wrapped<String?> ? overrideHelpURL, Wrapped<bool?> ? delayRevenueAndGlUntilMidnight, Wrapped<bool?> ? purgeOrderAuditHistory, Wrapped<int?> ? returnOnAssetYears, Wrapped<bool?> ? returnOnAssetUseDaysBilled, Wrapped<String?> ? returnOnAssetRevenueDate, Wrapped<String?> ? systemSettingsName, Wrapped<String?> ? companyName, Wrapped<String?> ? systemName, Wrapped<String?> ? databaseVersion, Wrapped<String?> ? dataLanguageId, Wrapped<String?> ? dataLanguage, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings -
Available on WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings, provided by the $WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings instance)