WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings({String? systemSettingsId, String? systemSettingsName, String? companyName, String? systemName, String? databaseVersion, bool? shareDealsAcrossOfficeLocations, bool? isVendorNumberAssignedByUser, int? lastVendorNumber, bool? allowDeleteExportedReceipts, bool? enableReceipts, bool? enableBetaUpdates, bool? enableQaUpdates, bool? enablePayments, bool? allowDeleteExportedPayments, bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? ordersCompleteWithItemsNotYetStaged, bool? populateInventoryUtilizationDataWeekly, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings.fromJson(Map<String, dynamic> json)
factory

Properties

allowDeleteExportedPayments bool?
final
allowDeleteExportedReceipts bool?
final
allowDeleteInvoices bool?
final
allowInvoiceDateChange bool?
final
auditNote String?
final
companyName String?
final
custom List<FwStandardDataFwCustomValue>?
final
databaseVersion String?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
enableBetaUpdates bool?
final
enablePayments bool?
final
enableQaUpdates bool?
final
enableReceipts bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
isVendorNumberAssignedByUser bool?
final
lastVendorNumber int?
final
ordersCompleteWithItemsNotYetStaged bool?
final
populateInventoryUtilizationDataWeekly bool?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareDealsAcrossOfficeLocations bool?
final
systemName String?
final
systemSettingsId String?
final
systemSettingsName String?
final

Methods

copyWith({String? systemSettingsId, String? systemSettingsName, String? companyName, String? systemName, String? databaseVersion, bool? shareDealsAcrossOfficeLocations, bool? isVendorNumberAssignedByUser, int? lastVendorNumber, bool? allowDeleteExportedReceipts, bool? enableReceipts, bool? enableBetaUpdates, bool? enableQaUpdates, bool? enablePayments, bool? allowDeleteExportedPayments, bool? allowDeleteInvoices, bool? allowInvoiceDateChange, bool? ordersCompleteWithItemsNotYetStaged, bool? populateInventoryUtilizationDataWeekly, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings

Available on WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings, provided by the $WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettingsExtension extension

copyWithWrapped({Wrapped<String?>? systemSettingsId, Wrapped<String?>? systemSettingsName, Wrapped<String?>? companyName, Wrapped<String?>? systemName, Wrapped<String?>? databaseVersion, Wrapped<bool?>? shareDealsAcrossOfficeLocations, Wrapped<bool?>? isVendorNumberAssignedByUser, Wrapped<int?>? lastVendorNumber, Wrapped<bool?>? allowDeleteExportedReceipts, Wrapped<bool?>? enableReceipts, Wrapped<bool?>? enableBetaUpdates, Wrapped<bool?>? enableQaUpdates, Wrapped<bool?>? enablePayments, Wrapped<bool?>? allowDeleteExportedPayments, Wrapped<bool?>? allowDeleteInvoices, Wrapped<bool?>? allowInvoiceDateChange, Wrapped<bool?>? ordersCompleteWithItemsNotYetStaged, Wrapped<bool?>? populateInventoryUtilizationDataWeekly, Wrapped<String?>? dateStamp, Wrapped<String?>? auditNote, Wrapped<String?>? recordTitle, Wrapped<List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?>? fields, Wrapped<List<FwStandardDataFwCustomValue>?>? custom, Wrapped<List<FwStandardDataFwDefaultAttribute>?>? defaultFieldAttributes}) WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings

Available on WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettings, provided by the $WebApiModulesSettingsSystemSettingsSystemSettingsSystemSettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override