WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem({String? taxOptionItemId, double? taxRate, String? taxVendor, String? taxItemCode, String? taxItemDescription, String? taxOptionId, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- original → FwStandardBusinessLogicFwBusinessLogic?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxItemCode → String?
-
final
- taxItemDescription → String?
-
final
- taxOptionId → String?
-
final
- taxOptionItemId → String?
-
final
- taxRate → double?
-
final
- taxVendor → String?
-
final
-
translation
→ List<
FwStandardDataFwTranslatedValue> ? -
final
- urlIdentifier → dynamic
-
final
Methods
-
copyWith(
{String? taxOptionItemId, double? taxRate, String? taxVendor, String? taxItemCode, String? taxItemDescription, String? taxOptionId, String? dateStamp, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes, FwStandardBusinessLogicFwBusinessLogic? original, List<FwStandardDataFwTranslatedValue> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem -
Available on WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem, provided by the $WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItemExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? taxOptionItemId, Wrapped<double?> ? taxRate, Wrapped<String?> ? taxVendor, Wrapped<String?> ? taxItemCode, Wrapped<String?> ? taxItemDescription, Wrapped<String?> ? taxOptionId, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes, Wrapped<FwStandardDataFwDefaultAttribute> ?>FwStandardBusinessLogicFwBusinessLogic?> ? original, Wrapped<List< ? translation, Wrapped<FwStandardDataFwTranslatedValue> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem -
Available on WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem, provided by the $WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsTaxSettingsTaxOptionItemTaxOptionItem instance)