WebApiModulesSettingsTemplateSettingsTemplateTemplate class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsTemplateSettingsTemplateTemplate({String? templateId, String? description, String? departmentId, String? department, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, String? rateType, bool? rental, bool? sales, bool? miscellaneous, bool? labor, bool? facilities, bool? transportation, int? lines, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsTemplateSettingsTemplateTemplate.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- department → String?
-
final
- departmentId → String?
-
final
- description → String?
-
final
- facilities → bool?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hasFacilitiesItem → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasLaborItem → bool?
-
final
- hasMiscellaneousItem → bool?
-
final
- hasRentalItem → bool?
-
final
- hasSalesItem → bool?
-
final
- labor → bool?
-
final
- lines → int?
-
final
- miscellaneous → bool?
-
final
- officeLocation → String?
-
final
- officeLocationId → String?
-
final
- rateType → String?
-
final
- recordTitle → String?
-
final
- rental → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sales → bool?
-
final
- templateId → String?
-
final
- transportation → bool?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{String? templateId, String? description, String? departmentId, String? department, String? officeLocationId, String? officeLocation, String? warehouseId, String? warehouse, String? warehouseCode, String? rateType, bool? rental, bool? sales, bool? miscellaneous, bool? labor, bool? facilities, bool? transportation, int? lines, bool? hasRentalItem, bool? hasSalesItem, bool? hasMiscellaneousItem, bool? hasLaborItem, bool? hasFacilitiesItem, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsTemplateSettingsTemplateTemplate -
Available on WebApiModulesSettingsTemplateSettingsTemplateTemplate, provided by the $WebApiModulesSettingsTemplateSettingsTemplateTemplateExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsTemplateSettingsTemplateTemplate Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsTemplateSettingsTemplateTemplate instance)