WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse({String? vehicleTypeId, double? hourlyRate, double? dailyRate, double? weeklyRate, double? monthlyRate, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dailyRate double?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
hourlyRate double?
final
itemDescription String?
final
monthlyRate double?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vehicleTypeId String?
final
warehouse String?
final
warehouseCode String?
final
warehouseId String?
final
warehouseOrderBy int?
final
weeklyRate double?
final

Methods

copyWith({String? vehicleTypeId, double? hourlyRate, double? dailyRate, double? weeklyRate, double? monthlyRate, String? itemDescription, String? warehouseId, String? warehouseCode, String? warehouse, int? warehouseOrderBy, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse

Available on WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouse, provided by the $WebApiModulesSettingsVehicleTypeWarehouseVehicleTypeWarehouseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override