WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse({String? warehouseId, String? warehouse, String? warehouseCode, String? taxOptionId, String? taxOption, String? taxCountry, String? taxRule, double? rentalTaxRate1, double? rentalTaxRate2, bool? rentalExempt, double? salesTaxRate1, double? salesTaxRate2, bool? salesExempt, double? laborTaxRate1, double? laborTaxRate2, bool? laborExempt, String? attention, String? address1, String? address2, String? city, String? zipCode, String? state, String? countryId, String? country, String? phone, String? fax, String? assignBarCodesBy, double? salesMarkupPercent, double? partsMarkupPercent, bool? markupSales, bool? markupParts, bool? includeFreightInSalesCost, bool? includeFreightInPartsCost, bool? receiveVendorBarCodes, bool? allowNegativeInventory, String? defaultDeliveryType, bool? exchangedItemsRepairByDefault, String? stagingCompleteComponents, String? checkInSortBy, String? defaultPackageTruckScheduleMethod, bool? stageQuantityAccessories, bool? promptForCheckOutExceptions, bool? promptForCheckInExceptions, bool? deleteAssetLocationOnOut, bool? deleteAssetConditionOnOut, bool? stagingShowCheckedInHoldingItems, String? poDeliveryType, int? availabilityCacheDays, bool? availabilityPreserveConflicts, int? defaultRepairDays, String? quikLocateDefaultDeliveryType, String? repairBillableOrderAgentFrom, bool? returnListPrintInQuantity, bool? returnListPrintOutQuantity, bool? availabilityUseOnPO, String? regionId, String? region, String? color, int? availabilityLateDays, bool? useBarCodeLabelDesigner, String? inventoryLabelDesignId, String? inventoryLabelDesign, String? itemLabelDesignId, String? itemLabelDesign, bool? dataWarehouseExcludeFromROA, int? availabilityLateHours, int? availabilityStartHour, int? availabilityStopHour, bool? includeTaxInAssetValue, int? productionExchangeAvailabilityPercent, bool? productionexchangeEnabled, String? productionExchangeWarehouseCode, double? week4RatePercent, String? glSuffix, bool? requireScanVendorBarCodeOnReturn, String? glPrefix, String? internalDealId, String? internalDeal, String? internalVendorId, String? internalVendor, bool? calculateOnPoAfterApproved, bool? transferDefaultReturnToWarehouse, bool? availabilityCalculateInBackground, bool? quikLocateCannotTransfer, String? quikLocateDefaultRequiredDate, int? quikLocateRequiredDaysBefore, bool? calculateDefaultRentalRates, double? rentalDailyRatePercentOfReplacementCost, double? rentalWeeklyRateMultipleOfDailyRate, bool? checkInEnableScanningToAisleShelf, String? currencyId, String? currencyCode, String? currency, String? rentalBarCodeRangeId, String? rentalBarCodeRange, String? rentalFixedAssetBarCodeRangeId, String? rentalFixedAssetBarCodeRange, String? salesBarCodeRangeId, String? salesBarCodeRange, bool? autoUpdateUnitValueOnReceivingHigherCostItem, bool? markupReplacementCost, double? replacementCostMarkupPercent, int? availabilityHourlyDays, int? transferAvailabilityDays, double? salesRestockPercent, bool? availabilityExcludeConsigned, bool? availabilityRequireConsignedReserved, bool? availabilityEnableQcDelay, bool? availabilityQcDelayExcludeWeekend, bool? availabilityQcDelayExcludeHoliday, bool? availabilityQcDelayIndefinite, bool? defaultNoChargePrintItemsAddedToOrderAtStaging, bool? quikReceiptEnable, bool? storageContainerCheckInEnable, bool? storageContainerStagingEnable, bool? storageContainerRescanRequired, String? quikReceiptTermsConditionsId, String? quikReceiptTermsConditions, bool? disableSubstituteNote, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address1 → String?
-
final
- address2 → String?
-
final
- allowNegativeInventory → bool?
-
final
- assignBarCodesBy → String?
-
final
- attention → String?
-
final
- auditNote → String?
-
final
- autoUpdateUnitValueOnReceivingHigherCostItem → bool?
-
final
- availabilityCacheDays → int?
-
final
- availabilityCalculateInBackground → bool?
-
final
- availabilityEnableQcDelay → bool?
-
final
- availabilityExcludeConsigned → bool?
-
final
- availabilityHourlyDays → int?
-
final
- availabilityLateDays → int?
-
final
- availabilityLateHours → int?
-
final
- availabilityPreserveConflicts → bool?
-
final
- availabilityQcDelayExcludeHoliday → bool?
-
final
- availabilityQcDelayExcludeWeekend → bool?
-
final
- availabilityQcDelayIndefinite → bool?
-
final
- availabilityRequireConsignedReserved → bool?
-
final
- availabilityStartHour → int?
-
final
- availabilityStopHour → int?
-
final
- availabilityUseOnPO → bool?
-
final
- calculateDefaultRentalRates → bool?
-
final
- calculateOnPoAfterApproved → bool?
-
final
- checkInEnableScanningToAisleShelf → bool?
-
final
- checkInSortBy → String?
-
final
- city → String?
-
final
- color → String?
-
final
- country → String?
-
final
- countryId → String?
-
final
- currency → String?
-
final
- currencyCode → String?
-
final
- currencyId → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dataWarehouseExcludeFromROA → bool?
-
final
- dateStamp → String?
-
final
- defaultDeliveryType → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- defaultNoChargePrintItemsAddedToOrderAtStaging → bool?
-
final
- defaultPackageTruckScheduleMethod → String?
-
final
- defaultRepairDays → int?
-
final
- deleteAssetConditionOnOut → bool?
-
final
- deleteAssetLocationOnOut → bool?
-
final
- disableSubstituteNote → bool?
-
final
- exchangedItemsRepairByDefault → bool?
-
final
- fax → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- glPrefix → String?
-
final
- glSuffix → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactive → bool?
-
final
- includeFreightInPartsCost → bool?
-
final
- includeFreightInSalesCost → bool?
-
final
- includeTaxInAssetValue → bool?
-
final
- internalDeal → String?
-
final
- internalDealId → String?
-
final
- internalVendor → String?
-
final
- internalVendorId → String?
-
final
- inventoryLabelDesign → String?
-
final
- inventoryLabelDesignId → String?
-
final
- itemLabelDesign → String?
-
final
- itemLabelDesignId → String?
-
final
- laborExempt → bool?
-
final
- laborTaxRate1 → double?
-
final
- laborTaxRate2 → double?
-
final
- markupParts → bool?
-
final
- markupReplacementCost → bool?
-
final
- markupSales → bool?
-
final
- partsMarkupPercent → double?
-
final
- phone → String?
-
final
- poDeliveryType → String?
-
final
- productionExchangeAvailabilityPercent → int?
-
final
- productionexchangeEnabled → bool?
-
final
- productionExchangeWarehouseCode → String?
-
final
- promptForCheckInExceptions → bool?
-
final
- promptForCheckOutExceptions → bool?
-
final
- quikLocateCannotTransfer → bool?
-
final
- quikLocateDefaultDeliveryType → String?
-
final
- quikLocateDefaultRequiredDate → String?
-
final
- quikLocateRequiredDaysBefore → int?
-
final
- quikReceiptEnable → bool?
-
final
- quikReceiptTermsConditions → String?
-
final
- quikReceiptTermsConditionsId → String?
-
final
- receiveVendorBarCodes → bool?
-
final
- recordTitle → String?
-
final
- region → String?
-
final
- regionId → String?
-
final
- rentalBarCodeRange → String?
-
final
- rentalBarCodeRangeId → String?
-
final
- rentalDailyRatePercentOfReplacementCost → double?
-
final
- rentalExempt → bool?
-
final
- rentalFixedAssetBarCodeRange → String?
-
final
- rentalFixedAssetBarCodeRangeId → String?
-
final
- rentalTaxRate1 → double?
-
final
- rentalTaxRate2 → double?
-
final
- rentalWeeklyRateMultipleOfDailyRate → double?
-
final
- repairBillableOrderAgentFrom → String?
-
final
- replacementCostMarkupPercent → double?
-
final
- requireScanVendorBarCodeOnReturn → bool?
-
final
- returnListPrintInQuantity → bool?
-
final
- returnListPrintOutQuantity → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesBarCodeRange → String?
-
final
- salesBarCodeRangeId → String?
-
final
- salesExempt → bool?
-
final
- salesMarkupPercent → double?
-
final
- salesRestockPercent → double?
-
final
- salesTaxRate1 → double?
-
final
- salesTaxRate2 → double?
-
final
- stageQuantityAccessories → bool?
-
final
- stagingCompleteComponents → String?
-
final
- stagingShowCheckedInHoldingItems → bool?
-
final
- state → String?
-
final
- storageContainerCheckInEnable → bool?
-
final
- storageContainerRescanRequired → bool?
-
final
- storageContainerStagingEnable → bool?
-
final
- taxCountry → String?
-
final
- taxOption → String?
-
final
- taxOptionId → String?
-
final
- taxRule → String?
-
final
- transferAvailabilityDays → int?
-
final
- transferDefaultReturnToWarehouse → bool?
-
final
- useBarCodeLabelDesigner → bool?
-
final
- warehouse → String?
-
final
- warehouseCode → String?
-
final
- warehouseId → String?
-
final
- week4RatePercent → double?
-
final
- zipCode → String?
-
final
Methods
-
copyWith(
{String? warehouseId, String? warehouse, String? warehouseCode, String? taxOptionId, String? taxOption, String? taxCountry, String? taxRule, double? rentalTaxRate1, double? rentalTaxRate2, bool? rentalExempt, double? salesTaxRate1, double? salesTaxRate2, bool? salesExempt, double? laborTaxRate1, double? laborTaxRate2, bool? laborExempt, String? attention, String? address1, String? address2, String? city, String? zipCode, String? state, String? countryId, String? country, String? phone, String? fax, String? assignBarCodesBy, double? salesMarkupPercent, double? partsMarkupPercent, bool? markupSales, bool? markupParts, bool? includeFreightInSalesCost, bool? includeFreightInPartsCost, bool? receiveVendorBarCodes, bool? allowNegativeInventory, String? defaultDeliveryType, bool? exchangedItemsRepairByDefault, String? stagingCompleteComponents, String? checkInSortBy, String? defaultPackageTruckScheduleMethod, bool? stageQuantityAccessories, bool? promptForCheckOutExceptions, bool? promptForCheckInExceptions, bool? deleteAssetLocationOnOut, bool? deleteAssetConditionOnOut, bool? stagingShowCheckedInHoldingItems, String? poDeliveryType, int? availabilityCacheDays, bool? availabilityPreserveConflicts, int? defaultRepairDays, String? quikLocateDefaultDeliveryType, String? repairBillableOrderAgentFrom, bool? returnListPrintInQuantity, bool? returnListPrintOutQuantity, bool? availabilityUseOnPO, String? regionId, String? region, String? color, int? availabilityLateDays, bool? useBarCodeLabelDesigner, String? inventoryLabelDesignId, String? inventoryLabelDesign, String? itemLabelDesignId, String? itemLabelDesign, bool? dataWarehouseExcludeFromROA, int? availabilityLateHours, int? availabilityStartHour, int? availabilityStopHour, bool? includeTaxInAssetValue, int? productionExchangeAvailabilityPercent, bool? productionexchangeEnabled, String? productionExchangeWarehouseCode, double? week4RatePercent, String? glSuffix, bool? requireScanVendorBarCodeOnReturn, String? glPrefix, String? internalDealId, String? internalDeal, String? internalVendorId, String? internalVendor, bool? calculateOnPoAfterApproved, bool? transferDefaultReturnToWarehouse, bool? availabilityCalculateInBackground, bool? quikLocateCannotTransfer, String? quikLocateDefaultRequiredDate, int? quikLocateRequiredDaysBefore, bool? calculateDefaultRentalRates, double? rentalDailyRatePercentOfReplacementCost, double? rentalWeeklyRateMultipleOfDailyRate, bool? checkInEnableScanningToAisleShelf, String? currencyId, String? currencyCode, String? currency, String? rentalBarCodeRangeId, String? rentalBarCodeRange, String? rentalFixedAssetBarCodeRangeId, String? rentalFixedAssetBarCodeRange, String? salesBarCodeRangeId, String? salesBarCodeRange, bool? autoUpdateUnitValueOnReceivingHigherCostItem, bool? markupReplacementCost, double? replacementCostMarkupPercent, int? availabilityHourlyDays, int? transferAvailabilityDays, double? salesRestockPercent, bool? availabilityExcludeConsigned, bool? availabilityRequireConsignedReserved, bool? availabilityEnableQcDelay, bool? availabilityQcDelayExcludeWeekend, bool? availabilityQcDelayExcludeHoliday, bool? availabilityQcDelayIndefinite, bool? defaultNoChargePrintItemsAddedToOrderAtStaging, bool? quikReceiptEnable, bool? storageContainerCheckInEnable, bool? storageContainerStagingEnable, bool? storageContainerRescanRequired, String? quikReceiptTermsConditionsId, String? quikReceiptTermsConditions, bool? disableSubstituteNote, bool? inactive, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse -
Available on WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse, provided by the $WebApiModulesSettingsWarehouseSettingsWarehouseWarehouseExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? warehouseId, Wrapped<String?> ? warehouse, Wrapped<String?> ? warehouseCode, Wrapped<String?> ? taxOptionId, Wrapped<String?> ? taxOption, Wrapped<String?> ? taxCountry, Wrapped<String?> ? taxRule, Wrapped<double?> ? rentalTaxRate1, Wrapped<double?> ? rentalTaxRate2, Wrapped<bool?> ? rentalExempt, Wrapped<double?> ? salesTaxRate1, Wrapped<double?> ? salesTaxRate2, Wrapped<bool?> ? salesExempt, Wrapped<double?> ? laborTaxRate1, Wrapped<double?> ? laborTaxRate2, Wrapped<bool?> ? laborExempt, Wrapped<String?> ? attention, Wrapped<String?> ? address1, Wrapped<String?> ? address2, Wrapped<String?> ? city, Wrapped<String?> ? zipCode, Wrapped<String?> ? state, Wrapped<String?> ? countryId, Wrapped<String?> ? country, Wrapped<String?> ? phone, Wrapped<String?> ? fax, Wrapped<String?> ? assignBarCodesBy, Wrapped<double?> ? salesMarkupPercent, Wrapped<double?> ? partsMarkupPercent, Wrapped<bool?> ? markupSales, Wrapped<bool?> ? markupParts, Wrapped<bool?> ? includeFreightInSalesCost, Wrapped<bool?> ? includeFreightInPartsCost, Wrapped<bool?> ? receiveVendorBarCodes, Wrapped<bool?> ? allowNegativeInventory, Wrapped<String?> ? defaultDeliveryType, Wrapped<bool?> ? exchangedItemsRepairByDefault, Wrapped<String?> ? stagingCompleteComponents, Wrapped<String?> ? checkInSortBy, Wrapped<String?> ? defaultPackageTruckScheduleMethod, Wrapped<bool?> ? stageQuantityAccessories, Wrapped<bool?> ? promptForCheckOutExceptions, Wrapped<bool?> ? promptForCheckInExceptions, Wrapped<bool?> ? deleteAssetLocationOnOut, Wrapped<bool?> ? deleteAssetConditionOnOut, Wrapped<bool?> ? stagingShowCheckedInHoldingItems, Wrapped<String?> ? poDeliveryType, Wrapped<int?> ? availabilityCacheDays, Wrapped<bool?> ? availabilityPreserveConflicts, Wrapped<int?> ? defaultRepairDays, Wrapped<String?> ? quikLocateDefaultDeliveryType, Wrapped<String?> ? repairBillableOrderAgentFrom, Wrapped<bool?> ? returnListPrintInQuantity, Wrapped<bool?> ? returnListPrintOutQuantity, Wrapped<bool?> ? availabilityUseOnPO, Wrapped<String?> ? regionId, Wrapped<String?> ? region, Wrapped<String?> ? color, Wrapped<int?> ? availabilityLateDays, Wrapped<bool?> ? useBarCodeLabelDesigner, Wrapped<String?> ? inventoryLabelDesignId, Wrapped<String?> ? inventoryLabelDesign, Wrapped<String?> ? itemLabelDesignId, Wrapped<String?> ? itemLabelDesign, Wrapped<bool?> ? dataWarehouseExcludeFromROA, Wrapped<int?> ? availabilityLateHours, Wrapped<int?> ? availabilityStartHour, Wrapped<int?> ? availabilityStopHour, Wrapped<bool?> ? includeTaxInAssetValue, Wrapped<int?> ? productionExchangeAvailabilityPercent, Wrapped<bool?> ? productionexchangeEnabled, Wrapped<String?> ? productionExchangeWarehouseCode, Wrapped<double?> ? week4RatePercent, Wrapped<String?> ? glSuffix, Wrapped<bool?> ? requireScanVendorBarCodeOnReturn, Wrapped<String?> ? glPrefix, Wrapped<String?> ? internalDealId, Wrapped<String?> ? internalDeal, Wrapped<String?> ? internalVendorId, Wrapped<String?> ? internalVendor, Wrapped<bool?> ? calculateOnPoAfterApproved, Wrapped<bool?> ? transferDefaultReturnToWarehouse, Wrapped<bool?> ? availabilityCalculateInBackground, Wrapped<bool?> ? quikLocateCannotTransfer, Wrapped<String?> ? quikLocateDefaultRequiredDate, Wrapped<int?> ? quikLocateRequiredDaysBefore, Wrapped<bool?> ? calculateDefaultRentalRates, Wrapped<double?> ? rentalDailyRatePercentOfReplacementCost, Wrapped<double?> ? rentalWeeklyRateMultipleOfDailyRate, Wrapped<bool?> ? checkInEnableScanningToAisleShelf, Wrapped<String?> ? currencyId, Wrapped<String?> ? currencyCode, Wrapped<String?> ? currency, Wrapped<String?> ? rentalBarCodeRangeId, Wrapped<String?> ? rentalBarCodeRange, Wrapped<String?> ? rentalFixedAssetBarCodeRangeId, Wrapped<String?> ? rentalFixedAssetBarCodeRange, Wrapped<String?> ? salesBarCodeRangeId, Wrapped<String?> ? salesBarCodeRange, Wrapped<bool?> ? autoUpdateUnitValueOnReceivingHigherCostItem, Wrapped<bool?> ? markupReplacementCost, Wrapped<double?> ? replacementCostMarkupPercent, Wrapped<int?> ? availabilityHourlyDays, Wrapped<int?> ? transferAvailabilityDays, Wrapped<double?> ? salesRestockPercent, Wrapped<bool?> ? availabilityExcludeConsigned, Wrapped<bool?> ? availabilityRequireConsignedReserved, Wrapped<bool?> ? availabilityEnableQcDelay, Wrapped<bool?> ? availabilityQcDelayExcludeWeekend, Wrapped<bool?> ? availabilityQcDelayExcludeHoliday, Wrapped<bool?> ? availabilityQcDelayIndefinite, Wrapped<bool?> ? defaultNoChargePrintItemsAddedToOrderAtStaging, Wrapped<bool?> ? quikReceiptEnable, Wrapped<bool?> ? storageContainerCheckInEnable, Wrapped<bool?> ? storageContainerStagingEnable, Wrapped<bool?> ? storageContainerRescanRequired, Wrapped<String?> ? quikReceiptTermsConditionsId, Wrapped<String?> ? quikReceiptTermsConditions, Wrapped<bool?> ? disableSubstituteNote, Wrapped<bool?> ? inactive, Wrapped<String?> ? dateStamp, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped<List< ? fields, Wrapped<FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ?>List< ? custom, Wrapped<FwStandardDataFwCustomValue> ?>List< ? defaultFieldAttributes}) → WebApiModulesSettingsWarehouseSettingsWarehouseWarehouseFwStandardDataFwDefaultAttribute> ?> -
Available on WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse, provided by the $WebApiModulesSettingsWarehouseSettingsWarehouseWarehouseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesSettingsWarehouseSettingsWarehouseWarehouse instance)