WebApiModulesWarehouseShippingCaseShippingCase class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesWarehouseShippingCaseShippingCase({int? shippingCaseId, String? orderId, String? orderNumber, String? orderDescription, String? orderType, String? itemId, String? inventoryId, String? iCode, String? itemDescription, String? barCode, String? description, String? shippingCaseNumber, double? itemCount, String? shippingCaseTitle, String? warehouseId, String? warehouse, String? auditNote, String? recordTitle, dynamic urlIdentifier, List<
Object> ? custom, List<Object> ? defaultFieldAttributes, dynamic original, List<Object> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) -
const
-
WebApiModulesWarehouseShippingCaseShippingCase.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auditNote → String?
-
final
- barCode → String?
-
final
- createdByUserId → String?
-
final
- createdByUserName → String?
-
final
- createdDateTime → String?
-
final
-
custom
→ List<
Object> ? -
final
-
defaultFieldAttributes
→ List<
Object> ? -
final
- description → String?
-
final
- hasDocuments → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasImport → bool?
-
final
- iCode → String?
-
final
- inventoryId → String?
-
final
- itemCount → double?
-
final
- itemDescription → String?
-
final
- itemId → String?
-
final
- modifiedByUserId → String?
-
final
- modifiedByUserName → String?
-
final
- modifiedDateTime → String?
-
final
- orderDescription → String?
-
final
- orderId → String?
-
final
- orderNumber → String?
-
final
- orderType → String?
-
final
- original → dynamic
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingCaseId → int?
-
final
- shippingCaseNumber → String?
-
final
- shippingCaseTitle → String?
-
final
-
translation
→ List<
Object> ? -
final
- urlIdentifier → dynamic
-
final
- warehouse → String?
-
final
- warehouseId → String?
-
final
Methods
-
copyWith(
{int? shippingCaseId, String? orderId, String? orderNumber, String? orderDescription, String? orderType, String? itemId, String? inventoryId, String? iCode, String? itemDescription, String? barCode, String? description, String? shippingCaseNumber, double? itemCount, String? shippingCaseTitle, String? warehouseId, String? warehouse, String? auditNote, String? recordTitle, dynamic urlIdentifier, List< Object> ? custom, List<Object> ? defaultFieldAttributes, dynamic original, List<Object> ? translation, bool? hasImport, bool? hasDocuments, String? createdByUserId, String? createdByUserName, String? createdDateTime, String? modifiedByUserId, String? modifiedByUserName, String? modifiedDateTime}) → WebApiModulesWarehouseShippingCaseShippingCase -
Available on WebApiModulesWarehouseShippingCaseShippingCase, provided by the $WebApiModulesWarehouseShippingCaseShippingCaseExtension extension
-
copyWithWrapped(
{Wrapped< int?> ? shippingCaseId, Wrapped<String?> ? orderId, Wrapped<String?> ? orderNumber, Wrapped<String?> ? orderDescription, Wrapped<String?> ? orderType, Wrapped<String?> ? itemId, Wrapped<String?> ? inventoryId, Wrapped<String?> ? iCode, Wrapped<String?> ? itemDescription, Wrapped<String?> ? barCode, Wrapped<String?> ? description, Wrapped<String?> ? shippingCaseNumber, Wrapped<double?> ? itemCount, Wrapped<String?> ? shippingCaseTitle, Wrapped<String?> ? warehouseId, Wrapped<String?> ? warehouse, Wrapped<String?> ? auditNote, Wrapped<String?> ? recordTitle, Wrapped? urlIdentifier, Wrapped<List< ? custom, Wrapped<Object> ?>List< ? defaultFieldAttributes, Wrapped? original, Wrapped<Object> ?>List< ? translation, Wrapped<Object> ?>bool?> ? hasImport, Wrapped<bool?> ? hasDocuments, Wrapped<String?> ? createdByUserId, Wrapped<String?> ? createdByUserName, Wrapped<String?> ? createdDateTime, Wrapped<String?> ? modifiedByUserId, Wrapped<String?> ? modifiedByUserName, Wrapped<String?> ? modifiedDateTime}) → WebApiModulesWarehouseShippingCaseShippingCase -
Available on WebApiModulesWarehouseShippingCaseShippingCase, provided by the $WebApiModulesWarehouseShippingCaseShippingCaseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesWarehouseShippingCaseShippingCase Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesWarehouseShippingCaseShippingCase instance)