WebApiModulesBillingInvoiceInvoiceProcessBatchRequest class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- WebApiModulesBillingInvoiceInvoiceProcessBatchRequest({String? locationId, String? singleInvoiceId, DateTime? asOfDate})
-
const
-
WebApiModulesBillingInvoiceInvoiceProcessBatchRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- asOfDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- locationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleInvoiceId → String?
-
final
Methods
-
copyWith(
{String? locationId, String? singleInvoiceId, DateTime? asOfDate}) → WebApiModulesBillingInvoiceInvoiceProcessBatchRequest -
Available on WebApiModulesBillingInvoiceInvoiceProcessBatchRequest, provided by the $WebApiModulesBillingInvoiceInvoiceProcessBatchRequestExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? locationId, Wrapped<String?> ? singleInvoiceId, Wrapped<DateTime?> ? asOfDate}) → WebApiModulesBillingInvoiceInvoiceProcessBatchRequest -
Available on WebApiModulesBillingInvoiceInvoiceProcessBatchRequest, provided by the $WebApiModulesBillingInvoiceInvoiceProcessBatchRequestExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesBillingInvoiceInvoiceProcessBatchRequest Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesBillingInvoiceInvoiceProcessBatchRequest instance)