WebApiModulesInventoryInventoryUnretireInventoryRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesInventoryInventoryUnretireInventoryRequest({String? retiredId, String? itemId, String? unretiredReasonId, String? notes, double? quantity})
WebApiModulesInventoryInventoryUnretireInventoryRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
itemId String?
final
notes String?
final
quantity double?
final
retiredId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unretiredReasonId String?
final

Methods

copyWith({String? retiredId, String? itemId, String? unretiredReasonId, String? notes, double? quantity}) WebApiModulesInventoryInventoryUnretireInventoryRequest

Available on WebApiModulesInventoryInventoryUnretireInventoryRequest, provided by the $WebApiModulesInventoryInventoryUnretireInventoryRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override