WebApiModulesUtilitiesControlsQuikActivitySettingsQuikActivitySettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

auditNote String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
description String?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings String?
final
webUsersId String?
final

Methods

copyWith({int? id, String? webUsersId, String? description, String? settings, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesUtilitiesControlsQuikActivitySettingsQuikActivitySettings

Available on WebApiModulesUtilitiesControlsQuikActivitySettingsQuikActivitySettings, provided by the $WebApiModulesUtilitiesControlsQuikActivitySettingsQuikActivitySettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override