WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatch class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatch({int? rateUpdateBatchId, String? rateUpdateBatch, String? usersId, String? userName, DateTime? applied, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatch.fromJson(Map<
String, dynamic> json) -
factory
Properties
- applied → DateTime?
-
final
- auditNote → String?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- rateUpdateBatch → String?
-
final
- rateUpdateBatchId → int?
-
final
- recordTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userName → String?
-
final
- usersId → String?
-
final
Methods
-
copyWith(
{int? rateUpdateBatchId, String? rateUpdateBatch, String? usersId, String? userName, DateTime? applied, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatch -
Available on WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatch, provided by the $WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatchExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatch Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesUtilitiesRateUpdateBatchRateUpdateBatch instance)