WebApiModulesUtilitiesReceiptProcessBatchReceiptProcessBatch class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WebApiModulesUtilitiesReceiptProcessBatchReceiptProcessBatch({String? batchId, String? locationId, String? batchType, String? divisionCode, String? batchNumber, String? batchDate, String? batchTime, String? batchDateTime, String? exportDate, bool? exported, int? recordCount, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes})
WebApiModulesUtilitiesReceiptProcessBatchReceiptProcessBatch.fromJson(Map<String, dynamic> json)
factory

Properties

auditNote String?
final
batchDate String?
final
batchDateTime String?
final
batchId String?
final
batchNumber String?
final
batchTime String?
final
batchType String?
final
custom List<FwStandardDataFwCustomValue>?
final
dateStamp String?
final
defaultFieldAttributes List<FwStandardDataFwDefaultAttribute>?
final
divisionCode String?
final
exportDate String?
final
exported bool?
final
fields List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>?
final
hashCode int
The hash code for this object.
no setteroverride
locationId String?
final
recordCount int?
final
recordTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? batchId, String? locationId, String? batchType, String? divisionCode, String? batchNumber, String? batchDate, String? batchTime, String? batchDateTime, String? exportDate, bool? exported, int? recordCount, String? dateStamp, String? auditNote, String? recordTitle, List<FwStandardBusinessLogicFwBusinessLogicFieldDefinition>? fields, List<FwStandardDataFwCustomValue>? custom, List<FwStandardDataFwDefaultAttribute>? defaultFieldAttributes}) WebApiModulesUtilitiesReceiptProcessBatchReceiptProcessBatch

Available on WebApiModulesUtilitiesReceiptProcessBatchReceiptProcessBatch, provided by the $WebApiModulesUtilitiesReceiptProcessBatchReceiptProcessBatchExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override