WebApiModulesUtilitiesUserProfileUserProfile class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
WebApiModulesUtilitiesUserProfileUserProfile({String? webUserId, String? userName, String? userId, String? loginName, int? browseDefaultRows, String? applicationTheme, String? homeMenuGuid, String? homeMenuPath, String? successSoundId, String? successSound, String? successBase64Sound, String? errorSoundId, String? errorSound, String? errorBase64Sound, String? notificationSoundId, String? notificationSound, String? notificationBase64Sound, String? favoritesJson, int? firstDayOfWeek, bool? mainMenuPinned, bool? webAdministrator, String? quikActivitySetting, String? emailSignature, String? newPassword, String? oldPassword, String? locale, String? availabilityPreference, bool? availabilityAllWarehouses, String? dateStamp, String? auditNote, String? recordTitle, List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) -
WebApiModulesUtilitiesUserProfileUserProfile.fromJson(Map<
String, dynamic> json) -
factory
Properties
- applicationTheme → String?
-
final
- auditNote → String?
-
final
- availabilityAllWarehouses → bool?
-
final
- availabilityPreference → String?
-
final
- browseDefaultRows → int?
-
final
-
custom
→ List<
FwStandardDataFwCustomValue> ? -
final
- dateStamp → String?
-
final
-
defaultFieldAttributes
→ List<
FwStandardDataFwDefaultAttribute> ? -
final
- emailSignature → String?
-
final
- errorBase64Sound → String?
-
final
- errorSound → String?
-
final
- errorSoundId → String?
-
final
- favoritesJson → String?
-
final
-
fields
→ List<
FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? -
final
- firstDayOfWeek → int?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- homeMenuGuid → String?
-
final
- homeMenuPath → String?
-
final
- locale → String?
-
final
- loginName → String?
-
final
- mainMenuPinned → bool?
-
final
- newPassword → String?
-
final
- notificationBase64Sound → String?
-
final
- notificationSound → String?
-
final
- notificationSoundId → String?
-
final
- oldPassword → String?
-
final
- quikActivitySetting → String?
-
final
- recordTitle → String?
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- successBase64Sound → String?
-
final
- successSound → String?
-
final
- successSoundId → String?
-
final
- userId → String?
-
final
- userName → String?
-
final
- webAdministrator → bool?
-
final
- webUserId → String?
-
final
Methods
-
copyWith(
{String? webUserId, String? userName, String? userId, String? loginName, int? browseDefaultRows, String? applicationTheme, String? homeMenuGuid, String? homeMenuPath, String? successSoundId, String? successSound, String? successBase64Sound, String? errorSoundId, String? errorSound, String? errorBase64Sound, String? notificationSoundId, String? notificationSound, String? notificationBase64Sound, String? favoritesJson, int? firstDayOfWeek, bool? mainMenuPinned, bool? webAdministrator, String? quikActivitySetting, String? emailSignature, String? newPassword, String? oldPassword, String? locale, String? availabilityPreference, bool? availabilityAllWarehouses, String? dateStamp, String? auditNote, String? recordTitle, List< FwStandardBusinessLogicFwBusinessLogicFieldDefinition> ? fields, List<FwStandardDataFwCustomValue> ? custom, List<FwStandardDataFwDefaultAttribute> ? defaultFieldAttributes}) → WebApiModulesUtilitiesUserProfileUserProfile -
Available on WebApiModulesUtilitiesUserProfileUserProfile, provided by the $WebApiModulesUtilitiesUserProfileUserProfileExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const WebApiModulesUtilitiesUserProfileUserProfile Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(WebApiModulesUtilitiesUserProfileUserProfile instance)